(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    497591,      25795]*)
(*NotebookOutlinePosition[    498534,      25826]*)
(*  CellTagsIndexPosition[    498490,      25822]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Pressure Sensitive Lens", "Chapter"],

Cell[TextData[{
  "This notebook demonstrates the flexibility of ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  ". A lens made of a polymer membrane is modeled. The membrane seals a \
chamber with a pressure higher than the environment and is therefore \
deformed.\nA ray traversing the flexible lens passes a window, the pressure \
fluid and the membrane.\nThe theory applied for calculation of the \
deformation is the plate theory that assumes a two dimensional stress. \
Normally, the limits of this theory are reached, if the membrane is no longer \
thin in thickness compared to its other dimensions. We use here the term \
plate rather than membrane.\nShort names for symbols are used to reduce the \
overall size of the formulas."
}], "Text"],

Cell["\<\
(*this avoids a lot of warning messages for similar names*)
Off[General::\"spell\"];\
\>", "Input",
  CellLabel->"In[2]:="],

Cell["\<\
(*these symbols are used only symbolically*)
Clear[x, y, F0];\
\>", "Input",
  CellLabel->"In[4]:="],

Cell[CellGroupData[{

Cell["Plate theory (shear elastic, cylinder symmetric)", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Plate values (all units SI)", "SubsubsectionIcon"],

Cell["\<\
The values are typical values also usable in experiments. Usually \
t0 is smaller in practice.\
\>", "Text"],

Cell["\<\
Clear[t0,EM,ny,K,R0];
R0 = 10*10^(-3); (*plate radius*)
t0 = 0.5*1.5 10^(-3); (*half plate thickness*)
EM = 5.1*10^9; (*Pa, Youngs modulus, measured value for PET*)
ny = 0.5; (*Poisson number, incompressible*)
K = EM*t0^3 / (12*(1-ny^2)); (*plate stiffness*)\
\>", "Input",
  CellLabel->"In[6]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Translation (plate center plane, 0 for r>=R0)", "SubsubsectionIcon"],

Cell["\<\
The plate is assumed to be fixed at its boundary, the translation \
and its first derivative is zero at the boundary. The force on the plate is \
the pressure in the chamber.\
\>", "Text"],

Cell["\<\
Clear[w];
w[F0_,r_] := 
If[r<R0,
\t1/64 * F0/(Pi*K) * R0^2 * 
\t\t( (1-(r/R0)^2)^2 + 16/5*1/(1-ny)*(t0/R0)^2*(1-(r/R0)^2)^2 )
,0];\
\>", "Input",
  CellLabel->"In[12]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["half thickness change (0 for r>=R0)", "SubsubsectionIcon"],

Cell["\<\
Deformation of the plate also causes a change in the plate \
thickness.\
\>", "Text"],

Cell["\<\
Clear[Deltat];
Deltat[F0_,r_] := 
If[r<R0,
\tt0/2 * t0^2/10/(1-ny) * F0/Pi/K * r/R0^2
,0];\
\>", "Input",
  CellLabel->"In[14]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Plate surfaces (translation of plate center plane included)", 
  "SubsubsectionIcon"],

Cell["\<\
These are the boundary surfaces forming the optical meniscus lens \
made of the polymer plate.\
\>", "Text"],

Cell["\<\
Clear[S1,S2];
S1[Deltax_,Deltay_,F0_,x_,y_] :=
\t{w[F0,Sqrt[(x-Deltax)^2+(y-Deltay)^2]] -
\tDeltat[F0,Sqrt[(x-Deltax)^2+(y-Deltay)^2]],x,y};
S2[Deltax_,Deltay_,F0_,x_,y_] := 
\t{w[F0,Sqrt[(x-Deltax)^2+(y-Deltay)^2]] +
\tDeltat[F0,Sqrt[(x-Deltax)^2+(y-Deltay)^2]]+t0,x,y};\
\>", "Input",
  CellLabel->"In[16]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Rayica",
    FontSlant->"Italic"],
  "l components definition"
}], "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Window", "SubsubsectionIcon"],

Cell["\<\
The Window forms the one side of the flexible plano convex lens. It \
is bigger than the plate to place the deformed plate off-axis.\
\>", "Text"],

Cell["\<\
Clear[LensWindow];
LensWindow = Window[R0 * 4, t0 * 10];\
\>", "Input",
  CellLabel->"In[19]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Plate material", "SubsubsectionIcon"],

Cell["\<\
For simplicity, constant refractive indices are assumed for the \
plate and the pressure fluid.\
\>", "Text"],

Cell["\<\
Clear[PlateMaterial,FluidMaterial];
Unprotect[ModelRefractiveIndex];
ModelRefractiveIndex[PlateMaterial] = IndexFunction[1.6^2, 0, 0, 0, 0, 0];
ModelRefractiveIndex[FluidMaterial] = IndexFunction[1.61^2, 0, 0, 0, 0, 0];
Protect[ModelRefractiveIndex];\
\>", "Input",
  CellLabel->"In[21]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Lens parameters", "SubsubsectionIcon"],

Cell["These translations place the plate in an off-axis position.", "Text"],

Cell["\<\
Clear[Deltax,Deltay];
Deltax = 0.5 * R0; (*m, Translation of plate center in x direction*)
Deltay = 1.0 * R0; (*m, Translation of plate center in y direction*)\
\>", 
  "Input",
  CellLabel->"In[26]:="],

Cell["\<\
The surfaces O1 and O2 are in the coordinate system that already \
include the translation.\
\>", "Text"],

Cell["\<\
Clear[O1,O2,PlateThickness];
O1 = Map[Function[{x,y},#]&,S1[Deltax,Deltay,F0,x,y]];
O2 = Map[Function[{x,y},#]&,S2[Deltax,Deltay,F0,x,y]];
PlateThickness = t0;\
\>", "Input",
  CellLabel->"In[29]:="],

Cell[TextData[{
  "Now, ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " is informed about the new shapes."
}], "Text"],

Cell["\<\
Clear[PlateFrontSurface,PlateBackSurface];
Unprotect[ModelSurfaceShape];
ModelSurfaceShape[PlateFrontSurface,{F0_}] = {SurfaceFunction->O1};
ModelSurfaceShape[PlateBackSurface,{F0_}] = {SurfaceFunction->O2};
Protect[ModelSurfaceShape];\
\>", "Input",
  CellLabel->"In[33]:="],

Cell["\<\
The force on the plate is the pressure times the area of the plate. \
It is perpendicular to the plate and measured in Newton. Its value is choosen \
to yield graphics that show clearly the function of the lens. The lens \
thickness is arbitrarily choosen to be 80% of the plate radius.\
\>", "Text"],

Cell["\<\
Clear[Force,LensThickness];
Force = -1200;
LensThickness = 0.8 * R0;\
\>", "Input",
  CellLabel->"In[38]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Lens surfaces", "SubsubsectionIcon"],

Cell[TextData[{
  "We now form the ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " objects representing the flexible lens in terms of surfaces. The whole \
lens is wrapped by Resonate to allow any path through the flexible lens."
}], "Text"],

Cell["\<\
Clear[
\tOuterPlateSurface, InnerPlateSurface,
\tInnerWindowSurface, OuterWindowSurface,
\tLensSurfaces];
OuterPlateSurface = CustomLensSurface[
\t{Force}, R0 4,
\tSurfaceLabel -> PlateFrontSurface,
\tComponentMedium -> PlateMaterial,
\tGraphicDesign -> Wire, CrossRendering -> Mesh,
\tSurfaceRayIntersections -> Numeric];
InnerPlateSurface = CustomLensSurface[
\t{Force}, R0 4,
\tSurfaceLabel -> PlateBackSurface,
\tComponentMedium -> {PlateMaterial, FluidMaterial},
\tGraphicDesign -> Wire, CrossRendering -> Mesh,
\tSurfaceRayIntersections -> Numeric];
InnerWindowSurface = LensSurface[
\tR0 4,
\tComponentMedium -> {FluidMaterial, BK7},
\tGraphicDesign -> Wire, CrossRendering -> Mesh];
OuterWindowSurface = LensSurface[
\tR0 4,
\tComponentMedium -> BK7,
\tGraphicDesign -> Wire, CrossRendering -> Mesh];
LensSurfaces = Resonate[{
\tOuterPlateSurface,
\tInnerPlateSurface,
\tMove[InnerWindowSurface, LensThickness],
\tMove[OuterWindowSurface, LensThickness+t0 10]
}];\
\>", "Input",
  CellLabel->"In[41]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Lenses", "SubsubsectionIcon"],

Cell[TextData[{
  "We now form the ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " objects representing the flexible lens in terms of bulk lenses to test an \
alternative way of definig the same object. The whole lens is wrapped by \
Resonate to allow any path through the flexible lens."
}], "Text"],

Cell["\<\
Clear[Plate];
Plate = CustomLens[{Force}, {Force}, R0 4, PlateThickness,
\tSurfaceLabel -> {PlateFrontSurface, PlateBackSurface},
\tComponentMedium -> PlateMaterial,
\tGraphicDesign -> Wire,
\tSurfaceRayIntersections -> Numeric];
Clear[Fluid];
Fluid=CustomLens[{Force}, {Force}, R0 4, LensThickness,
\tSurfaceLabel -> {PlateBackSurface, PlanarShape},
\tComponentMedium -> FluidMaterial,
\tGraphicDesign -> Wire,
\tCrossRendering -> Mesh,
\tSurfaceRayIntersections -> Numeric];
Clear[FlexibleLens];
FlexibleLens = Resonate[{
\tPlate,
\tMove[Fluid, t0],
\tMove[LensWindow, LensThickness+t0]
}];\
\>", "Input",
  CellLabel->"In[47]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphics of the flexible lens", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Plate", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell["ShowSystem[Plate, Axes->True, BoxRatios -> {1/4, 1, 1}];", "Input",
  CellLabel->"In[53]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.815 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.386592 1.87247 -1.92121e-16 1.87247 [
[.11001 .08829 -30.6531 -10.9375 ]
[.11001 .08829 2.78436 0 ]
[.17924 .05908 -30.2712 -10.9375 ]
[.17924 .05908 3.1663 0 ]
[.24948 .02945 -8.04496 -10.9375 ]
[.24948 .02945 .95504 0 ]
[.32074 -0.0006 -23.3852 -10.9375 ]
[.32074 -0.0006 3.11477 0 ]
[-0.00126 1.24293 -28.4375 -3.79291 ]
[-0.00126 1.24293 0 7.14459 ]
[.19654 1.40856 -28.4375 -3.92045 ]
[.19654 1.40856 0 7.01705 ]
[.37306 1.55637 -9 -4.02996 ]
[.37306 1.55637 0 6.90754 ]
[.53155 1.68907 -21.5 -4.125 ]
[.53155 1.68907 0 6.8125 ]
[.67464 1.80889 -21.5 -4.20826 ]
[.67464 1.80889 0 6.72924 ]
[.07283 .14905 -28.4375 -3.18123 ]
[.07283 .14905 0 7.75627 ]
[.05275 .37598 -28.4375 -3.30628 ]
[.05275 .37598 0 7.63122 ]
[.03084 .62365 -9 -3.44336 ]
[.03084 .62365 0 7.49414 ]
[.00683 .89504 -21.5 -3.5943 ]
[.00683 .89504 0 7.3432 ]
[-0.01958 1.19373 -21.5 -3.7613 ]
[-0.01958 1.19373 0 7.1762 ]
[ 0 0 0 0 ]
[ 1 1.815 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09632 .11832 m
.37773 0 L
s
.125 .10627 m
.13249 .11526 L
s
gsave
.11001 .08829 -91.6531 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.002) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.19398 .07726 m
.20135 .08635 L
s
gsave
.17924 .05908 -91.2712 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.26396 .04784 m
.2712 .05703 L
s
gsave
.24948 .02945 -69.045 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.33496 .01799 m
.34207 .02728 L
s
gsave
.32074 -0.0006 -84.3852 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.13872 .1005 m
.1432 .1059 L
s
.15247 .09471 m
.15694 .10013 L
s
.16627 .08891 m
.17072 .09434 L
s
.18011 .0831 m
.18454 .08854 L
s
.2079 .07141 m
.2123 .07688 L
s
.22185 .06554 m
.22624 .07102 L
s
.23585 .05966 m
.24022 .06515 L
s
.24988 .05376 m
.25424 .05926 L
s
.27808 .0419 m
.28241 .04743 L
s
.29223 .03595 m
.29655 .04149 L
s
.30643 .02998 m
.31073 .03553 L
s
.32067 .02399 m
.32496 .02956 L
s
.11132 .11202 m
.11583 .1174 L
s
.09768 .11775 m
.1022 .12312 L
s
.34928 .01196 m
.35353 .01755 L
s
.36364 .00592 m
.36788 .01153 L
s
.25 Mabswid
0 1.21835 m
.711 1.815 L
s
.02112 1.23608 m
.03231 1.23265 L
s
gsave
-0.00126 1.24293 -89.4375 -7.79291 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.21907 1.40219 m
.23033 1.399 L
s
gsave
.19654 1.40856 -89.4375 -7.92045 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.3957 1.55041 m
.40701 1.54743 L
s
gsave
.37306 1.55637 -70 -8.02996 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.55428 1.68349 m
.56564 1.6807 L
s
gsave
.53155 1.68907 -82.5 -8.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69744 1.80363 m
.70885 1.801 L
s
gsave
.67464 1.80889 -82.5 -8.20826 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06259 1.27088 m
.06932 1.26886 L
s
.1031 1.30487 m
.10983 1.30287 L
s
.14265 1.33806 m
.14939 1.3361 L
s
.1813 1.3705 m
.18805 1.36856 L
s
.25598 1.43317 m
.26275 1.43128 L
s
.29208 1.46346 m
.29885 1.4616 L
s
.32738 1.49308 m
.33415 1.49125 L
s
.36191 1.52206 m
.36869 1.52025 L
s
.42876 1.57816 m
.43556 1.5764 L
s
.46114 1.60533 m
.46794 1.60359 L
s
.49283 1.63192 m
.49964 1.63021 L
s
.52387 1.65797 m
.53069 1.65628 L
s
.58407 1.70849 m
.59089 1.70684 L
s
.61326 1.73299 m
.62009 1.73135 L
s
.64188 1.757 m
.64871 1.75539 L
s
.66993 1.78055 m
.67677 1.77895 L
s
.25 Mabswid
.09632 .11832 m
0 1.21835 L
s
.09442 .14002 m
.10522 .1355 L
s
gsave
.07283 .14905 -89.4375 -7.18123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.07452 .36737 m
.0854 .36307 L
s
gsave
.05275 .37598 -89.4375 -7.30628 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.05279 .61552 m
.06376 .61145 L
s
gsave
.03084 .62365 -70 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02898 .88745 m
.04005 .88365 L
s
gsave
.00683 .89504 -82.5 -7.5943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.00277 1.18676 m
.01394 1.18327 L
s
gsave
-0.01958 1.19373 -82.5 -7.7613 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.09058 .18395 m
.09706 .18126 L
s
.08666 .22863 m
.09316 .22597 L
s
.08268 .27408 m
.08919 .27145 L
s
.07864 .32032 m
.08515 .31771 L
s
.07032 .41525 m
.07686 .41269 L
s
.06606 .46398 m
.07261 .46145 L
s
.06171 .51358 m
.06827 .51108 L
s
.05729 .56409 m
.06386 .56162 L
s
.0482 .6679 m
.0548 .66549 L
s
.04353 .72125 m
.05014 .71887 L
s
.03877 .77561 m
.04539 .77326 L
s
.03392 .831 m
.04055 .82869 L
s
.02394 .94499 m
.03059 .94275 L
s
.0188 1.00366 m
.02547 1.00146 L
s
.01356 1.06349 m
.02024 1.06132 L
s
.00822 1.12451 m
.01491 1.12238 L
s
0 0 m
1 0 L
1 1.815 L
0 1.815 L
closepath
clip
newpath
.5 Mabswid
.8023 .95359 m
.76046 .81657 L
s
.76046 .81657 m
.85799 .78485 L
s
.76046 .81657 m
.70737 .6855 L
s
.70479 .8504 m
.76046 .81657 L
s
.83097 1.09039 m
.8023 .95359 L
s
.8023 .95359 m
.90035 .92314 L
s
.73374 .94537 m
.8023 .95359 L
s
.70737 .6855 m
.80505 .65231 L
s
.70737 .6855 m
.64526 .56653 L
s
.66781 .75988 m
.70737 .6855 L
s
.85799 .78485 m
.90035 .92314 L
s
.80505 .65231 m
.85799 .78485 L
s
.8057 .81773 m
.85799 .78485 L
s
.83097 1.09039 m
.93019 1.06097 L
s
.75312 1.03986 m
.83097 1.09039 L
s
.90035 .92314 m
.93019 1.06097 L
s
.83502 .91362 m
.90035 .92314 L
s
.74375 .53171 m
.80505 .65231 L
s
.76882 .72616 m
.80505 .65231 L
s
.85523 1.00884 m
.93019 1.06097 L
s
.64526 .56653 m
.74375 .53171 L
s
.76172 1.12879 m .94577 1.19193 L .84476 1.22058 L .656 .751 .92 r
F
0 g
.84227 1.33737 m
.84476 1.22058 L
s
.83097 1.09039 m
.8378 1.15489 L
s
.72622 .64381 m
.74375 .53171 L
s
.76172 1.12879 m .86509 1.09831 L .94577 1.19193 L .656 .751 .92 r
F
0 g
.94563 1.30922 m
.94577 1.19193 L
s
.93019 1.06097 m
.94577 1.19193 L
s
.84476 1.22058 m
.94577 1.19193 L
s
.73374 .94537 m
.70479 .8504 L
s
.64451 .88703 m
.70479 .8504 L
s
.70479 .8504 m
.66781 .75988 L
s
.75312 1.03986 m
.73374 .94537 L
s
.65956 .93648 m
.73374 .94537 L
s
.57676 .46596 m .68006 .57543 L .57747 .61149 L .544 .324 .532 r
F
0 g
.62464 .67867 m
.64111 .58912 L
s
.57676 .46596 m .67668 .42939 L .68006 .57543 L .544 .324 .532 r
F
0 g
.67668 .42939 m
.74375 .53171 L
s
.57676 .46596 m
.67668 .42939 L
s
.50503 .39022 m
.57676 .46596 L
s
.66781 .75988 m
.62464 .67867 L
s
.83502 .91362 m
.8057 .81773 L
s
.8057 .81773 m
.76882 .72616 L
s
.74902 .85337 m
.8057 .81773 L
s
.82247 1.43355 m
.84227 1.33737 L
s
.84227 1.33737 m
.94563 1.30922 L
s
.7587 1.20705 m
.84227 1.33737 L
s
.85523 1.00884 m
.83502 .91362 L
s
.76427 .90332 m
.83502 .91362 L
s
.60698 .35188 m
.67668 .42939 L
s
.76882 .72616 m
.72622 .64381 L
s
.72972 .80586 m
.76882 .72616 L
s
.67332 1.03107 m .86509 1.09831 L .76172 1.12879 L .656 .751 .92 r
F
0 g
.7587 1.20705 m
.76172 1.12879 L
s
.75312 1.03986 m
.75504 1.05973 L
s
.76172 1.12879 m
.84476 1.22058 L
s
.94563 1.30922 m
.92864 1.40557 L
s
.86369 1.17689 m
.94563 1.30922 L
s
.70748 .76367 m
.72622 .64381 L
s
.67332 1.03107 m .77914 .99859 L .86509 1.09831 L .656 .751 .92 r
F
0 g
.86369 1.17689 m
.86509 1.09831 L
s
.86509 1.09831 m
.94577 1.19193 L
s
.66937 .98549 m
.71831 1.01726 L
s
.85523 1.00884 m
.86509 1.09831 L
s
.57747 .61149 m .68363 .72945 L .57822 .76489 L .544 .324 .532 r
F
0 g
.60261 .7985 m
.61081 .75394 L
s
.62515 .84008 m
.66781 .75988 L
s
.57747 .61149 m .68006 .57543 L .68363 .72945 L .544 .324 .532 r
F
0 g
.57676 .46596 m
.57747 .61149 L
s
.68006 .57543 m
.72622 .64381 L
s
.67668 .42939 m
.68006 .57543 L
s
.52883 .5628 m
.57747 .61149 L
s
.50503 .39022 m
.60698 .35188 L
s
.50503 .39022 m
.43394 .34573 L
s
.52883 .5628 m
.50503 .39022 L
s
.70553 1.2803 m
.7587 1.20705 L
s
.65568 1.07502 m
.7587 1.20705 L
s
.78504 1.50162 m
.82247 1.43355 L
s
.82247 1.43355 m
.92864 1.40557 L
s
.70553 1.2803 m
.82247 1.43355 L
s
.63283 .52556 m
.68006 .57543 L
s
.53841 .30568 m
.60698 .35188 L
s
.63283 .52556 m
.60698 .35188 L
s
.65956 .93648 m
.64451 .88703 L
s
.64451 .88703 m
.62515 .84008 L
s
.66937 .98549 m
.65956 .93648 L
s
.62515 .84008 m
.60261 .7985 L
s
.81093 1.25063 m
.86369 1.17689 L
s
.76121 1.04303 m
.86369 1.17689 L
s
.52883 .5628 m
.48159 .5366 L
s
.55347 .74156 m
.52883 .5628 L
s
.92864 1.40557 m
.89433 1.47344 L
s
.81093 1.25063 m
.92864 1.40557 L
s
.59929 1.34424 m
.70553 1.2803 L
s
.60771 1.1172 m
.70553 1.2803 L
s
.57902 .92683 m .77914 .99859 L .67332 1.03107 L .656 .751 .92 r
F
0 g
.65568 1.07502 m
.67332 1.03107 L
s
.77453 .95272 m
.85523 1.00884 L
s
.67332 1.03107 m
.76172 1.12879 L
s
.76427 .90332 m
.74902 .85337 L
s
.74902 .85337 m
.72972 .80586 L
s
.76427 .90332 m
.77453 .95272 L
s
.72972 .80586 m
.70748 .76367 L
s
.57822 .76489 m .68739 .89213 L .57902 .92683 L .544 .324 .532 r
F
.57822 .76489 m .68363 .72945 L .68739 .89213 L F
0 g
.57747 .61149 m
.57822 .76489 L
s
.68006 .57543 m
.68363 .72945 L
s
.55347 .74156 m
.57822 .76489 L
s
.60771 1.1172 m
.65568 1.07502 L
s
.63283 .52556 m
.58734 .49829 L
s
.63283 .52556 m
.65962 .70553 L
s
.68363 .72945 m
.70748 .76367 L
s
.70534 1.31473 m
.81093 1.25063 L
s
.71354 1.08541 m
.81093 1.25063 L
s
.57902 .92683 m .68739 .89213 L .77914 .99859 L .656 .751 .92 r
F
0 g
.76121 1.04303 m
.77914 .99859 L
s
.77453 .95272 m
.77914 .99859 L
s
.77914 .99859 m
.86509 1.09831 L
s
.43394 .34573 m
.53841 .30568 L
s
.43394 .34573 m
.36807 .33831 L
s
.48159 .5366 m
.43394 .34573 L
s
.55332 1.1483 m
.60771 1.1172 L
s
.51185 1.37526 m
.59929 1.34424 L
s
.59929 1.34424 m
.78504 1.50162 L
s
.55332 1.1483 m
.59929 1.34424 L
s
.55347 .74156 m
.52995 .73028 L
s
.65962 .70553 m
.68363 .72945 L
s
.71354 1.08541 m
.76121 1.04303 L
s
.48159 .5366 m
.43895 .53604 L
s
.52995 .73028 m
.48159 .5366 L
s
.51251 1.16107 m
.55332 1.1483 L
s
.72233 1.53644 m
.78504 1.50162 L
s
.78504 1.50162 m
.89433 1.47344 L
s
.47546 .29679 m
.53841 .30568 L
s
.58734 .49829 m
.53841 .30568 L
s
.65946 1.11657 m
.71354 1.08541 L
s
.6191 1.3455 m
.70534 1.31473 L
s
.70534 1.31473 m
.89433 1.47344 L
s
.65946 1.11657 m
.70534 1.31473 L
s
.65962 .70553 m
.637 .69375 L
s
.52995 .73028 m
.50926 .73221 L
s
.58734 .49829 m
.54667 .49683 L
s
.637 .69375 m
.58734 .49829 L
s
.49616 1.15182 m
.51251 1.16107 L
s
.51251 1.16107 m
.51185 1.37526 L
s
.61928 1.12915 m
.65946 1.11657 L
s
.4816 1.36076 m
.51185 1.37526 L
s
.51185 1.37526 m
.72233 1.53644 L
s
.89433 1.47344 m
.83377 1.50791 L
s
.57902 .92683 m .61233 1.08818 L .50311 1.12129 L .544 .324 .532 r
F
0 g
.49616 1.15182 m
.50794 1.11983 L
s
.51251 1.16107 m
.52575 1.11443 L
s
.55332 1.1483 m
.5584 1.10453 L
s
.60373 1.09079 m
.60771 1.1172 L
s
.57902 .92683 m .68739 .89213 L .61233 1.08818 L .544 .324 .532 r
F
0 g
.63366 1.03247 m
.65568 1.07502 L
s
.64583 1.00068 m
.67332 1.03107 L
s
.4782 .81539 m .68739 .89213 L .57902 .92683 L .656 .751 .92 r
F
0 g
.5203 1.07486 m
.57902 .92683 L
s
.52634 1.02176 m
.57902 .92683 L
s
.5076 .97023 m
.57902 .92683 L
s
.49128 .91631 m
.57902 .92683 L
s
.50926 .73221 m
.54829 .8411 L
s
.57902 .92683 m
.57902 .92683 L
s
.52995 .73028 m
.55856 .84487 L
s
.55347 .74156 m
.5682 .84841 L
s
.57822 .76489 m
.57865 .85224 L
s
.637 .69375 m
.61731 .69527 L
s
.50926 .73221 m
.49292 .74764 L
s
.43895 .53604 m
.50926 .73221 L
s
.60399 1.11943 m
.61928 1.12915 L
s
.61928 1.12915 m
.6191 1.3455 L
s
.49616 1.15182 m
.4816 1.36076 L
s
.43895 .53604 m
.40417 .5629 L
s
.36807 .33831 m
.43895 .53604 L
s
.59102 1.33014 m
.6191 1.3455 L
s
.6191 1.3455 m
.83377 1.50791 L
s
.4782 .81539 m .58924 .77824 L .68739 .89213 L .656 .751 .92 r
F
0 g
.60399 1.11943 m
.68739 .89213 L
s
.63091 1.04088 m
.68739 .89213 L
s
.6378 .98695 m
.68739 .89213 L
s
.62013 .93443 m
.68739 .89213 L
s
.60357 .87993 m
.68739 .89213 L
s
.59302 .82651 m
.68739 .89213 L
s
.59238 .73866 m
.68739 .89213 L
s
.60203 .71045 m
.68739 .89213 L
s
.61731 .69527 m
.68739 .89213 L
s
.68739 .89213 m
.68739 .89213 L
s
.61928 1.12915 m
.68739 .89213 L
s
.637 .69375 m
.68739 .89213 L
s
.49292 .74764 m
.51893 .80177 L
s
.48225 .77593 m
.50238 .80731 L
s
.48125 .86336 m
.57902 .92683 L
s
.65946 1.11657 m
.68739 .89213 L
s
.65962 .70553 m
.68739 .89213 L
s
.68739 .89213 m
.71354 1.08541 L
s
.68739 .89213 m
.76121 1.04303 L
s
.68363 .72945 m
.68739 .89213 L
s
.68739 .89213 m
.74902 .85337 L
s
.68739 .89213 m
.76427 .90332 L
s
.68739 .89213 m
.72972 .80586 L
s
.68739 .89213 m
.77453 .95272 L
s
.68739 .89213 m
.70748 .76367 L
s
.68739 .89213 m
.77914 .99859 L
s
.36807 .33831 m
.31263 .37237 L
s
.47546 .29679 m
.36807 .33831 L
s
.61731 .69527 m
.60203 .71045 L
s
.54667 .49683 m
.61731 .69527 L
s
.49292 .74764 m
.40417 .5629 L
s
.49292 .74764 m
.48225 .77593 L
s
.54667 .49683 m
.514 .52309 L
s
.47546 .29679 m
.54667 .49683 L
s
.50311 1.12129 m .61418 1.26977 L .50175 1.30183 L .544 .324 .532 r
F
0 g
.59102 1.33014 m
.59439 1.27542 L
s
.50311 1.12129 m .61233 1.08818 L .61418 1.26977 L .544 .324 .532 r
F
0 g
.50311 1.12129 m
.57902 .92683 L
s
.49616 1.15182 m
.50311 1.12129 L
s
.61233 1.08818 m
.68739 .89213 L
s
.50311 1.12129 m
.5203 1.07486 L
s
.65864 1.52625 m
.72233 1.53644 L
s
.72233 1.53644 m
.83377 1.50791 L
s
.42317 .32978 m
.47546 .29679 L
s
.60203 .71045 m
.59238 .73866 L
s
.40417 .5629 m
.31263 .37237 L
s
.40417 .5629 m
.38039 .61707 L
s
.61233 1.08818 m
.63091 1.04088 L
s
.83377 1.50791 m
.77325 1.49661 L
s
.52634 1.02176 m
.5203 1.07486 L
s
.51873 1.21517 m
.5203 1.07486 L
s
.37018 .69599 m .58924 .77824 L .4782 .81539 L .656 .751 .92 r
F
0 g
.4782 .81539 m
.48125 .86336 L
s
.514 .52309 m
.60203 .71045 L
s
.4782 .81539 m
.57902 .92683 L
s
.3751 .79445 m
.48125 .86336 L
s
.48125 .86336 m
.49128 .91631 L
s
.5076 .97023 m
.52634 1.02176 L
s
.47446 1.12342 m
.52634 1.02176 L
s
.514 .52309 m
.42317 .32978 L
s
.514 .52309 m
.4923 .57702 L
s
.49128 .91631 m
.39532 .90481 L
s
.49128 .91631 m
.5076 .97023 L
s
.6378 .98695 m
.63091 1.04088 L
s
.63091 1.04088 m
.63376 1.18143 L
s
.5076 .97023 m
.42942 1.01774 L
s
.37018 .69599 m .48399 .65612 L .58924 .77824 L .656 .751 .92 r
F
0 g
.58924 .77824 m
.59302 .82651 L
s
.4923 .57702 m
.59238 .73866 L
s
.58924 .77824 m
.59238 .73866 L
s
.58924 .77824 m
.68739 .89213 L
s
.38039 .61707 m
.41984 .67859 L
s
.31263 .37237 m
.42317 .32978 L
s
.31263 .37237 m
.27302 .44961 L
s
.50175 1.30183 m .70008 1.44009 L .58169 1.47159 L .544 .324 .532 r
F
0 g
.4816 1.36076 m
.56717 1.44075 L
s
.59607 1.46776 m
.65864 1.52625 L
s
.50175 1.30183 m .61418 1.26977 L .70008 1.44009 L .544 .324 .532 r
F
0 g
.50175 1.30183 m
.50311 1.12129 L
s
.4816 1.36076 m
.50175 1.30183 L
s
.69042 1.42095 m
.77325 1.49661 L
s
.50175 1.30183 m
.58169 1.47159 L
s
.50175 1.30183 m
.51873 1.21517 L
s
.61233 1.08818 m
.61418 1.26977 L
s
.49048 .7552 m
.59302 .82651 L
s
.59302 .82651 m
.60357 .87993 L
s
.62013 .93443 m
.6378 .98695 L
s
.6378 .98695 m
.59134 1.08791 L
s
.60357 .87993 m
.62013 .93443 L
s
.5118 .86657 m
.60357 .87993 L
s
.62013 .93443 m
.54641 .98079 L
s
.58169 1.47159 m
.65864 1.52625 L
s
.65864 1.52625 m
.77325 1.49661 L
s
.38673 .40652 m
.42317 .32978 L
s
.61418 1.26977 m
.70008 1.44009 L
s
.61418 1.26977 m
.63376 1.18143 L
s
.70008 1.44009 m
.77325 1.49661 L
s
.25415 .56773 m .48399 .65612 L .37018 .69599 L .656 .751 .92 r
F
0 g
.37018 .69599 m
.3751 .79445 L
s
.27302 .44961 m
.37972 .61602 L
s
.37018 .69599 m
.4782 .81539 L
s
.47446 1.12342 m
.51873 1.21517 L
s
.49698 1.373 m
.51873 1.21517 L
s
.38673 .40652 m
.27302 .44961 L
s
.25415 .56773 m .37084 .52483 L .48399 .65612 L .656 .751 .92 r
F
0 g
.48399 .65612 m
.49048 .7552 L
s
.37084 .52483 m
.48399 .65612 L
s
.25415 .56773 m
.27302 .44961 L
s
.48399 .65612 m
.58924 .77824 L
s
.48399 .65612 m
.4923 .57702 L
s
.38673 .40652 m
.4923 .57702 L
s
.25415 .56773 m
.37018 .69599 L
s
.3751 .79445 m
.25947 .71938 L
s
.3751 .79445 m
.39532 .90481 L
s
.59134 1.08791 m
.63376 1.18143 L
s
.61744 1.3395 m
.63376 1.18143 L
s
.42942 1.01774 m
.47446 1.12342 L
s
.47446 1.12342 m
.41489 1.23541 L
s
.58169 1.47159 m
.70008 1.44009 L
s
.49698 1.373 m
.58169 1.47159 L
s
.39532 .90481 m
.28994 .89218 L
s
.39532 .90481 m
.42942 1.01774 L
s
.37084 .52483 m
.38673 .40652 L
s
.42942 1.01774 m
.34346 1.06997 L
s
.37866 .67744 m
.49048 .7552 L
s
.49048 .7552 m
.5118 .86657 L
s
.54641 .98079 m
.59134 1.08791 L
s
.59134 1.08791 m
.53654 1.1996 L
s
.61744 1.3395 m
.70008 1.44009 L
s
.5118 .86657 m
.41091 .85188 L
s
.5118 .86657 m
.54641 .98079 L
s
.54641 .98079 m
.46528 1.0318 L
s
.25415 .56773 m
.37084 .52483 L
s
.25415 .56773 m
.25947 .71938 L
s
.41489 1.23541 m
.49698 1.373 L
s
.49698 1.373 m
.61744 1.3395 L
s
.37084 .52483 m
.37866 .67744 L
s
.61744 1.3395 m
.53654 1.1996 L
s
.25947 .71938 m
.37866 .67744 L
s
.25947 .71938 m
.28994 .89218 L
s
.34346 1.06997 m
.41489 1.23541 L
s
.41489 1.23541 m
.53654 1.1996 L
s
.28994 .89218 m
.34346 1.06997 L
s
.41091 .85188 m
.28994 .89218 L
s
.41091 .85188 m
.37866 .67744 L
s
.34346 1.06997 m
.46528 1.0318 L
s
.53654 1.1996 m
.46528 1.0318 L
s
.46528 1.0318 m
.41091 .85188 L
s
.25 Mabswid
.09632 .11832 m
.37773 0 L
s
.125 .10627 m
.13249 .11526 L
s
gsave
.11001 .08829 -91.6531 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.002) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.19398 .07726 m
.20135 .08635 L
s
gsave
.17924 .05908 -91.2712 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.26396 .04784 m
.2712 .05703 L
s
gsave
.24948 .02945 -69.045 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.33496 .01799 m
.34207 .02728 L
s
gsave
.32074 -0.0006 -84.3852 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.13872 .1005 m
.1432 .1059 L
s
.15247 .09471 m
.15694 .10013 L
s
.16627 .08891 m
.17072 .09434 L
s
.18011 .0831 m
.18454 .08854 L
s
.2079 .07141 m
.2123 .07688 L
s
.22185 .06554 m
.22624 .07102 L
s
.23585 .05966 m
.24022 .06515 L
s
.24988 .05376 m
.25424 .05926 L
s
.27808 .0419 m
.28241 .04743 L
s
.29223 .03595 m
.29655 .04149 L
s
.30643 .02998 m
.31073 .03553 L
s
.32067 .02399 m
.32496 .02956 L
s
.11132 .11202 m
.11583 .1174 L
s
.09768 .11775 m
.1022 .12312 L
s
.34928 .01196 m
.35353 .01755 L
s
.36364 .00592 m
.36788 .01153 L
s
.25 Mabswid
0 1.21835 m
.711 1.815 L
s
.02112 1.23608 m
.03231 1.23265 L
s
gsave
-0.00126 1.24293 -89.4375 -7.79291 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.21907 1.40219 m
.23033 1.399 L
s
gsave
.19654 1.40856 -89.4375 -7.92045 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.3957 1.55041 m
.40701 1.54743 L
s
gsave
.37306 1.55637 -70 -8.02996 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.55428 1.68349 m
.56564 1.6807 L
s
gsave
.53155 1.68907 -82.5 -8.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69744 1.80363 m
.70885 1.801 L
s
gsave
.67464 1.80889 -82.5 -8.20826 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06259 1.27088 m
.06932 1.26886 L
s
.1031 1.30487 m
.10983 1.30287 L
s
.14265 1.33806 m
.14939 1.3361 L
s
.1813 1.3705 m
.18805 1.36856 L
s
.25598 1.43317 m
.26275 1.43128 L
s
.29208 1.46346 m
.29885 1.4616 L
s
.32738 1.49308 m
.33415 1.49125 L
s
.36191 1.52206 m
.36869 1.52025 L
s
.42876 1.57816 m
.43556 1.5764 L
s
.46114 1.60533 m
.46794 1.60359 L
s
.49283 1.63192 m
.49964 1.63021 L
s
.52387 1.65797 m
.53069 1.65628 L
s
.58407 1.70849 m
.59089 1.70684 L
s
.61326 1.73299 m
.62009 1.73135 L
s
.64188 1.757 m
.64871 1.75539 L
s
.66993 1.78055 m
.67677 1.77895 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[53]:=",
  ImageSize->{144.562, 262.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@00011PP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000091d002@M000T7@0091d002@M000T7@0091d
002@M000T7@0091d002@M000T7@0091d002@M000T7@0091d002@M000T7@0091d002@M000T7@0091d
002@M000;G@24@=d00<AM7@00Q43M08A0g@34Did000/M0044GAd4@Ad00HAM7@AM142M0054GAdM140
Cg@002ad00@AM7@A17@01Q5dM15d4@9d00DAM7Ad4@1?M000;7@0115dM144M0064GAd4G@A0W@01A5d
M7@A04md000/M0044GAd4@Ad0Q4017@AM142M0054GAdM140Cg@002ad00@AM7@A0g@24@05M14AM140
0W@00a5dM0024Dmd000]M08A17@0115d4A43M08A17@00a5dM004M08AAg@001ad0Q43M0034GAd008A
0g@24@=d0a42M0044GAd4@ed0a59M0006g@0115dM144M0064GAd4G@A0W@01A5dM7@A00=d00@AM7@A
37@34DYd000EM0@A0W@0115dM144M0064GAd4G@A0W@01A5dM7@A00=d00@AM7@A27@54Dad000DM08A
0g@00a5d4@034@9d0a400g@A4@024@9d00DAM7Ad4@04M08A27@34Dmd000CM0044GAd4@Ad00HAM7@A
M142M0064GAd4G@A0W@01A5dM7@A00Yd00<AM1400Q5AM0003G@44@9d00@AM7@A17@01Q5dM15d4@9d
00<AM7@00a42M0034GAd008A2G@34EAd000CM0044GAd4@Ad114017@AM7@34@03M15d008A17@00a5d
M004M0@A00=d4G@0Dg@001=d00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM009M0<AFG@001=d
00@AM7@A17@01Q5dM15d4@9d00<AM1400W@00a5dM007M0<AFg@001Ad0Q46M08A0g@24@=d0Q47M0<A
00=d4G@0Fg@002ed115OM000:W@44F9d000WM0034G@A008AI7@002Md0Q5WM0009g@00a5dM01VM000
9g@24FMd000WM0034GAd06Id000WM0034GAd06Id000BM08A0g@00a5dM0024@9d1145M0034GAd06Id
000AM0044GAd4@Ad00@AM7@A0W@00a5dM004M0034GAd06Md000;M0@A0W@0115dM144M0044GAd4@=d
00<AM7@00g@24FQd000AM0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd06Md000AM0044GAd4@Ad
00@AM7@A17@00a5dM002M0034GAd06Md000AM0044GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@0
Ig@0019d0Q46M08A0g@24@Ed00<AM7@0Ig@002Id0Q5XM0009W@00a5dM01WM0009W@00a5dM01WM000
9W@00a5dM01WM0009W@00a5dM01WM0009W@00a5dM01WM0009G@00a5dM01XM0009G@00a5dM01XM000
9G@00a5dM00ZM0DA>G@002Ed00<AM7@0:7@44@=d114eM0009G@24BId1143M0034GAd008A00Ad4A4A
<g@002Ed00<AM7@08W@34@03M14A00Ad0a44M0034G@A039d000UM0034GAd021d0Q42M08A17@34@Id
00<AM7@00Q4`M0009G@00a5dM00NM0HA00Ad4GAd0Q43M0034GAd00=d00<AM7@00W@24Bid000UM003
4GAd01ad3145M0034GAd00=d00<AM7@00g@24Bed000UM0034GAd01]d1A44M0034G@A008A17@00a5d
M004M0034GAd008A00=d4A40;7@002Ed0Q4JM0<A0g@01A5dM7@A009d0Q400g@AM003M0034GAd00=d
0a43M0034G@A02]d000TM0034GAd01Ud0Q46M0044GAd4@=d00<AM7@00Q42M0044GAdM0<A1G@0115d
M14ZM00097@00a5dM00HM08A1g@00a5d4@04M08A0g@34@03M14A009d00<AM7@017@0115dM14YM000
47@24@=d00<AM7@00Q43M0<A17@00a5dM00HM0034G@A00Id00<AM14017@24@Ed0Q45M0034GAd00=d
00@AM7@A:G@000md00@AM7@A17@0115dM143M0034GAd00=d00<AM7@05g@0115dM147M0034GAd00=d
00<AM14017@24@Ed00<AM7@00g@01A5dM7@A02Qd0009M0@A0W@0115dM144M0044GAd4@=d00<AM7@0
0g@24AQd00DAM7Ad4@05M08A1W@24@Ad00<AM14017@00a5dM003M0034GAd009d00<AM7@09G@000md
00@AM7@A17@0115dM143M0034GAd00=d00<AM7@05W@00a5dM002M0034GAd00<A00=d4A401G@00a5d
4@03M0044G@A4@Ad00<AM7@00W@00a5dM003M0034GAd02Ad000?M0044GAd4@Ad00@AM7@A0g@00a5d
M003M0034GAd01Id00<AM7@00W@34@Ad0Q45M0034G@A00Ad0Q400g@AM002M0034GAd009d00<AM7@0
0g@24BEd000?M0044GAd4@Ad00@AM7@A0W@24@Ed00<AM7@05G@0115dM7@24@03M15d00Ad0a44M003
4G@A00Ad00@AM14A0g@00a5dM002M0044GAdM08A00<n4A4097@0011d0Q46M08A17@00a5dM003M003
4GAd01Ed1144M0054GAdM1400W@24@=d00@AM7@A0g@01A5d4G@A009d00<AM7@00g@34@03?cho008A
97@002Ad00<AM7@057@24@Md00DAM7Ad4@02M08A17@00a5d4@03M0034G@A009d00@AM7@A0W@34@08
?ULnEchAM14SM00097@00a5dM00DM08A27@0115dM142M0034G@A00=d00@AM7@A0W@0115dM142M003
4G@A008A00Tn?a4o?Sln?a400W@00a5dM00PM00097@00a5dM00DM08A27@0115dM143M08A0g@0115d
M142M0044GAd4@=d0Q402eLnEchA?ULnEchA009d00<AM7@087@002=d00<AM7@05G@00a5d4@08M003
4G@A00=d00<AM1400W@01a5dM7@AM1400W@0115dM7@24@0;?Sln?a4o?Sln?a400g@00a5dM00OM000
8g@00a5dM00DM0054GAdM1401g@00a5d4@04M0034G@A009d00@AM7@A0W@0115dM142M00=4ChA?ULn
4CiG?ULn4@04M0034GAd01id000SM0034GAd01Ad00DAM7Ad4@08M0034GAd00=d00<AM1400W@01a5d
M7@AM1400W@64@0:?cho?Q4n?cho4@Ad00<AM7@07W@002=d00<AM7@057@00a5dM002M0034GAd00Ed
00<AM7@00g@01Q5dM15d4@=d00<AM1400a42M0034ChA008A00PnEa5G?ULn4@Ed00<AM7@07G@002=d
0Q4EM0034GAd00=d00<AM7@017@24@Ed00<AM7@00Q44M08A0g@01a5d4ClA?ch00a401Cho?SlA00Id
00<AM7@077@002=d00<AM7@057@00a5dM003M0034GAd00=d0a45M0064GAd4G@A0g@24@=d00lAM14n
Ea5G?ULAEciG?Q401W@00a5dM00LM0008g@00a5dM00DM0034GAd00Ad00<AM1400Q4014LA4A45M003
4GAd008A0g@24@=d00TAM14o?Q4n?ch00Q4013ln?a46M08A7G@002=d00<AM7@04g@00a5dM004M0<A
15`00a5L4@05M0DA0W@0115d4A43M08A00`nEa5G?ULAEa5G?Q43M0<A00=d4G@077@002=d00<AM7@0
4g@00a5dM002M08A00]7G4MLAea74DML4@02M0<A0g@44@03M14A00=d0Q402cln4Cho?Q4n4Cho00@A
17@24Aad000SM0034GAd01=d00<AM1400Q49G0064EaL4G@A0g@01Q5dM7@AM08A00=d4G@00W@24@0<
?ULn4CiG?Q4n4ChA1g@24Aad000SM0034GAd01=d0Q404Ea7G4MLAea7G4MLAa57G4LA00Ad00@AM7Ad
0Q42M08A17@02a4o?SlA?cho4Cln008A1W@0115dM14KM0008W@00a5dM00DM08A35`00a5LG002G005
4GAdM1400g@24@=d0Q43M00=4CiG?Q4nEchA?ULn4@06M0044GAd4A]d000RM0034GAd01Ad01DAM157
G4MLAea7G4MLAa57G4MLAa400g@00a5dM0034@9d0a42M00<4Cln?a4o?SlA?cho0Q45M0054GAdM140
6W@0029d00<AM7@057@0115dM14:G0034EaL00AL00@AM7@A0g@24@9d00DAM14AM0024@0:EchA?ULn
4CiG?P8A1G@01A5dM7@A01Yd000RM0034GAd01Ad01LAM7Ad4DMLAea7G4MLAa57G4MLAea74@02M006
4GAd4G@A0W@24@0AM14A4Cho?Q4n?a4o?SlAM14017@00a5dM002M0034GAd01Md000RM08A5G@00a5d
M002M0034EaL00ML00<AG5`01E`00a5d4@02M0034G@A009d014AM15d4ChA?ULAEchA?ULn4@02M005
4GAdM14017@00a5dM00GM0008W@00a5dM00DM0034GAd00=d018AAea7G4MLAe`AG4MLAea7G4L24@03
M14A009d01<AM15d4G@A?a4o?Q4n?chA?SlA00=d00<AM1401W@00a5dM00FM0008W@00a5dM00DM003
4GAd00Ad00<AG5`01E`00a5LG006G00J4G@A4G@AM15d4G@AM14n4CiG4ELnEa5G?Q43M0034G@A00Id
00<AM7@05W@001Yd0Q46M0034GAd01Ad00<AM7@017@04Q5LAea7G4ML4Ea7G4MLAea7G0<A00Ad4GAd
0Q42M08A00`o?Q4n4Cho?Q4n?a44M08A1g@00a5dM00EM0006G@0115dM145M0034GAd01Ad00<AM7@0
1G@00a5LG004G0034EaL00QL0Q400g@AM002M0034GAd008A00`nEa5G?Q4nEa5G?Q45M0034GAd00Ed
00<AM7@05G@001Ud00@AM7@A1G@00a5dM00EM0034GAd00Ed01<AG4MLAe`AG4MLAea7G4MLAe`A009d
00@AM7@A0g@0314o?Q4n?a4o?Q4n?`8A17@00a5dM005M08A5W@001Ud00@AM7@A1G@00a5dM00EM003
4GAd00Id00<AG5`00U`00a5LG009G08A00=d4G@00W@04A5dM14nEchA?Q4nEa5G?ULA00Ad0Q43M0DA
5W@001Ud00@AM7@A1G@00a5dM00EM0034GAd00Md018AG4ML4Ea7G4MLAea7G4ML4E`24@=d00<AM7@0
0Q402cho4ClA?chA?Sln008A0W@00a5d4@034@=d00<AM1405G@001Ud00@AM7@A17@00a5dM00FM003
4GAd00Qd00@AG14A2e`0115LG143M08A00id4A5G?Q4nEa5G?Q4nE`8A0W@44@Ad00@AM7@A5G@001Yd
0Q45M0034GAd01Id00<AM7@01g@34@0@G14AAea7G4MLAea7G15LA`8A0W@04Q5d4A4o4Cln4ChA?SlA
?chAM0<A0W@00a5dM002M0054GAdM14057@0025d00<AM7@05W@00a5dM004M0<A0g@24@03G14A00QL
00DAG5aL4@02M0044G@AM08A00<nEa400a402ChA?ULAM15d4@03M0044GAd4@Ad00<AM7@04W@0025d
00<AM7@05W@00a5dM002M08A1W@24@0CG4ML4Ea7G4MLAe`AG4MLAa5d4@02M08A00Ln4A4A?Q4n008A
00Do?Q4AM0024@=d00<AM1401G@00a5dM00BM0008G@00a5dM00FM0034G@A008A27@00a5d4@03G003
4EaL00AL00<AG5`00e`0115d4G@24@08Ea5G?Q4n4Ch24@05Ea4AM1401G@24@Id00<AM7@04G@0025d
0Q4GM08A2g@01a5d4A5LAe`00Q402dMLAe`AG4MLAea7008A0W@02a4n4Cho4ClA?a4o008A0W@24@Ad
00<AM7@01G@00a5dM00AM0008G@00a5dM00FM0<A2W@0115d4A45G0054EaLG1401e`00a5dM0024@0;
?Q4n4ChA?Q4nEa400W@24@Ad00<AM7@01W@00a5dM00@M0008G@00a5dM00FM0034GAd008A27@0615d
4G@AAea7G4LAAe`AG4MLAea7G4LAM08A00@o4Cln0Q401Cln4ChA009d00<AM1400W@00a5d4@07M003
4GAd011d000QM0034GAd01Id00<AM7@00W@00a5dM005M0034G@A009d00<AG5`00e`34@QL00<AM140
0Q402ELAEa5G4ELAE`034@9d00HAM7@AM147M0034GAd011d000QM0034GAd01Md00<AM7@00W@24@Ed
00<AM1400g@04A57G4MLAe`AG4MLAea7G4ML00@A00Tn4ChA?Q4n4Ch00a43M08A0g@00a5dM005M003
4GAd00md000QM0034GAd01Md00<AM7@017@00a5dM002M0034G@A00Ad00<AG5`00e`34@QL0Q401ChA
?Q4n008A00IG4ELAM143M08A0g@00a5dM005M0034GAd00md000PM08A6G@00a5dM005M08A0W@0115d
M144M00G4DMLAe`AG4LAAea7G4MLAe`A?a4o4Cl00Q401ChA?Q5d008A0g@00a5dM002M0034GAd00Ed
00<AM7@03W@0021d00<AM7@067@00a5dM007M0<A0W@00a5dM003M0034EaL009L00<AG5`00Q46G08A
00=G4EL00Q401ShA4ELAM08A0W@24@Ad00<AM7@017@24A1d000PM0034GAd01Qd00<AM7@02G@0115d
M145M00D4Ea7G4LAAea7G15LAea7G15L4Cl24@0>?Q4A4ChAM15d4G@AM144M0034GAd00DA47@0021d
00<AM7@067@00a5dM009M0@A1W@01A5LG5`A00EL0Q43G0064E`A?Q4n11400eLA4@02M08A0W@00a5d
M002M0<A00=d4G@00W@00a5dM00=M00087@00a5dM00HM0034GAd00Ud00@AM7@A1g@00a5LA`024@0>
G4MLAea74DML4Ea74Ch24@03?a4o00<A0g@01Q5dM7@AM0HA17@00a5dM00=M00087@00a5dM00IM003
4GAd00Ud00<AM1400Q46M0044EaL4@ML0a43G08A00=G4A401143M0044GAdM08A0g@00a5dM004M003
4GAd00ed000PM08A6W@00a5dM009M0064GAd4G@A1G@24@0@G15LAea7G4MLAe`AG4MLA`PA0W@00a5d
4@034@9d0a47M0034GAd00ad000PM0034GAd01Ud00<AM7@02G@0115dM142M08A0g@0115d4A49G0<A
0U`00a5G4@054@9d0a42M0<A0g@00a5dM004M0034GAd00ad000PM0034GAd01Ud00<AM7@02G@0115d
M144M0044GAd4@9d010AG4MLAea7G4ML4Ea74DML2Q42M0@A17@00a5dM004M0034GAd00ad000PM003
4GAd01Ud00<AM7@02W@54@=d0a43M0034EaL00=L00@AG5`A0e`00a5LG0084@=d00@AM7@A17@00a5d
M004M0034GAd00ad000PM0034GAd01Ud00<AM7@027@34@04M15dM0HA0g@24@0<G4MLAea7G4LAAea7
0Q400e`A4@044@9d0a42M0034GAd009d00<AM7@01G@00a5dM00;M0007g@00a5dM00KM0034GAd00Ad
0a42M0044GAd4@Id2A45G0034EaL00=L00<AG1400Q4017@A4A43M0034G@A00Ed00<AM7@017@00a5d
M00;M0007g@00a5dM00KM0034GAd009d0Q45M0044GAd4@Md00PAM14AM157G0PA00A7G4ML1A400g@A
M003M0044GAd4@Ad00<AM7@017@00a5dM00;M0007g@34A]d00<AM1400Q48M0034G@A00Md00<AM7@0
0Q400g@AG005G0034EaL00/A17@0115dM144M0034GAd00Ed00<AM7@02W@001md00<AM7@06g@74@Id
00@AM7@A1W@0115dM7@24@0?M157G4MLAe`AG4MLAea700LA17@00a5d4@04M0034GAd00Ed00<AM7@0
2W@000Yd0Q43M0034GAd008A0g@34@Ed00<AM7@06g@00a5dM004M0`A1G@01A5dM15d00<A1E`00a5L
G003G0HA00=d4A401a44M0034GAd00Ad00<AM7@02W@000Ud00@AM7@A17@0115dM143M0034GAd00Ad
00<AM7@077@00a5dM009M0044GAd4@9d214017@AM7@24@08Aea7G15LAcl24@03?SlA00DA17@00a5d
M0094@Ad00<AM7@02G@000Ud00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@077@00a5dM009M005
4GAdM1401W@00a5dM0084@9L00MG4A4AEciG00<A00=L4A400Q43M0044GAd4@Ad00@AM7Ad1A4;M000
2G@0115dM144M0044GAd4@=d00<AM7@017@00a5dM00LM0034GAd00Yd00@AM7@A1W@01A5dM7@A00=d
0a402Cho?Q4n?cho?P054@03Aa5d008A0W@00a5d4@04M0044GAdM0<A00=d4G@02W@000Ud00@AM7@A
17@0115dM143M0034GAd00Ad0Q4NM0034GAd00Ud00@AM7@A1W@01A5dM7@A00=d0a4025LA4A5G?ULn
0a401U`AG15L4@9d0a400g@AM004M0<A17@00a5dM009M0002G@0115dM144M0044GAd4@9d0Q46M003
4GAd01ed00<AM7@02G@01A5dM7@A00Id00@AM7Ad0a4037@A?a4o?SlA?chA?P8A00EL4E`AG0044@06
M15dM15d1147M0034GAd00Qd000:M08A1W@24@Ad00<AM7@017@00a5dM00MM0034GAd00Ud00DAM7Ad
4@06M0034GAd008A0W@34@07EciG?Q4nE`044@07G15LG15L4@02M0HA0g@00a5dM005M0034GAd00Qd
000OM0034GAd01id00<AM7@02G@0115dM146M0<A00Ad4GAd0Q402Cln?cho4ClA?`034@08G15LAa57
G142M0044G@A4@Ad00<AM7@01G@00a5dM008M0007W@00a5dM00OM0034GAd00Ud00DAM7Ad4@05M003
4GAd009d0a401eLnEciG?UL0114015`AG143G0064EaL4G@A0g@01A5dM7@A00Md00<AM7@027@001id
00<AM7@07g@00a5dM009M0054GAdM1400g@24@03M15d009d00`AM14n?cho?Sln4Ch24@0>G15L4Ea7
G15LAe`AM142M08A0W@00a5dM005M0034GAd00Qd000NM0034GAd021d00<AM7@027@01Q5dM7@AM08A
0g@00a5d4@034@0:?ULnEciG?ULAE`8A00AL4E`A15`0115LG5`24@9d00HAM14AM146M0034GAd00Qd
000NM08A8G@00a5dM009M0034GAd008A1W@0315d4G@A?cho?Sln?`@A00m7G15LAa57G4LAAea7G140
0W@0115dM7@24@Md00<AM7@01g@001id00<AM7@08G@00a5dM008M0<A00=d4G@00g@34@0;M14A4CiG
?ULnEch011400e`AG002G0034EaL009L00@AG5aL0Q42M0054GAdM1401g@00a5dM007M0007W@00a5d
M00QM0034GAd00Qd00DAM7Ad4@03M00@4GAdM15d4ChA?Sln?chA?PDA0157G4LAAea7G15LAa57G15d
4@03M0<A1G@00a5dM007M0007W@00a5dM00QM0034GAd00Id0a44M0<A17@34@09Ea5G?ULnEa5G00<A
00=d4E`00U`00a5LG003G0034E`A00=L0Q43M0044GAd4@Ad00<AM7@01g@001id00<AM7@08W@00a5d
M004M0054GAdM1400W@24@Ed0a4023ln4Cho?Sln1142M08A00QLAa57G4MLA`8A00ILAea7G144M003
4GAd008A0W@00a5dM007M0007W@00a5dM00RM0034GAd009d0Q43M0@A00=d4G@017@34@09?ULn4CiG
?Q4n00<A0W@01A5d4E`A00IL00<AG5`015`01A5dM7@A00Ad00@AM7@A27@001id00<AM7@08W@01A5d
M7@A009d0a42M0054GAdM1400g@34@0:?Sln?a4o?SlA?`<A0W@00a5dM0024@0>Aea7G4LAAa57G4ML
Aa43M0034GAd00=d0a48M0007W@00a5dM00SM0HA1G@01A5dM7@A00=d0a402ELnEciG4ELAE`044@03
M14A00=d0Q42G0<A00=L4E`01E`0115dM146M08A27@001ed00<AM7@097@24@Yd01<AM7Ad4G@AM14o
?Sln?chA?Q4n00<A00Ad4A4A17@04Q5L4Ea7G4ML4Ea7G4MLAa5d4@9d11400g@AM007M0007G@00a5d
M00TM0034GAd00Ud018AM7Ad4G@AM14nEciG?ULn4Ch44@03M14A00Ed0Q47G0034EaL00AL1145M003
4GAd00Id000MM0034GAd02Ed00<AM7@02G@01A5dM7@A009d00XA?cho?Sln?a4o1A400g@AM003M0<A
00m7G4MLAea7G15LAea7G4L00Q46M0034GAd00Id000MM0034GAd02Ed00<AM7@02G@01Q5dM7@AM08A
00TnEciG?ULn4Ch01142M08A00=d4A400W@24@ML00<AG5`01E`00a5dM005M0034GAd00Ed000MM003
4GAd02Id00<AM7@02G@01A5d4A5d008A00Po?Sln?chA?PDA0W@34@Ad014AM157G4MLAea74DMLAea7
G0024@Id00<AM7@01G@001ed00<AM7@09W@00a5dM009M00?4G@AM14n4CiG?ULnEa5G008A00Ad4A5d
0Q400g@AM004M0034G@A00ML00<AG5`00e`00a5L4@05M0034GAd00Ed000MM08A:7@00a5dM009M00?
4GAd4ClA?cho?SlA?cho008A00Ed4A5d4@02M0034GAd009d01<AM7@AAea7G4MLAa57G4ML4E`A00Ed
00<AM7@01G@001ed00<AM7@09g@00a5dM008M08A0W@34@09?ULnEchA?ULn00@A0W@01A5dM7@A00Ad
00@AM7@A1U`00a5LG002G0044EaL4@Ad00<AM7@01G@001ed00<AM7@09g@00a5dM008M0034G@A00@A
00To?Sln4Cho?Sl01143M0054GAdM1400g@00a5dM0024@0?Aea7G4ML4Ea74DMLAe`A00=d00<AM7@0
1G@001ed00<AM7@0:7@00a5dM006M0034GAd00DA00TnEciG4ELnEch01143M0054GAdM14017@01A5d
4G@A00IL00<AG1401E`0115dM147M0007G@00a5dM00XM0034GAd00Id00@AM7Ad0Q402clA?cho4Cln
?cho00@A0g@00a5dM002M0034GAd009d0Q42M0074DMLAe`AG0024@09Aea7G4ML4G@A00Md000MM003
4GAd02Ud00<AM7@017@00a5dM002M08A00/n4CiG?Q4nEciG?P044@=d00<AM7@00g@0115dM7@24@=d
00<AG5`00e`24@ML00<AM1401W@001ad00<AM7@0:W@00a5dM004M0034GAd009d0Q402clA4ChA?Sln
?cho008A00=d4A400g@00a5dM003M0034GAd008A0g@04Q5LAea7G4LAAea7G4MLAa5d4@Id000LM0<A
:W@00a5dM003M0034GAd00=d0Q404ChA4ELAEciG?ULnEa5d4G@A009d00<AM7@017@0115d4A44M003
4EaL009L00<AG1401e`24@Id000LM0034GAd02]d00<AM7@00W@00a5dM003M0@A00lo4Cln?cho?Sln
4G@AM1400W@00a5dM004M0054G@AM14017@03A5LAe`AG15LAea7G4L00a46M00077@00a5dM00[M005
4GAdM1401W@64@0;?ULnEciG?ULAM1400W@00a5d4@07M08A0W@00a5dM002M0034E`A00=L00<AG140
0a42M0034GAd00Ad0007M08A0g@00a5dM0024@9d1145M0034GAd02ad00@AM7@A1G@54@0:?chA?Sln
?cho?P<A0W@00a5d4@08M0044GAd4@Ed00<AG4L01146M0034GAd00Ad0006M0044GAd4@Ad00@AM7@A
0W@00a5dM005M0034GAd02ad00<AM14017@34@0>M14n4CiG4ELnEciG?UL34@=d00<AM1401W@00a5d
4@02M0034GAd009d0a43M0034GAd00Ad00<AM7@017@000Id00@AM7@A17@0115dM143M0034GAd00Ed
00<AM7@0;7@64@9d00lAM14o4Cln?a4o?Sln?ch00Q45M08A1W@00a5d4@02M0074GAdM15d4@05M003
4GAd00=d00<AM7@017@000Id00@AM7@A17@0115dM143M0034GAd00Id0a4[M08A1W@03a5d4ChA?ULn
4CiG?ULnE`024@Ed0Q45M0054GAdM1400W@00a5d4@02M0034GAd00Ad00<AM7@00W@00a5dM004M000
1W@0115dM144M0044GAd4@Ad00<AM7@01W@24Bad00<AM7@017@00a5d4@024@0:?cho?Q4n?cho?P8A
1W@00a5dM002M0034GAd00=d00DAM15d4@02M0034GAd00Ad00<AM7@00W@00a5dM004M0001W@00a5d
M0024@=d00<AM7@00a400g@A4@024@Qd00<AM7@0:G@00a5dM004M00?4G@A4ELnEciG4ELnEciG008A
1W@01A5dM7@A00Id00@AM7@A0g@00a5dM005M0054GAdM1401W@000Md0Q42M0044GAdM08A0W@44@]d
00<AM7@0:G@00a5dM003M00?4G@A4Cho?Sln?a4o?Sln008A1g@0115dM147M08A00Ed4GAd4@08M004
4GAd4@Id0003M0@A00Ed4GAd4@04M0044GAd4@=d00<AM7@02G@24BUd00<AM7@00g@03a5d4A5G?ULn
EchA?ULnE`024@Md00<AM1401W@24@07M15dM15d4@08M0044GAd4@Id0008M0044GAd4@Ad00@AM7@A
0g@00a5dM00:M0034GAd02Qd00<AM7@00W@03a5d4A4n?cho?Sln4Cho?P024@Md0Q45M08A0g@01Q5d
M15d4@Ud00<AM1401W@000Qd00@AM7@A17@0115dM144M0034GAd00Yd0Q4XM0034GAd009d014AM14A
EciG?ULnEchA?ULn4@06M08A00=d4G@00W@00a5dM004M0034GAd008A2W@24@Id0008M0044GAd4@Ad
00HAM7@AM142M0034GAd00ad00<AM7@09W@01Q5dM7@AM08A00dn?cho?Sln?a4o?SlA00Ed00DAM7@A
M0034@Qd00@AM7@A2W@24@Id0009M08A1W@24@=d0Q4@M08A9W@05Q5dM7@AM14nEciG?ULnEciG4ELA
Ea42M08A0g@34@Yd00<AM7@00Q49M08A1W@002Ud00<AM7@09G@00a5d4@02M00B4Cln?cho?Sln?chA
?Q4n4G@A17@24@9d00<AM7@027@0115d4A46M0<A00=d4G@01G@002Yd00<AM7@09G@24@0>M14A4ELn
EciG?ULnEch24@03EchA00=d0Q42M0044GAd4@Yd0Q4017@AM7@34@Ad00<AM7@017@002]d0Q4UM08A
00id4A4A?Sln?cho?Sln?`8A00<n?a400a45M08A00=d4G@027@24@04M14A4@Md00<AM7@017@002ad
0Q4UM08A00ed4A4A?ULnEciG?ULn008A00AG?ULA2G@24@Yd0Q42M0034GAd00Ad00<AM7@01G@002id
00<AM7@08W@24@09M14A4Cln?cho00@A00Hn?a4o?Q4:M08A2G@00a5dM002M0034GAd00=d00<AM7@0
1G@002md00<AM7@08G@34@05M15d4EL00a402eLnEciG?ULAEchA00Yd0Q48M0034GAd009d00<AM7@0
0g@00a5dM005M000<7@00a5d4@0QM08A00=d4A400Q403Sln?cho?Sln?chA?SlA2g@24@Id00<AM7@0
17@00a5dM002M0034GAd00Ed000aM0034GAd025d11404G@A?ULnEciG?ULnEchA?ULA00]d0Q45M003
4GAd00Ed00DAM7Ad4@07M000<W@24B9d01@AM15d4Cln?cho?Sln?cho?Q4n4@ad0Q44M0034GAd00Id
00@AM7@A1g@003Ad00<AM7@087@00a5d4@024@0?EciG?ULnEciG?ULn4ChA00ad0Q43M0034GAd00Id
00<AM14027@003Ed0a4PM00A4GAd4Cho?Sln?cho?Sln?ch0114;M08A0W@00a5dM007M08A27@003Id
00<AM7@087@04A5dM14nEciG?ULnEciG?ULn008A00=d4G@02W@44@Qd0a48M00087@24@=d00<AM7@0
0Q43M0<A1g@00a5dM00PM00@4G@A?cho?Sln?cho?Sln?`8A0W@00a5dM008M0044G@A4@Ad11400g@A
M008M0007g@0115dM144M0044GAd4@=d00<AM7@01g@24B1d0Q403g@AEciG?ULnEciG?ULnE`024@9d
0Q49M08A00=d4A400Q45M0034GAd00Md000IM0@A0W@0115dM144M0044GAd4@=d00<AM7@02G@00a5d
M00NM0<A00hn?cho?Sln?cho?Sln?`8A0g@00a5dM007M08A00=d4G@01G@00a5dM008M0007g@0115d
M144M0044GAd4@=d00<AM7@02W@00a5dM00NM0<A00`nEciG?ULnEciG?UL44@=d00<AM7@01G@00a5d
M002M0034GAd00=d00<AM7@027@001md00@AM7@A17@0115dM143M0034GAd00]d00<AM7@07W@24@07
?cho?Sln?`054@=d0Q43M08A1G@00a5dM003M08A0W@00a5dM009M0007g@0115dM144M0044GAd4@9d
0Q4>M08A7g@24@03EchA00<A2G@34@=d00DAM7Ad4@08M0034G@A00]d000PM08A1W@24@Ad00<AM7@0
3G@24Amd0a43M0034GAd00Ud0Q43M08A00=d4G@01g@24@ad0010M0034GAd01ed0a43M0034GAd00Ud
0Q44M0034GAd00Ad114=M000@G@00a5d4@0NM08A0g@24@Yd0Q42M0044G@AM0HA3g@0049d00<AM7@0
7W@34@=d00<AM7@01g@94@03M14A015d0013M0034GAd01md0Q43M0034GAd009d1143M08A00=d4A40
0Q4CM000A7@00a5dM00OM08A0g@44@Ed0Q42M0<A5G@004Ed0Q4QM0<A00=d4A4017@64AQd0017M003
4GAd021d1A400g@A4@024Aad0018M0034GAd02=d0a4OM000BG@34DAd001:M0034GAd04=d0011M08A
27@24D=d0010M0044GAd4@Ud0Q51M000@7@0115dM14:M0034GAd03md0010M0044GAd4@]d00<AM7@0
?W@0041d00@AM7@A37@00a5d4@0mM000@7@0115dM14=M08A?G@0045d0Q4@M0034GAd03Yd001DM003
4G@A03Ud001EM0034GAd03Qd001FM0034GAd03Md001GM0<A=W@005Qd0Q4fM000FW@00a5dM00cM000
Fg@00a5d4@0bM000G7@00a5dM00aM000Ag@24@=d00<AM7@00Q43M0<A1W@00a5dM00`M000AW@0115d
M144M0044GAd4@=d00<AM7@01W@34Bmd0016M0044GAd4@Ad00@AM7@A0g@00a5dM008M0034GAd02ed
0016M0044GAd4@Ad00@AM7@A0g@00a5dM009M0034GAd02ad0016M0044GAd4@Ad00@AM7@A0g@00a5d
M00:M08A;7@004Id00@AM7@A17@0115dM142M08A3G@00a5dM00ZM000Ag@24@Id0Q44M0034GAd00ad
0Q4ZM000IW@24BQd001WM0034GAd02Id001XM0034G@A02Ed001YM0034GAd02Ad001ZM08A97@006ad
0a4QM000KG@00a5dM00PM000Eg@24@=d00<AM7@00Q42M0@A1g@00a5dM00OM000EW@0115dM144M004
4GAd4@9d00<AM7@0:G@005Id00@AM7@A17@0115dM143M0034GAd02Qd001FM0044GAd4@Ad00@AM7@A
0g@00a5dM00XM000EW@0115dM144M0044GAd4@Ad00<AM7@09g@005Id00@AM7@A17@01Q5dM15d4@9d
00<AM7@09g@005Md0Q46M08A0g@24BYd002@M000T7@0091d002@M000T7@0091d002@M000T7@0091d
002@M000T7@0091d002@M000T7@0091d002@M000T7@00001\
\>"],
  ImageRangeCache->{{{0, 143.562}, {261.375, 0}} -> {0.073699, -0.133928, 
  0.0046448, 0.0046448}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Curvature of the flexible lens", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell["\<\
ComparasionLens=PlanoConvexLens[
\t5*R0,2*R0,Abs[S2[Deltax,Deltay,Force,Deltax,Deltay][[1]]],
\tComponentMedium->BK7,GraphicDesign->Wire,CrossRendering->Mesh];
ShowSystem[{
\tFluid,
\tMove3D[ComparasionLens,
\t\t{t0-Abs[S2[Deltax,Deltay,Force,Deltax,Deltay][[1]]],0,-Deltay},
\t\t{1,0,0},0]
}, 
Frame->True, PlotType->SideView, AspectRatio -> 1/2,
ShowLabels -> False, PlotRange -> {{-0.01, 0.01}, {-0.02, 0.02}}];\
\>", 
  "Input",
  CellLabel->"In[54]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.5 50 0.25 12.5 [
[.125 -0.0125 -19.2188 -11 ]
[.125 -0.0125 19.2188 0 ]
[.25 -0.0125 -16.7188 -11 ]
[.25 -0.0125 16.7188 0 ]
[.375 -0.0125 -19.2188 -11 ]
[.375 -0.0125 19.2188 0 ]
[.5 -0.0125 -4.5 -10.9375 ]
[.5 -0.0125 4.5 0 ]
[.625 -0.0125 -15.75 -11 ]
[.625 -0.0125 15.75 0 ]
[.75 -0.0125 -13.25 -11 ]
[.75 -0.0125 13.25 0 ]
[.875 -0.0125 -15.75 -11 ]
[.875 -0.0125 15.75 0 ]
[1 -0.0125 -10.75 -10.9375 ]
[1 -0.0125 10.75 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0625 -33.4375 -5.5 ]
[-0.0125 .0625 0 5.5 ]
[-0.0125 .125 -28.4375 -5.46875 ]
[-0.0125 .125 0 5.46875 ]
[-0.0125 .1875 -33.4375 -5.5 ]
[-0.0125 .1875 0 5.5 ]
[-0.0125 .25 -9 -5.46875 ]
[-0.0125 .25 0 5.46875 ]
[-0.0125 .3125 -26.5 -5.5 ]
[-0.0125 .3125 0 5.5 ]
[-0.0125 .375 -21.5 -5.46875 ]
[-0.0125 .375 0 5.46875 ]
[-0.0125 .4375 -26.5 -5.5 ]
[-0.0125 .4375 0 5.5 ]
[-0.0125 .5 -21.5 -5.46875 ]
[-0.0125 .5 0 5.46875 ]
[ 0 0 -0.125 0 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -80.2188 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0075) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -77.7188 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -80.2188 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0025) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.5 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -76.75 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0025) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -74.25 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -76.75 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0075) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -71.75 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0625 m
.00625 .0625 L
s
gsave
-0.0125 .0625 -94.4375 -9.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .125 m
.00625 .125 L
s
gsave
-0.0125 .125 -89.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .1875 m
.00625 .1875 L
s
gsave
-0.0125 .1875 -94.4375 -9.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25 m
.00625 .25 L
s
gsave
-0.0125 .25 -70 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .3125 m
.00625 .3125 L
s
gsave
-0.0125 .3125 -87.5 -9.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .375 m
.00625 .375 L
s
gsave
-0.0125 .375 -82.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .4375 m
.00625 .4375 L
s
gsave
-0.0125 .4375 -87.5 -9.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -82.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .0125 m
.00375 .0125 L
s
0 .025 m
.00375 .025 L
s
0 .0375 m
.00375 .0375 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .0875 m
.00375 .0875 L
s
0 .1 m
.00375 .1 L
s
0 .1125 m
.00375 .1125 L
s
0 .1375 m
.00375 .1375 L
s
0 .15 m
.00375 .15 L
s
0 .1625 m
.00375 .1625 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .2125 m
.00375 .2125 L
s
0 .225 m
.00375 .225 L
s
0 .2375 m
.00375 .2375 L
s
0 .2625 m
.00375 .2625 L
s
0 .275 m
.00375 .275 L
s
0 .2875 m
.00375 .2875 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .3375 m
.00375 .3375 L
s
0 .35 m
.00375 .35 L
s
0 .3625 m
.00375 .3625 L
s
0 .3875 m
.00375 .3875 L
s
0 .4 m
.00375 .4 L
s
0 .4125 m
.00375 .4125 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .4625 m
.00375 .4625 L
s
0 .475 m
.00375 .475 L
s
0 .4875 m
.00375 .4875 L
s
.25 Mabswid
0 0 m
0 .5 L
s
0 .49375 m
0 .5 L
s
.125 .49375 m
.125 .5 L
s
.25 .49375 m
.25 .5 L
s
.375 .49375 m
.375 .5 L
s
.5 .49375 m
.5 .5 L
s
.625 .49375 m
.625 .5 L
s
.75 .49375 m
.75 .5 L
s
.875 .49375 m
.875 .5 L
s
.125 Mabswid
.025 .49625 m
.025 .5 L
s
.05 .49625 m
.05 .5 L
s
.075 .49625 m
.075 .5 L
s
.1 .49625 m
.1 .5 L
s
.15 .49625 m
.15 .5 L
s
.175 .49625 m
.175 .5 L
s
.2 .49625 m
.2 .5 L
s
.225 .49625 m
.225 .5 L
s
.275 .49625 m
.275 .5 L
s
.3 .49625 m
.3 .5 L
s
.325 .49625 m
.325 .5 L
s
.35 .49625 m
.35 .5 L
s
.4 .49625 m
.4 .5 L
s
.425 .49625 m
.425 .5 L
s
.45 .49625 m
.45 .5 L
s
.475 .49625 m
.475 .5 L
s
.525 .49625 m
.525 .5 L
s
.55 .49625 m
.55 .5 L
s
.575 .49625 m
.575 .5 L
s
.6 .49625 m
.6 .5 L
s
.65 .49625 m
.65 .5 L
s
.675 .49625 m
.675 .5 L
s
.7 .49625 m
.7 .5 L
s
.725 .49625 m
.725 .5 L
s
.775 .49625 m
.775 .5 L
s
.8 .49625 m
.8 .5 L
s
.825 .49625 m
.825 .5 L
s
.85 .49625 m
.85 .5 L
s
.9 .49625 m
.9 .5 L
s
.925 .49625 m
.925 .5 L
s
.95 .49625 m
.95 .5 L
s
.975 .49625 m
.975 .5 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.99375 0 m
1 0 L
s
.99375 .0625 m
1 .0625 L
s
.99375 .125 m
1 .125 L
s
.99375 .1875 m
1 .1875 L
s
.99375 .25 m
1 .25 L
s
.99375 .3125 m
1 .3125 L
s
.99375 .375 m
1 .375 L
s
.99375 .4375 m
1 .4375 L
s
.125 Mabswid
.99625 .0125 m
1 .0125 L
s
.99625 .025 m
1 .025 L
s
.99625 .0375 m
1 .0375 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .0875 m
1 .0875 L
s
.99625 .1 m
1 .1 L
s
.99625 .1125 m
1 .1125 L
s
.99625 .1375 m
1 .1375 L
s
.99625 .15 m
1 .15 L
s
.99625 .1625 m
1 .1625 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .2125 m
1 .2125 L
s
.99625 .225 m
1 .225 L
s
.99625 .2375 m
1 .2375 L
s
.99625 .2625 m
1 .2625 L
s
.99625 .275 m
1 .275 L
s
.99625 .2875 m
1 .2875 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35 m
1 .35 L
s
.99625 .3625 m
1 .3625 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .4 m
1 .4 L
s
.99625 .4125 m
1 .4125 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .4625 m
1 .4625 L
s
.99625 .475 m
1 .475 L
s
.99625 .4875 m
1 .4875 L
s
.25 Mabswid
1 0 m
1 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 0 m
.9 0 L
.9 .08333 L
.5375 .08333 L
.5375 0 L
s
.5375 .08333 m
.9 .08333 L
.9 .16667 L
.5375 .16667 L
.5375 .08333 L
s
.5375 .16667 m
.9 .16667 L
.9 .25 L
.5375 .25 L
.5375 .16667 L
s
.5375 .25 m
.9 .25 L
.9 .33333 L
.48451 .33333 L
.5375 .25 L
s
.48451 .33333 m
.9 .33333 L
.9 .41667 L
.48451 .41667 L
.48451 .33333 L
s
.48451 .41667 m
.9 .41667 L
.9 .5 L
.5375 .5 L
.48451 .41667 L
s
.5375 .25 m
.5375 .25 L
.52599 .27157 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.52599 .27157 L
.49821 .29167 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.49821 .29167 L
.47032 .30893 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.47032 .30893 L
.4559 .32217 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.4559 .32217 L
.46146 .33049 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.46146 .33049 L
.48451 .33333 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.48451 .33333 L
.51433 .33049 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.51433 .33049 L
.5351 .32217 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5351 .32217 L
.5375 .30893 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .30893 L
.5375 .29167 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .29167 L
.5375 .27157 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .27157 L
.5375 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .25 L
.5375 .22843 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .22843 L
.5375 .20833 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .20833 L
.5375 .19107 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .19107 L
.5375 .17783 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .17783 L
.5375 .16951 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .16951 L
.5375 .16667 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .16667 L
.5375 .16951 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .16951 L
.5375 .17783 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .17783 L
.5375 .19107 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .19107 L
.5375 .20833 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .20833 L
.5375 .22843 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .22843 L
.5375 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .25 L
.5375 .29314 L
.52599 .27157 L
.5375 .25 L
s
.52599 .27157 m
.5375 .29314 L
.50986 .33333 L
.49821 .29167 L
.52599 .27157 L
s
.49821 .29167 m
.50986 .33333 L
.45445 .36785 L
.47032 .30893 L
.49821 .29167 L
s
.47032 .30893 m
.45445 .36785 L
.42113 .39434 L
.4559 .32217 L
.47032 .30893 L
s
.4559 .32217 m
.42113 .39434 L
.43424 .41099 L
.46146 .33049 L
.4559 .32217 L
s
.46146 .33049 m
.43424 .41099 L
.48451 .41667 L
.48451 .33333 L
.46146 .33049 L
s
.48451 .33333 m
.48451 .41667 L
.53187 .41099 L
.51433 .33049 L
.48451 .33333 L
s
.51433 .33049 m
.53187 .41099 L
.5375 .39434 L
.5351 .32217 L
.51433 .33049 L
s
.5351 .32217 m
.5375 .39434 L
.5375 .36785 L
.5375 .30893 L
.5351 .32217 L
s
.5375 .30893 m
.5375 .36785 L
.5375 .33333 L
.5375 .29167 L
.5375 .30893 L
s
.5375 .29167 m
.5375 .33333 L
.5375 .29314 L
.5375 .27157 L
.5375 .29167 L
s
.5375 .27157 m
.5375 .29314 L
.5375 .25 L
.5375 .25 L
.5375 .27157 L
s
.5375 .25 m
.5375 .25 L
.5375 .20686 L
.5375 .22843 L
.5375 .25 L
s
.5375 .22843 m
.5375 .20686 L
.5375 .16667 L
.5375 .20833 L
.5375 .22843 L
s
.5375 .20833 m
.5375 .16667 L
.5375 .13215 L
.5375 .19107 L
.5375 .20833 L
s
.5375 .19107 m
.5375 .13215 L
.5375 .10566 L
.5375 .17783 L
.5375 .19107 L
s
.5375 .17783 m
.5375 .10566 L
.5375 .08901 L
.5375 .16951 L
.5375 .17783 L
s
.5375 .16951 m
.5375 .08901 L
.5375 .08333 L
.5375 .16667 L
.5375 .16951 L
s
.5375 .16667 m
.5375 .08333 L
.5375 .08901 L
.5375 .16951 L
.5375 .16667 L
s
.5375 .16951 m
.5375 .08901 L
.5375 .10566 L
.5375 .17783 L
.5375 .16951 L
s
.5375 .17783 m
.5375 .10566 L
.5375 .13215 L
.5375 .19107 L
.5375 .17783 L
s
.5375 .19107 m
.5375 .13215 L
.5375 .16667 L
.5375 .20833 L
.5375 .19107 L
s
.5375 .20833 m
.5375 .16667 L
.5375 .20686 L
.5375 .22843 L
.5375 .20833 L
s
.5375 .22843 m
.5375 .20686 L
.5375 .25 L
.5375 .25 L
.5375 .22843 L
s
.5375 .25 m
.5375 .25 L
.5375 .3147 L
.5375 .29314 L
.5375 .25 L
s
.5375 .29314 m
.5375 .3147 L
.5375 .375 L
.50986 .33333 L
.5375 .29314 L
s
.50986 .33333 m
.5375 .375 L
.5375 .42678 L
.45445 .36785 L
.50986 .33333 L
s
.45445 .36785 m
.5375 .42678 L
.53127 .46651 L
.42113 .39434 L
.45445 .36785 L
s
.42113 .39434 m
.53127 .46651 L
.53496 .49148 L
.43424 .41099 L
.42113 .39434 L
s
.43424 .41099 m
.53496 .49148 L
.5375 .5 L
.48451 .41667 L
.43424 .41099 L
s
.48451 .41667 m
.5375 .5 L
.5375 .49148 L
.53187 .41099 L
.48451 .41667 L
s
.53187 .41099 m
.5375 .49148 L
.5375 .46651 L
.5375 .39434 L
.53187 .41099 L
s
.5375 .39434 m
.5375 .46651 L
.5375 .42678 L
.5375 .36785 L
.5375 .39434 L
s
.5375 .36785 m
.5375 .42678 L
.5375 .375 L
.5375 .33333 L
.5375 .36785 L
s
.5375 .33333 m
.5375 .375 L
.5375 .3147 L
.5375 .29314 L
.5375 .33333 L
s
.5375 .29314 m
.5375 .3147 L
.5375 .25 L
.5375 .25 L
.5375 .29314 L
s
.5375 .25 m
.5375 .25 L
.5375 .1853 L
.5375 .20686 L
.5375 .25 L
s
.5375 .20686 m
.5375 .1853 L
.5375 .125 L
.5375 .16667 L
.5375 .20686 L
s
.5375 .16667 m
.5375 .125 L
.5375 .07322 L
.5375 .13215 L
.5375 .16667 L
s
.5375 .13215 m
.5375 .07322 L
.5375 .03349 L
.5375 .10566 L
.5375 .13215 L
s
.5375 .10566 m
.5375 .03349 L
.5375 .00852 L
.5375 .08901 L
.5375 .10566 L
s
.5375 .08901 m
.5375 .00852 L
.5375 0 L
.5375 .08333 L
.5375 .08901 L
s
.5375 .08333 m
.5375 0 L
.5375 .00852 L
.5375 .08901 L
.5375 .08333 L
s
.5375 .08901 m
.5375 .00852 L
.5375 .03349 L
.5375 .10566 L
.5375 .08901 L
s
.5375 .10566 m
.5375 .03349 L
.5375 .07322 L
.5375 .13215 L
.5375 .10566 L
s
.5375 .13215 m
.5375 .07322 L
.5375 .125 L
.5375 .16667 L
.5375 .13215 L
s
.5375 .16667 m
.5375 .125 L
.5375 .1853 L
.5375 .20686 L
.5375 .16667 L
s
.5375 .20686 m
.5375 .1853 L
.5375 .25 L
.5375 .25 L
.5375 .20686 L
s
.9 .25 m
.9 .25 L
.9 .27157 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .27157 L
.9 .29167 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .29167 L
.9 .30893 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .30893 L
.9 .32217 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .32217 L
.9 .33049 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .33049 L
.9 .33333 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .33333 L
.9 .33049 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .33049 L
.9 .32217 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .32217 L
.9 .30893 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .30893 L
.9 .29167 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .29167 L
.9 .27157 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .27157 L
.9 .25 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .25 L
.9 .22843 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .22843 L
.9 .20833 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .20833 L
.9 .19107 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .19107 L
.9 .17783 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .17783 L
.9 .16951 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .16951 L
.9 .16667 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .16667 L
.9 .16951 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .16951 L
.9 .17783 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .17783 L
.9 .19107 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .19107 L
.9 .20833 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .20833 L
.9 .22843 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .22843 L
.9 .25 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .25 L
.9 .29314 L
.9 .27157 L
.9 .25 L
s
.9 .27157 m
.9 .29314 L
.9 .33333 L
.9 .29167 L
.9 .27157 L
s
.9 .29167 m
.9 .33333 L
.9 .36785 L
.9 .30893 L
.9 .29167 L
s
.9 .30893 m
.9 .36785 L
.9 .39434 L
.9 .32217 L
.9 .30893 L
s
.9 .32217 m
.9 .39434 L
.9 .41099 L
.9 .33049 L
.9 .32217 L
s
.9 .33049 m
.9 .41099 L
.9 .41667 L
.9 .33333 L
.9 .33049 L
s
.9 .33333 m
.9 .41667 L
.9 .41099 L
.9 .33049 L
.9 .33333 L
s
.9 .33049 m
.9 .41099 L
.9 .39434 L
.9 .32217 L
.9 .33049 L
s
.9 .32217 m
.9 .39434 L
.9 .36785 L
.9 .30893 L
.9 .32217 L
s
.9 .30893 m
.9 .36785 L
.9 .33333 L
.9 .29167 L
.9 .30893 L
s
.9 .29167 m
.9 .33333 L
.9 .29314 L
.9 .27157 L
.9 .29167 L
s
.9 .27157 m
.9 .29314 L
.9 .25 L
.9 .25 L
.9 .27157 L
s
.9 .25 m
.9 .25 L
.9 .20686 L
.9 .22843 L
.9 .25 L
s
.9 .22843 m
.9 .20686 L
.9 .16667 L
.9 .20833 L
.9 .22843 L
s
.9 .20833 m
.9 .16667 L
.9 .13215 L
.9 .19107 L
.9 .20833 L
s
.9 .19107 m
.9 .13215 L
.9 .10566 L
.9 .17783 L
.9 .19107 L
s
.9 .17783 m
.9 .10566 L
.9 .08901 L
.9 .16951 L
.9 .17783 L
s
.9 .16951 m
.9 .08901 L
.9 .08333 L
.9 .16667 L
.9 .16951 L
s
.9 .16667 m
.9 .08333 L
.9 .08901 L
.9 .16951 L
.9 .16667 L
s
.9 .16951 m
.9 .08901 L
.9 .10566 L
.9 .17783 L
.9 .16951 L
s
.9 .17783 m
.9 .10566 L
.9 .13215 L
.9 .19107 L
.9 .17783 L
s
.9 .19107 m
.9 .13215 L
.9 .16667 L
.9 .20833 L
.9 .19107 L
s
.9 .20833 m
.9 .16667 L
.9 .20686 L
.9 .22843 L
.9 .20833 L
s
.9 .22843 m
.9 .20686 L
.9 .25 L
.9 .25 L
.9 .22843 L
s
.9 .25 m
.9 .25 L
.9 .3147 L
.9 .29314 L
.9 .25 L
s
.9 .29314 m
.9 .3147 L
.9 .375 L
.9 .33333 L
.9 .29314 L
s
.9 .33333 m
.9 .375 L
.9 .42678 L
.9 .36785 L
.9 .33333 L
s
.9 .36785 m
.9 .42678 L
.9 .46651 L
.9 .39434 L
.9 .36785 L
s
.9 .39434 m
.9 .46651 L
.9 .49148 L
.9 .41099 L
.9 .39434 L
s
.9 .41099 m
.9 .49148 L
.9 .5 L
.9 .41667 L
.9 .41099 L
s
.9 .41667 m
.9 .5 L
.9 .49148 L
.9 .41099 L
.9 .41667 L
s
.9 .41099 m
.9 .49148 L
.9 .46651 L
.9 .39434 L
.9 .41099 L
s
.9 .39434 m
.9 .46651 L
.9 .42678 L
.9 .36785 L
.9 .39434 L
s
.9 .36785 m
.9 .42678 L
.9 .375 L
.9 .33333 L
.9 .36785 L
s
.9 .33333 m
.9 .375 L
.9 .3147 L
.9 .29314 L
.9 .33333 L
s
.9 .29314 m
.9 .3147 L
.9 .25 L
.9 .25 L
.9 .29314 L
s
.9 .25 m
.9 .25 L
.9 .1853 L
.9 .20686 L
.9 .25 L
s
.9 .20686 m
.9 .1853 L
.9 .125 L
.9 .16667 L
.9 .20686 L
s
.9 .16667 m
.9 .125 L
.9 .07322 L
.9 .13215 L
.9 .16667 L
s
.9 .13215 m
.9 .07322 L
.9 .03349 L
.9 .10566 L
.9 .13215 L
s
.9 .10566 m
.9 .03349 L
.9 .00852 L
.9 .08901 L
.9 .10566 L
s
.9 .08901 m
.9 .00852 L
.9 0 L
.9 .08333 L
.9 .08901 L
s
.9 .08333 m
.9 0 L
.9 .00852 L
.9 .08901 L
.9 .08333 L
s
.9 .08901 m
.9 .00852 L
.9 .03349 L
.9 .10566 L
.9 .08901 L
s
.9 .10566 m
.9 .03349 L
.9 .07322 L
.9 .13215 L
.9 .10566 L
s
.9 .13215 m
.9 .07322 L
.9 .125 L
.9 .16667 L
.9 .13215 L
s
.9 .16667 m
.9 .125 L
.9 .1853 L
.9 .20686 L
.9 .16667 L
s
.9 .20686 m
.9 .1853 L
.9 .25 L
.9 .25 L
.9 .20686 L
s
.5375 .25 m
.9 .25 L
.9 .3147 L
.5375 .3147 L
.5375 .25 L
s
.5375 .3147 m
.9 .3147 L
.9 .375 L
.5375 .375 L
.5375 .3147 L
s
.5375 .375 m
.9 .375 L
.9 .42678 L
.5375 .42678 L
.5375 .375 L
s
.5375 .42678 m
.9 .42678 L
.9 .46651 L
.53127 .46651 L
.5375 .42678 L
s
.53127 .46651 m
.9 .46651 L
.9 .49148 L
.53496 .49148 L
.53127 .46651 L
s
.53496 .49148 m
.9 .49148 L
.9 .5 L
.5375 .5 L
.53496 .49148 L
s
.5375 .5 m
.9 .5 L
.9 .49148 L
.5375 .49148 L
.5375 .5 L
s
.5375 .49148 m
.9 .49148 L
.9 .46651 L
.5375 .46651 L
.5375 .49148 L
s
.5375 .46651 m
.9 .46651 L
.9 .42678 L
.5375 .42678 L
.5375 .46651 L
s
.5375 .42678 m
.9 .42678 L
.9 .375 L
.5375 .375 L
.5375 .42678 L
s
.5375 .375 m
.9 .375 L
.9 .3147 L
.5375 .3147 L
.5375 .375 L
s
.5375 .3147 m
.9 .3147 L
.9 .25 L
.5375 .25 L
.5375 .3147 L
s
.5375 .25 m
.9 .25 L
.9 .1853 L
.5375 .1853 L
.5375 .25 L
s
.5375 .1853 m
.9 .1853 L
.9 .125 L
.5375 .125 L
.5375 .1853 L
s
.5375 .125 m
.9 .125 L
.9 .07322 L
.5375 .07322 L
.5375 .125 L
s
.5375 .07322 m
.9 .07322 L
.9 .03349 L
.5375 .03349 L
.5375 .07322 L
s
.5375 .03349 m
.9 .03349 L
.9 .00852 L
.5375 .00852 L
.5375 .03349 L
s
.5375 .00852 m
.9 .00852 L
.9 0 L
.5375 0 L
.5375 .00852 L
s
.5375 0 m
.9 0 L
.9 .00852 L
.5375 .00852 L
.5375 0 L
s
.5375 .00852 m
.9 .00852 L
.9 .03349 L
.5375 .03349 L
.5375 .00852 L
s
.5375 .03349 m
.9 .03349 L
.9 .07322 L
.5375 .07322 L
.5375 .03349 L
s
.5375 .07322 m
.9 .07322 L
.9 .125 L
.5375 .125 L
.5375 .07322 L
s
.5375 .125 m
.9 .125 L
.9 .1853 L
.5375 .1853 L
.5375 .125 L
s
.5375 .1853 m
.9 .1853 L
.9 .25 L
.5375 .25 L
.5375 .1853 L
s
.54595 .125 m
.5375 .125 L
.5375 .125 L
.48925 .125 L
.54595 .125 L
s
.48925 .125 m
.5375 .125 L
.5375 .125 L
.45643 .125 L
.48925 .125 L
s
.45643 .125 m
.5375 .125 L
.5375 .125 L
.44568 .125 L
.45643 .125 L
s
.44568 .125 m
.5375 .125 L
.5375 .125 L
.45643 .125 L
.44568 .125 L
s
.45643 .125 m
.5375 .125 L
.5375 .125 L
.48925 .125 L
.45643 .125 L
s
.48925 .125 m
.5375 .125 L
.5375 .125 L
.54595 .125 L
.48925 .125 L
s
.54595 0 m
.5375 0 L
.5375 .04167 L
.48925 .04167 L
.54595 0 L
s
.48925 .04167 m
.5375 .04167 L
.5375 .08333 L
.45643 .08333 L
.48925 .04167 L
s
.45643 .08333 m
.5375 .08333 L
.5375 .125 L
.44568 .125 L
.45643 .08333 L
s
.44568 .125 m
.5375 .125 L
.5375 .16667 L
.45643 .16667 L
.44568 .125 L
s
.45643 .16667 m
.5375 .16667 L
.5375 .20833 L
.48925 .20833 L
.45643 .16667 L
s
.48925 .20833 m
.5375 .20833 L
.5375 .25 L
.54595 .25 L
.48925 .20833 L
s
.44568 .125 m
.45643 .125 L
.45643 .13578 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .13578 L
.45643 .14583 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .14583 L
.45643 .15446 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .15446 L
.45643 .16108 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16108 L
.45643 .16525 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16525 L
.45643 .16667 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16667 L
.45643 .16525 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16525 L
.45643 .16108 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16108 L
.45643 .15446 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .15446 L
.45643 .14583 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .14583 L
.45643 .13578 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .13578 L
.45643 .125 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .125 L
.45643 .11422 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .11422 L
.45643 .10417 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .10417 L
.45643 .09554 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .09554 L
.45643 .08892 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08892 L
.45643 .08475 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08475 L
.45643 .08333 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08333 L
.45643 .08475 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08475 L
.45643 .08892 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08892 L
.45643 .09554 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .09554 L
.45643 .10417 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .10417 L
.45643 .11422 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .11422 L
.45643 .125 L
.44568 .125 L
.44568 .125 L
s
.45643 .125 m
.48925 .125 L
.48925 .14657 L
.45643 .13578 L
.45643 .125 L
s
.45643 .13578 m
.48925 .14657 L
.48925 .16667 L
.45643 .14583 L
.45643 .13578 L
s
.45643 .14583 m
.48925 .16667 L
.48925 .18393 L
.45643 .15446 L
.45643 .14583 L
s
.45643 .15446 m
.48925 .18393 L
.48925 .19717 L
.45643 .16108 L
.45643 .15446 L
s
.45643 .16108 m
.48925 .19717 L
.48925 .20549 L
.45643 .16525 L
.45643 .16108 L
s
.45643 .16525 m
.48925 .20549 L
.48925 .20833 L
.45643 .16667 L
.45643 .16525 L
s
.45643 .16667 m
.48925 .20833 L
.48925 .20549 L
.45643 .16525 L
.45643 .16667 L
s
.45643 .16525 m
.48925 .20549 L
.48925 .19717 L
.45643 .16108 L
.45643 .16525 L
s
.45643 .16108 m
.48925 .19717 L
.48925 .18393 L
.45643 .15446 L
.45643 .16108 L
s
.45643 .15446 m
.48925 .18393 L
.48925 .16667 L
.45643 .14583 L
.45643 .15446 L
s
.45643 .14583 m
.48925 .16667 L
.48925 .14657 L
.45643 .13578 L
.45643 .14583 L
s
.45643 .13578 m
.48925 .14657 L
.48925 .125 L
.45643 .125 L
.45643 .13578 L
s
.45643 .125 m
.48925 .125 L
.48925 .10343 L
.45643 .11422 L
.45643 .125 L
s
.45643 .11422 m
.48925 .10343 L
.48925 .08333 L
.45643 .10417 L
.45643 .11422 L
s
.45643 .10417 m
.48925 .08333 L
.48925 .06607 L
.45643 .09554 L
.45643 .10417 L
s
.45643 .09554 m
.48925 .06607 L
.48925 .05283 L
.45643 .08892 L
.45643 .09554 L
s
.45643 .08892 m
.48925 .05283 L
.48925 .04451 L
.45643 .08475 L
.45643 .08892 L
s
.45643 .08475 m
.48925 .04451 L
.48925 .04167 L
.45643 .08333 L
.45643 .08475 L
s
.45643 .08333 m
.48925 .04167 L
.48925 .04451 L
.45643 .08475 L
.45643 .08333 L
s
.45643 .08475 m
.48925 .04451 L
.48925 .05283 L
.45643 .08892 L
.45643 .08475 L
s
.45643 .08892 m
.48925 .05283 L
.48925 .06607 L
.45643 .09554 L
.45643 .08892 L
s
.45643 .09554 m
.48925 .06607 L
.48925 .08333 L
.45643 .10417 L
.45643 .09554 L
s
.45643 .10417 m
.48925 .08333 L
.48925 .10343 L
.45643 .11422 L
.45643 .10417 L
s
.45643 .11422 m
.48925 .10343 L
.48925 .125 L
.45643 .125 L
.45643 .11422 L
s
.48925 .125 m
.54595 .125 L
.54595 .15735 L
.48925 .14657 L
.48925 .125 L
s
.48925 .14657 m
.54595 .15735 L
.54595 .1875 L
.48925 .16667 L
.48925 .14657 L
s
.48925 .16667 m
.54595 .1875 L
.54595 .21339 L
.48925 .18393 L
.48925 .16667 L
s
.48925 .18393 m
.54595 .21339 L
.54595 .23325 L
.48925 .19717 L
.48925 .18393 L
s
.48925 .19717 m
.54595 .23325 L
.54595 .24574 L
.48925 .20549 L
.48925 .19717 L
s
.48925 .20549 m
.54595 .24574 L
.54595 .25 L
.48925 .20833 L
.48925 .20549 L
s
.48925 .20833 m
.54595 .25 L
.54595 .24574 L
.48925 .20549 L
.48925 .20833 L
s
.48925 .20549 m
.54595 .24574 L
.54595 .23325 L
.48925 .19717 L
.48925 .20549 L
s
.48925 .19717 m
.54595 .23325 L
.54595 .21339 L
.48925 .18393 L
.48925 .19717 L
s
.48925 .18393 m
.54595 .21339 L
.54595 .1875 L
.48925 .16667 L
.48925 .18393 L
s
.48925 .16667 m
.54595 .1875 L
.54595 .15735 L
.48925 .14657 L
.48925 .16667 L
s
.48925 .14657 m
.54595 .15735 L
.54595 .125 L
.48925 .125 L
.48925 .14657 L
s
.48925 .125 m
.54595 .125 L
.54595 .09265 L
.48925 .10343 L
.48925 .125 L
s
.48925 .10343 m
.54595 .09265 L
.54595 .0625 L
.48925 .08333 L
.48925 .10343 L
s
.48925 .08333 m
.54595 .0625 L
.54595 .03661 L
.48925 .06607 L
.48925 .08333 L
s
.48925 .06607 m
.54595 .03661 L
.54595 .01675 L
.48925 .05283 L
.48925 .06607 L
s
.48925 .05283 m
.54595 .01675 L
.54595 .00426 L
.48925 .04451 L
.48925 .05283 L
s
.48925 .04451 m
.54595 .00426 L
.54595 0 L
.48925 .04167 L
.48925 .04451 L
s
.48925 .04167 m
.54595 0 L
.54595 .00426 L
.48925 .04451 L
.48925 .04167 L
s
.48925 .04451 m
.54595 .00426 L
.54595 .01675 L
.48925 .05283 L
.48925 .04451 L
s
.48925 .05283 m
.54595 .01675 L
.54595 .03661 L
.48925 .06607 L
.48925 .05283 L
s
.48925 .06607 m
.54595 .03661 L
.54595 .0625 L
.48925 .08333 L
.48925 .06607 L
s
.48925 .08333 m
.54595 .0625 L
.54595 .09265 L
.48925 .10343 L
.48925 .08333 L
s
.48925 .10343 m
.54595 .09265 L
.54595 .125 L
.48925 .125 L
.48925 .10343 L
s
.5375 .125 m
.5375 .125 L
.5375 .13578 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .13578 L
.5375 .14583 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .14583 L
.5375 .15446 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .15446 L
.5375 .16108 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16108 L
.5375 .16525 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16525 L
.5375 .16667 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16667 L
.5375 .16525 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16525 L
.5375 .16108 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16108 L
.5375 .15446 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .15446 L
.5375 .14583 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .14583 L
.5375 .13578 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .13578 L
.5375 .125 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .125 L
.5375 .11422 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .11422 L
.5375 .10417 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .10417 L
.5375 .09554 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .09554 L
.5375 .08892 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08892 L
.5375 .08475 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08475 L
.5375 .08333 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08333 L
.5375 .08475 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08475 L
.5375 .08892 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08892 L
.5375 .09554 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .09554 L
.5375 .10417 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .10417 L
.5375 .11422 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .11422 L
.5375 .125 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .125 L
.5375 .14657 L
.5375 .13578 L
.5375 .125 L
s
.5375 .13578 m
.5375 .14657 L
.5375 .16667 L
.5375 .14583 L
.5375 .13578 L
s
.5375 .14583 m
.5375 .16667 L
.5375 .18393 L
.5375 .15446 L
.5375 .14583 L
s
.5375 .15446 m
.5375 .18393 L
.5375 .19717 L
.5375 .16108 L
.5375 .15446 L
s
.5375 .16108 m
.5375 .19717 L
.5375 .20549 L
.5375 .16525 L
.5375 .16108 L
s
.5375 .16525 m
.5375 .20549 L
.5375 .20833 L
.5375 .16667 L
.5375 .16525 L
s
.5375 .16667 m
.5375 .20833 L
.5375 .20549 L
.5375 .16525 L
.5375 .16667 L
s
.5375 .16525 m
.5375 .20549 L
.5375 .19717 L
.5375 .16108 L
.5375 .16525 L
s
.5375 .16108 m
.5375 .19717 L
.5375 .18393 L
.5375 .15446 L
.5375 .16108 L
s
.5375 .15446 m
.5375 .18393 L
.5375 .16667 L
.5375 .14583 L
.5375 .15446 L
s
.5375 .14583 m
.5375 .16667 L
.5375 .14657 L
.5375 .13578 L
.5375 .14583 L
s
.5375 .13578 m
.5375 .14657 L
.5375 .125 L
.5375 .125 L
.5375 .13578 L
s
.5375 .125 m
.5375 .125 L
.5375 .10343 L
.5375 .11422 L
.5375 .125 L
s
.5375 .11422 m
.5375 .10343 L
.5375 .08333 L
.5375 .10417 L
.5375 .11422 L
s
.5375 .10417 m
.5375 .08333 L
.5375 .06607 L
.5375 .09554 L
.5375 .10417 L
s
.5375 .09554 m
.5375 .06607 L
.5375 .05283 L
.5375 .08892 L
.5375 .09554 L
s
.5375 .08892 m
.5375 .05283 L
.5375 .04451 L
.5375 .08475 L
.5375 .08892 L
s
.5375 .08475 m
.5375 .04451 L
.5375 .04167 L
.5375 .08333 L
.5375 .08475 L
s
.5375 .08333 m
.5375 .04167 L
.5375 .04451 L
.5375 .08475 L
.5375 .08333 L
s
.5375 .08475 m
.5375 .04451 L
.5375 .05283 L
.5375 .08892 L
.5375 .08475 L
s
.5375 .08892 m
.5375 .05283 L
.5375 .06607 L
.5375 .09554 L
.5375 .08892 L
s
.5375 .09554 m
.5375 .06607 L
.5375 .08333 L
.5375 .10417 L
.5375 .09554 L
s
.5375 .10417 m
.5375 .08333 L
.5375 .10343 L
.5375 .11422 L
.5375 .10417 L
s
.5375 .11422 m
.5375 .10343 L
.5375 .125 L
.5375 .125 L
.5375 .11422 L
s
.5375 .125 m
.5375 .125 L
.5375 .15735 L
.5375 .14657 L
.5375 .125 L
s
.5375 .14657 m
.5375 .15735 L
.5375 .1875 L
.5375 .16667 L
.5375 .14657 L
s
.5375 .16667 m
.5375 .1875 L
.5375 .21339 L
.5375 .18393 L
.5375 .16667 L
s
.5375 .18393 m
.5375 .21339 L
.5375 .23325 L
.5375 .19717 L
.5375 .18393 L
s
.5375 .19717 m
.5375 .23325 L
.5375 .24574 L
.5375 .20549 L
.5375 .19717 L
s
.5375 .20549 m
.5375 .24574 L
.5375 .25 L
.5375 .20833 L
.5375 .20549 L
s
.5375 .20833 m
.5375 .25 L
.5375 .24574 L
.5375 .20549 L
.5375 .20833 L
s
.5375 .20549 m
.5375 .24574 L
.5375 .23325 L
.5375 .19717 L
.5375 .20549 L
s
.5375 .19717 m
.5375 .23325 L
.5375 .21339 L
.5375 .18393 L
.5375 .19717 L
s
.5375 .18393 m
.5375 .21339 L
.5375 .1875 L
.5375 .16667 L
.5375 .18393 L
s
.5375 .16667 m
.5375 .1875 L
.5375 .15735 L
.5375 .14657 L
.5375 .16667 L
s
.5375 .14657 m
.5375 .15735 L
.5375 .125 L
.5375 .125 L
.5375 .14657 L
s
.5375 .125 m
.5375 .125 L
.5375 .09265 L
.5375 .10343 L
.5375 .125 L
s
.5375 .10343 m
.5375 .09265 L
.5375 .0625 L
.5375 .08333 L
.5375 .10343 L
s
.5375 .08333 m
.5375 .0625 L
.5375 .03661 L
.5375 .06607 L
.5375 .08333 L
s
.5375 .06607 m
.5375 .03661 L
.5375 .01675 L
.5375 .05283 L
.5375 .06607 L
s
.5375 .05283 m
.5375 .01675 L
.5375 .00426 L
.5375 .04451 L
.5375 .05283 L
s
.5375 .04451 m
.5375 .00426 L
.5375 0 L
.5375 .04167 L
.5375 .04451 L
s
.5375 .04167 m
.5375 0 L
.5375 .00426 L
.5375 .04451 L
.5375 .04167 L
s
.5375 .04451 m
.5375 .00426 L
.5375 .01675 L
.5375 .05283 L
.5375 .04451 L
s
.5375 .05283 m
.5375 .01675 L
.5375 .03661 L
.5375 .06607 L
.5375 .05283 L
s
.5375 .06607 m
.5375 .03661 L
.5375 .0625 L
.5375 .08333 L
.5375 .06607 L
s
.5375 .08333 m
.5375 .0625 L
.5375 .09265 L
.5375 .10343 L
.5375 .08333 L
s
.5375 .10343 m
.5375 .09265 L
.5375 .125 L
.5375 .125 L
.5375 .10343 L
s
.54595 .125 m
.5375 .125 L
.5375 .15735 L
.54595 .15735 L
.54595 .125 L
s
.54595 .15735 m
.5375 .15735 L
.5375 .1875 L
.54595 .1875 L
.54595 .15735 L
s
.54595 .1875 m
.5375 .1875 L
.5375 .21339 L
.54595 .21339 L
.54595 .1875 L
s
.54595 .21339 m
.5375 .21339 L
.5375 .23325 L
.54595 .23325 L
.54595 .21339 L
s
.54595 .23325 m
.5375 .23325 L
.5375 .24574 L
.54595 .24574 L
.54595 .23325 L
s
.54595 .24574 m
.5375 .24574 L
.5375 .25 L
.54595 .25 L
.54595 .24574 L
s
.54595 .25 m
.5375 .25 L
.5375 .24574 L
.54595 .24574 L
.54595 .25 L
s
.54595 .24574 m
.5375 .24574 L
.5375 .23325 L
.54595 .23325 L
.54595 .24574 L
s
.54595 .23325 m
.5375 .23325 L
.5375 .21339 L
.54595 .21339 L
.54595 .23325 L
s
.54595 .21339 m
.5375 .21339 L
.5375 .1875 L
.54595 .1875 L
.54595 .21339 L
s
.54595 .1875 m
.5375 .1875 L
.5375 .15735 L
.54595 .15735 L
.54595 .1875 L
s
.54595 .15735 m
.5375 .15735 L
.5375 .125 L
.54595 .125 L
.54595 .15735 L
s
.54595 .125 m
.5375 .125 L
.5375 .09265 L
.54595 .09265 L
.54595 .125 L
s
.54595 .09265 m
.5375 .09265 L
.5375 .0625 L
.54595 .0625 L
.54595 .09265 L
s
.54595 .0625 m
.5375 .0625 L
.5375 .03661 L
.54595 .03661 L
.54595 .0625 L
s
.54595 .03661 m
.5375 .03661 L
.5375 .01675 L
.54595 .01675 L
.54595 .03661 L
s
.54595 .01675 m
.5375 .01675 L
.5375 .00426 L
.54595 .00426 L
.54595 .01675 L
s
.54595 .00426 m
.5375 .00426 L
.5375 0 L
.54595 0 L
.54595 .00426 L
s
.54595 0 m
.5375 0 L
.5375 .00426 L
.54595 .00426 L
.54595 0 L
s
.54595 .00426 m
.5375 .00426 L
.5375 .01675 L
.54595 .01675 L
.54595 .00426 L
s
.54595 .01675 m
.5375 .01675 L
.5375 .03661 L
.54595 .03661 L
.54595 .01675 L
s
.54595 .03661 m
.5375 .03661 L
.5375 .0625 L
.54595 .0625 L
.54595 .03661 L
s
.54595 .0625 m
.5375 .0625 L
.5375 .09265 L
.54595 .09265 L
.54595 .0625 L
s
.54595 .09265 m
.5375 .09265 L
.5375 .125 L
.54595 .125 L
.54595 .09265 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{288, 144},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@003Ud0Q43M0034GAd008A0g@24@=d00@AM7Ad0a47M08A0g@00a5dM0024@=d
0Q42M0<A27@24@=d00<AM7@00Q43M08A0W@44@04M14A4Amd0Q43M0034GAd008A0g@24@9d114017@A
4A48M08A0g@00a5dM0024@=d0Q42M0<A1g@24@=d00<AM7@00Q43M08A0g@0115dM7@34Aid000hM004
4GAd4@Ad00HAM7@AM142M0044GAd4@=d00@AM7@A1G@0115dM144M0064GAd4G@A0W@00a5d4@02M003
4GAd00Ad00@AM7@A17@01Q5dM15d4@9d00@AM7@A0g@0115dM14;M08A47@0115dM144M0064GAd4G@A
0W@0115dM143M0044GAd4@Id00@AM7@A17@01Q5dM15d4@9d00<AM1400W@00a5dM003M0044GAd4@Ad
00HAM7@AM142M0044GAd4@=d00@AM7@A2G@24@=d00<AM7@00Q43M0<A17@0039d1142M0044GAd4@Ad
00HAM7@AM142M0044GAd4@Id1142M0044GAd4@Ad00HAM7@AM142M0034GAd009d1A42M0044GAd4@Ad
00HAM7@AM142M0054GAdM1401G@00a5dM008M0044GAd4@md00@AM7@A17@01Q5dM15d4@9d00DAM7Ad
4@05M0034GAd00Ad00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM003M0044GAd4@Ad00HAM7@A
M142M0044GAd4@Id00<AM7@01W@0115dM144M0044GAd4@=d00<AM7@00g@003Qd00@AM7@A17@01Q5d
M15d4@9d00DAM7Ad4@05M0034GAd00=d00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM004M004
4GAd4@Ad00HAM7@AM142M0054GAdM1401G@00a5dM008M0044GAd4@md00@AM7@A17@01Q5dM15d4@9d
00DAM7Ad4@05M0034GAd00Ad00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM003M0044GAd4@Ad
00HAM7@AM142M0054GAdM1401G@00a5dM006M0044GAd4@Ad00@AM7@A0g@00a5dM003M000>7@0115d
M144M0064GAd4G@A0W@01A5dM7@A009d0a46M0044GAd4@Ad00HAM7@AM142M0034G@A008A1g@0115d
M144M0064GAd4G@A0W@00a5dM002M0034G@A008A2g@0115dM14?M0044GAd4@Ad00HAM7@AM142M003
4GAd009d00<AM1400Q47M0044GAd4@Ad00HAM7@AM142M0034G@A008A1W@0115dM144M0064GAd4G@A
0W@01A5dM7@A009d0a49M0044GAd4@Ad00@AM7@A0g@00a5dM003M000>7@0115dM144M0064GAd4G@A
0W@00a5d4@02M0044GAd4@Md00@AM7@A17@01Q5dM15d4@9d00@AM7@A27@0115dM144M0064GAd4G@A
0W@00a5d4@02M0044GAd4@ad00@AM7@A3g@0115dM144M0064GAd4G@A0W@00a5d4@02M0044GAd4@Qd
00@AM7@A17@01Q5dM15d4@9d00@AM7@A1g@0115dM144M0064GAd4G@A0W@00a5d4@02M0044GAd4@Yd
00@AM7@A17@0115dM143M0034GAd00=d000iM08A1W@24@=d0Q42M0@A0W@34@Id0Q46M08A0g@24@=d
0a47M08A1W@24@=d0Q43M08A0g@34@Yd00@AM7@A47@24@Id0Q43M08A0g@24@=d0a47M08A1W@24@=d
0Q43M0<A1W@24@Id0Q43M08A0W@44@9d0a48M0044GAd4@Ad00@AM7@A0W@24@Ed002JM08AL7@24@Id
0Q44M0034GAd00=d003oM25d000TM?4A2g@002Ad00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0
0g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M003
4GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0
0g@00a5dM003M0034GAd00=d00<AM7@01145M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d
00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5d
M003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM009M00097@00a5d
M00KM0034GAd01]d00<AM7@06g@00a5dM00KM0034GAd00EdFA4GM0034GAd00Ud000TM08AOG@34@03
M15d05=d00<AM7@057@24@]d000TM0034GAd07Yd0a4017@A4A5DM0034GAd01Ed00<AM7@02G@002Ad
00<AM7@0NG@34@9d0a5DM0034GAd01Ed00<AM7@02G@002Ad0Q5hM0<A0g@24@03M15d05=d00<AM7@0
57@24@]d000TM0034GAd07Id0a42M08A00Ad4G@AE7@00a5dM00EM0034GAd00Ud000TM0034GAd07Ed
0Q42M08A0gAH4AMd00<AM7@02G@002Ad0Q5dM0<A0W@00a5dM003M0<AE7@00a5dM00DM08A2g@002Ad
00<AM7@0LW@=4@03M15d05=d00<AM7@05G@00a5dM009M00097@00a5dM01aM08A0W@00a5dM003M08A
00Ad4G@AE7@00a5dM00EM0034GAd00Ud000TM08ALG@54@Ad0Q43M0034G@A05Ad00<AM7@057@24@]d
000TM0034GAd071d00<AM14017@24@Ed00<AM140E7@00a5dM00EM0034GAd00Ud000TM0034GAd06md
1142M08A1g@00a5d4@1DM0034GAd01Ed00<AM7@02G@000Ud0Q43M0034GAd008A0g@34@04M14A4@Md
0Q5_M0<A00Ad4A4A2G@34EAd00<AM7@04g@34@]d0008M0044GAd4@Ad00@AM7@A0g@0115dM142M003
4GAd00Ad00<AM7@0KG@34@9d00<AM7@01g@34@03M15d05=d00<AM7@05G@00a5dM009M0000g@44@05
M15dM14017@0115dM143M0034GAd00=d00<AM7@017@00a5dM01/M0<A0W@24@Id0a42M0034G@A05Ad
00<AM7@05G@00a5dM009M00027@0115dM144M0044GAd4@=d00<AM7@00g@00a5dM004M08AKG@01a5d
4G@AM14017@24@EdF14FM08A2g@000Qd00@AM7@A17@0115dM143M0034GAd00<A1g@00a5dM01[M0DA
0W@00a5d4@024@Md00<AM140E7@00a5dM00EM0034GAd00Ud0008M0044GAd4@Ad00@AM7@A0W@24@=d
00<AM7@01W@00a5dM01ZM6`A5g@00a5dM009M0002G@24@Id0Q44M0044GAdM0<A1W@24F]d0a43M0<A
2g@00a5d4@1DM0034GAd01Ad0Q4;M00097@00a5dM01ZM08A0W@24@9d00<AM7@02G@00a5d4@1DM003
4GAd01Ed00<AM7@02G@002Ad00<AM7@0JG@24@9d00<AM7@00W@00a5dM008M0@AE7@00a5dM00EM003
4GAd00Ud000TM08AJW@44@Ed00@AM7Ad1a4017@AM15DM0034GAd01Ad0Q4;M00097@00a5dM01YM08A
1W@54@Qd00<AM140E7@00a5dM00EM0034GAd00Ud000TM0034GAd06Ud0Q43M0<A00=d4G@02W@00a5d
4@1DM0034GAd01Ed00<AM7@02G@002Ad0Q5ZM08A00=d4A4017@00a5dM009M0034G@A05Ad00<AM7@0
57@24@]d000TM0034GAd06Qd1146M0034GAd00Ud00<AM140E7@00a5dM00EM0034GAd00Ud000TM003
4GAd06Qd0a47M0034GAd00Ud00<AM140E7@00a5dM00EM0034GAd00Ud000>M08A0g@00a5dM0024@=d
0a46M08AJGA^4AEd0a4;M0003G@0115dM144M0044GAd4@=d00<AM7@01G@00a5dM01XM0<A1g@00a5d
M009M0034G@A05Ad00<AM7@05G@00a5dM009M00027@44@05M15dM14017@0115dM143M0034GAd00Ed
00<AM7@0J7@34@Md00<AM7@02G@00a5d4@1DM0034GAd01Ed00<AM7@02G@000ed00@AM7@A17@0115d
M143M0034GAd00Ed0Q5ZM0<A1W@00a5dM009M0034G@A05Ad00<AM7@057@24@]d000=M0044GAd4@Ad
00@AM7@A0g@00a5dM005M0034GAd06Ud0Q400g@A4@024@9d00<AM7@02G@00a5d4@1DM0034GAd01Ed
00<AM7@02G@000ed00@AM7@A17@0115dM142M08A1g@00a5dM01YM08A1G@54@Ud00<AM140E7@00a5d
M00EM0034GAd00Ud000>M08A1W@24@Ad00<AM7@01G@24FYd1145M0034GAd00@A1G@00a5d4@1DM003
4GAd01Ad0Q4;M00097@00a5dM01YM08A0W@00a5dM002M0034GAd00Ad1Q400g@AM01CM0034GAd01Ed
00<AM7@02G@002Ad00<AM7@0JW@24@9d0Q42M0034GAd00Ud0a5DM0034GAd01Ed00<AM7@02G@002Ad
0Q5[M0034G@A00=d0a4;M0034G@A05Ad00<AM7@057@24@]d000TM0034GAd06YdK14GM0034GAd00Ud
000TM0034GAd06]d0Q400g@A4@02M0034G@A008A1g@00a5d4@1DM0034GAd01Ed00<AM7@02G@002Ad
0Q5]M08A0W@00a5d4@04M08A1G@00a5d4@1DM0034GAd01Ad0Q4;M00097@00a5dM01/M0034G@A009d
0Q46M0<A0W@00a5d4@1DM0034GAd01Ed00<AM7@02G@002Ad00<AM7@0KG@24@=d00<AM7@01g@34@03
M15d05=d00<AM7@05G@00a5dM009M0002G@24@=d00<AM7@00Q43M08A0W@34@Md0Q5_M08A0W@34@Ud
F14EM0<A2g@000Qd00@AM7@A17@01Q5dM15d4@9d00<AM1400W@00a5dM004M0034GAd06md0Q4017@A
M7@24@Md00<AM140E7@00a5dM00EM0034GAd00Ud0003M0@A00Ed4GAd4@04M0064GAd4G@A0W@00a5d
M002M0034GAd00Ad00<AM7@0L7@34@Ad0Q45M0034G@A05Ad00<AM7@05G@00a5dM009M00027@0115d
M144M0064GAd4G@A0W@00a5dM002M0034GAd00Ad0Q5aM0034G@A00Id0Q43M0034G@A05Ad00<AM7@0
57@24@]d0008M0044GAd4@Ad00HAM7@AM142M0034G@A008A1g@00a5dM01aM0@A1W@24@04M15d4EAd
00<AM7@05G@00a5dM009M00027@0115dM144M0064GAd4G@A0W@0115dM148M0034GAd079d3A400g@A
M01CM0034GAd01Ed00<AM7@02G@000Ud0Q46M08A0g@24@=d0a46M08AM7@24@9d0Q45M0<AE7@00a5d
M00DM08A2g@002Ad00<AM7@0MG@01A5dM7@A00Ad00<AM140E7@00a5dM00EM0034GAd00Ud000TM003
4GAd07Id0Q42M08A0W@00a5d4@1DM0034GAd01Ed00<AM7@02G@002Ad0Q5hM08A0g@34@03M15d05=d
00<AM7@057@24@]d000TM0034GAd07Ud0Q43M0<AE7@00a5dM00EM0034GAd00Ud000TM0034GAd07Yd
0a4017@A4A5DM0034GAd01Ed00<AM7@02G@002Ad0Q5mM0<A00=d4G@0Dg@00a5dM00DM08A2g@002Ad
00<AM7@0OG@44EAd00<AM7@05G@00a5dM009M00097@00a5dM01nM0<AE7@00a5dM00EM0034GAd00Ud
000KM08A1g@24GmdF14EM0<A2g@001Yd00@AM7@A1W@00a5dM01mM08AEW@00a5dM00EM0034GAd00Ud
000JM0044GAd4@Id00<AM7@0O7@34EId00<AM7@05G@00a5dM009M0006W@0115dM146M08ANg@54EId
00<AM7@057@24@]d000JM0044GAd4@Id00<AM7@0NG@64EId00<AM7@05G@00a5dM009M0006W@0115d
M146M0034GAd07Qd11400g@A4@1FM0034GAd01Ed00<AM7@02G@001]d0Q47M08AN7@64@03M15d05Ed
00<AM7@057@24@]d000TM0034GAd07Id1142M0034G@A05Id00<AM7@05G@00a5dM009M00097@00a5d
M01eM0<A00Md4GAd4G@A05Id00<AM7@05G@00a5dM009M00097@24GEd0a401W@AM7@AM08AEW@00a5d
M00DM08A2g@002Ad00<AM7@0LW@44@9d00DAM7@AM0024EId00<AM7@05G@00a5dM009M00097@00a5d
M01aM0@A0W@01Q5dM7@AM08AEW@00a5dM00EM0034GAd00Ud000TM08ALG@24@03M15d008A0g@00a5d
M0024EId00<AM7@057@24@]d000TM0034GAd06md0Q4017@AM7@24@=d00<AM1400Q5FM0034GAd01Ed
00<AM7@02G@002Ad00<AM7@0KW@0115dM143M0034GAd009d00<AM1400Q5FM0034GAd01Ed00<AM7@0
2G@000Ud0Q43M0034GAd008A0g@24@9d0a47M08AKW@24@9d00<AM7@00Q44M08A00=d4A40EW@00a5d
M00CM0<A2g@000Qd00@AM7@A17@01Q5dM15d4@9d00<AM1400W@00a5dM004M0034GAd06ad0Q42M007
4GAdM15d4@02M08A0WAI4AMd00<AM7@02G@000Qd00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5d
M004M0034GAd06]d00DAM15d4@03M0044GAd4@9d00@AM7Ad0Q5FM0034GAd01Ed00<AM7@02G@000Qd
00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM004M08AJg@00a5dM0024@=d00DAM7Ad4@02M003
4GAd00<AEW@00a5dM00DM08A2g@000Qd00@AM7@A17@01Q5dM15d4@9d00<AM1400Q47M0034GAd06Yd
0Q400g@AM003M0034GAd009d0Q4017@A4G@24EId00<AM7@05G@00a5dM009M00027@0115dM144M006
4GAd4G@A0W@0115dM148M0034GAd06Ud00<AM7@0JQ4GM0034GAd00Ud0009M08A1W@24@=d0Q43M0<A
1W@24FYd00@AM7@A17@0115dM7@24@03M15d00=d0Q5FM0034GAd01Ad0Q4;M00097@00a5dM01XM003
4GAd008A17@0115dM143M0034GAd009d0Q5FM0034GAd01Ed00<AM7@02G@002Ad00<AM7@0J7@00a5d
M0024@Ad0a45M0044GAdM08AEW@00a5dM00EM0034GAd00Ud000TM08AJ7@01A5dM7@A00Ed00<AM7@0
1G@24@9d0Q5FM0034GAd01Ad0Q4;M00097@00a5dM01WM0034GAd008A17@24@Md0Q42M08AEW@00a5d
M00EM0034GAd00Ud000TM0034GAd06Id00@AM7Ad0Q42M08A00=d4G@01W@0115d4G@24EId00<AM7@0
5G@00a5dM009M00097@24FMd00PAM7@AM15d4@=d00<AM7@01G@01Q5dM15d4EId00<AM7@057@24@]d
000TM0034GAd06Ed00@AM7Ad1144M0034GAd00Id00<AM7@00Q5FM0034GAd01Ed00<AM7@02G@002Ad
00<AM7@0IG@0115dM7@24@Id00<AM7@01W@00a5dM0024EId00<AM7@05G@00a5dM009M0003W@24@=d
00<AM7@00Q43M0<A1W@24FEd00@AM7Ad0Q400g@A4@04M0034GAd00Id00@AM7AdF14EM0<A2g@000ed
00@AM7@A17@0115dM143M0034GAd00Ed00<AM7@0I7@00a5dM0024@Ad00DAM7Ad4@08M0054GAdM140
EW@00a5dM00EM0034GAd00Ud000=M0044GAd4@Ad00@AM7@A0g@00a5dM005M0034GAd06=d00HAM7@A
M145M0044GAd4@Ud00@AM7@AEW@00a5dM00EM0034GAd00Ud000=M0044GAd4@Ad00@AM7@A0g@00a5d
M005M08AI7@34@03M15d00Id0a49M0044GAd4EId00<AM7@057@24@]d000=M0044GAd4@Ad00@AM7@A
0g@00a5dM005M0034GAd069d0Q43M0034GAd00Md00<AM7@01g@0115dM15FM0034GAd01Ed00<AM7@0
2G@000ed00@AM7@A17@0115dM142M08A1g@00a5dM01RM0054GAdM1402W@34@Md00@AM7@AEW@00a5d
M00EM0034GAd00Ud000>M08A1W@24@Ad00<AM7@01G@24FAd0Q400g@AM009M0044GAd4@Id00@AM7@A
EW@00a5dM00DM08A2g@002Ad00<AM7@0Hg@0115d4A4:M0044GAdM08A1G@34EId00<AM7@05G@00a5d
M009M00097@00a5dM01TM0@A2G@00a5dM003M0034GAd009d0a5FM0034GAd01Ed00<AM7@02G@002Ad
0Q5VM0HA1W@00a5dM003M0HA00=d4G@0EG@00a5dM00DM08A2g@002Ad00<AM7@0IW@00a5dM01]4AMd
00<AM7@02G@002Ad00<AM7@0Ig@24@9d00<AM7@017@00a5dM006M08A00=d4G@0EG@00a5dM00EM003
4GAd00Ud000TM08AJW@00a5dM0024@Ad00<AM7@01g@34EId00<AM7@057@24@]d000TM0034GAd06Yd
00DAM7Ad4@04M0034GAd00Id00<AM140Ea4GM0034GAd00Ud000TM0034GAd06]d00@AM7Ad0Q43M003
4GAd00Id0Q5FM0034GAd01Ed00<AM7@02G@000Ud0Q43M0034GAd008A0g@34@04M14A4@Md0Q5]M08A
0g@24@03M15d00Md0Q5FM0034GAd01=d0a4;M00027@0115dM144M0044GAd4@=d00@AM7@A0W@00a5d
M004M0034GAd06id00<AM7@00W@00a5d4@07M08AEW@00a5dM00EM0034GAd00Ud0008M0044GAd4@Ad
00@AM7@A0g@00a5dM003M0034GAd00Ad00<AM7@0Kg@00a5dM002M0<A1W@24EId00<AM7@05G@00a5d
M009M00027@0115dM144M0044GAd4@=d00<AM7@00g@00a5dM004M08ALG@00a5dM003M0034GAd00Ad
0Q5FM0034GAd01Ad0Q4;M00027@0115dM144M0044GAd4@=d00<AM7@00a47M0034GAd075d0Q44M08A
17@24EId00<AM7@05G@00a5dM009M00027@0115dM144M0044GAd4@9d0Q43M0034GAd00Id00<AM7@0
Lg@01a5dM7@AM1400W@34EId00<AM7@05G@00a5dM009M0002G@24@Id0Q44M0044GAdM0<A1W@24GEd
00HAM7Ad4G@54EId00<AM7@057@24@]d000TM0034GAd07Ed0Q42M0034GAd05XA5g@00a5dM009M000
97@00a5dM01gM0034G@A009d0a5FM0034GAd01Ed00<AM7@02G@002Ad0Q5iM0074G@AM15d4@1FM003
4GAd01Ad0Q4;M00097@00a5dM01iM0064G@A4G@AEW@00a5dM00EM0034GAd00Ud000TM0034GAd07Yd
0Q400g@A4@1FM0034GAd01Ed00<AM7@02G@002Ad0Q5mM0<AEW@00a5dM00DM08A2g@002Ad00<AM7@0
OGAI4AMd00<AM7@02G@002Ad00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M003
4GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0
0g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M003
4GAd00=d00@AM14A0W@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0
0g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M003
4GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM009M0003W@24@=d00<AM7@0
0Q42M0@A1WCa4@]d000=M0044GAd4@Ad00@AM7@A0W@00a5dM03oM0=d000=M0044GAd4@Ad00@AM7@A
0g@00a5dM03oM09d000=M0044GAd4@Ad00@AM7@A0g@00a5dM03oM09d000=M0044GAd4@Ad00@AM7@A
17@00a5dM03oM05d000=M0044GAd4@Ad00HAM7@AM142M0034GAd0?md0G@000id0Q46M08A0g@24Omd
17@00?md8G@00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-0.0130387, -0.0252746, 
  8.33985*^-5, 0.000333594}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Flexible Lenses", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell["ShowSystem[FlexibleLens, Axes->True];", "Input",
  CellLabel->"In[56]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.49507 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.237324 1.5606 1.51517e-16 1.5606 [
[.13763 .13498 -8.36108 -10.9375 ]
[.13763 .13498 .63892 0 ]
[.24117 .09129 -24.0399 -11 ]
[.24117 .09129 2.46008 0 ]
[.34759 .04639 -19.0345 -10.9375 ]
[.34759 .04639 2.46552 0 ]
[.45702 .00023 -22.8823 -11 ]
[.45702 .00023 3.61771 0 ]
[.01503 1.06963 -15.7145 0 ]
[.01503 1.06963 12.723 10.9375 ]
[.17582 1.19707 -15.2332 0 ]
[.17582 1.19707 13.2043 10.9375 ]
[.31949 1.31093 -4.69119 0 ]
[.31949 1.31093 4.30881 10.9375 ]
[.44865 1.4133 -10.9391 0 ]
[.44865 1.4133 10.5609 10.9375 ]
[.56538 1.50581 -10.7058 0 ]
[.56538 1.50581 10.7942 10.9375 ]
[.07415 .19806 -28.4375 -3.18123 ]
[.07415 .19806 0 7.75627 ]
[.05454 .37645 -28.4375 -3.30628 ]
[.05454 .37645 0 7.63122 ]
[.03316 .57094 -9 -3.44336 ]
[.03316 .57094 0 7.49414 ]
[.00977 .78379 -21.5 -3.5943 ]
[.00977 .78379 0 7.3432 ]
[-0.01593 1.01774 -21.5 -3.7613 ]
[-0.01593 1.01774 0 7.1762 ]
[ 0 0 0 0 ]
[ 1 1.49507 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09401 .17347 m
.50657 0 L
s
.15034 .14978 m
.15669 .15719 L
s
gsave
.13763 .13498 -69.3611 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25349 .10641 m
.25964 .11398 L
s
gsave
.24117 .09129 -85.0399 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.3595 .06184 m
.36545 .06957 L
s
gsave
.34759 .04639 -80.0345 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.46849 .01601 m
.47423 .0239 L
s
gsave
.45702 .00023 -83.8823 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17074 .1412 m
.17453 .14567 L
s
.19126 .13258 m
.19503 .13706 L
s
.21189 .1239 m
.21563 .1284 L
s
.23263 .11518 m
.23635 .1197 L
s
.27445 .0976 m
.27813 .10215 L
s
.29554 .08873 m
.29919 .09331 L
s
.31674 .07982 m
.32036 .08441 L
s
.33806 .07085 m
.34166 .07547 L
s
.38105 .05278 m
.3846 .05743 L
s
.40273 .04366 m
.40625 .04834 L
s
.42453 .0345 m
.42802 .03919 L
s
.44645 .02528 m
.44992 .02999 L
s
.13004 .15832 m
.13387 .16274 L
s
.10985 .16681 m
.11371 .17121 L
s
.49066 .00669 m
.49407 .01144 L
s
.25 Mabswid
0 1.03666 m
.57632 1.49507 L
s
.01707 1.05023 m
.01809 1.04053 L
s
gsave
.01503 1.06963 -76.7145 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.17721 1.17761 m
.1779 1.16788 L
s
gsave
.17582 1.19707 -76.2332 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32032 1.29145 m
.32074 1.2817 L
s
gsave
.31949 1.31093 -65.6912 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.44899 1.39379 m
.44916 1.38404 L
s
gsave
.44865 1.4133 -71.9391 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5653 1.48631 m
.56526 1.47655 L
s
gsave
.56538 1.50581 -71.7058 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.0506 1.0769 m
.05117 1.07108 L
s
.08336 1.10296 m
.08389 1.09713 L
s
.11536 1.12841 m
.11585 1.12258 L
s
.14663 1.15329 m
.14709 1.14745 L
s
.2071 1.20139 m
.20748 1.19555 L
s
.23634 1.22464 m
.23668 1.2188 L
s
.26494 1.24739 m
.26525 1.24155 L
s
.29293 1.26966 m
.29321 1.26381 L
s
.34714 1.31278 m
.34736 1.30693 L
s
.3734 1.33366 m
.37359 1.32781 L
s
.39912 1.35412 m
.39927 1.34827 L
s
.42431 1.37416 m
.42444 1.36831 L
s
.47318 1.41304 m
.47326 1.40718 L
s
.4969 1.4319 m
.49695 1.42604 L
s
.52015 1.45039 m
.52017 1.44454 L
s
.54294 1.46852 m
.54294 1.46267 L
s
.25 Mabswid
.09401 .17347 m
0 1.03666 L
s
.09215 .19053 m
.10115 .18677 L
s
gsave
.07415 .19806 -89.4375 -7.18123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.07268 .36928 m
.08175 .36569 L
s
gsave
.05454 .37645 -89.4375 -7.30628 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.05146 .56416 m
.0606 .56077 L
s
gsave
.03316 .57094 -70 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02823 .77746 m
.03745 .7743 L
s
gsave
.00977 .78379 -82.5 -7.5943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.00269 1.01192 m
.012 1.00902 L
s
gsave
-0.01593 1.01774 -82.5 -7.7613 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.08838 .22509 m
.09379 .22285 L
s
.08456 .26023 m
.08997 .25801 L
s
.08067 .29596 m
.08609 .29376 L
s
.07671 .33231 m
.08214 .33013 L
s
.06858 .4069 m
.07404 .40477 L
s
.06442 .44518 m
.06988 .44307 L
s
.06017 .48413 m
.06564 .48205 L
s
.05585 .52379 m
.06133 .52173 L
s
.04698 .60527 m
.05248 .60326 L
s
.04242 .64713 m
.04793 .64515 L
s
.03778 .68977 m
.0433 .68781 L
s
.03305 .7332 m
.03857 .73128 L
s
.02332 .82256 m
.02886 .82069 L
s
.01831 .86853 m
.02387 .8667 L
s
.01321 .9154 m
.01877 .91359 L
s
.008 .96319 m
.01358 .96141 L
s
0 0 m
1 0 L
1 1.49507 L
0 1.49507 L
closepath
clip
newpath
.5 Mabswid
.556 .73575 m
.51391 .63465 L
s
.58415 .7266 m
.556 .73575 L
s
.556 .73575 m
.50697 .76386 L
s
.5882 .84186 m
.556 .73575 L
s
.60901 .94814 m
.5882 .84186 L
s
.5882 .84186 m
.6165 .83307 L
s
.52922 .83735 m
.5882 .84186 L
s
.6165 .83307 m
.58415 .7266 L
s
.58415 .7266 m
.7231 .68141 L
s
.58415 .7266 m
.5421 .62507 L
s
.53604 .75445 m
.58415 .7266 L
s
.63764 .93965 m
.6165 .83307 L
s
.6165 .83307 m
.75618 .78968 L
s
.55841 .82821 m
.6165 .83307 L
s
.51391 .63465 m
.5421 .62507 L
s
.51391 .63465 m
.46371 .54334 L
s
.47765 .69409 m
.51391 .63465 L
s
.60901 .94814 m
.63764 .93965 L
s
.54323 .91072 m
.60901 .94814 L
s
.5421 .62507 m
.68124 .5778 L
s
.5421 .62507 m
.49212 .5333 L
s
.50675 .68438 m
.5421 .62507 L
s
.63764 .93965 m
.77896 .89775 L
s
.57265 .90178 m
.63764 .93965 L
s
.46371 .54334 m
.49212 .5333 L
s
.44275 .63182 m
.46371 .54334 L
s
.75618 .78968 m
.7231 .68141 L
s
.7231 .68141 m
.87202 .63297 L
s
.7231 .68141 m
.68124 .5778 L
s
.67966 .70796 m
.7231 .68141 L
s
.77896 .89775 m
.75618 .78968 L
s
.75618 .78968 m
.90589 .74318 L
s
.70254 .78302 m
.75618 .78968 L
s
.49212 .5333 m
.63235 .48372 L
s
.472 .62178 m
.49212 .5333 L
s
.5481 .98001 m .64628 1.04134 L .61716 1.04959 L .656 .751 .92 r
F
0 g
.61161 1.14093 m
.61716 1.04959 L
s
.60901 .94814 m
.61492 1.02175 L
s
.68124 .5778 m
.8304 .52712 L
s
.68124 .5778 m
.63235 .48372 L
s
.65049 .6364 m
.68124 .5778 L
s
.5481 .98001 m .57786 .97124 L .64628 1.04134 L .656 .751 .92 r
F
0 g
.64138 1.13282 m
.64628 1.04134 L
s
.63764 .93965 m
.64628 1.04134 L
s
.61716 1.04959 m
.64628 1.04134 L
s
.77896 .89775 m
.93048 .85282 L
s
.52922 .83735 m
.50697 .76386 L
s
.50697 .76386 m
.47765 .69409 L
s
.45395 .79425 m
.50697 .76386 L
s
.87202 .63297 m
.90589 .74318 L
s
.8304 .52712 m
.87202 .63297 L
s
.54323 .91072 m
.52922 .83735 L
s
.4655 .83249 m
.52922 .83735 L
s
.90589 .74318 m
.93048 .85282 L
s
.40751 .46671 m .43353 .57029 L .40401 .58067 L .544 .324 .532 r
F
.40751 .46671 m .4363 .45617 L .43353 .57029 L F
0 g
.43513 .50437 m
.46371 .54334 L
s
.40751 .46671 m
.4363 .45617 L
s
.34788 .4097 m
.40751 .46671 L
s
.4363 .45617 m
.49212 .5333 L
s
.63235 .48372 m
.78277 .43053 L
s
.55841 .82821 m
.53604 .75445 L
s
.48401 .78457 m
.53604 .75445 L
s
.53604 .75445 m
.50675 .68438 L
s
.57265 .90178 m
.55841 .82821 L
s
.49562 .82295 m
.55841 .82821 L
s
.47765 .69409 m
.44275 .63182 L
s
.43861 .7581 m
.47765 .69409 L
s
.37722 .39867 m
.4363 .45617 L
s
.78277 .43053 m
.8304 .52712 L
s
.50675 .68438 m
.472 .62178 L
s
.46868 .74826 m
.50675 .68438 L
s
.72491 .92789 m .94438 .95681 L .79009 1.00056 L .656 .751 .92 r
F
0 g
.78845 1.09277 m
.79009 1.00056 L
s
.77896 .89775 m
.78305 .93555 L
s
.64628 1.04134 m
.79009 1.00056 L
s
.59174 1.2165 m
.61161 1.14093 L
s
.61161 1.14093 m
.64138 1.13282 L
s
.54324 1.04124 m
.61161 1.14093 L
s
.62227 1.20845 m
.64138 1.13282 L
s
.64138 1.13282 m
.78845 1.09277 L
s
.57345 1.03256 m
.64138 1.13282 L
s
.45053 .71622 m
.472 .62178 L
s
.47467 .90603 m .57786 .97124 L .5481 .98001 L .656 .751 .92 r
F
0 g
.54324 1.04124 m
.5481 .98001 L
s
.54323 .91072 m
.54607 .95115 L
s
.5481 .98001 m
.61716 1.04959 L
s
.70254 .78302 m
.67966 .70796 L
s
.63261 .73672 m
.67966 .70796 L
s
.67966 .70796 m
.65049 .6364 L
s
.47467 .90603 m .50509 .89669 L .57786 .97124 L .656 .751 .92 r
F
0 g
.57345 1.03256 m
.57786 .97124 L
s
.57786 .97124 m
.64628 1.04134 L
s
.47257 .87052 m
.54323 .91072 L
s
.57265 .90178 m
.57786 .97124 L
s
.50281 .86109 m
.57265 .90178 L
s
.71795 .85766 m
.70254 .78302 L
s
.6445 .7758 m
.70254 .78302 L
s
.57851 .40413 m .73623 .4639 L .57945 .51901 L .544 .324 .532 r
F
0 g
.61652 .57218 m
.62916 .50154 L
s
.57851 .40413 m .73117 .34827 L .73623 .4639 L .544 .324 .532 r
F
0 g
.4363 .45617 m
.57851 .40413 L
s
.73117 .34827 m
.78277 .43053 L
s
.57851 .40413 m
.73117 .34827 L
s
.52221 .34413 m
.57851 .40413 L
s
.65049 .6364 m
.61652 .57218 L
s
.72491 .92789 m .88286 .88133 L .94438 .95681 L .656 .751 .92 r
F
0 g
.94438 .95681 m
.94637 1.04976 L
s
.93048 .85282 m
.94438 .95681 L
s
.79009 1.00056 m
.94438 .95681 L
s
.71795 .85766 m
.77896 .89775 L
s
.40401 .58067 m .43062 .69049 L .40033 .70068 L .544 .324 .532 r
F
0 g
.42037 .72623 m
.42869 .69114 L
s
.40401 .58067 m .43353 .57029 L .43062 .69049 L .544 .324 .532 r
F
0 g
.40401 .58067 m
.40751 .46671 L
s
.43238 .61812 m
.44275 .63182 L
s
.43083 .68213 m
.44275 .63182 L
s
.43353 .57029 m
.472 .62178 L
s
.43353 .57029 m
.4363 .45617 L
s
.36351 .54408 m
.40401 .58067 L
s
.34788 .4097 m
.37722 .39867 L
s
.34788 .4097 m
.28799 .3772 L
s
.36351 .54408 m
.34788 .4097 L
s
.39342 .53337 m
.43353 .57029 L
s
.77323 1.16867 m
.78845 1.09277 L
s
.78845 1.09277 m
.94637 1.04976 L
s
.72276 .98967 m
.78845 1.09277 L
s
.37722 .39867 m
.52221 .34413 L
s
.37722 .39867 m
.31801 .3657 L
s
.39342 .53337 m
.37722 .39867 L
s
.51743 1.09355 m
.54324 1.04124 L
s
.46715 .93813 m
.54324 1.04124 L
s
.54787 1.08498 m
.57345 1.03256 L
s
.49753 .92892 m
.57345 1.03256 L
s
.55749 1.27047 m
.59174 1.2165 L
s
.59174 1.2165 m
.62227 1.20845 L
s
.51743 1.09355 m
.59174 1.2165 L
s
.4655 .83249 m
.45395 .79425 L
s
.45395 .79425 m
.43861 .7581 L
s
.65551 .85052 m .88286 .88133 L .72491 .92789 L .656 .751 .92 r
F
0 g
.72276 .98967 m
.72491 .92789 L
s
.71795 .85766 m
.71808 .859 L
s
.72491 .92789 m
.79009 1.00056 L
s
.57786 .97124 m
.72491 .92789 L
s
.47257 .87052 m
.4655 .83249 L
s
.58887 1.26238 m
.62227 1.20845 L
s
.62227 1.20845 m
.77323 1.16867 L
s
.54787 1.08498 m
.62227 1.20845 L
s
.43861 .7581 m
.42037 .72623 L
s
.67801 .28553 m
.73117 .34827 L
s
.49562 .82295 m
.48401 .78457 L
s
.48401 .78457 m
.46868 .74826 L
s
.50281 .86109 m
.49562 .82295 L
s
.46868 .74826 m
.45053 .71622 L
s
.36351 .54408 m
.32363 .52507 L
s
.37969 .68316 m
.36351 .54408 L
s
.39645 .82721 m .50509 .89669 L .47467 .90603 L .656 .751 .92 r
F
0 g
.46715 .93813 m
.47467 .90603 L
s
.47257 .87052 m
.4729 .8761 L
s
.47467 .90603 m
.5481 .98001 L
s
.39342 .53337 m
.354 .51406 L
s
.39342 .53337 m
.41018 .67282 L
s
.57945 .51901 m .74157 .58593 L .58043 .64012 L .544 .324 .532 r
F
0 g
.5996 .66671 m
.60589 .63156 L
s
.61734 .69961 m
.65049 .6364 L
s
.57945 .51901 m .73623 .4639 L .74157 .58593 L .544 .324 .532 r
F
0 g
.57851 .40413 m
.57945 .51901 L
s
.43353 .57029 m
.57945 .51901 L
s
.54127 .48044 m
.57945 .51901 L
s
.73117 .34827 m
.73623 .4639 L
s
.46997 1.13337 m
.51743 1.09355 L
s
.44751 .96551 m
.51743 1.09355 L
s
.94637 1.04976 m
.9355 1.12591 L
s
.52221 .34413 m
.67801 .28553 L
s
.52221 .34413 m
.46648 .30879 L
s
.54127 .48044 m
.52221 .34413 L
s
.39645 .82721 m .42755 .81725 L .50509 .89669 L .656 .751 .92 r
F
0 g
.49753 .92892 m
.50509 .89669 L
s
.50509 .89669 m
.57786 .97124 L
s
.44056 .83058 m
.4655 .83249 L
s
.50281 .86109 m
.50509 .89669 L
s
.40033 .70068 m .42755 .81725 L .39645 .82721 L .544 .324 .532 r
F
.40033 .70068 m .43062 .69049 L .42755 .81725 L F
0 g
.40033 .70068 m
.40401 .58067 L
s
.42775 .80927 m
.45395 .79425 L
s
.42859 .77452 m
.43861 .7581 L
s
.43062 .69049 m
.45053 .71622 L
s
.43062 .69049 m
.43353 .57029 L
s
.37969 .68316 m
.40033 .70068 L
s
.50087 1.12478 m
.54787 1.08498 L
s
.47812 .95631 m
.54787 1.08498 L
s
.71118 1.039 m
.72276 .98967 L
s
.65385 .88154 m
.72276 .98967 L
s
.44751 .96551 m
.46715 .93813 L
s
.41018 .67282 m
.43062 .69049 L
s
.65551 .85052 m .81728 .80086 L .88286 .88133 L .656 .751 .92 r
F
0 g
.88286 .88133 m
.94438 .95681 L
s
.65231 .81452 m
.69067 .83973 L
s
.28799 .3772 m
.31801 .3657 L
s
.28799 .3772 m
.23165 .37359 L
s
.32363 .52507 m
.28799 .3772 L
s
.47812 .95631 m
.49753 .92892 L
s
.74414 1.22234 m
.77323 1.16867 L
s
.77323 1.16867 m
.9355 1.12591 L
s
.71118 1.039 m
.77323 1.16867 L
s
.6445 .7758 m
.63261 .73672 L
s
.63261 .73672 m
.61734 .69961 L
s
.65231 .81452 m
.6445 .7758 L
s
.37969 .68316 m
.35978 .67505 L
s
.31801 .3657 m
.46648 .30879 L
s
.31801 .3657 m
.26245 .36168 L
s
.354 .51406 m
.31801 .3657 L
s
.42295 .98435 m
.44751 .96551 L
s
.61734 .69961 m
.5996 .66671 L
s
.32363 .52507 m
.28701 .52597 L
s
.35978 .67505 m
.32363 .52507 L
s
.41018 .67282 m
.39051 .66456 L
s
.45378 .97513 m
.47812 .95631 L
s
.54127 .48044 m
.50425 .45962 L
s
.56101 .62163 m
.54127 .48044 L
s
.42252 1.1518 m
.46997 1.13337 L
s
.46997 1.13337 m
.55749 1.27047 L
s
.42295 .98435 m
.46997 1.13337 L
s
.5073 1.29781 m
.55749 1.27047 L
s
.55749 1.27047 m
.58887 1.26238 L
s
.354 .51406 m
.31791 .51472 L
s
.39051 .66456 m
.354 .51406 L
s
.62621 .24757 m
.67801 .28553 L
s
.58148 .76797 m .81728 .80086 L .65551 .85052 L .656 .751 .92 r
F
0 g
.65385 .88154 m
.65551 .85052 L
s
.65551 .85052 m
.72491 .92789 L
s
.50509 .89669 m
.65551 .85052 L
s
.45393 1.14308 m
.50087 1.12478 L
s
.50087 1.12478 m
.58887 1.26238 L
s
.45378 .97513 m
.50087 1.12478 L
s
.53929 1.28962 m
.58887 1.26238 L
s
.58887 1.26238 m
.74414 1.22234 L
s
.39981 .9917 m
.42295 .98435 L
s
.35978 .67505 m
.34194 .67717 L
s
.69034 1.07207 m
.71118 1.039 L
s
.64729 .90549 m
.71118 1.039 L
s
.58043 .64012 m .74722 .71491 L .58148 .76797 L .544 .324 .532 r
F
.58043 .64012 m .74157 .58593 L .74722 .71491 L F
0 g
.57945 .51901 m
.58043 .64012 L
s
.43062 .69049 m
.58043 .64012 L
s
.73623 .4639 m
.74157 .58593 L
s
.56101 .62163 m
.58043 .64012 L
s
.43089 .98241 m
.45378 .97513 L
s
.39051 .66456 m
.37295 .66657 L
s
.64729 .90549 m
.65385 .88154 L
s
.9355 1.12591 m
.91125 1.17925 L
s
.39645 .82721 m .4017 .95799 L .37009 .96757 L .544 .324 .532 r
F
0 g
.39914 .95877 m
.39981 .9917 L
s
.38202 .98603 m
.38408 .96333 L
s
.39645 .82721 m .42755 .81725 L .4017 .95799 L .544 .324 .532 r
F
0 g
.42115 .8521 m
.47467 .90603 L
s
.41917 .86287 m
.46715 .93813 L
s
.416 .88016 m
.44751 .96551 L
s
.41046 .91031 m
.42295 .98435 L
s
.31294 .74307 m .42755 .81725 L .39645 .82721 L .656 .751 .92 r
F
0 g
.36115 .93842 m
.39645 .82721 L
s
.35003 .9023 m
.39645 .82721 L
s
.33386 .86309 m
.39645 .82721 L
s
.32135 .82147 m
.39645 .82721 L
s
.34194 .67717 m
.38215 .78787 L
s
.39645 .82721 m
.39645 .82721 L
s
.35978 .67505 m
.38785 .79156 L
s
.37969 .68316 m
.39266 .79467 L
s
.39735 .7977 m
.40033 .70068 L
s
.46648 .30879 m
.62621 .24757 L
s
.46648 .30879 m
.41493 .30273 L
s
.50425 .45962 m
.46648 .30879 L
s
.38202 .98603 m
.39981 .9917 L
s
.39981 .9917 m
.42252 1.1518 L
s
.34194 .67717 m
.32747 .68972 L
s
.28701 .52597 m
.34194 .67717 L
s
.31294 .74307 m .34476 .73243 L .42755 .81725 L .656 .751 .92 r
F
0 g
.42755 .81725 m
.43089 .98241 L
s
.41337 .97662 m
.42755 .81725 L
s
.39297 .92864 m
.42755 .81725 L
s
.38196 .89233 m
.42755 .81725 L
s
.36609 .85284 m
.42755 .81725 L
s
.35351 .81105 m
.42755 .81725 L
s
.34623 .76987 m
.42755 .81725 L
s
.34909 .70145 m
.42755 .81725 L
s
.35876 .67905 m
.42755 .81725 L
s
.37295 .66657 m
.42755 .81725 L
s
.42755 .81725 m
.42755 .81725 L
s
.32747 .68972 m
.35328 .74116 L
s
.31752 .71213 m
.33392 .73605 L
s
.31422 .78043 m
.39645 .82721 L
s
.39051 .66456 m
.42755 .81725 L
s
.42755 .81725 m
.45378 .97513 L
s
.42755 .81725 m
.47812 .95631 L
s
.41018 .67282 m
.42755 .81725 L
s
.42755 .81725 m
.49753 .92892 L
s
.42755 .81725 m
.43062 .69049 L
s
.42755 .81725 m
.48401 .78457 L
s
.42755 .81725 m
.49562 .82295 L
s
.42755 .81725 m
.46868 .74826 L
s
.42755 .81725 m
.50281 .86109 L
s
.42755 .81725 m
.45053 .71622 L
s
.42755 .81725 m
.50509 .89669 L
s
.56101 .62163 m
.54258 .61266 L
s
.41337 .97662 m
.43089 .98241 L
s
.43089 .98241 m
.45393 1.14308 L
s
.28701 .52597 m
.25641 .54807 L
s
.23165 .37359 m
.28701 .52597 L
s
.37295 .66657 m
.35876 .67905 L
s
.31791 .51472 m
.37295 .66657 L
s
.38773 1.14362 m
.42252 1.1518 L
s
.42252 1.1518 m
.5073 1.29781 L
s
.63612 .92062 m
.64729 .90549 L
s
.50425 .45962 m
.47088 .45905 L
s
.54258 .61266 m
.50425 .45962 L
s
.58148 .76797 m .74722 .71491 L .81728 .80086 L .656 .751 .92 r
F
0 g
.81728 .80086 m
.88286 .88133 L
s
.23165 .37359 m
.18317 .40207 L
s
.26245 .36168 m
.23165 .37359 L
s
.70171 1.24804 m
.74414 1.22234 L
s
.74414 1.22234 m
.91125 1.17925 L
s
.69034 1.07207 m
.74414 1.22234 L
s
.31791 .51472 m
.28789 .53666 L
s
.26245 .36168 m
.31791 .51472 L
s
.41967 1.13468 m
.45393 1.14308 L
s
.45393 1.14308 m
.53929 1.28962 L
s
.32747 .68972 m
.25641 .54807 L
s
.32747 .68972 m
.31752 .71213 L
s
.66103 1.08561 m
.69034 1.07207 L
s
.63612 .92062 m
.69034 1.07207 L
s
.26245 .36168 m
.21482 .38987 L
s
.41493 .30273 m
.26245 .36168 L
s
.54258 .61266 m
.5264 .61412 L
s
.41337 .97662 m
.41967 1.13468 L
s
.35876 .67905 m
.34909 .70145 L
s
.62096 .9256 m
.63612 .92062 L
s
.57919 .23923 m
.62621 .24757 L
s
.44966 1.29214 m
.5073 1.29781 L
s
.5073 1.29781 m
.53929 1.28962 L
s
.58148 .76797 m .7532 .85143 L .58258 .90316 L .544 .324 .532 r
F
0 g
.61302 .89393 m
.62096 .9256 L
s
.59966 .89798 m
.6027 .91976 L
s
.62524 .89022 m
.63612 .92062 L
s
.63811 .88632 m
.64729 .90549 L
s
.58148 .76797 m .74722 .71491 L .7532 .85143 L .544 .324 .532 r
F
.50232 .67972 m .74722 .71491 L .58148 .76797 L .656 .751 .92 r
F
0 g
.56202 .8767 m
.58148 .76797 L
s
.54256 .84216 m
.58148 .76797 L
s
.52572 .80206 m
.58148 .76797 L
s
.51281 .75944 m
.58148 .76797 L
s
.50482 .7176 m
.58148 .76797 L
s
.51366 .62626 m
.54197 .68541 L
s
.5264 .61412 m
.55246 .68692 L
s
.58148 .76797 m
.58148 .76797 L
s
.54258 .61266 m
.5615 .68822 L
s
.58043 .64012 m
.58085 .691 L
s
.42755 .81725 m
.58148 .76797 L
s
.56101 .62163 m
.57051 .68951 L
s
.37009 .96757 m .39763 1.09939 L .36513 1.10866 L .544 .324 .532 r
F
0 g
.38202 .98603 m
.38371 1.03278 L
s
.38624 1.10264 m
.38773 1.14362 L
s
.37009 .96757 m .4017 .95799 L .39763 1.09939 L .544 .324 .532 r
F
0 g
.37009 .96757 m
.39645 .82721 L
s
.4017 .95799 m
.41337 .97662 L
s
.4017 .95799 m
.42755 .81725 L
s
.36115 .93842 m
.37009 .96757 L
s
.48248 1.28365 m
.53929 1.28962 L
s
.53929 1.28962 m
.70171 1.24804 L
s
.5264 .61412 m
.51366 .62626 L
s
.47088 .45905 m
.5264 .61412 L
s
.39297 .92864 m
.4017 .95799 L
s
.25641 .54807 m
.18317 .40207 L
s
.25641 .54807 m
.23452 .59113 L
s
.6027 .91976 m
.62096 .9256 L
s
.62096 .9256 m
.66103 1.08561 L
s
.47088 .45905 m
.44374 .48015 L
s
.41493 .30273 m
.47088 .45905 L
s
.91125 1.17925 m
.87386 1.20396 L
s
.2236 .65306 m .34476 .73243 L .31294 .74307 L .656 .751 .92 r
F
0 g
.31294 .74307 m
.31422 .78043 L
s
.31719 .71437 m
.31752 .71213 L
s
.28789 .53666 m
.35876 .67905 L
s
.31294 .74307 m
.39645 .82721 L
s
.28789 .53666 m
.21482 .38987 L
s
.28789 .53666 m
.26656 .57966 L
s
.35003 .9023 m
.36115 .93842 L
s
.36115 .93842 m
.34102 1.05243 L
s
.41967 1.13468 m
.48248 1.28365 L
s
.41493 .30273 m
.37163 .32945 L
s
.57919 .23923 m
.41493 .30273 L
s
.2236 .65306 m .25615 .64165 L .34476 .73243 L .656 .751 .92 r
F
0 g
.34476 .73243 m
.34623 .76987 L
s
.34476 .73243 m
.42755 .81725 L
s
.23452 .59113 m
.29996 .68654 L
s
.34476 .73243 m
.34909 .70145 L
s
.26656 .57966 m
.34909 .70145 L
s
.38196 .89233 m
.39297 .92864 L
s
.37394 1.04277 m
.39297 .92864 L
s
.62474 1.0773 m
.66103 1.08561 L
s
.66103 1.08561 m
.70171 1.24804 L
s
.22511 .72974 m
.31422 .78043 L
s
.31422 .78043 m
.32135 .82147 L
s
.33386 .86309 m
.35003 .9023 L
s
.35003 .9023 m
.30116 .98341 L
s
.32135 .82147 m
.23939 .81521 L
s
.32135 .82147 m
.33386 .86309 L
s
.33386 .86309 m
.26548 .90228 L
s
.25809 .71852 m
.34623 .76987 L
s
.34623 .76987 m
.35351 .81105 L
s
.50232 .67972 m .67222 .62288 L .74722 .71491 L .656 .751 .92 r
F
0 g
.50539 .64857 m
.51366 .62626 L
s
.44374 .48015 m
.51366 .62626 L
s
.74722 .71491 m
.81728 .80086 L
s
.50539 .64857 m
.52121 .6734 L
s
.74157 .58593 m
.74722 .71491 L
s
.36609 .85284 m
.38196 .89233 L
s
.33456 .97327 m
.38196 .89233 L
s
.18317 .40207 m
.21482 .38987 L
s
.18317 .40207 m
.14714 .46372 L
s
.64762 1.24093 m
.70171 1.24804 L
s
.70171 1.24804 m
.87386 1.20396 L
s
.35351 .81105 m
.27267 .80429 L
s
.35351 .81105 m
.36609 .85284 L
s
.36609 .85284 m
.29891 .89172 L
s
.21482 .38987 m
.37163 .32945 L
s
.21482 .38987 m
.17965 .4514 L
s
.58258 .90316 m .75954 .99619 L .58375 1.04632 L .544 .324 .532 r
F
0 g
.619 1.03627 m
.62474 1.0773 L
s
.58258 .90316 m .7532 .85143 L .75954 .99619 L .544 .324 .532 r
F
0 g
.58148 .76797 m
.58258 .90316 L
s
.4017 .95799 m
.58258 .90316 L
s
.74722 .71491 m
.7532 .85143 L
s
.56202 .8767 m
.58258 .90316 L
s
.36513 1.10866 m .41725 1.24281 L .38342 1.25181 L .544 .324 .532 r
F
.36513 1.10866 m .39763 1.09939 L .41725 1.24281 L F
0 g
.36513 1.10866 m
.37009 .96757 L
s
.41147 1.20056 m
.44966 1.29214 L
s
.39763 1.09939 m
.41967 1.13468 L
s
.36513 1.10866 m
.38342 1.25181 L
s
.34102 1.05243 m
.36513 1.10866 L
s
.39763 1.09939 m
.4017 .95799 L
s
.44374 .48015 m
.37163 .32945 L
s
.44374 .48015 m
.42528 .52285 L
s
.38342 1.25181 m
.44966 1.29214 L
s
.44966 1.29214 m
.48248 1.28365 L
s
.54079 .26427 m
.57919 .23923 L
s
.39763 1.09939 m
.41725 1.24281 L
s
.37394 1.04277 m
.39763 1.09939 L
s
.41749 .58514 m .67222 .62288 L .50232 .67972 L .656 .751 .92 r
F
0 g
.50232 .67972 m
.50482 .7176 L
s
.42528 .52285 m
.46992 .5929 L
s
.50232 .67972 m
.58148 .76797 L
s
.34476 .73243 m
.50232 .67972 L
s
.41725 1.24281 m
.48248 1.28365 L
s
.48248 1.28365 m
.64762 1.24093 L
s
.54256 .84216 m
.56202 .8767 L
s
.56202 .8767 m
.54107 .99375 L
s
.62474 1.0773 m
.64762 1.24093 L
s
.42159 .6629 m
.50482 .7176 L
s
.50482 .7176 m
.51281 .75944 L
s
.52572 .80206 m
.54256 .84216 L
s
.54256 .84216 m
.50018 .92295 L
s
.87386 1.20396 m
.82464 1.19514 L
s
.51281 .75944 m
.52572 .80206 L
s
.4377 .7501 m
.51281 .75944 L
s
.12779 .55652 m .25615 .64165 L .2236 .65306 L .656 .751 .92 r
F
0 g
.2236 .65306 m
.22511 .72974 L
s
.22881 .62352 m
.23452 .59113 L
s
.2236 .65306 m
.31294 .74307 L
s
.52572 .80206 m
.46466 .83937 L
s
.37163 .32945 m
.54079 .26427 L
s
.37163 .32945 m
.34082 .39032 L
s
.30116 .98341 m
.34102 1.05243 L
s
.34102 1.05243 m
.31353 1.17713 L
s
.12779 .55652 m .1611 .54428 L .25615 .64165 L .656 .751 .92 r
F
0 g
.25615 .64165 m
.25809 .71852 L
s
.1611 .54428 m
.25615 .64165 L
s
.25615 .64165 m
.34476 .73243 L
s
.14714 .46372 m
.23452 .59113 L
s
.25615 .64165 m
.26656 .57966 L
s
.17965 .4514 m
.26656 .57966 L
s
.12779 .55652 m
.2236 .65306 L
s
.33456 .97327 m
.37394 1.04277 L
s
.3479 1.16757 m
.37394 1.04277 L
s
.12779 .55652 m
.14714 .46372 L
s
.17965 .4514 m
.14714 .46372 L
s
.41749 .58514 m .59171 .5241 L .67222 .62288 L .656 .751 .92 r
F
0 g
.67222 .62288 m
.74722 .71491 L
s
.22511 .72974 m
.12822 .67462 L
s
.22511 .72974 m
.23939 .81521 L
s
.1611 .54428 m
.17965 .4514 L
s
.34082 .39032 m
.17965 .4514 L
s
.58375 1.04632 m .76627 1.14995 L .58499 1.19818 L .544 .324 .532 r
F
0 g
.64762 1.24093 m
.82464 1.19514 L
s
.58499 1.19818 m
.64762 1.24093 L
s
.58375 1.04632 m .75954 .99619 L .76627 1.14995 L .544 .324 .532 r
F
0 g
.58258 .90316 m
.58375 1.04632 L
s
.39763 1.09939 m
.58375 1.04632 L
s
.54107 .99375 m
.58375 1.04632 L
s
.58375 1.04632 m
.58499 1.19818 L
s
.7532 .85143 m
.75954 .99619 L
s
.26548 .90228 m
.30116 .98341 L
s
.30116 .98341 m
.24704 1.07213 L
s
.25809 .71852 m
.16221 .66266 L
s
.25809 .71852 m
.27267 .80429 L
s
.38342 1.25181 m
.41725 1.24281 L
s
.31353 1.17713 m
.38342 1.25181 L
s
.29891 .89172 m
.33456 .97327 L
s
.33456 .97327 m
.28171 1.06193 L
s
.23939 .81521 m
.14957 .80835 L
s
.23939 .81521 m
.26548 .90228 L
s
.26548 .90228 m
.19047 .94528 L
s
.41725 1.24281 m
.58499 1.19818 L
s
.3479 1.16757 m
.41725 1.24281 L
s
.51493 .32433 m
.54079 .26427 L
s
.27267 .80429 m
.18404 .79687 L
s
.27267 .80429 m
.29891 .89172 L
s
.32635 .48353 m .59171 .5241 L .41749 .58514 L .656 .751 .92 r
F
0 g
.41749 .58514 m
.42159 .6629 L
s
.41749 .58514 m
.50232 .67972 L
s
.25615 .64165 m
.41749 .58514 L
s
.34082 .39032 m
.40819 .49604 L
s
.29891 .89172 m
.22518 .9344 L
s
.50018 .92295 m
.54107 .99375 L
s
.54107 .99375 m
.51845 1.12013 L
s
.76627 1.14995 m
.82464 1.19514 L
s
.51493 .32433 m
.34082 .39032 L
s
.75954 .99619 m
.76627 1.14995 L
s
.12779 .55652 m
.1611 .54428 L
s
.12779 .55652 m
.12822 .67462 L
s
.3309 .6033 m
.42159 .6629 L
s
.42159 .6629 m
.4377 .7501 L
s
.1611 .54428 m
.16221 .66266 L
s
.46466 .83937 m
.50018 .92295 L
s
.50018 .92295 m
.45386 1.01126 L
s
.24704 1.07213 m
.31353 1.17713 L
s
.31353 1.17713 m
.3479 1.16757 L
s
.58499 1.19818 m
.76627 1.14995 L
s
.51845 1.12013 m
.58499 1.19818 L
s
.4377 .7501 m
.35519 .73985 L
s
.4377 .7501 m
.46466 .83937 L
s
.46466 .83937 m
.39753 .88041 L
s
.28171 1.06193 m
.3479 1.16757 L
s
.3479 1.16757 m
.51845 1.12013 L
s
.32635 .48353 m .50509 .41782 L .59171 .5241 L .656 .751 .92 r
F
0 g
.1611 .54428 m
.32635 .48353 L
s
.32635 .48353 m
.34082 .39032 L
s
.59171 .5241 m
.67222 .62288 L
s
.32635 .48353 m
.41749 .58514 L
s
.50509 .41782 m
.59171 .5241 L
s
.12822 .67462 m
.16221 .66266 L
s
.12822 .67462 m
.14957 .80835 L
s
.50509 .41782 m
.51493 .32433 L
s
.19047 .94528 m
.24704 1.07213 L
s
.24704 1.07213 m
.28171 1.06193 L
s
.16221 .66266 m
.3309 .6033 L
s
.16221 .66266 m
.18404 .79687 L
s
.32635 .48353 m
.50509 .41782 L
s
.32635 .48353 m
.3309 .6033 L
s
.22518 .9344 m
.28171 1.06193 L
s
.28171 1.06193 m
.45386 1.01126 L
s
.70299 1.0688 m
.76627 1.14995 L
s
.14957 .80835 m
.19047 .94528 L
s
.18404 .79687 m
.14957 .80835 L
s
.19047 .94528 m
.22518 .9344 L
s
.45386 1.01126 m
.51845 1.12013 L
s
.51845 1.12013 m
.70299 1.0688 L
s
.18404 .79687 m
.35519 .73985 L
s
.18404 .79687 m
.22518 .9344 L
s
.22518 .9344 m
.39753 .88041 L
s
.3309 .6033 m
.51353 .53904 L
s
.3309 .6033 m
.35519 .73985 L
s
.50509 .41782 m
.51353 .53904 L
s
.39753 .88041 m
.45386 1.01126 L
s
.45386 1.01126 m
.64027 .95639 L
s
.70299 1.0688 m
.64027 .95639 L
s
.35519 .73985 m
.39753 .88041 L
s
.54057 .67809 m
.35519 .73985 L
s
.39753 .88041 m
.58423 .82192 L
s
.54057 .67809 m
.51353 .53904 L
s
.64027 .95639 m
.58423 .82192 L
s
.58423 .82192 m
.54057 .67809 L
s
.25 Mabswid
.09401 .17347 m
.50657 0 L
s
.15034 .14978 m
.15669 .15719 L
s
gsave
.13763 .13498 -69.3611 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25349 .10641 m
.25964 .11398 L
s
gsave
.24117 .09129 -85.0399 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.3595 .06184 m
.36545 .06957 L
s
gsave
.34759 .04639 -80.0345 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.46849 .01601 m
.47423 .0239 L
s
gsave
.45702 .00023 -83.8823 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17074 .1412 m
.17453 .14567 L
s
.19126 .13258 m
.19503 .13706 L
s
.21189 .1239 m
.21563 .1284 L
s
.23263 .11518 m
.23635 .1197 L
s
.27445 .0976 m
.27813 .10215 L
s
.29554 .08873 m
.29919 .09331 L
s
.31674 .07982 m
.32036 .08441 L
s
.33806 .07085 m
.34166 .07547 L
s
.38105 .05278 m
.3846 .05743 L
s
.40273 .04366 m
.40625 .04834 L
s
.42453 .0345 m
.42802 .03919 L
s
.44645 .02528 m
.44992 .02999 L
s
.13004 .15832 m
.13387 .16274 L
s
.10985 .16681 m
.11371 .17121 L
s
.49066 .00669 m
.49407 .01144 L
s
.25 Mabswid
0 1.03666 m
.57632 1.49507 L
s
.01707 1.05023 m
.01809 1.04053 L
s
gsave
.01503 1.06963 -76.7145 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.17721 1.17761 m
.1779 1.16788 L
s
gsave
.17582 1.19707 -76.2332 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32032 1.29145 m
.32074 1.2817 L
s
gsave
.31949 1.31093 -65.6912 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.44899 1.39379 m
.44916 1.38404 L
s
gsave
.44865 1.4133 -71.9391 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5653 1.48631 m
.56526 1.47655 L
s
gsave
.56538 1.50581 -71.7058 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.0506 1.0769 m
.05117 1.07108 L
s
.08336 1.10296 m
.08389 1.09713 L
s
.11536 1.12841 m
.11585 1.12258 L
s
.14663 1.15329 m
.14709 1.14745 L
s
.2071 1.20139 m
.20748 1.19555 L
s
.23634 1.22464 m
.23668 1.2188 L
s
.26494 1.24739 m
.26525 1.24155 L
s
.29293 1.26966 m
.29321 1.26381 L
s
.34714 1.31278 m
.34736 1.30693 L
s
.3734 1.33366 m
.37359 1.32781 L
s
.39912 1.35412 m
.39927 1.34827 L
s
.42431 1.37416 m
.42444 1.36831 L
s
.47318 1.41304 m
.47326 1.40718 L
s
.4969 1.4319 m
.49695 1.42604 L
s
.52015 1.45039 m
.52017 1.44454 L
s
.54294 1.46852 m
.54294 1.46267 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[56]:=",
  ImageSize->{192.625, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400030000180P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000<1d0030M000`7@00<1d0030M000`7@00<1d
0030M000`7@00<1d0030M000`7@0051d0Q43M0034GAd008A0g@34@04M14A4Ead001?M0044GAd4@Ad
00@AM7@A0g@0115dM142M0034GAd05Ud001?M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd05Ud
001?M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd05Ud001?M0044GAd4@Ad00@AM7@A0g@00a5d
M0034Ead001?M0044GAd4@Ad00@AM7@A0W@24@=d00<AM7@0Fg@0051d0Q46M08A17@0115dM7@34@Id
0Q5CM000JG@24EEd0012M08A0g@00a5dM0024@=d0a4EM08A00=d4G@0E7@0045d00@AM7@A17@0115d
M143M0034GAd015d0a5IM000@G@0115dM144M0044GAd4@=d00<AM7@03g@24@=d00<AM7@0EW@0045d
00@AM7@A17@0115dM143M0034GAd00ad0a400g@AM01KM000@G@0115dM144M0044GAd4@=d00<AM7@0
2W@34F1d0011M0044GAd4@Ad00@AM7@A0W@24@Yd0Q5SM000@W@24@Id0Q44M0034GAd00Ed0a400g@A
M01RM000:g@24@=d00<AM7@00Q43M08A0W@34AMd0Q5XM000:W@0115dM144M0064GAd4G@A0W@00a5d
4@02M0034GAd019d0Q42M0034GAd06Ed000ZM0044GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@0
3g@44F]d000ZM0044GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@03G@24@Ad00<AM7@0J7@002Yd
00@AM7@A17@01Q5dM15d4@9d00<AM1400Q4=M0<A0W@00a5dM01/M000:W@0115dM144M0064GAd4G@A
0W@0115dM14<M08A00=d4G@0LG@002]d0Q46M08A0g@24@=d0a48M08AMW@004Ed0a42M0034GAd07=d
000YM08A67@24@03M15d07Qd000XM0044GAd4AAd0a5mM000:7@0115dM14BM08A0g@00a5dM01jM000
:7@0115dM14@M08A00=d4G@0Og@002Qd00@AM7@A3G@44H=d000XM0044GAd4@]d0Q67M000:G@24@Yd
0Q400g@AM026M000<W@44HYd000`M08ASW@002ed0a42M0034GAd08]d000[M08A00=d4G@0T7@002Ud
0Q6EM0009g@24@9d00<AM7@0TW@002Md00<AM7@0UW@002Md0a6FM0009g@00a5dM02FM0009g@00a5d
M02FM0009W@00a5dM02GM0004W@24@=d00<AM7@00Q42M0@A17@00a5dM02GM0004G@0115dM144M004
4GAd4@9d00<AM7@017@00a5dM02GM0002g@44@9d00@AM7@A17@0115dM143M0034GAd00=d0Q6HM000
4G@0115dM144M0044GAd4@=d00<AM7@00g@00a5dM02GM0004G@0115dM144M0044GAd4@Ad00<AM7@0
0W@00a5dM02GM0004G@0115dM144M0064GAd4G@A0W@00a5dM002M0034GAd04md1A53M0004W@24@Id
0Q43M08A1G@00a5dM01=M0<A17@54Cid000VM0034GAd04Yd1147M08A0W@00a5dM00kM0009W@24DUd
1146M0<A1G@00a5dM00jM0009G@24DMd1A46M08A2G@00a5dM00iM0009G@00a5dM013M0<A00Ed4A5d
4@03M0<A37@24CUd000UM0034GAd045d0Q4017@A4A42M0034GAd008A4G@00a5dM00fM0009G@00a5d
M00nM0<A00=d4A401G@34AAd00<AM7@0=G@002Ed00<AM7@0?7@24@04M14A4@Ed0a4FM08A=W@002Ed
0Q4jM0HA1W@24@03M15d01Ad0Q42M0034GAd03=d000UM0034GAd03Md0Q400g@A4@06M0<A0g@00a5d
M00@M0<A1G@00a5dM00bM0009G@00a5dM00dM0HA1W@24@Ed00<AM7@03W@34@Ud00<AM7@0<G@002Ed
00<AM7@0<G@64@=d1Q47M0034GAd00ad0Q4=M0034GAd031d000UM0034GAd02md1Q400g@AM002M0<A
00Ad4A4A1G@00a5dM00:M0<A3g@00a5dM00`M00097@00a5dM00]M0HA17@0115d4A44M0044GAd4@=d
0Q4:M08A4g@00a5dM00_M00097@24B]d0a4017@A4A45M0<A1g@00a5dM0034@03M15d00Id0a4FM003
4GAd02id000TM08A:7@34@9d0Q400g@AM002M0<A0W@00a5dM005M0@A00Ad4G@A17@34AYd00<AM7@0
;G@002Ad00<AM7@097@34@9d0a42M0034G@A008A1G@00a5dM003M0<A1G@24@9d0Q4NM0034GAd02ad
000TM0034GAd029d0Q42M0<A17@44@Qd00<AM7@00Q42M0034GAd00Ad0a4PM08A;G@002Ad00<AM7@0
7g@34@9d0Q45M0<A0g@00a5dM005M0<A1G@00a5dM0034@03M14A01id0Q400chA4@0/M00097@00a5d
M00LM0PA17@34@9d00DAM7Ad4@04M0@A1g@34@9d00DAM15d4@0JM0<A00<o?Sl00Q4/M00097@24AYd
1A4017@A4G@64@Ad00<AM7@00g@0115d4A44M0034GAd009d0a44M0034G@A009d00<AM7@05G@24@09
EciG?ULn4G@A02]d000TM0034GAd01Md2144M08A00Ad4A4A0g@00a5dM002M0<A1W@00a5d4@024@9d
00<AM7@00W@0115dM142M0034GAd015d0a402Cho?Sln?cho4@02M0034GAd02Qd000SM0034GAd01Id
3Q43M0034GAd00<A0W@34@9d00<AM7@017@24@Id00DAM7Ad4@02M0054GAdM14047@24@0<?ULnEciG
?ULnEchA0W@00a5dM00XM0008g@00a5dM00DM08A00Ad4A4A1G@00a5dM0034@=d00@AM7Ad0a45M004
4GAdM0<A00=d4G@01G@01A5dM7@A009d00<AM7@00W@00a5dM00:M0<A00ho?Sln?cho?Sln?cho4@=d
00<AM7@09g@000id0Q43M0034GAd008A0g@34@Ed00<AM7@04g@00a5d4@024@03M15d00Ed00<AM140
0W@24@03M15d00DA1W@34@Ad00<AM7@017@01A5dM7@A009d00<AM7@00g@00a5dM007M08A015G?ULn
EciG?ULnEciG?ULn4@03M0034GAd02Md000=M0044GAd4@Ad00@AM7@A0g@00a5dM004M0034GAd015d
1Q43M0034GAd00=d00@AM7@A0g@34@03M14A009d0Q42M0<A1g@00a5dM003M0054GAdM1400W@00a5d
M004M0034GAd00=d0a404cho?Sln?cho?Sln?cho?Sln?a4017@00a5dM00VM0001g@44@9d00@AM7@A
17@0115dM143M0034GAd00Ad00<AM7@047@24@=d00<AM1400W@00a5dM003M0054GAd4G@01A400g@A
4@03M0<A0g@00a5dM004M0034GAd00Ad00<AM1400g@00a5dM005M0034GAd008A01HnEciG?ULnEciG
?ULnEciG?ULnEchA1G@00a5dM00UM0003G@0115dM144M0044GAd4@=d00<AM7@017@24A1d00<AM140
0W@0115dM142M0034GAd00Ad00@AM14A17@34@05M14A4G@00Q43M0034GAd00Ed00<AM7@00g@00a5d
4@03M0034GAd00Ed0a4063ln?cho?Sln?cho?Sln?cho?Sln?cho4@Ed00<AM7@09G@000ed00@AM7@A
17@0115dM143M0034GAd00Ad00<AM7@03g@00a5d4@02M0054GAdM1400W@00a5dM002M0@A1G@24@03
M14A00=d00<AM1400g@00a5dM004M0034GAd00=d00<AM1400g@00a5dM002M0<A01ad4ELnEciG?ULn
EciG?ULnEciG?ULnEciG?ULA1G@00a5dM00TM0003G@0115dM144M0044GAd4@9d0Q46M0034GAd00id
00@AM7Ad0Q44M0044GAd4@9d0Q401G@AM7@A00Ad0Q4017@A4A42M0044GAd4@9d00<AM7@017@00a5d
M003M0<A17@44@Ad01/A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q401W@00a5dM00SM0003W@24@Id
0Q44M0034GAd00Ad00<AM7@03W@0115dM7@24@Ed00<AM1400Q44M0034G@A00Ad0Q400g@AM0024@9d
00@AM7@A0W@00a5dM004M0034GAd00<A00AL4A5d0a47M00K4ELnEciG?ULnEciG?ULnEciG?ULnEciG
?ULA00Id00<AM7@08g@002=d00<AM7@03G@00a5dM002M08A1G@44@Ed00<AM1401G@00a5d4@02M004
4GAd4@=d0a46M0<A00M7G4ML4E`A009d00<AM7@01G@06a4n?cho?Sln?cho?Sln?cho?Sln?cho?Sln
4@06M08A97@0029d00<AM7@03W@00a5dM002M08A0g@24@04M15d4@Ed00<AM1401G@0115dM142M003
4G@A00Ed0Q43M0<A1U`00a5L4@02M0034GAd00Ed01/AEciG?ULnEciG?ULnEciG?ULnEciG?ULnEa40
0g@34@03M15d02=d000RM08A3W@00a5dM002M0034GAd00<A0g@0115dM145M0034G@A00=d0Q42M003
4GAd00<A1W@44@0?G4MLAea7G4ML4Ea74G@A00Md01`A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q5d
0Q45M0034GAd025d000RM0034GAd00ed00<AM7@00W@44@Id00<AM1401G@00a5d4@03M08A0W@0115d
M7@34@=d0a4<G0044EaLG08A1g@06Q5G?ULnEciG?ULnEciG?ULnEciG?ULnEciG0Q47M0034GAd025d
000RM0034GAd00ad00@AM7Ad0a43M0034GAd00=d00<AM1401W@24@=d00DAM15d4@04M0034G@A008A
01ELAea7G4MLAea7G4MLAea74DMLAa401g@06a4n?cho?Sln?cho?Sln?cho?Sln?cho?Sln4@09M003
4GAd021d000RM0034GAd00ad11400g@A4@03M0034GAd00Ad00<AM1401G@24@=d00DAM15d4@04M0<A
4U`00a5LG002G0034GAd00Ad01/AEciG?ULnEciG?ULnEciG?ULnEciG?ULnEa402G@00a5dM00PM000
8W@00a5dM00;M08A17@24@Ad00<AM7@00g@00a5d4@05M0034G@A009d00HAM15d4G@34@0LAea7G4ML
Aea7G4MLAea7G4MLAea74DMLAea74@Ed01/A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q402W@00a5d
M00OM0008W@00a5dM00;M08A0g@0115dM143M0034GAd00Ad00<AM1401G@24@06M15dM15d0Q4HG003
4EaL00=L00<AM7@00g@06a5G?ULnEciG?ULnEciG?ULnEciG?ULnEciG4@0:M0034GAd01md000RM003
4GAd00]d0Q43M0054GAdM1400g@00a5dM003M0034G@A00Ed0Q400g@AM0034@0RG4MLAea7G4MLAea7
G4MLAea7G4MLAea7G4LAAea7G4ML4@Ad01/A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q402g@00a5d
M00NM0008W@24@]d00@AM7@A0W@01A5dM7@A00=d00<AM7@017@24@Ed1A4MG0034EaL00EL01lAM7Ad
4ELnEciG?ULnEciG?ULnEciG?ULnEciG?ULA00]d00<AM7@07W@0029d00<AM7@02W@01a5dM7@AM140
17@01A5dM7@A00Ed00<AM1400g@64@0WAea7G4MLAea7G4MLAea7G4MLAea7G4MLAea7G4LAAea7G4ML
Ae`A009d01/A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q4037@00a5dM00MM0008G@00a5dM00;M003
4GAd009d0Q45M0044GAd4@Id0Q400g@A4@02M0<A00=d4E`06e`00a5LG007G00M4G@AEciG?ULnEciG
?ULnEciG?ULnEciG?ULnEa4037@00a5dM00MM0008G@00a5dM00;M0034GAd009d00<AM7@017@01A5d
M7@A00Ed0a44M0<A0W@09a57G4MLAea7G4MLAea7G4MLAea7G4MLAea7G4LAAea7G4MLAea7G0024@0J
?Sln?cho?Q4n?cho?Sln?cho?Sln?cho?Q4=M0034GAd01ad000QM0034GAd00]d00<AM7@00W@24@Id
00@AM7@A0W@34@03M14A00Ed0Q43M0034EaL01QL00<AG5`025`24@0JEciG?ULnEciG?ULnEciG?ULn
EciG?ULnEa4=M0034GAd01ad000QM0034GAd00Yd00<AM7@00g@00a5d4@06M0034GAd008A17@24@Ed
1a40@4MLAea7G4MLAea7G4MLAea7G4MLAea7G4ML4Ea7G4MLAea7G4LA?Sln?cho?Sln?cho?Sln?cho
?Sln?cho?Q4>M0034GAd01]d000QM08A2g@00a5dM003M0034G@A00Id1146M08A0g@34@Ad0Q4IG003
4EaL00UL01XA?ULnEciG?ULnEciG?ULnEciG?ULnEciG4@id00<AM7@06g@0025d00<AM7@02W@00a5d
M003M0044GAd4@9d0a401G@AM7@A00Ed2A43M0114G@AAea7G4MLAea7G4MLAea7G4MLAea7G4ML4Ea7
G4MLAea7G4MLAa4n?cho?Sln?cho?Sln?cho?Sln?cho?Q403W@24Aad000QM0034GAd00Yd00<AM7@0
0W@00a5dM002M08A1G@00a5d4@05M0<A17@0115d4A42M0<A5e`00a5LG00;G00I4CiG?ULnEciG?ULn
EciG?ULnEciG?ULn4@0:M0<A00=d4G@06g@0025d00<AM7@02W@00a5dM002M0034G@A008A00=d4G@0
17@0115dM142M08A00=d4A4017@0115dM7@54@0FG4MLAea7G4MLAea7G4MLAea7G4MLA`8A02ILAea7
G4MLAea7G4MLAa4n?cho?Sln?cho?Sln?cho?Sln?cho4@Qd0Q45M0034GAd01Ud000QM0034GAd00Ud
00<AM7@00W@34@Ad00<AM7@017@01A5d4G@A009d0a44M08A17@24@03M15L015L0a400e`AG00=G00H
4ELnEciG?ULnEciG?ULnEciG?ULnEchA1G@34@Md00<AM7@06G@0021d00<AM7@02W@00a5d4@024@03
Aa4A00Ed00<AM7@017@00a5d4@03M0034G@A00Ed00<AM7@00W@34@0@M15LAea7G4MLAea7G4MLA`<A
02]7G4ML4Ea7G4MLAea7G4MLAea7G14o?Sln?cho?Sln?cho?Sln?cho?SlA009d0a4;M0034GAd01Qd
000PM0034GAd00Yd0Q44G0034E`A00Ed00<AM7@00g@24@04M15d4@9d0Q44M0034GAd00=d00DAM15d
4@0;G08A25`00a5LG00=G00E4ELnEciG?ULnEciG?ULnEciG?ULn00<A3W@00a5dM00HM00087@34@Yd
0Q4025a7G4LAAe`A17@00a5dM004M0054G@AM1400g@00a5dM002M08A17@03A5dM15d4Ea7G4MLAe`0
0a40<5a7G4MLAea7G4LAAea7G4MLAea7G4MLAea7G14o?Sln?cho?Sln?cho?Sln?cho4A1d00<AM7@0
67@0021d00<AM7@02W@00a5d4@03G0054EaLG14017@00a5dM002M0054G@AM14017@24@=d0Q44M004
4GAdM0<A0e`34@eL00<AG5`03e`0515G?ULnEciG?ULnEciG?ULnEchA4G@00a5dM00GM00087@00a5d
M00:M00<4GAd4Ea74DMLAe`A17@02A5dM7@AM15d4@05M0044GAdM08A17@00a5dM002M0DA03ILAea7
G4MLAea7G4MLAea74DMLAea7G4MLAea7G4MLAea74Cho?Sln?cho?Sln?cho?Sln?a4AM0034GAd01Md
000GM08A1g@00a5dM00:M0074GAdM15L4@05G0034GAd009d00<AM1400g@00a5d4@04M0044GAdM0<A
17@00a5dM0034@03Ea5L011L00<AG5`045`04a4nEciG?ULnEciG?ULnEciG?Q404G@00a5dM00GM000
5W@0115dM146M0034GAd00Yd00<AM7@00W@24@07Aea7G4ML4@03M0034G@A00=d0a45M0034GAd00<A
17@34@9d03XA?Q4AG4MLAea7G4MLAea7G4MLAa57G4MLAea7G4MLAea7G4MLAea74Cho?Sln?cho?Sln
?cho?SlA4W@00a5dM00FM0005W@0115dM146M0034GAd00Yd00<AM7@00g@00a5LG005G0054GAdM140
17@24@03M15d00=d00HAM7@AM142M0<A0g@34@03?Q4A011L00<AG5`04E`04A4nEciG?ULnEciG?ULn
EchA019d00<AM7@05W@001Id00@AM7@A1W@00a5dM00:M0034GAd00=d0Q4025a7G4MLAe`A0W@24@=d
00@AM14A17@24@03M15d00<A0W@44@0kM14n?a4o4Ea7G4MLAea7G4MLAea7G15LAea7G4MLAea7G4ML
Aea7G4MLAa4n?cho?Sln?cho?Sln?a404g@00a5dM00EM0005W@0115dM146M0034GAd00Yd00<AM7@0
0g@00a5d4@07G0044G@A4@=d00<AM7@00Q44M0HA00=d4A400Q43M0054ELn4Ch00Q4>G0034EaL01=L
00lA?ULnEciG?ULnEciG?Q404g@00a5dM00EM0005W@0115dM145M0034GAd00]d00<AM7@00g@0315d
M15LAea7G4ML4@9d00@AM7@A0W@24@9d2A42M08A0g@01A4n?a4o008A03=7G4MLAea7G4MLAea7G15L
Aea7G4MLAea7G4MLAea7G4MLAe`A?cho?Sln?cho?Sln?a404g@00a5dM00EM0005g@24@Id00<AM7@0
2g@00a5dM003M0054GAdM1401e`00a5dM0024@Ad0a42M0@A00=d4A400W@24@=d00PAEchA?Q5d4@eL
00<AG5`055`03Q5G?ULnEciG?ULnEchA57@00a5dM00DM0007g@00a5dM00;M0034GAd00=d00<AM7@0
0W@02Q5LAea7G15L4G@24@9d0Q400g@AM0064@05M14A4G@00Q43M0054Cho4Cl01140<DMLAea7G4ML
Aea7G15LAea7G4MLAea7G4MLAea7G4MLAea7G14o?Sln?cho?Sln?a4057@00a5dM00DM0007g@00a5d
M00;M0034GAd00=d00<AM7@00g@00a5LG005G0034G@A008A0W@34@=d0a400g@AM0034@09M15dM15G
?Q4n00<A00=d4E`02e`00a5LG00EG00<4ELnEciG?ULnEchA5G@00a5dM00CM0007g@00a5dM00;M003
4GAd00=d00<AM7@017@01Q5LAea7G0PA0W@0315dM7@AM15d4G@AM0<A0W@0214n?a4o4G@A0W@0<157
G4MLAea7G4MLAa57G4MLAea7G4MLAea7G4MLAea7G4MLAe`A?cho?Sln?cho4AAd0Q4EM0007g@00a5d
M00;M0034GAd00=d00<AM7@01G@00a5L4@024@=L0Q46M0044GAdM08A0W@24@04M15d4@9d00LAEchA
?Q5d008A0W@00a5LG008G0034EaL01IL00/A?ULnEciG?ULn4@0AM0<A00=d4G@057@001md0Q4<M003
4GAd00=d00<AM7@017@34@06G4MLAea70a45M08A0W@34@03M15d008A00=d4A400a401ClA?a5d008A
0W@24@0]Aea7G4MLAea74DMLAea7G4MLAea7G4MLAea7G4MLAea7G4LA?Sln?cho?SlA00id0a45M003
4GAd019d000OM0034GAd00]d00<AM7@00g@00a5dM002M08A0g@00a5LG003G0044E`A4@Ed00@AM7Ad
0Q402G@AM15d4G@AM0024@03?Q4n008A0W@01A5d4G@A00QL00<AG5`065`02A4nEciG?ULn4@0;M0<A
27@00a5dM00BM0007g@00a5dM00;M0034GAd00=d00<AM1400Q45M08A00MLAea74DML008A17@24@9d
11401g@AM15d4G@011400clA4@02M00b4G@AM15LAea7G4MLAa57G4MLAea7G4MLAea7G4MLAea7G4ML
Aea7G4LA?Sln?cho?Q46M0@A2g@00a5dM00BM0007g@00a5dM00;M0034GAd009d0a48M0034G@A00=L
00<AG5`00Q45M08A00Md4A4AM15d00@A00Id4A4n4Ch24@=d00DAM7Ad4@08G0034EaL01UL00PA?ULn
EciG4@=d0a4?M0034GAd019d000NM0034GAd00ad00<AM1400Q4017@A4A47M00:4GAd4Ea74DMLA`8A
17@24@9d00DAM14AM0024@03M14A008A00<o4A400Q43M08A0g@0:a5LAea7G4ML4Ea7G4MLAea7G4ML
Aea7G4MLAea7G4MLAea7G14o?Sln?ch0114CM0034GAd015d000NM0034GAd00ad0Q44M0034GAd008A
1G@01a5dM7@AG14015`24@Ad0Q400g@A4@054@03M15d008A00<n4Ch00Q43M0LA0e`0115L4A4LG007
4ELnEciG4@0FM0034GAd015d000NM0034GAd00ad0a43M0034GAd009d0Q43M0034GAd009d0Q401TML
Aea74@Ad00@AM14A0W@0115d4A42M0@A00@n4A5d0Q401g@A4A5d4G@00Q40:E`A4A5L4Ea7G4MLAea7
G4MLAea7G4MLAea7G4MLAea7G4ML4Cln?chA01Id00<AM7@04G@001id0Q4=M0034GAd008A0W@00a5d
M003M0044GAd4@Ed00<AG5`015`00a5dM002M0034G@A00@A00Ad4A5d0a401ChA4A5d00<A0W@74@AL
0Q4MG0054ELnEa405W@00a5dM00AM0007W@00a5dM00=M0044GAdM0<A1W@34@Ed0Q401ea7G4MLAa40
0g@00a5d4@024@05M15d4G@011400cln4@024@9d1a40:g@A4A5LAea74DMLAea74DMLAea7G4MLAea7
G4MLAea7G4MLAea7G14o?Q405g@00a5dM00@M0007W@00a5dM00=M0034GAd00=d00<AM7@01W@24@Ad
00<AM1401U`01a5d4G@AM1400W@01A5d4A5d00<A00<nEa401A4017@A4A43M0044G@A4@=L00<AG5`0
7E`00a5G4@0GM0034GAd011d000NM0034GAd00ed00<AM7@00g@34@Id00@AM14A0W@02Q5dM15LAea7
G4L24@03M15d008A00=d4A400Q42M0044ChA?P<A00Ud4A4AM15d4G@00Q40:G@A4DMLAe`AG4MLAea7
G4MLAea7G4MLAea7G4MLAea7G4MLAea74ChA01Md00<AM7@047@001id00<AM7@03G@00a5dM003M003
4GAd008A17@0115dM7@34@=d00<AG5`00e`0115dM7@34@9d00DAM14AM0044@03?Q4A008A0W@00a5d
M0044@04M15d4@=L00<AG5`07E`24AQd00<AM7@03g@001id00<AM7@03G@00a5dM003M0034GAd009d
0Q42M0034GAd00=d00<AM7@00W@01a5LAea7G1400W@24@03M15d00HA00<n4A400Q42M0034G@A00Ad
00<AM1400W@09a5d4DML4Ea7G4MLAea7G4MLAea7G4MLAea7G4MLAea7G4MLAea74@0HM0034GAd00md
000MM0034GAd00id00<AM7@00g@00a5dM004M0<A1G@34@=d00<AG5`00e`01A5d4A5d00HA00Md4A4A
EchA009d0a43M08A00=d4A400Q42M0044EaL4AaL00=G?UL00Q4GM0034GAd00md000MM08A47@00a5d
M002M0034GAd00Id00<AM7@00g@00a5dM0024@9d00HAG4MLAe`74@03M14A00@A00<n?a400W@24@=d
00<AM1400W@0115d4A42M00U4DLAAea7G4MLAea7G4MLAea7G4MLAea7G4MLAcln?cho?Q574@0FM003
4GAd00md000MM0034GAd00md00<AM7@00g@00a5dM005M0<A0g@00a5dM002M0044GAd4@EL0a400g@A
4@024@03M14A008A00IG?Q5d4G@24@03M15d009d00<AM1400W@24@9d0Q4FG00:EciG?ULnEciG4@9L
00<AM7@057@00a5dM00>M0007G@00a5dM00?M0034GAd00=d00<AM7@01G@00a5dM0024@9d00<AM7@0
0W@24@06M15LAea73A400cho4@034@04M15d4@=d00<AM1400W@00a5d4@044@0RG4MLAea7G4MLAea7
G4MLAea7?cho?Sln?cho?Sln4DML4AEd0Q4@M0007G@00a5dM00?M0034GAd00=d00<AM7@01W@01a5d
M7@AM1401W@34@09G14A4E`AM15d00LA00=G?Q400Q43M0034GAd00=d0Q43M0<A0W@00a5LG00=G00@
EciG?ULnEciG?ULnEciG4@=L00<AM7@03g@34@03M15d00md000MM0034GAd00md00<AM7@00g@00a5d
M006M0034GAd009d0Q46M0@A00MLAa57G15d00<A00Ed4A4A?`0:4@Ad00@AM15d0Q42M0<A02ALAea7
G4MLAea7G4Lo?Sln?cho?Sln?cho?Sln?chAAea7G14=M0<A17@00a5dM00>M0007G@00a5dM00@M003
4GAd009d00<AM7@01W@00a5dM003M0<A00Md4A4AM15d008A0U`00a5L4@024@03M15d008A00IG4A4A
M143M0034G@A00XA17@24@QL01IG?ULnEciG?ULnEciG?ULnEciG?ULA1E`00a5dM007M0<A27@00a5d
M00=M0007G@00a5dM00@M0034GAd009d00<AM7@01W@00a5dM003M0@A17@0115dM7@34@03G15L00dA
00Ed4GAd4@05M08A0W@94@0SAea7?cho?Sln?cho?Sln?cho?Sln?cho?Sln4DMLAea7G14017@44@]d
00<AM7@03G@001ed00<AM7@047@00a5dM002M0034GAd00Id00@AM7Ad0a43M08A0W@00a5dM002M08A
0U`00a5L4@0;4@03M15d009d00<AM7@00a401G@AM7@A00Ad0a4075LnEciG?ULnEciG?ULnEciG?ULn
EciG?ULnEa47G0@A3g@00a5dM00=M00077@34A5d00<AM7@00g@00a5dM006M0<A0W@00a5dM003M0<A
1G@44@03Ae`A008A00<o4A400Q4017@A4A44M0@A00Ad4G@A0W@00a5dM0054@0U?Sln?cho?Sln?cho
?Sln?cho?Sln?cho?Sln4DMLAea7G4ML4@0AM0034GAd00ed000LM0034GAd015d00<AM7@00g@00a5d
M002M0DA17@00a5dM005M0034GAd00=d0Q400e`A4@02G0PA00=d4A400g@34@Ad0Q400g@A4@074@0L
EciG?ULnEciG?ULnEciG?ULnEciG?ULnEciG4@QL00<AM7@03g@00a5dM00=M00077@00a5dM00AM003
4GAd00=d00<AM1400Q44M0034GAd00=d00<AM7@017@34@=d00XAM14AAa57G14o1A4017@A4G@54@Ad
0a42M08A0W@34@0V?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Sln?a5LAea7G4MLAa4AM0034GAd00ad
0007M08A0g@00a5dM0024@=d0a45M0034GAd019d00@AM7Ad1A45M0034GAd00=d00<AM7@017@00a5d
M0024@9d00DAM14AG0024@03G14A00DA00=d4A400Q43M0DA00=d4A400Q43M0<A01eG?ULnEciG?ULn
EciG?ULnEciG?ULnEciG?ULn4@09G0034GAd00id00<AM7@037@000Id00@AM7@A17@0115dM143M003
4GAd00Ad00<AM7@04W@01Q5d4A5d4@=d2143M0034GAd00Ad00<AM7@00W@34@9d00HAG4ML4E`94@=d
0a43M0034G@A009d00@AM7Ad0a40:3ho?Sln?cho?Sln?cho?Sln?cho?Sln?cho?SlAG4MLAea7G4ML
Aa4?M0034GAd00ad0006M0044GAd4@Ad00@AM7@A0g@00a5dM004M0034GAd019d2147M0034G@A00TA
00=d4G@017@24@03M14A00=L1Q400g@A4@044@9d00@AM7Ad0a43M0044G@AM08A01eG?ULnEciG?ULn
EciG?ULnEciG?ULnEciG?ULn4@0;G0034GAd00ad00<AM7@037@000Id00@AM7@A17@0115dM143M003
4GAd00Ad00<AM7@04W@00a5dM003M0034G@A00dA1G@=4@04G4MLA`TA17@0215d4A5d4G@A0W@0115d
4G@24@0Z?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Sln?a5LAea7G4MLAea7G4LA3W@00a5dM00;M000
1W@0115dM144M0044GAd4@=d00<AM7@017@24AAd00<AM7@00W@00a5dM006M0034GAd00=d3Q43M0lA
17@24@=d00<AM1400W@24@9d0a4073iG?ULnEciG?ULnEciG?ULnEciG?ULnEciG?Q4<G0034GAd00ad
00<AM7@02g@000Id00@AM7@A17@0115dM142M08A1W@00a5dM00CM0034GAd00=d00<AM7@01W@00a5d
M002M0034GAd00Ad00<AM7@017@74@03?chA00@A0W@<4@9d00@AM7@A0W@34@0Z?cho?Sln?cho?Sln
?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4MLAe`A3G@00a5dM00;M0001g@24@Id0Q44M0034GAd00Ad
00<AM7@04g@00a5dM003M0034GAd00Id00<AM7@00W@00a5dM005M0034GAd00=d00@AM7Ad1A400chA
4@0<4@Ad2a4073iG?ULnEciG?ULnEciG?ULnEciG?ULnEciG?Q4>G0034GAd00Yd00<AM7@02g@001ad
00<AM7@057@00a5dM002M0034GAd00Id00<AM7@00g@00a5dM004M0034GAd00=d00<AM14011400cln
4@054@04M14A4@Ad2a40<G@AM14n4Cho?Sln?cho?Sln?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4ML
Aea7G1402g@00a5dM00;M0006g@00a5dM00EM0034GAd009d00<AM7@01W@00a5dM003M0034GAd00Ed
00<AM7@00W@24@9d0a400ciG4@0:4@=d00<AM7@011400g@AM0054@0MEa5G?ULnEciG?ULnEciG?ULn
EciG?ULnEciG?Q403e`00a5dM00:M0034GAd00Yd000KM0034GAd01Ed00<AM7@00g@00a5dM006M003
4GAd009d00<AM7@01G@0115dM7@74@03?SlA00HA00EL4G@AM0064@9d00@AM14A0W@24@0`M14n?a4o
?Sln?cho?Sln?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4MLAea7G4LA2g@00a5dM00:M0006g@00a5d
M00EM0034GAd00=d00<AM7@01W@00a5dM003M0034GAd00Ed0a42M0034G@A008A00=G?Q401A400e`A
G0084@Ad0Q400g@AM0024@0OM15G?Q4nEciG?ULnEciG?ULnEciG?ULnEciG?ULn4@0AG0034GAd00Md
0Q4<M0006g@00a5dM00FM0034GAd009d00<AM7@01W@00a5dM003M0034GAd00Ed00<AM7@011401W@A
4ChA?P@A00=L4A401144M0034GAd009d00DAM7@AM0024@0bM14n?a4o?Sln?cho?Sln?cho?Sln?cho
?Sln?cho4Ea7G4MLAea7G4MLAea7G4MLAa44M0@A00=d4G@02g@001]d0Q4GM0034GAd00=d00<AM7@0
1G@00a5dM004M0034GAd009d1A43M0034G@A008A00<n4A401A401E`AG5`A00Ad0a42M0044GAdM08A
0W@07Q5G?ULAEciG?ULnEciG?ULnEciG?ULnEciG?ULn4A=L1145M0034GAd00Yd000KM0034GAd01Id
00<AM7@00g@00a5dM006M0034GAd00=d00<AM7@00Q4017@A4A43M0<A00=d4A401A402G@AAa574DML
4@03M0034GAd00<A0g@54@0a?Sln4Cho?Sln?cho?Sln?cho?Sln?cho?Sln?a5LAea7G4MLAea7G4ML
Aea7G4ML4@09M0034GAd00Ud000KM0034GAd01Md00<AM7@00W@00a5dM006M0034GAd00=d0a400g@A
4@02M0044GAd4@9d00<AM1402Q42G0@A0W@01A5dM15d008A00=d4A400Q407g@AEciG?Q4nEciG?ULn
EciG?ULnEciG?ULnEciG?Q4055`00a5dM006M0034GAd00Ud000KM0034GAd01Md00<AM7@00g@00a5d
M005M0034GAd00=d1144M0054GAd4G@01Q400chA4@034@08M157G15L4E`34@9d00<AM1400Q42M08A
03Ed4Cho?SlA?cho?Q4n?cho?Sln?cho?Sln?cho?SlAG4MLAea7G4MLAea7G4MLAea7G4ML4@07M003
4GAd00Ud000KM0034GAd01Md00<AM7@00g@00a5dM005M0044GAdM08A00=d4G@01G@54@07M14A?ULA
E`034@05M15dM1400U`0115L4E`64@03M15d00@A01md4ELnEchA?Q4nEciG?ULnEciG?ULnEciG?ULn
EchA01IL00<AM7@017@00a5dM009M0006W@00a5dM00IM0034GAd009d00<AM7@01W@34@04M14A4@Ad
1A42M0<A00@o?Q4n0a4017@A4G@24@06Ae`A4DML1142M0034GAd00DA03Dn?a4o?Q4n?cho?Sln?cho
?Sln?cho?Sln?cho4Ea7G4MLAea7G4MLAea7G4MLAea7G4ML4@05M0034GAd00Ud000JM0034GAd01Ud
00<AM7@00W@00a5dM006M0044G@A4@=d1143M0044GAdM0<A00<n4Ch01A402g@AM15d4E`AG15L008A
0W@24@04M15d4@9d0Q407ELnEciG4ELnEciG?ULnEciG?ULnEciG?ULnEchA01ML00<AM7@00g@00a5d
M009M0006W@00a5dM00IM0034GAd00=d00<AM7@00g@44@=d0a45M08A0g@0215d4ClA?a5d0a4027@A
4G@AM1570Q4015`AG143M0PA03Hn?cho?SlA?cho?Sln?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4ML
Aea7G4MLAea7G4MLAa45M0034GAd00Qd000JM08A6W@00a5dM003M0044GAdM0@A00=d4A400Q43M003
4GAd009d00@AM15d0Q401G@A4A4n00DA00=d4G@00Q4017@A4E`34@9L00<AM1401142M08A01eG?ULn
EchA?ULnEciG?ULnEciG?ULnEciG?ULn4@0IG0034GAd009d00<AM7@027@001Yd00<AM7@06W@00a5d
M002M0034G@A00LA1W@01A5dM7@A009d00TAM15d4ChA?Sl00a401g@AM15d4G@00Q401W@A4A57G0<A
0W@01A5d4A5d008A03Pn?cho?Sln4Cho?Sln?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4MLAea7G4ML
Aea7G4MLAea74@=d00<AM7@027@001Yd00<AM7@06W@00a5dM003M0DA17@00a5dM004M0044GAd4@9d
010AM15d4ELAEchAM15d4G@A0W@24@=d1143G0044G@A4@9d0a407ELnEciG?ULAEciG?ULnEciG?ULn
EciG?ULnEchA01]L00@AM7@A2W@001Yd00<AM7@06W@0115dM7@44@Md00<AM7@017@00a5d4@04M008
4GAd4ChA?Sl34@06M14AM15d21401Ea7G4ML00<A0g@24@0l?Sln?cho?Q4n?cho?Sln?cho?Sln?cho
?Sln?chAAea7G4MLAea7G4MLAea7G4MLAea7G4MLAea74G@A2W@001Yd00<AM7@06g@44@03M15d00Qd
00<AM7@00g@00a5d4@03M08A0W@01A5G4A4n008A00Ed4A4AM0054@9d00@AM14A15`34@=d0Q407ULn
EciG?ULn4CiG?ULnEciG?ULnEciG?ULnEciG4@=L00<AG5`05E`00a5d4@0:M0006W@00a5dM00KM08A
17@00a5dM006M0034GAd00Ad00<AM7@00W@24@9d00<A?Q400Q400g@AM0054@06M15d4G@A0g@01Q57
G4MLA`8A0g@24@0m?Sln?cho?SlA?cho?Sln?cho?Sln?cho?Sln?chAAea7G4MLAea7G4MLAea7G4ML
Aea7G4MLAea7G15d4@09M0006W@00a5dM00KM0034GAd00=d00<AM7@01W@00a5dM003M08A0g@01A5d
4A5d008A00@nEa5d11401G@A4G@A009d0Q44M0034EaL009L0Q43M08A01iG?ULnEciG?ULAEciG?ULn
EciG?ULnEciG?ULnEa4MG08A2G@001Ud00<AM7@07G@00a5dM003M0034GAd00Id00<AM7@00W@00a5d
4@02M0034G@A008A00@o4Cln0a42M0034G@A008A0g@00a5dM003M08A00I7G4LAAa42M08A00Pn?cho
?Sln?`8A034n?cho?Sln?cho?Sln?cho?Sln4DMLAea7G4MLAea7G4MLAea7G4MLAea7G4MLAea7008A
2G@001Ud0Q4NM0034GAd00=d00<AM7@01W@01A5dM7@A009d00DAM15d4@02M0054ChA?UL00a42M003
4GAd008A00=d4A400Q45M08A0U`01A5LG15d008A00AG?ULn11405ULn4CiG?ULnEciG?ULnEciG?ULn
Ea4IG0@A00=d4G@027@001Ud00<AM7@07W@00a5dM003M0034GAd00Id00@AM7@A0g@24@09M15dM14o
4Cln00@A00Ad4A5d0a400g@AM0024@Ed0Q401DLAAea700<A03<n4A4A?Sln?cho4Cln?cho?Sln?cho
?Sln?cho?Q57G4MLAea7G4MLAea7G4MLAea7G4L01145M0034GAd00Md000IM0034GAd01id00<AM7@0
0g@00a5dM006M0034G@A00Ad00@AM7@A0W@01a4n4CiG4G@00Q400g@A4@034@9d00DAM15d4@04M0@A
0e`44@0L?ULnEciG?ULnEa5G?ULnEciG?ULnEciG?ULnE`8A45`44@Ud00<AM7@01g@001Ud00<AM7@0
7g@00a5dM003M0034GAd00Id0Q43M08A0W@02Q5dM14o4Cln4G@64@04M15d4@=d0Q45M0HA02mL4A4n
?cho?Sln?cho?Q4n?cho?Sln?cho?Sln?cho?Q5d4DMLAea7G4MLAea7G0034@ed00<AM7@01g@001Ud
00<AM7@07g@00a5dM003M0034GAd00Id00<AM7@00W@01A5d4G@A009d00LA?Q4nEa5d008A00Ad4G@A
0W@24@=d00<AM14017@44@=L0Q407ULnEciG?ULnEciG?Q4nEciG?ULnEciG?ULnEciG4@9d00<AG5`0
1E`44A1d00<AM7@01g@001Ud00<AM7@07g@00a5dM004M0034GAd00Ad00<AM1400W@01Q5dM15d4@9d
0Q400cho?P044@07M15dM15d4@05M0034G@A00<A00Md4A5d4DML008A01hn?cho?Sln?cho?SlA?cho
?Sln?cho?Sln?cho?Q43M0034DML00@A57@00a5dM007M0006G@00a5dM00PM0034GAd00=d00<AM7@0
17@00a5d4@02M0054GAdM1400g@24@07EciG4G@AM0024@9d00@AM14A0g@34@03M15d009d0a400g@A
G0024@0NEciG?ULnEciG?ULnEa5G?ULnEciG?ULnEciG?ULA0g@34AQd00<AM7@01g@001Ud00<AM7@0
87@00a5dM003M0034GAd00=d00@AM7Ad0Q44M0044GAdM08A00Xn?chAM15d4G@A0W@00a5d4@034@9d
00<AM1400g@34@9d0a407Cho?Sln?cho?Sln?chA?Sln?cho?Sln?cho?Sln00@A00=d4G@067@00a5d
M007M00067@34B9d00<AM7@00g@01A5dM7@A00Ad0Q44M08A0W@24@0;EciG4G@AM15d4G@01A44M007
4GAd4G@AM0034@9d0Q407ULnEciG?ULnEciG?ULn4CiG?ULnEciG?ULnEciG4@Ad00<AM7@05g@00a5d
M007M00067@00a5dM00RM0034GAd00=d00DAM7Ad4@04M08A17@24@9d0Q401Sho?Q5d4@9d0a42M0<A
1G@00a5dM0024@03M15d008A025d4A4n?cho?Sln?cho?Sln?a4o?Sln?cho?Sln?cho?Q4017@00a5d
M00GM0034GAd00Md000HM0034GAd02=d00<AM7@00g@00a5d4@04M0044GAd4@=d00@AM15d0Q400eLn
E`074@=d00@AM14A17@01a5dM7@AM1400W@44@0NEciG?ULnEciG?ULnEciG4ELnEciG?ULnEciG?ULA
17@00a5dM00GM0034GAd00Md0003M08A0g@00a5dM0024@9d1145M0034GAd02=d00<AM7@00g@00a5d
4@04M0044GAd4@=d00LAM15d4Cln00DA0W@24@Ad0a45M0064GAd4G@A0g@34@0N?Sln?cho?Sln?cho
?Sln4Cho?Sln?cho?Sln?chA17@00a5dM00GM0034GAd00Md0002M0044GAd4@Ad00@AM7@A0W@00a5d
M005M0034GAd02=d00<AM7@017@00a5dM002M0034GAd009d00<AM1400g@44@03?Q5d008A0g@00a5d
M002M08A00=d4G@00g@00a5dM0034@=d0a407ULnEciG4ELnEciG?ULnEchA?ULnEciG?ULnEciG4@Ad
00<AM7@05g@00a5dM007M0000W@0115dM144M0044GAd4@=d00<AM7@017@0115dM14SM0034GAd009d
0Q43M0034GAd00Ad0Q400g@A4@024@05?cho4G@00Q43M0034GAd00=d0a45M0054G@AM1400g@34@0N
?Sln?cho?Sln?cho?Sln?a4o?Sln?cho?Sln?chA17@00a5dM00GM0034GAd00Md0002M0044GAd4@Ad
00@AM7@A0g@00a5dM005M0034G@A02=d00<AM7@00W@00a5d4@02M0034GAd00Ad0a42M08A00DnEchA
M0024@=d0Q44M08A00=d4G@00g@24@04M15d4@9d0a407ULnEciG?ULnEciG?ULnEciG4ELnEciG?ULn
EciG4@Ad00<AM7@05g@00a5dM007M0000W@0115dM144M0044GAd4@Ad00<AM7@01G@24BAd00@AM7@A
0W@00a5d4@03M0@A00=d4G@00W@24@05?cho4G@00Q44M0034GAd00=d00<AM1401G@0115d4G@44@0P
M14n?cho?Sln?cho?Sln?cho?Q4n?cho?Sln?cho?Q44M0034GAd01Id0Q49M0000W@0115dM144M006
4GAd4G@A0W@00a5dM007M0034GAd025d00<AM14017@54@Ed00@AM7Ad0a401eLn4G@AM1400g@00a5d
M003M0044GAd4@Ad11400g@A4@02M00N4ELnEciG?ULnEciG?ULnEciG?Q4nEciG?ULnEciG0Q43M003
4GAd019d11400g@AM008M0000g@24@Id0Q43M08A2g@00a5dM00QM08A00=d4A400a48M08A0W@02Q4n
4Cho4G@AM143M0034GAd00Ad00@AM15d1A43M08A0W@08A4n?cho?Sln?cho?Sln?cho?SlA?cho?Sln
?cho?Q5d4@02M0034GAd00id1145M0034GAd00Md000NM0034G@A021d0a44M0034GAd00Ed00<AM140
0W@02Q5G?Q4n4G@AM143M0034GAd00Ad1143M08A0g@24@9d01<AEciG?ULnEciG?ULnEciG?ULn008A
00aG?ULnEciG?ULAM142M0034GAd00Yd1149M0034GAd00Md000OM08A8G@00a5dM003M0034GAd00Ed
00/AM7@AM14n?a4o4@02M08A0g@24@=d114017@AM7@24@04M15d4@9d014AM14n?cho?Sln?cho?Sln
?`044@0A?SlA?cho?Sln?cho4G@AM1402G@34@ad00<AM7@027@0025d00<AM7@07W@00a5dM004M003
4GAd00Ad00TAM7@AM15G?UL00Q42M08A17@44@=d00HAM7@AM142M0034G@A00=d0Q402eLnEciG?ULn
EciG00<A015G?ULnEciG4ELnEciG?ULn4@02M08A1G@44@md00<AM7@027@0029d00<AM7@07W@00a5d
M004M0034GAd00=d00TAM7@AM14n?ch00Q42M08A00=d4A400Q46M08A00Ad4G@A0g@00a5dM002M08A
00Ln?cho?Sln00@A01@o?Sln?cho?Sln?a4o?Sln?cho4@9d0Q400g@A4@024A=d00<AM7@027@002=d
00<AM7@07G@00a5dM004M0034GAd009d00<AM7@00W@24@06EciG?Q5d1143M08A1G@24@9d0Q42M003
4G@A00Ad00DAEciG?P034@0H?ULnEciG?ULnEciG?ULn4CiG?ULnEchA0W@34AMd00<AM7@027@001Ad
0Q43M0034GAd008A0W@74Aed00<AM7@017@01A5dM7@A00Ad0Q4013ho?Sl24@03M14A00Ad0Q46M0<A
00Ad4G@A0W@00a5dM002M0034ChA008A01Xn?cho?Sln?cho?Sln?cho?Sln4Cho?Sln?`<A00=d4G@0
5g@00a5dM008M0004g@0115dM144M0044GAd4@9d00<AM7@00W@00a5dM00LM0034GAd00Ad00@AM7@A
17@24@04EciG?P8A00=d4A4017@24@Id0Q42M08A17@00a5d4@034@0N?ULnEciG?ULnEciG?ULnEciG
?ULnEchA?ULnEchA0g@00a5dM00FM0034GAd00Qd000>M0@A00Ed4GAd4@04M0044GAd4@=d00<AM7@0
0W@00a5dM00KM0034GAd00Ad00@AM7@A17@24@04?Sln?`8A00=d4A4017@00a5d4@04M08A00Ed4A5d
4@03M0<A0W@0814n?cho?Sln?cho?Sln?cho?Sln?cho?Sln4Cho?SlA0W@00a5dM00FM0034GAd00Ud
000CM0044GAd4@Ad00@AM7@A0g@00a5dM003M08A77@00a5dM004M08A1G@24@06EciG?Q5d0a44M003
4G@A00=d00<AM7@00a400g@A4@024@9d02<AM7@AEciG?ULnEciG?ULnEciG?ULnEciG?ULnEchA?ULn
4@02M0034GAd01Id00<AM7@02G@001=d00@AM7@A17@0115dM144M0034GAd00Ad0Q4JM0034GAd00Ad
0Q44M00:4G@A?Sln?chAM08A1G@24@9d00<AM7@01A400g@AM004M00R4G@A?Sln?cho?Sln?cho?Sln
?cho?Sln?cho?Sln4Cho4@9d00<AM7@05G@24@]d000CM0044GAd4@Ad00HAM7@AM142M0034GAd00Ed
00<AM7@06G@00a5dM004M0034GAd009d00XAM15G?ULnEa5d0Q45M0034G@A00DA00Ad4G@A0W@00a5d
M003M00Q4G@A?ULnEciG?ULnEciG?ULnEciG?ULnEciG?ULAEchA009d00<AM7@04G@44@03M15d00Yd
000DM08A1W@24@=d0Q49M0034GAd01Ud00<AM7@00g@24@=d00TAM14n?cho?Q400W@34@=d1145M006
4GAd4G@A1G@08a5d4Cln?cho?Sln?cho?Sln?cho?Sln?cho?Sln?a4o4G@A015d0a44M0034GAd00Yd
000]M08A6G@00a5dM002M0034G@A00=d00TAM7@A?ULnEa400W@00a5d4@054@03M15d00Ed00HAM7@A
M145M08A01`nEciG?ULnEciG?ULnEciG?ULnEciG?ULnEciG0Q400g@AM00=M0<A1g@00a5dM00:M000
;g@24AQd00DAM7Ad4@02M0044GAd4@9d00DA?cho?P074@=d00<AM1401W@01a5dM7@AM14017@24@0L
?cho?Sln?cho?Sln?cho?Sln?cho?Sln?cho?P8A00=d4G@02G@44@Ud00<AM7@02g@0031d00<AM7@0
5g@0115dM143M08A0g@00a4n4@034@04M14A4@Ed00@AM7@A1W@0115dM7@24@Ed01TA?ULnEciG?ULn
EciG?ULnEciG?ULnEciG00@A00Ad4A4A1g@34@ed00<AM7@02g@0035d00<AM7@05W@0115dM143M08A
00=d4A400Q401Cho?SlA009d0Q45M0044GAd4@Id00@AM7Ad0Q44M00F4Cln?cho?Sln?cho?Sln?cho
?Sln?`<A1G@44@=d0a4?M0034GAd00ad000bM08A00=d4G@057@24@Ad0a42M0074CiG?ULn4@02M08A
1G@0115dM146M0044GAdM08A17@04a4nEciG?ULnEciG?ULnEciG?UL00a400g@AM006M0034G@A00<A
4W@00a5dM00<M000=7@24AEd0Q4017@A4A42M00:4GAd4Cln?cho4@=d00<AM7@017@0115dM146M004
4GAdM08A0g@03a4o?Sln?cho?Sln?cho?P044@Ad00<AM7@00g@44@9d00<AM7@047@00a5dM00=M000
=G@00a5dM00DM08A1W@02A5d4CiG?ULn4@03M08A1G@01A5dM7@A00Ed00<AM7@00W@24@9d00`A?ULn
EciG?ULnEch34@03M15d00Ed00<AM1400a400g@AM004M0034GAd00id0Q4?M000=W@00a5dM00DM003
4GAd00Ed0Q401Sln?cho4@Ad00<AM7@017@0115dM146M0034GAd009d00`AM7@A?cho?Sln?ch34@Ad
00<AM7@00W@44@Ed00<AM7@017@24@Yd1A4@M000=g@24AEd00<AM7@01G@24@05EciG?Q401G@00a5d
M003M0054GAdM1401W@00a5dM002M0074G@A?ULnE`054@Id1A43M0034GAd009d00<AM7@01g@00a5d
M004M0<A0W@24A5d000iM08A57@00a5dM005M0074Cho?Sln4@04M0034GAd00Ad00DAM7Ad4@05M003
4GAd00=d0Q400clA4@024@04M15d4@=d1A46M0034GAd009d00<AM7@01g@74@Ad00<AM7@04G@003Yd
00<AM7@04g@00a5dM004M08A00DnEciG4@04M08A1W@0115dM146M0044GAdM0DA0W@24@9d1144M003
4GAd00Ed00@AM7@A1W@;4@=d00<AM7@04W@003]d00<AM7@04g@00a5dM003M08A00Do?Sln4@05M08A
1G@01A5dM7@A00Ed1142M0<A0W@54@Md00<AM7@01G@0115dM142M0PA1g@34AEd000lM08A57@00a5d
M002M0064ELAEciG0Q44M08A1W@01A5dM15d00@A00=d4G@00g@24@04M14A4@=d00<AM7@01G@00a5d
M005M0034G@A00<A00Ad4A4A1g@44AQd000nM08A4W@00a5dM002M0064Cho4Cln0Q45M08A1G@54@Id
00<AM7@00W@24@03M14A00=d00<AM7@01W@00a5dM003M0PA1W@44Aad000oM0034GAd015d00dAM7Ad
4ELnEa5G4G@A00Ad0Q42M0DA0g@00a5dM003M0054GAdM1400g@34@=d00<AM7@01G@00a5d4@074@Id
114PM000<7@24@=d00<AM7@00Q43M0DA4W@02Q5dM14n?cho4Cl24@Ad1144M0054GAdM1401W@0115d
M142M0054GAdM1400W@00a5dM003M0XA17@44BAd000_M0044GAd4@Ad00@AM7@A0g@01A5dM7@A019d
00PAM7@A?ULnE`LA00Ad4G@A1G@01A5dM7@A00Id0Q43M0034GAd009d0a400g@A4@064@9d0Q42M0@A
:7@002Ud1142M0044GAd4@Ad00@AM7@A0g@00a5dM002M08A4G@01a5d4Cln?ch01144M0034G@A00Id
00DAM7Ad4@05M0054GAdM1401G@84@=d1a4/M000;g@0115dM144M0044GAd4@=d00<AM7@00g@00a5d
M00@M08A00@n4A4A0W@24@Ed00<AM1401G@01A5dM7@A00Ed0Q4017@AM7@74@Ad1a4`M000;g@0115d
M144M0044GAd4@=d00<AM7@017@24A5d0Q47M0034GAd009d00@AM7@A1G@01A5dM7@A00=d00<AM140
1a47M0@A=7@002md00@AM7@A17@0115dM142M08A27@00a5dM00?M08A1W@24@=d00@AM7@A1G@00a5d
M002M0034G@A00HA1g@44CQd000`M08A1W@24@Ad00<AM7@01g@24A5d0Q44M0044G@A4@9d00@AM7@A
1G@00a5d4@074@Id114lM000BG@00a5dM00AM08A0g@01Q5dM15d4@9d00@AM7Ad1142M0@A17@44D1d
001:M08A4g@24@03M15d009d0a400g@A4@024@=d0a4017@AM7@44DAd001<M08A4g@34@9d1a43M08A
00=d4A400a58M000CG@00a5dM00CM0DA17@84Dad001>M0034GAd01Md215@M000Cg@24Fmd001AM08A
KG@0059d00<AM7@0Jg@005=d00<AM7@0JW@005Ad0a5YM000EW@00a5dM01WM000Eg@00a5dM01VM000
Bg@24@]d0Q5VM000BW@0115dM14<M08AI7@004Yd00@AM7@A3G@00a5dM01RM000BW@0115dM14>M003
4GAd065d001:M0044GAd4@md0a5PM000BW@0115dM14AM0034GAd05id001;M08A4g@00a5dM01MM000
HG@00a5d4@1LM000HW@24Ead001TM0034GAd05Ud001UM0034GAd05Qd001VM08AF7@006Md0Q5GM000
JG@00a5dM01DM000JW@24EAd001[M0034GAd059d001/M08ADW@005]d0Q43M0034GAd008A0g@34@=d
0Q5@M000FW@0115dM144M0044GAd4@=d00<AM7@00g@00a5dM01>M000FW@0115dM144M0044GAd4@=d
00<AM7@017@24Did001JM0044GAd4@Ad00@AM7@A0g@00a5dM006M08AC7@005Yd00@AM7@A17@0115d
M143M0034GAd00Md00<AM7@0BW@005Yd00@AM7@A17@0115dM142M08A2W@00a5d4@19M000Fg@24@Id
0Q44M0034GAd00Ud0Q59M000MW@24DQd001hM0034GAd04Ed0030M000`7@00<1d0030M000`7@00<1d
001_M08A0g@00a5dM0024@9d1151M000KW@0115dM144M0044GAd4@9d00<AM7@0@G@006id00@AM7@A
17@0115dM143M0034GAd041d001^M0044GAd4@Ad00@AM7@A0g@00a5dM010M000KW@0115dM144M004
4GAd4@Ad00<AM7@0?g@006id00@AM7@A17@01Q5dM15d4@9d00<AM7@0?g@006md0Q46M08A0g@24D9d
0030M000`7@00<1d0030M000`7@00<1d0000\
\>"],
  ImageRangeCache->{{{0, 191.625}, {287, 0}} -> {0.0595904, -0.0667112, 
  0.00382656, 0.00382656}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[LensSurfaces, Axes->True];", "Input",
  CellLabel->"In[57]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5175 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.247638 1.58239 -1.94072e-17 1.58239 [
[.13847 .13053 -8.34633 -10.9375 ]
[.13847 .13053 .65367 0 ]
[.24417 .08593 -23.9965 -11 ]
[.24417 .08593 2.5035 0 ]
[.35281 .04009 -18.9993 -10.9375 ]
[.35281 .04009 2.50074 0 ]
[.46453 -0.00703 -22.8389 -11 ]
[.46453 -0.00703 3.66112 0 ]
[.01532 1.08294 -15.6886 0 ]
[.01532 1.08294 12.7489 10.9375 ]
[.17878 1.21308 -15.2086 0 ]
[.17878 1.21308 13.2289 10.9375 ]
[.32483 1.32936 -4.68376 0 ]
[.32483 1.32936 4.31624 10.9375 ]
[.4561 1.43388 -10.9222 0 ]
[.4561 1.43388 10.5778 10.9375 ]
[.57473 1.52833 -10.6897 0 ]
[.57473 1.52833 10.8103 10.9375 ]
[.0741 .1946 -28.4375 -3.18123 ]
[.0741 .1946 0 7.75627 ]
[.05445 .3764 -28.4375 -3.30628 ]
[.05445 .3764 0 7.63122 ]
[.03302 .57462 -9 -3.44336 ]
[.03302 .57462 0 7.49414 ]
[.00958 .79158 -21.5 -3.5943 ]
[.00958 .79158 0 7.3432 ]
[-0.01618 1.03008 -21.5 -3.7613 ]
[-0.01618 1.03008 0 7.1762 ]
[ 0 0 0 0 ]
[ 1 1.5175 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09421 .16958 m
.49753 0 L
s
.15133 .14557 m
.15775 .15308 L
s
gsave
.13847 .13053 -69.3463 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25663 .10129 m
.26286 .10897 L
s
gsave
.24417 .08593 -84.9965 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.36485 .05578 m
.37088 .06363 L
s
gsave
.35281 .04009 -79.9993 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.47613 .009 m
.48193 .01701 L
s
gsave
.46453 -0.00703 -83.8389 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17216 .13681 m
.17599 .14134 L
s
.1931 .128 m
.19691 .13255 L
s
.21416 .11914 m
.21795 .12371 L
s
.23534 .11024 m
.2391 .11483 L
s
.27804 .09229 m
.28175 .09692 L
s
.29956 .08324 m
.30325 .08789 L
s
.32121 .07414 m
.32487 .07881 L
s
.34297 .06499 m
.34661 .06967 L
s
.38686 .04653 m
.39045 .05126 L
s
.40899 .03723 m
.41255 .04197 L
s
.43125 .02787 m
.43478 .03264 L
s
.45362 .01846 m
.45713 .02325 L
s
.13061 .15428 m
.13449 .15877 L
s
.11 .16294 m
.1139 .16741 L
s
.25 Mabswid
0 1.0494 m
.58581 1.5175 L
s
.01735 1.06326 m
.01837 1.05342 L
s
gsave
.01532 1.08294 -76.6886 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18016 1.19335 m
.18084 1.18349 L
s
gsave
.17878 1.21308 -76.2086 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32563 1.3096 m
.32604 1.29972 L
s
gsave
.32483 1.32936 -65.6838 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.45641 1.4141 m
.45657 1.40421 L
s
gsave
.4561 1.43388 -71.9222 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.57462 1.50855 m
.57456 1.49866 L
s
gsave
.57473 1.52833 -71.6897 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05145 1.09051 m
.05201 1.0846 L
s
.08475 1.11711 m
.08527 1.1112 L
s
.11728 1.14311 m
.11777 1.1372 L
s
.14908 1.16852 m
.14953 1.1626 L
s
.21055 1.21764 m
.21092 1.21171 L
s
.24027 1.24138 m
.24061 1.23546 L
s
.26934 1.26462 m
.26965 1.25869 L
s
.29779 1.28735 m
.29806 1.28142 L
s
.35289 1.33138 m
.3531 1.32545 L
s
.37958 1.35271 m
.37976 1.34677 L
s
.40572 1.37359 m
.40587 1.36766 L
s
.43133 1.39405 m
.43145 1.38812 L
s
.481 1.43375 m
.48107 1.42781 L
s
.5051 1.453 m
.50514 1.44707 L
s
.52873 1.47188 m
.52874 1.46595 L
s
.55189 1.49039 m
.55188 1.48446 L
s
.25 Mabswid
.09421 .16958 m
0 1.0494 L
s
.09235 .18697 m
.10147 .18315 L
s
gsave
.0741 .1946 -89.4375 -7.18123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.07284 .36913 m
.08204 .36549 L
s
gsave
.05445 .3764 -89.4375 -7.30628 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.05157 .56775 m
.06085 .56432 L
s
gsave
.03302 .57462 -70 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02829 .78517 m
.03765 .78196 L
s
gsave
.00958 .79158 -82.5 -7.5943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.0027 1.02418 m
.01214 1.02123 L
s
gsave
-0.01618 1.03008 -82.5 -7.7613 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.08857 .22219 m
.09406 .21992 L
s
.08474 .25799 m
.09023 .25575 L
s
.08084 .29441 m
.08634 .29218 L
s
.07687 .33145 m
.08238 .32925 L
s
.06873 .40747 m
.07426 .40531 L
s
.06456 .44648 m
.07009 .44435 L
s
.06031 .48619 m
.06585 .48408 L
s
.05598 .5266 m
.06153 .52452 L
s
.04709 .60965 m
.05266 .60761 L
s
.04252 .65232 m
.0481 .65031 L
s
.03786 .69578 m
.04346 .6938 L
s
.03312 .74005 m
.03873 .7381 L
s
.02337 .83114 m
.02899 .82925 L
s
.01835 .87801 m
.02399 .87614 L
s
.01324 .92578 m
.01888 .92395 L
s
.00802 .9745 m
.01367 .9727 L
s
0 0 m
1 0 L
1 1.5175 L
0 1.5175 L
closepath
clip
newpath
.5 Mabswid
.56398 .74349 m
.59682 .85168 L
s
.51426 .77206 m
.56398 .74349 L
s
.52111 .64038 m
.56398 .74349 L
s
.59682 .85168 m
.61811 .96003 L
s
.53696 .847 m
.59682 .85168 L
s
.57832 .73882 m
.61124 .8472 L
s
.52907 .76726 m
.57832 .73882 L
s
.53547 .6355 m
.57832 .73882 L
s
.61124 .8472 m
.63269 .95571 L
s
.55183 .84234 m
.61124 .8472 L
s
.4844 .7009 m
.52111 .64038 L
s
.47002 .54724 m
.52111 .64038 L
s
.49922 .69596 m
.53547 .6355 L
s
.48449 .54212 m
.53547 .6355 L
s
.61811 .96003 m
.62653 1.06345 L
s
.55129 .9218 m
.61811 .96003 L
s
.63269 .95571 m
.64137 1.05925 L
s
.56628 .91725 m
.63269 .95571 L
s
.71962 .69287 m
.75328 .80308 L
s
.67511 .71999 m
.71962 .69287 L
s
.67696 .58742 m
.71962 .69287 L
s
.75328 .80308 m
.7764 .9131 L
s
.6984 .79639 m
.75328 .80308 L
s
.44888 .63738 m
.47002 .54724 L
s
.41286 .46904 m
.47002 .54724 L
s
.46378 .63226 m
.48449 .54212 L
s
.42752 .46367 m
.48449 .54212 L
s
.64539 .64717 m
.67696 .58742 L
s
.6271 .4917 m
.67696 .58742 L
s
.62653 1.06345 m
.55634 .99243 L
s
.62653 1.06345 m
.62105 1.15654 L
s
.62653 1.06345 m
.62653 1.06345 L
s
.64137 1.05925 m
.5715 .98796 L
s
.64137 1.05925 m
.63621 1.15241 L
s
.64137 1.05925 m
.64137 1.05925 L
s
.7764 .9131 m
.78761 1.01778 L
s
.71403 .87237 m
.7764 .9131 L
s
.87107 .64361 m
.90554 .75579 L
s
.83185 .66925 m
.87107 .64361 L
s
.82865 .53589 m
.87107 .64361 L
s
.53696 .847 m
.51426 .77206 L
s
.4605 .80295 m
.51426 .77206 L
s
.51426 .77206 m
.4844 .7009 L
s
.90554 .75579 m
.93049 .86741 L
s
.85572 .74706 m
.90554 .75579 L
s
.55129 .9218 m
.53696 .847 L
s
.47228 .84194 m
.53696 .847 L
s
.61074 .58182 m
.6271 .4917 L
s
.57214 .41075 m
.6271 .4917 L
s
.55183 .84234 m
.52907 .76726 L
s
.47581 .79802 m
.52907 .76726 L
s
.52907 .76726 m
.49922 .69596 L
s
.56628 .91725 m
.55183 .84234 L
s
.48762 .83708 m
.55183 .84234 L
s
.40948 .58518 m
.41286 .46904 L
s
.35225 .41084 m
.41286 .46904 L
s
.41286 .46904 m
.41286 .46904 L
s
.4844 .7009 m
.44888 .63738 L
s
.44487 .76608 m
.4844 .7009 L
s
.42452 .5799 m
.42752 .46367 L
s
.36719 .40522 m
.42752 .46367 L
s
.42752 .46367 m
.42752 .46367 L
s
.8023 .5948 m
.82865 .53589 L
s
.78006 .43762 m
.82865 .53589 L
s
.49922 .69596 m
.46378 .63226 L
s
.46018 .76107 m
.49922 .69596 L
s
.55634 .99243 m
.55129 .9218 L
s
.47951 .88071 m
.55129 .9218 L
s
.78761 1.01778 m
.72103 .94388 L
s
.78761 1.01778 m
.78576 1.11168 L
s
.78761 1.01778 m
.78761 1.01778 L
s
.5715 .98796 m
.56628 .91725 L
s
.49491 .87592 m
.56628 .91725 L
s
.93049 .86741 m
.9445 .97329 L
s
.87266 .8242 m
.93049 .86741 L
s
.62105 1.15654 m
.60099 1.23355 L
s
.5515 1.05483 m
.62105 1.15654 L
s
.63621 1.15241 m
.61655 1.22945 L
s
.56689 1.05041 m
.63621 1.15241 L
s
.44888 .63738 m
.40948 .58518 L
s
.42631 .73357 m
.44888 .63738 L
s
.46378 .63226 m
.42452 .5799 L
s
.44167 .72847 m
.46378 .63226 L
s
.5515 1.05483 m
.55634 .99243 L
s
.55634 .99243 m
.4817 .91691 L
s
.55634 .99243 m
.55634 .99243 L
s
.6984 .79639 m
.67511 .71999 L
s
.6269 .74936 m
.67511 .71999 L
s
.67511 .71999 m
.64539 .64717 L
s
.5715 .98796 m
.5715 .98796 L
s
.56689 1.05041 m
.5715 .98796 L
s
.5715 .98796 m
.49719 .91216 L
s
.76855 .52766 m
.78006 .43762 L
s
.72737 .35394 m
.78006 .43762 L
s
.71403 .87237 m
.6984 .79639 L
s
.63901 .78915 m
.6984 .79639 L
s
.57289 .52775 m
.57214 .41075 L
s
.51462 .34976 m
.57214 .41075 L
s
.57214 .41075 m
.57214 .41075 L
s
.64539 .64717 m
.61074 .58182 L
s
.61135 .7116 m
.64539 .64717 L
s
.9445 .97329 m
.88163 .89654 L
s
.9445 .97329 m
.94634 1.06795 L
s
.9445 .97329 m
.9445 .97329 L
s
.72103 .94388 m
.71403 .87237 L
s
.64692 .82856 m
.71403 .87237 L
s
.40948 .58518 m
.36832 .54782 L
s
.40593 .70749 m
.40948 .58518 L
s
.40948 .58518 m
.40948 .58518 L
s
.36832 .54782 m
.35225 .41084 L
s
.29141 .37761 m
.35225 .41084 L
s
.42452 .5799 m
.38355 .54237 L
s
.42136 .7023 m
.42452 .5799 L
s
.42452 .5799 m
.42452 .5799 L
s
.78576 1.11168 m
.77004 1.18899 L
s
.71871 1.0068 m
.78576 1.11168 L
s
.38355 .54237 m
.36719 .40522 L
s
.3067 .37175 m
.36719 .40522 L
s
.52532 1.10814 m
.5515 1.05483 L
s
.47408 .94964 m
.5515 1.05483 L
s
.61074 .58182 m
.57289 .52775 L
s
.59325 .67813 m
.61074 .58182 L
s
.54072 1.1038 m
.56689 1.05041 L
s
.48944 .94498 m
.56689 1.05041 L
s
.71871 1.0068 m
.72103 .94388 L
s
.72103 .94388 m
.65014 .86521 L
s
.72103 .94388 m
.72103 .94388 L
s
.60099 1.23355 m
.56631 1.28852 L
s
.52532 1.10814 m
.60099 1.23355 L
s
.85572 .74706 m
.83185 .66925 L
s
.78932 .69706 m
.83185 .66925 L
s
.83185 .66925 m
.8023 .5948 L
s
.87266 .8242 m
.85572 .74706 L
s
.80174 .73761 m
.85572 .74706 L
s
.47228 .84194 m
.4605 .80295 L
s
.4605 .80295 m
.44487 .76608 L
s
.40218 .83646 m
.4605 .80295 L
s
.61655 1.22945 m
.5823 1.2844 L
s
.54072 1.1038 m
.61655 1.22945 L
s
.47951 .88071 m
.47228 .84194 L
s
.40218 .83646 m
.47228 .84194 L
s
.73231 .47172 m
.72737 .35394 L
s
.67304 .29017 m
.72737 .35394 L
s
.72737 .35394 m
.72737 .35394 L
s
.48762 .83708 m
.47581 .79802 L
s
.47581 .79802 m
.46018 .76107 L
s
.41802 .83139 m
.47581 .79802 L
s
.49491 .87592 m
.48762 .83708 L
s
.41802 .83139 m
.48762 .83708 L
s
.44487 .76608 m
.42631 .73357 L
s
.40218 .83646 m
.44487 .76608 L
s
.8023 .5948 m
.76855 .52766 L
s
.77385 .65841 m
.8023 .5948 L
s
.4817 .91691 m
.47951 .88071 L
s
.40218 .83646 m
.47951 .88071 L
s
.46018 .76107 m
.44167 .72847 L
s
.41802 .83139 m
.46018 .76107 L
s
.49719 .91216 m
.49491 .87592 L
s
.41802 .83139 m
.49491 .87592 L
s
.88163 .89654 m
.87266 .8242 L
s
.81036 .77764 m
.87266 .8242 L
s
.36832 .54782 m
.32781 .52837 L
s
.38495 .68961 m
.36832 .54782 L
s
.42631 .73357 m
.40593 .70749 L
s
.40218 .83646 m
.42631 .73357 L
s
.38355 .54237 m
.34328 .52277 L
s
.40048 .68434 m
.38355 .54237 L
s
.57368 .65108 m
.57289 .52775 L
s
.57289 .52775 m
.57289 .52775 L
s
.57289 .52775 m
.53389 .48854 L
s
.44167 .72847 m
.42136 .7023 L
s
.41802 .83139 m
.44167 .72847 L
s
.47408 .94964 m
.4817 .91691 L
s
.4817 .91691 m
.40218 .83646 L
s
.4817 .91691 m
.4817 .91691 L
s
.94634 1.06795 m
.93503 1.14551 L
s
.88187 .95994 m
.94634 1.06795 L
s
.53389 .48854 m
.51462 .34976 L
s
.45766 .31388 m
.51462 .34976 L
s
.47706 1.14871 m
.52532 1.10814 L
s
.45412 .97753 m
.52532 1.10814 L
s
.48944 .94498 m
.49719 .91216 L
s
.49719 .91216 m
.41802 .83139 L
s
.49719 .91216 m
.49719 .91216 L
s
.49274 1.14435 m
.54072 1.1038 L
s
.46962 .97288 m
.54072 1.1038 L
s
.76855 .52766 m
.73231 .47172 L
s
.75624 .624 m
.76855 .52766 L
s
.70677 1.05705 m
.71871 1.0068 L
s
.64838 .8968 m
.71871 1.0068 L
s
.40593 .70749 m
.40218 .83646 L
s
.40593 .70749 m
.40593 .70749 L
s
.40593 .70749 m
.38495 .68961 L
s
.42136 .7023 m
.41802 .83139 L
s
.42136 .7023 m
.42136 .7023 L
s
.42136 .7023 m
.40048 .68434 L
s
.45412 .97753 m
.47408 .94964 L
s
.40218 .83646 m
.47408 .94964 L
s
.88187 .95994 m
.88163 .89654 L
s
.88163 .89654 m
.81462 .81473 L
s
.88163 .89654 m
.88163 .89654 L
s
.46962 .97288 m
.48944 .94498 L
s
.41802 .83139 m
.48944 .94498 L
s
.77004 1.18899 m
.74017 1.24369 L
s
.70677 1.05705 m
.77004 1.18899 L
s
.32781 .52837 m
.29141 .37761 L
s
.2342 .37383 m
.29141 .37761 L
s
.63901 .78915 m
.6269 .74936 L
s
.57452 .78128 m
.6269 .74936 L
s
.6269 .74936 m
.61135 .7116 L
s
.64692 .82856 m
.63901 .78915 L
s
.57452 .78128 m
.63901 .78915 L
s
.34328 .52277 m
.3067 .37175 L
s
.2499 .36776 m
.3067 .37175 L
s
.61135 .7116 m
.59325 .67813 L
s
.57452 .78128 m
.61135 .7116 L
s
.38495 .68961 m
.36472 .68131 L
s
.40218 .83646 m
.38495 .68961 L
s
.65014 .86521 m
.64692 .82856 L
s
.57452 .78128 m
.64692 .82856 L
s
.42914 .99672 m
.45412 .97753 L
s
.40218 .83646 m
.45412 .97753 L
s
.40048 .68434 m
.38038 .67596 L
s
.41802 .83139 m
.40048 .68434 L
s
.44477 .99205 m
.46962 .97288 L
s
.41802 .83139 m
.46962 .97288 L
s
.32781 .52837 m
.29063 .52923 L
s
.36472 .68131 m
.32781 .52837 L
s
.53389 .48854 m
.49605 .46741 L
s
.55384 .63229 m
.53389 .48854 L
s
.59325 .67813 m
.57368 .65108 L
s
.57452 .78128 m
.59325 .67813 L
s
.73752 .59599 m
.73231 .47172 L
s
.73231 .47172 m
.73231 .47172 L
s
.73231 .47172 m
.69554 .43066 L
s
.34328 .52277 m
.30637 .5235 L
s
.38038 .67596 m
.34328 .52277 L
s
.69554 .43066 m
.67304 .29017 L
s
.62006 .25164 m
.67304 .29017 L
s
.42884 1.16746 m
.47706 1.14871 L
s
.47706 1.14871 m
.56631 1.28852 L
s
.42914 .99672 m
.47706 1.14871 L
s
.56631 1.28852 m
.5154 1.31634 L
s
.64838 .8968 m
.65014 .86521 L
s
.65014 .86521 m
.57452 .78128 L
s
.65014 .86521 m
.65014 .86521 L
s
.4448 1.16302 m
.49274 1.14435 L
s
.49274 1.14435 m
.5823 1.2844 L
s
.44477 .99205 m
.49274 1.14435 L
s
.5823 1.2844 m
.53157 1.3122 L
s
.68538 1.09076 m
.70677 1.05705 L
s
.64162 .92121 m
.70677 1.05705 L
s
.87293 1.01026 m
.88187 .95994 L
s
.81418 .84654 m
.88187 .95994 L
s
.40563 1.0042 m
.42914 .99672 L
s
.40218 .83646 m
.42914 .99672 L
s
.36472 .68131 m
.34662 .68344 L
s
.40218 .83646 m
.36472 .68131 L
s
.57368 .65108 m
.57452 .78128 L
s
.57368 .65108 m
.57368 .65108 L
s
.57368 .65108 m
.55384 .63229 L
s
.4214 .99949 m
.44477 .99205 L
s
.41802 .83139 m
.44477 .99205 L
s
.38038 .67596 m
.36241 .67804 L
s
.41802 .83139 m
.38038 .67596 L
s
.64162 .92121 m
.64838 .8968 L
s
.57452 .78128 m
.64838 .8968 L
s
.93503 1.14551 m
.91007 1.19987 L
s
.87293 1.01026 m
.93503 1.14551 L
s
.80174 .73761 m
.78932 .69706 L
s
.74303 .72733 m
.78932 .69706 L
s
.78932 .69706 m
.77385 .65841 L
s
.81036 .77764 m
.80174 .73761 L
s
.74303 .72733 m
.80174 .73761 L
s
.49605 .46741 m
.45766 .31388 L
s
.40492 .30783 m
.45766 .31388 L
s
.40218 .83646 m
.40218 .83646 L
s
.40218 .83646 m
.34662 .68344 L
s
.40218 .83646 m
.33195 .6962 L
s
.40218 .83646 m
.32188 .71904 L
s
.40218 .83646 m
.31728 .75057 L
s
.40218 .83646 m
.31863 .78865 L
s
.40218 .83646 m
.32594 .8305 L
s
.40218 .83646 m
.3387 .87294 L
s
.40218 .83646 m
.35516 .91294 L
s
.40218 .83646 m
.36645 .94979 L
s
.40218 .83646 m
.3755 .97954 L
s
.40218 .83646 m
.38758 .99839 L
s
.40218 .83646 m
.40563 1.0042 L
s
.77385 .65841 m
.75624 .624 L
s
.74303 .72733 m
.77385 .65841 L
s
.41802 .83139 m
.41802 .83139 L
s
.41802 .83139 m
.36241 .67804 L
s
.41802 .83139 m
.34789 .69077 L
s
.41802 .83139 m
.33796 .7136 L
s
.41802 .83139 m
.33349 .74515 L
s
.41802 .83139 m
.33494 .78327 L
s
.41802 .83139 m
.34232 .82519 L
s
.41802 .83139 m
.35511 .86771 L
s
.41802 .83139 m
.37129 .9079 L
s
.41802 .83139 m
.38255 .94484 L
s
.41802 .83139 m
.39151 .97469 L
s
.41802 .83139 m
.40348 .99362 L
s
.41802 .83139 m
.4214 .99949 L
s
.81462 .81473 m
.81036 .77764 L
s
.74303 .72733 m
.81036 .77764 L
s
.38758 .99839 m
.40563 1.0042 L
s
.40563 1.0042 m
.42884 1.16746 L
s
.55384 .63229 m
.535 .62319 L
s
.57452 .78128 m
.55384 .63229 L
s
.34662 .68344 m
.33195 .6962 L
s
.29063 .52923 m
.34662 .68344 L
s
.40348 .99362 m
.4214 .99949 L
s
.4214 .99949 m
.4448 1.16302 L
s
.69554 .43066 m
.66044 .40784 L
s
.71885 .57629 m
.69554 .43066 L
s
.36241 .67804 m
.34789 .69077 L
s
.30637 .5235 m
.36241 .67804 L
s
.75624 .624 m
.73752 .59599 L
s
.74303 .72733 m
.75624 .624 L
s
.63017 .93663 m
.64162 .92121 L
s
.57452 .78128 m
.64162 .92121 L
s
.49605 .46741 m
.4619 .4669 L
s
.535 .62319 m
.49605 .46741 L
s
.29063 .52923 m
.2596 .5517 L
s
.2342 .37383 m
.29063 .52923 L
s
.39353 1.15907 m
.42884 1.16746 L
s
.42884 1.16746 m
.5154 1.31634 L
s
.81418 .84654 m
.81462 .81473 L
s
.81462 .81473 m
.74303 .72733 L
s
.81462 .81473 m
.81462 .81473 L
s
.74017 1.24369 m
.69669 1.26992 L
s
.68538 1.09076 m
.74017 1.24369 L
s
.30637 .5235 m
.27564 .54589 L
s
.2499 .36776 m
.30637 .5235 L
s
.40976 1.15453 m
.4448 1.16302 L
s
.4448 1.16302 m
.53157 1.3122 L
s
.18503 .40276 m
.2342 .37383 L
s
.85484 1.04362 m
.87293 1.01026 L
s
.80896 .87093 m
.87293 1.01026 L
s
.65536 1.10459 m
.68538 1.09076 L
s
.63017 .93663 m
.68538 1.09076 L
s
.20116 .39655 m
.2499 .36776 L
s
.3755 .97954 m
.38758 .99839 L
s
.38758 .99839 m
.39353 1.15907 L
s
.73752 .59599 m
.74303 .72733 L
s
.73752 .59599 m
.73752 .59599 L
s
.73752 .59599 m
.71885 .57629 L
s
.535 .62319 m
.51843 .62471 L
s
.57452 .78128 m
.535 .62319 L
s
.33195 .6962 m
.2596 .5517 L
s
.33195 .6962 m
.32188 .71904 L
s
.39151 .97469 m
.40348 .99362 L
s
.40348 .99362 m
.40976 1.15453 L
s
.80896 .87093 m
.81418 .84654 L
s
.74303 .72733 m
.81418 .84654 L
s
.34789 .69077 m
.27564 .54589 L
s
.34789 .69077 m
.33796 .7136 L
s
.61464 .94173 m
.63017 .93663 L
s
.57452 .78128 m
.63017 .93663 L
s
.66044 .40784 m
.62006 .25164 L
s
.57192 .24326 m
.62006 .25164 L
s
.57452 .78128 m
.57452 .78128 L
s
.57452 .78128 m
.51843 .62471 L
s
.57452 .78128 m
.50538 .6371 L
s
.57452 .78128 m
.49687 .65983 L
s
.57452 .78128 m
.49368 .69156 L
s
.57452 .78128 m
.49617 .73012 L
s
.57452 .78128 m
.50427 .77272 L
s
.57452 .78128 m
.5174 .81609 L
s
.57452 .78128 m
.53456 .8569 L
s
.57452 .78128 m
.55441 .89203 L
s
.57452 .78128 m
.57541 .91894 L
s
.57452 .78128 m
.59597 .93581 L
s
.57452 .78128 m
.61464 .94173 L
s
.5154 1.31634 m
.45689 1.31047 L
s
.71885 .57629 m
.70143 .56639 L
s
.74303 .72733 m
.71885 .57629 L
s
.53157 1.3122 m
.47347 1.30619 L
s
.37067 1.12335 m
.3755 .97954 L
s
.3755 .97954 m
.3755 .97954 L
s
.36645 .94979 m
.3755 .97954 L
s
.32188 .71904 m
.31728 .75057 L
s
.23745 .59556 m
.32188 .71904 L
s
.51843 .62471 m
.50538 .6371 L
s
.4619 .4669 m
.51843 .62471 L
s
.38713 1.11866 m
.39151 .97469 L
s
.39151 .97469 m
.39151 .97469 L
s
.38255 .94484 m
.39151 .97469 L
s
.79916 .88611 m
.80896 .87093 L
s
.74303 .72733 m
.80896 .87093 L
s
.33796 .7136 m
.33349 .74515 L
s
.25377 .58972 m
.33796 .7136 L
s
.66044 .40784 m
.62942 .40593 L
s
.70143 .56639 m
.66044 .40784 L
s
.59597 .93581 m
.61464 .94173 L
s
.61464 .94173 m
.65536 1.10459 L
s
.4619 .4669 m
.43409 .48845 L
s
.40492 .30783 m
.4619 .4669 L
s
.2596 .5517 m
.18503 .40276 L
s
.2596 .5517 m
.23745 .59556 L
s
.91007 1.19987 m
.87171 1.2251 L
s
.85484 1.04362 m
.91007 1.19987 L
s
.37067 1.12335 m
.39353 1.15907 L
s
.39353 1.15907 m
.45689 1.31047 L
s
.27564 .54589 m
.20116 .39655 L
s
.27564 .54589 m
.25377 .58972 L
s
.38713 1.11866 m
.40976 1.15453 L
s
.40976 1.15453 m
.47347 1.30619 L
s
.31728 .75057 m
.22645 .65867 L
s
.31728 .75057 m
.31863 .78865 L
s
.31728 .75057 m
.31728 .75057 L
s
.36057 .33513 m
.40492 .30783 L
s
.82816 1.05663 m
.85484 1.04362 L
s
.79916 .88611 m
.85484 1.04362 L
s
.35516 .91294 m
.36645 .94979 L
s
.36645 .94979 m
.34623 1.06597 L
s
.70143 .56639 m
.68645 .56728 L
s
.74303 .72733 m
.70143 .56639 L
s
.33349 .74515 m
.24303 .65286 L
s
.33349 .74515 m
.33494 .78327 L
s
.33349 .74515 m
.33349 .74515 L
s
.37129 .9079 m
.38255 .94484 L
s
.38255 .94484 m
.36287 1.06109 L
s
.61823 1.09619 m
.65536 1.10459 L
s
.65536 1.10459 m
.69669 1.26992 L
s
.50538 .6371 m
.43409 .48845 L
s
.50538 .6371 m
.49687 .65983 L
s
.78527 .89073 m
.79916 .88611 L
s
.74303 .72733 m
.79916 .88611 L
s
.31863 .78865 m
.22809 .73684 L
s
.31863 .78865 m
.32594 .8305 L
s
.57541 .91894 m
.59597 .93581 L
s
.59597 .93581 m
.61823 1.09619 L
s
.3387 .87294 m
.35516 .91294 L
s
.35516 .91294 m
.30568 .99555 L
s
.33494 .78327 m
.24489 .73112 L
s
.33494 .78327 m
.34232 .82519 L
s
.74303 .72733 m
.74303 .72733 L
s
.74303 .72733 m
.68645 .56728 L
s
.74303 .72733 m
.67505 .57926 L
s
.74303 .72733 m
.66815 .60187 L
s
.74303 .72733 m
.6664 .63377 L
s
.74303 .72733 m
.67006 .6728 L
s
.74303 .72733 m
.67896 .71611 L
s
.74303 .72733 m
.69246 .7604 L
s
.74303 .72733 m
.70953 .80224 L
s
.74303 .72733 m
.72883 .83844 L
s
.74303 .72733 m
.74887 .86635 L
s
.74303 .72733 m
.76813 .88411 L
s
.74303 .72733 m
.78527 .89073 L
s
.35511 .86771 m
.37129 .9079 L
s
.37129 .9079 m
.32269 .99038 L
s
.32594 .8305 m
.3387 .87294 L
s
.24272 .82399 m
.32594 .8305 L
s
.3387 .87294 m
.26934 .91279 L
s
.69669 1.26992 m
.64135 1.26276 L
s
.34232 .82519 m
.35511 .86771 L
s
.25967 .81843 m
.34232 .82519 L
s
.14854 .46554 m
.18503 .40276 L
s
.35511 .86771 m
.28636 .90741 L
s
.68645 .56728 m
.67505 .57926 L
s
.62942 .40593 m
.68645 .56728 L
s
.49687 .65983 m
.49368 .69156 L
s
.41512 .53197 m
.49687 .65983 L
s
.1651 .45927 m
.20116 .39655 L
s
.76813 .88411 m
.78527 .89073 L
s
.78527 .89073 m
.82816 1.05663 L
s
.57635 1.06471 m
.57541 .91894 L
s
.57541 .91894 m
.57541 .91894 L
s
.55441 .89203 m
.57541 .91894 L
s
.62942 .40593 m
.60492 .42652 L
s
.57192 .24326 m
.62942 .40593 L
s
.23745 .59556 m
.22645 .65867 L
s
.14854 .46554 m
.23745 .59556 L
s
.43409 .48845 m
.36057 .33513 L
s
.43409 .48845 m
.41512 .53197 L
s
.25377 .58972 m
.24303 .65286 L
s
.1651 .45927 m
.25377 .58972 L
s
.37067 1.12335 m
.38959 1.26928 L
s
.37067 1.12335 m
.37067 1.12335 L
s
.34623 1.06597 m
.37067 1.12335 L
s
.53254 .26886 m
.57192 .24326 L
s
.45689 1.31047 m
.38959 1.26928 L
s
.40683 1.2647 m
.38713 1.11866 L
s
.38713 1.11866 m
.38713 1.11866 L
s
.36287 1.06109 m
.38713 1.11866 L
s
.49368 .69156 m
.40704 .59541 L
s
.49368 .69156 m
.49617 .73012 L
s
.49368 .69156 m
.49368 .69156 L
s
.47347 1.30619 m
.40683 1.2647 L
s
.7942 1.04695 m
.82816 1.05663 L
s
.82816 1.05663 m
.87171 1.2251 L
s
.67505 .57926 m
.60492 .42652 L
s
.67505 .57926 m
.66815 .60187 L
s
.53456 .8569 m
.55441 .89203 L
s
.55441 .89203 m
.53277 1.01126 L
s
.57635 1.06471 m
.61823 1.09619 L
s
.61823 1.09619 m
.64135 1.26276 L
s
.74887 .86635 m
.76813 .88411 L
s
.76813 .88411 m
.7942 1.04695 L
s
.49617 .73012 m
.4111 .67458 L
s
.49617 .73012 m
.50427 .77272 L
s
.5174 .81609 m
.53456 .8569 L
s
.53456 .8569 m
.49106 .93923 L
s
.87171 1.2251 m
.8213 1.21622 L
s
.50427 .77272 m
.5174 .81609 L
s
.42743 .76335 m
.50427 .77272 L
s
.5174 .81609 m
.45486 .8542 L
s
.32894 .39717 m
.36057 .33513 L
s
.22645 .65867 m
.12903 .56011 L
s
.22645 .65867 m
.22809 .73684 L
s
.22645 .65867 m
.22645 .65867 L
s
.66815 .60187 m
.6664 .63377 L
s
.58923 .46965 m
.66815 .60187 L
s
.24303 .65286 m
.146 .55387 L
s
.24303 .65286 m
.24489 .73112 L
s
.24303 .65286 m
.24303 .65286 L
s
.75505 1.01375 m
.74887 .86635 L
s
.74887 .86635 m
.74887 .86635 L
s
.72883 .83844 m
.74887 .86635 L
s
.30568 .99555 m
.34623 1.06597 L
s
.34623 1.06597 m
.31853 1.19305 L
s
.41512 .53197 m
.40704 .59541 L
s
.32894 .39717 m
.41512 .53197 L
s
.60492 .42652 m
.53254 .26886 L
s
.60492 .42652 m
.58923 .46965 L
s
.32269 .99038 m
.36287 1.06109 L
s
.36287 1.06109 m
.33604 1.18818 L
s
.12903 .56011 m
.14854 .46554 L
s
.6664 .63377 m
.58415 .53336 L
s
.6664 .63377 m
.67006 .6728 L
s
.6664 .63377 m
.6664 .63377 L
s
.64135 1.26276 m
.57734 1.21933 L
s
.146 .55387 m
.1651 .45927 L
s
.57635 1.06471 m
.57734 1.21933 L
s
.57635 1.06471 m
.57635 1.06471 L
s
.53277 1.01126 m
.57635 1.06471 L
s
.70953 .80224 m
.72883 .83844 L
s
.72883 .83844 m
.71352 .95824 L
s
.75505 1.01375 m
.7942 1.04695 L
s
.7942 1.04695 m
.8213 1.21622 L
s
.22809 .73684 m
.12964 .6805 L
s
.22809 .73684 m
.24272 .82399 L
s
.24489 .73112 m
.14695 .6744 L
s
.24489 .73112 m
.25967 .81843 L
s
.67006 .6728 m
.59069 .61349 L
s
.67006 .6728 m
.67896 .71611 L
s
.26934 .91279 m
.30568 .99555 L
s
.30568 .99555 m
.25086 1.08592 L
s
.69246 .7604 m
.70953 .80224 L
s
.70953 .80224 m
.67299 .88396 L
s
.38959 1.26928 m
.38959 1.26928 L
s
.38959 1.26928 m
.31853 1.19305 L
s
.28636 .90741 m
.32269 .99038 L
s
.32269 .99038 m
.26853 1.08072 L
s
.67896 .71611 m
.60874 .70382 L
s
.67896 .71611 m
.69246 .7604 L
s
.69246 .7604 m
.63699 .79668 L
s
.40683 1.2647 m
.40683 1.2647 L
s
.40683 1.2647 m
.33604 1.18818 L
s
.24272 .82399 m
.26934 .91279 L
s
.15152 .81686 m
.24272 .82399 L
s
.26934 .91279 m
.19324 .95651 L
s
.50593 .3301 m
.53254 .26886 L
s
.25967 .81843 m
.16907 .81101 L
s
.25967 .81843 m
.28636 .90741 L
s
.40704 .59541 m
.31398 .49212 L
s
.40704 .59541 m
.4111 .67458 L
s
.40704 .59541 m
.40704 .59541 L
s
.28636 .90741 m
.21092 .95097 L
s
.58923 .46965 m
.58415 .53336 L
s
.50593 .3301 m
.58923 .46965 L
s
.49106 .93923 m
.53277 1.01126 L
s
.53277 1.01126 m
.5094 1.13996 L
s
.8213 1.21622 m
.76162 1.1703 L
s
.31398 .49212 m
.32894 .39717 L
s
.71352 .95824 m
.75505 1.01375 L
s
.75505 1.01375 m
.76162 1.1703 L
s
.75505 1.01375 m
.75505 1.01375 L
s
.12964 .6805 m
.12903 .56011 L
s
.12903 .56011 m
.12903 .56011 L
s
.4111 .67458 m
.31842 .61407 L
s
.4111 .67458 m
.42743 .76335 L
s
.14695 .6744 m
.146 .55387 L
s
.146 .55387 m
.146 .55387 L
s
.45486 .8542 m
.49106 .93923 L
s
.49106 .93923 m
.4435 1.02922 L
s
.57734 1.21933 m
.57734 1.21933 L
s
.57734 1.21933 m
.5094 1.13996 L
s
.31853 1.19305 m
.25086 1.08592 L
s
.42743 .76335 m
.45486 .8542 L
s
.34303 .75306 m
.42743 .76335 L
s
.45486 .8542 m
.3861 .89609 L
s
.33604 1.18818 m
.26853 1.08072 L
s
.58415 .53336 m
.49566 .42533 L
s
.58415 .53336 m
.59069 .61349 L
s
.58415 .53336 m
.58415 .53336 L
s
.67299 .88396 m
.71352 .95824 L
s
.71352 .95824 m
.69697 1.08779 L
s
.49566 .42533 m
.50593 .3301 L
s
.15152 .81686 m
.12964 .6805 L
s
.16907 .81101 m
.14695 .6744 L
s
.59069 .61349 m
.50404 .54875 L
s
.59069 .61349 m
.60874 .70382 L
s
.31842 .61407 m
.31398 .49212 L
s
.31398 .49212 m
.31398 .49212 L
s
.25086 1.08592 m
.19324 .95651 L
s
.63699 .79668 m
.67299 .88396 L
s
.67299 .88396 m
.63297 .97345 L
s
.26853 1.08072 m
.21092 .95097 L
s
.76162 1.1703 m
.76162 1.1703 L
s
.76162 1.1703 m
.69697 1.08779 L
s
.60874 .70382 m
.53146 .69029 L
s
.60874 .70382 m
.63699 .79668 L
s
.5094 1.13996 m
.4435 1.02922 L
s
.19324 .95651 m
.15152 .81686 L
s
.63699 .79668 m
.57586 .83665 L
s
.21092 .95097 m
.16907 .81101 L
s
.34303 .75306 m
.31842 .61407 L
s
.50404 .54875 m
.49566 .42533 L
s
.49566 .42533 m
.49566 .42533 L
s
.4435 1.02922 m
.3861 .89609 L
s
.69697 1.08779 m
.63297 .97345 L
s
.3861 .89609 m
.34303 .75306 L
s
.53146 .69029 m
.50404 .54875 L
s
.63297 .97345 m
.57586 .83665 L
s
.57586 .83665 m
.53146 .69029 L
s
.25 Mabswid
.09421 .16958 m
.49753 0 L
s
.15133 .14557 m
.15775 .15308 L
s
gsave
.13847 .13053 -69.3463 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25663 .10129 m
.26286 .10897 L
s
gsave
.24417 .08593 -84.9965 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.36485 .05578 m
.37088 .06363 L
s
gsave
.35281 .04009 -79.9993 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.47613 .009 m
.48193 .01701 L
s
gsave
.46453 -0.00703 -83.8389 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17216 .13681 m
.17599 .14134 L
s
.1931 .128 m
.19691 .13255 L
s
.21416 .11914 m
.21795 .12371 L
s
.23534 .11024 m
.2391 .11483 L
s
.27804 .09229 m
.28175 .09692 L
s
.29956 .08324 m
.30325 .08789 L
s
.32121 .07414 m
.32487 .07881 L
s
.34297 .06499 m
.34661 .06967 L
s
.38686 .04653 m
.39045 .05126 L
s
.40899 .03723 m
.41255 .04197 L
s
.43125 .02787 m
.43478 .03264 L
s
.45362 .01846 m
.45713 .02325 L
s
.13061 .15428 m
.13449 .15877 L
s
.11 .16294 m
.1139 .16741 L
s
.25 Mabswid
0 1.0494 m
.58581 1.5175 L
s
.01735 1.06326 m
.01837 1.05342 L
s
gsave
.01532 1.08294 -76.6886 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18016 1.19335 m
.18084 1.18349 L
s
gsave
.17878 1.21308 -76.2086 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32563 1.3096 m
.32604 1.29972 L
s
gsave
.32483 1.32936 -65.6838 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.45641 1.4141 m
.45657 1.40421 L
s
gsave
.4561 1.43388 -71.9222 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.57462 1.50855 m
.57456 1.49866 L
s
gsave
.57473 1.52833 -71.6897 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05145 1.09051 m
.05201 1.0846 L
s
.08475 1.11711 m
.08527 1.1112 L
s
.11728 1.14311 m
.11777 1.1372 L
s
.14908 1.16852 m
.14953 1.1626 L
s
.21055 1.21764 m
.21092 1.21171 L
s
.24027 1.24138 m
.24061 1.23546 L
s
.26934 1.26462 m
.26965 1.25869 L
s
.29779 1.28735 m
.29806 1.28142 L
s
.35289 1.33138 m
.3531 1.32545 L
s
.37958 1.35271 m
.37976 1.34677 L
s
.40572 1.37359 m
.40587 1.36766 L
s
.43133 1.39405 m
.43145 1.38812 L
s
.481 1.43375 m
.48107 1.42781 L
s
.5051 1.453 m
.50514 1.44707 L
s
.52873 1.47188 m
.52874 1.46595 L
s
.55189 1.49039 m
.55188 1.48446 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{189.75, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002m000180P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000;ed002mM000_G@00;ed002mM000_G@00;ed
002mM000_G@00;ed002mM000_G@0051d0Q43M0034GAd008A0g@34@04M14A4EUd001?M0044GAd4@Ad
00@AM7@A0g@0115dM142M0034GAd05Id001?M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd05Id
001?M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd05Id001?M0044GAd4@Ad00@AM7@A0g@00a5d
M0034EUd001?M0044GAd4@Ad00@AM7@A0W@24@=d00<AM7@0F7@0051d0Q46M08A17@0115dM7@34EQd
001YM08ADW@0049d0Q43M0034GAd008A0g@34AAd0a5DM000@G@0115dM144M0044GAd4@=d00<AM7@0
4W@24EId0011M0044GAd4@Ad00@AM7@A0g@00a5dM00?M0<A0W@00a5dM01CM000@G@0115dM144M004
4GAd4@=d00<AM7@037@34@03M15d05Qd0011M0044GAd4@Ad00@AM7@A0g@00a5dM00:M0<AGG@0045d
00@AM7@A17@0115dM142M08A2W@24F1d0012M08A1W@24@Ad00<AM7@017@01Q5d4A5d4F1d000[M08A
0g@00a5dM0024@=d0Q42M0<A5g@34FAd000ZM0044GAd4@Ad00HAM7@AM142M0034G@A009d00<AM7@0
4W@24FMd000ZM0044GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@03g@34@03M15d06Id000ZM004
4GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@03G@34F]d000ZM0044GAd4@Ad00HAM7@AM142M003
4G@A008A3W@24Fid000ZM0044GAd4@Ad00HAM7@AM142M0044GAd4@ad115_M000:g@24@Id0Q43M08A
0g@34@Qd0a5bM000AG@34GEd000YM08A67@24@03M15d07Ed000XM0044GAd4AEd0Q5jM000:7@0115d
M14BM0<A0W@00a5dM01gM000:7@0115dM14?M0<A00=d4G@0O7@002Qd00@AM7@A3G@44H1d000XM004
4GAd4@]d0Q64M000:G@24@Ud0a400g@AM023M000<W@44HMd000`M08ARg@002ed0a42M0034GAd08Qd
000[M08A00=d4G@0SG@002Ud0Q6BM0009g@24IAd000WM0034GAd09=d000WM08AU7@002Md00<AM7@0
Tg@002Md00<AM7@0Tg@002Id00<AM7@0U7@0015d0Q43M0034GAd008A0W@44@Ed00<AM7@0U7@0011d
00@AM7@A17@0115dM142M0034GAd00Ed00<AM7@0U7@000Yd1142M0044GAd4@Ad00@AM7@A0g@00a5d
M004M08AUG@0011d00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@0U7@0011d00@AM7@A17@0115d
M144M0034GAd00=d00<AM7@0U7@0011d00@AM7@A17@01Q5dM15d4@9d00<AM7@00g@00a5dM02DM000
4G@24@Id0Q43M08A1W@00a5dM01=M0@A@g@002Id00<AM7@0Bg@34@=d1A4nM0009W@24DYd0Q43M003
4GAd00Ad0Q4mM0009G@00a5dM018M08A1G@00a5dM004M0034G@A03ad000UM0034GAd04Md00<AM7@0
1G@00a5dM005M0034G@A03]d000UM0034GAd04Md00<AM7@01W@00a5dM004M0034GAd008A>G@002Ed
00<AM7@0AW@00a5d4@07M0034GAd00Ad00<AM7@00W@00a5dM00fM0009G@00a5dM016M0034G@A00Md
00<AM7@017@00a5dM003M0034GAd03Ed000UM08AAW@01A5dM7@A00Md00<AM7@017@00a5dM003M003
4GAd03Ad000UM0034GAd04Ed00DAM7Ad4@07M0034GAd00Ad00<AM7@00g@24CEd000UM0034GAd04Ed
00<AM7@00W@00a5dM004M0034GAd00Ad00<AM7@00g@00a5d4@0dM0009G@00a5dM00bM0XA27@00a5d
M003M0034GAd00Ed00<AM7@00g@00a5dM004M0034G@A03=d000UM0034GAd031d0a48M0<A1W@00a5d
M004M0034GAd00Ad00<AM7@017@00a5dM003M0044GAd4C9d000TM0034GAd02md0Q43M0034GAd00Ed
00@AM7@A17@00a5dM005M0034GAd00Ad00<AM7@017@00a5dM003M0044GAd4C9d000TM08A;W@24@Ed
00<AM7@01W@00a5dM0024@9d00<AM7@01W@00a5dM004M0034GAd00=d00<AM7@00g@01A5dM7@A035d
000TM0034GAd02ad00<AM7@01W@00a5dM005M0034GAd009d00@AM14A1g@00a5dM004M0034GAd00=d
00<AM7@00g@00a5dM002M0034GAd02id000TM0034GAd02ad00<AM7@01W@00a5dM005M0034GAd00=d
0a48M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0;G@002Ad00<AM7@0:g@00a5d
4@07M0034GAd00Ed00<AM7@017@34@Md00<AM7@017@00a5dM003M0034GAd00=d00<AM7@00g@00a5d
M00/M00097@00a5dM00[M0034G@A00Qd00<AM7@01G@00a5dM003M0<A1g@00a5dM004M0034GAd00=d
00<AM7@00g@00a5dM004M08A;7@002Ad00<AM7@0:W@01A5dM7@A00Md00<AM7@01G@00a5dM002M005
4G@AM1401g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM004M08A;7@002Ad0Q4KM0DA2g@01A5d
M7@A00Md00<AM7@01G@00a5dM002M0064GAd4G@A1W@00a5dM004M0034GAd009d00<AM7@00g@00a5d
M004M08A;7@002Ad00<AM7@05g@54@=d1A45M0034GAd00=d00<AM7@01G@00a5dM004M0034GAd009d
00DAM7@AM0024@Id00<AM7@00g@00a5dM003M0034GAd009d00<AM7@017@00a5d4@0[M0008g@00a5d
M00FM0<A0g@74@04M14A4@=d00<AM7@00g@00a5dM005M0034GAd00Ed00DAM7Ad4@02M0034GAd008A
1G@00a5dM003M0034GAd00=d00<AM7@00W@00a5dM004M0044GAd4BYd000SM0034GAd01Ad0a42M004
4GAd4@Ed0a42M0<A1g@00a5dM005M0034GAd00Ad00DAM7Ad4@02M0064GAd4G@A1G@00a5dM003M003
4GAd009d00<AM7@00g@00a5dM003M0044GAd4BYd000>M08A0g@00a5dM0024@=d0a45M0034GAd01=d
0a43M0044GAd4@Ed00<AM7@00Q42M0034GAd00Ed00<AM7@01G@00a5dM004M0054GAdM1400W@01a5d
M7@AM14017@00a5dM003M0034GAd009d00<AM7@00g@00a5dM003M0054GAdM140:G@000ed00@AM7@A
17@0115dM143M0034GAd00Ad00<AM7@04G@34@Ed00DAM7Ad4@05M0044G@AM08A00=d4A401W@00a5d
M004M0034GAd00Ad00DAM7Ad4@02M0034GAd009d00<AM14017@00a5dM002M0034GAd00=d00<AM7@0
0W@00a5dM003M0054GAdM140:G@000Md1142M0044GAd4@Ad00@AM7@A0g@00a5dM004M0034GAd011d
00@AM14A1W@0115dM145M0034G@A009d0a400g@A4@04M0034GAd00Ed00<AM7@00g@01A5dM7@A00=d
00DAM7Ad4@02M0054GAdM1401G@00a5dM002M0034GAd009d00<AM7@00g@00a5dM002M0034GAd02Id
000=M0044GAd4@Ad00@AM7@A0g@00a5dM004M08A47@24@04M15d4@Ed00@AM7@A1G@00a5d4@02M08A
00Ed4A5d4@04M0034GAd00Ad00<AM7@017@00a5d4@04M0034GAd009d00@AM7@A0g@00a5dM002M0HA
17@00a5dM003M0034GAd00=d00<AM7@09G@000ed00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@0
3g@00a5d4@02M0034GAd00=d00DAM7Ad4@04M0034GAd008A0W@00a5d4@034@=d00<AM7@01G@00a5d
M003M0034G@A00Ad00<AM7@00g@0115d4A42M0034GAd00<A17@34@9d00<AM7@017@00a5dM002M003
4GAd02Ed000=M0044GAd4@Ad00@AM7@A0W@24@Id00<AM7@03W@0115dM143M0034GAd00=d00@AM7@A
1G@0115d4A43M08A00Ad4G@A0g@00a5dM004M0034GAd00=d00<AM14017@00a5dM003M0044G@A4@=d
0Q43M0034GAd009d00<AM1400W@00a5dM003M0034GAd00=d00<AM7@097@000id0Q46M08A17@00a5d
M004M0034GAd00id00DAM15d4@02M0034GAd00=d00@AM7@A1G@0115d4A43M08A00Ed4A5d4@02M003
4GAd00Ad00<AM7@00g@00a5d4@04M0034GAd00Ad0Q401G@AM7@A00Ad00<AM7@00W@00a5dM0034@Ed
00<AM7@017@00a5dM00SM0008g@00a5dM00=M0034G@A009d00DAM7Ad4@04M0054GAdM14017@0115d
4A44M0034GAd008A00Ed4GAd4@06M0034GAd00=d0a43M0034GAd00Ad0Q42M0034G@A00Ed00DAM7Ad
4@04M0034GAd00=d00<AM7@017@00a5dM00SM0008W@00a5dM00=M0044GAd4@=d00@AM7@A1G@0115d
M144M0044GAd4@Ad00LAM7@AM15d00<A1W@00a5dM003M08A00=d4G@00W@00a5dM004M0034GAd008A
00=d4G@00g@01A5dM7@A00Ad0Q44M0034GAd00Ed00<AM7@08W@0029d0Q4>M0034G@A00Ad00DAM7Ad
4@04M0044GAd4@Ed00<AM1401G@00a5d4@02M0034GAd008A1G@00a5dM003M08A00=d4G@00W@00a5d
M004M08A0W@00a5d4@04M0034GAd009d00LAM7Ad4G@A00=d00<AM7@01G@00a5dM00RM0008W@00a5d
M00<M0044GAd4@Ed00@AM7@A17@01A5dM7@A00Ad0a45M0<A0g@0115dM146M0034GAd009d0Q42M004
4GAd4@Id0Q42M0044GAd4@Ad00DAM7Ad4@03M0044GAd4@9d00<AM7@01G@24B=d000RM0034GAd00ad
00<AM1401W@01A5dM7@A00Ad00@AM7@A17@34@Ed0a44M0044GAd4@Ed00<AM7@00g@01a5dM7@AM140
1W@0115d4G@24@03M15d00=d00DAM7Ad4@04M0064GAd4G@A1g@24B=d000RM0034GAd00]d00<AM7@0
0Q46M0044GAd4@Ad00DAM7Ad4@03M08A00=d4G@00g@00a5d4@05M0044G@A4@Ed00<AM7@00W@24@=d
0Q46M0044G@A4@9d00<AM1400g@01A5dM7@A00Ad00@AM7Ad0Q46M0044GAd4B9d000RM0034GAd00]d
0Q400g@A4@06M0054GAdM14017@0115dM144M0034G@A00Ad00@AM14A1G@0115d4A44M0LA17@00a5d
M004M0044GAd4@9d00<AM14017@01A5dM7@A00=d00<AM7@00W@00a5dM004M0044GAd4B9d000RM003
4GAd00]d0a42M0034GAd00Ad00@AM7@A17@0115dM144M0034G@A00Ad00@AM14A1G@44@9d0a44M0@A
0g@00a5dM003M0034GAd008A0W@00a5d4@03M0054GAdM1400g@00a5dM002M08A1G@01A5dM7@A025d
000RM0034GAd00Yd00@AM7@A0g@00a5dM003M0054GAdM1400g@01A5dM7@A009d0Q400g@AM003M003
4GAd008A17@64@=d00<AM7@00W@00a5dM0024@03M15d00Ad00<AM7@00Q43M08A17@0115dM143M003
4GAd009d0Q45M0054GAdM1408G@0029d0Q4;M0034GAd008A0W@00a5dM004M0044GAd4@Ad00@AM7@A
0W@24@9d00DAM7Ad4@02M0034G@A00=d00HAM14AM143M0034GAd009d00<AM7@00W@34@Ad00HAM7@A
M142M0034G@A00=d00@AM7@A0g@00a5dM002M0034G@A00Ad00<AM7@00W@00a5dM00NM0008W@00a5d
M00:M0034GAd008A0g@00a5dM003M0054GAdM1400g@0115dM142M0<A00=d4G@00W@01Q5dM15d4@=d
00HAM14AM143M0034GAd009d00<AM7@00g@34@=d00HAM7@AM143M08A0g@01A5dM7@A00=d00LAM7Ad
4G@A00Ad00<AM7@00W@00a5dM00NM0008G@00a5dM00;M0064GAd4G@A0W@00a5dM004M0044GAd4@=d
00HAM7Ad4G@34@03M15d009d00@AM7@A0W@01A5dM15d00<A00=d4G@00W@01A5dM7@A00Ed00@AM14A
0W@0115dM142M0064GAd4G@A0g@0115dM143M0054GAdM1400W@01A5dM7@A00Ed00<AM7@07G@0025d
00<AM7@02g@0115dM142M0044GAd4@Ed00DAM7Ad4@03M00:4GAd4G@AM15d4@=d00@AM7@A0W@0215d
M15d4G@A0W@0115dM143M08A17@00a5dM0024@04M15d4@Ad00<AM1400Q43M0044GAd4@=d00DAM7Ad
4@03M0044GAd4@Ed00<AM7@07G@0025d00<AM7@02g@00a5d4@03M0054GAdM1401G@0115dM143M007
4GAd4G@AM0024@05M15dM1400W@01Q5dM7@AM0<A0W@01Q5dM15d4@=d0Q44M0054GAd4G@00Q400g@A
M003M08A00Ad4G@A0g@0115dM142M0054GAdM1400g@00a5d4@07M0034GAd01ad000QM0034GAd00Yd
00@AM7@A17@0115dM145M0054GAdM1400W@0115dM7@24@9d0a43M0034G@A00Ad1142M08A00Ed4GAd
4@02M08A1G@00a5dM0034@03M15d00Ad00<AM7@00Q43M0044GAd4@9d00DAM7Ad4@04M08A1g@00a5d
M00LM0008G@24@]d00@AM7@A1G@0115dM145M0044GAd4@=d00<AM7@02142M0044GAd4@=d0Q400g@A
M002M0064GAd4G@A0g@24@Ad00@AM7Ad0Q400g@AM004M0064GAd4G@A0W@0115dM142M0054GAdM140
17@24@Qd00<AM7@06g@0025d00<AM7@02W@0115dM145M0054GAdM14017@01A5dM7@A009d21400g@A
4@034@9d00@AM7Ad0Q400g@AM002M08A0W@24@=d0Q44M0034GAd009d0a45M08A0W@24@=d00<AM140
0g@0115dM145M0034GAd00Id00<AM7@06g@0025d00<AM7@02W@0115dM146M0044GAd4@Ed00DAM7@A
M0034@9d00<AM7@00a400g@AM0024@03M15d009d1144M08A00Ad4G@A0W@24@Ad00<AM7@00W@34@Ed
0Q42M0034G@A009d00@AM7@A0W@01A5dM7@A00Ad0Q48M0034GAd01Yd000QM0034GAd00Yd00<AM140
27@0115dM144M0034GAd00<A00Ed4GAd4@02M0034GAd00@A00=d4A400g@44@Ad0Q42M08A0W@24@Ad
00<AM7@00W@44@=d00@AM7@A0W@24@9d00@AM7@A0W@01A5dM7@A00Ad0Q48M0034GAd01Yd000QM003
4GAd00Ud00@AM7@A2G@0115dM144M08A00Ed4GAd4@02M0084GAdM15d4G@24@9d0Q42M08A00=d4G@0
17@24@03M14A009d00<AM1400g@00a5dM002M0054G@AM1400W@02A5dM7@AM15d4@02M0034G@A009d
00DAM7Ad4@04M0034G@A00Id00<AM1406g@0021d00<AM7@02W@0115dM149M0044GAd4@Ad00@AM14A
0g@0115d4A42M0034G@A009d0Q401G@AM15d008A00=d4G@017@64@04M14A4@=d00<AM7@00W@00a5d
4@024@9d00DAM7Ad4@02M08A0W@00a5d4@02M0054GAdM14017@00a5d4@06M0034G@A01]d000PM003
4GAd00Yd00<AM7@00Q49M0044GAd4@=d0a401G@AM7@A009d00HAM7@AM142M0@A0W@34@03M14A00Ed
0Q42M0044G@AM08A0W@00a5dM002M0084G@A4G@AM144M0054G@AM1400W@01A5d4G@A00=d00DAM7Ad
4@03M0034GAd009d00DAM7Ad4@0JM00087@34@Yd0Q4017@AM149M0034G@A009d00<AM1400W@0115d
M142M08A00Qd4GAd4G@AM0<A0W@24@04M15d4@=d114017@A4G@24@05M15dM1400g@01Q5d4G@AM08A
17@00a5dM0024@9d0a42M0044GAd4@=d00DAM7Ad4@04M0054GAdM1406W@0021d00<AM7@02W@0115d
4A42M0034GAd00Id00LAM7@AM15d008A0W@01A5dM15d008A0W@00a5d4@02M0034G@A008A00=d4G@0
0Q400g@AM002M0044G@A4@9d00TAM15d4G@AM1400g@00a5d4@02M0<A1G@0115d4G@34@03M14A008A
0W@01A5dM7@A00Ad00DAM7Ad4@03M0034GAd01Qd000PM0034GAd00Yd00@AM7@A0g@00a5dM006M008
4GAd4G@AM142M0054GAd4G@00Q42M0034G@A009d00DAM7@AM0024@9d00@AM7@A0W@01Q5d4G@AM0<A
00Ad4GAd0Q43M0054GAd4G@00Q400g@AM004M0044G@A4@9d00DAM15d4@02M0054GAdM14017@0115d
M145M0034GAd01Md000GM08A1g@00a5dM00:M0034GAd008A0g@00a5dM006M0054G@AM1400W@0115d
M142M08A00Id4G@AM142M0034GAd008A00Ad4GAd0Q42M0044G@AM0<A0W@24@03M15d009d0Q42M004
4GAd4@9d00<AM1401G@0115d4A42M0044G@AM08A00=d4G@00W@00a5dM003M0034G@A00Ed00<AM7@0
5g@001Id00@AM7@A1W@00a5dM00:M0064GAd4G@A0g@00a5dM005M08A00=d4G@00W@0115dM142M08A
00Ad4G@A0W@00a5d4@02M0034G@A008A00=d4A400W@02A5d4A5d4G@AM0024@9d00PAM7@AM15d4@9d
00<AM7@00Q400g@AM004M00;4G@A4G@AM15d4G@00Q43M0034GAd00=d0Q46M0034GAd01Md000FM004
4GAd4@Id00<AM7@02W@0115dM142M0054GAdM1401g@0115d4A43M0054GAd4G@00Q402G@AM7@AM15d
4@02M0054GAd4G@00Q401g@AM7@AM1400W@24@03M14A009d00@AM7@A0W@24@9d00<AM7@00Q42M003
4GAd009d1142M08A00Ed4GAd4@03M0034GAd00Ad00<AM7@01G@00a5dM00FM0005W@0115dM146M003
4GAd00Yd00@AM7@A0g@01A5dM7@A00Id1143M0044GAd4@9d00XAM7@AM15d4G@A0W@00a5dM0044@9d
00DAM15d4@02M0044G@AM08A00Ed4GAd4@03M08A00Ad4G@A0W@0115dM144M00;4G@A4G@AM15d4G@0
0Q42M0034GAd00Ad00<AM7@01G@00a5dM00FM0005W@0115dM145M08A37@0115dM144M0054GAdM140
1G@34@03M15d009d00HAM7@AM142M0074G@AM15d4@02M0054GAd4G@00Q42M0034G@A008A0g@24@03
M14A008A0W@01Q5dM7@AM08A00Ed4GAd4@03M0034GAd00DA00Md4G@AM15d008A00=d4G@01G@00a5d
4@07M0034GAd01Ed000FM0044GAd4@Ed00<AM7@02g@0115dM145M0054GAdM1400g@0115dM142M004
4GAd4@9d00PAM14AM15d4@9d0Q43M0034G@A009d0Q42M08A00=d4G@00W@00a5d4@034@05M15dM140
0W@01Q5dM15d4@=d00HAM7Ad4G@34@04M14AM08A00Ed4G@AM0024@Id00<AM1401g@00a5dM00EM000
5g@24@Id00<AM7@02g@0115dM146M0054GAdM1400W@00a5dM0024@03M15d009d00<AM7@0114027@A
M15d4G@A0W@00a5d4@02M0034G@A009d0a44M08A00=d4G@00Q42M0044GAd4@9d0a44M0034GAd00<A
0W@34@08M14AM15d4G@24@Ed00DAM7Ad4@06M0034GAd01Ed000OM0034GAd00]d00@AM7@A1g@02a5d
M7@AM15d4G@A009d00@AM7@A0W@34@09M14AM15d4G@A009d00<AM1400W@34@06M14A4G@A0g@00a5d
4@074@9d00DAM7@AM0024@=d00@AM7Ad0Q42M08A00Ad4A5d0Q401G@AM7@A00Ed00DAM7Ad4@07M003
4GAd01Ad000OM0034GAd00]d00@AM7@A27@0115dM7@24@05M15dM1400W@0115dM142M0<A00Qd4A4A
M15d4@9d00<AM1400W@00a5d4@024@05M15dM1400g@34@9d00@AM7@A0W@01A5dM7@A009d00PAM7Ad
4G@AM08A0W@34@06M14A4G@A0W@24@=d00<AM7@00W@00a5dM005M0034GAd01Ad000OM0034GAd00]d
00@AM7@A2G@01a5dM7@AM1400g@01Q5dM15d4@9d0a42M08A0W@24@9d00<AM1400W@00a5dM0024@05
M14AM1400g@00a5d4@044@05M14AM1400g@01A5dM7@A009d00@AM15d0Q42M0<A00Ad4A5d0Q42M08A
0g@00a5dM003M0034GAd00Ed00<AM7@04g@001md00<AM7@02g@0115dM14:M0044G@AM08A17@00a5d
4@02M0094GAd4G@AM15d00@A0W@01A5d4G@A00Ad00@AM14A0W@00a5d4@054@05M15d4G@00Q43M003
4GAd009d0Q401g@AM7@AM1400W@54@03M14A009d00DAM15d4@06M0034GAd00Ed00<AM7@04g@001md
0Q4<M0044GAd4@]d0Q42M0034GAd009d00HAM7@AM142M0034G@A009d0Q400g@A4@02M0<A00=d4G@0
0g@24@9d00TAM15d4G@AM1400W@00a5d4@02M0054GAdM1401W@24@9d00<AM1400g@24@03M14A008A
0W@01A5d4G@A00Md00<AM7@00W@34AEd000OM0034GAd00]d00@AM7@A37@00a5dM0024@Ad00LAM7@A
M15d00<A0W@24@05M14A4G@00a400g@AM002M0064G@A4G@A0W@01A5d4A5d008A00Ad4A4A0W@24@9d
00<AM7@017@34@9d00<AM1400W@74@03M15d009d00<AM7@01W@01A5dM7@A00=d00<AM7@04W@001md
00<AM7@02g@0115dM14<M08A00Ad4G@A17@01Q5d4G@AM08A00=d4G@00Q42M0044G@AM08A00=d4G@0
0W@00a5d4@024@03M15d00<A00Ad4A4A0W@0115d4G@24@04M15d4@Ad00<AM7@00Q401G@AM7@A009d
1Q400g@AM002M0034GAd00Md0a44M0034GAd019d000OM0034GAd00]d00@AM7@A37@0115d4A42M005
4GAdM1400W@0115d4G@34@9d0Q4017@A4G@34@03M15d009d00<AM1400Q42M0<A00=d4A400a401g@A
M15d4G@00Q400g@AM003M0044GAdM0<A0g@0115d4G@34@03M14A009d00<AM14027@00a5dM004M003
4GAd019d000NM0034GAd00ad00@AM7@A37@0115dM143M0054GAdM1400W@24@06M14AM15d1A42M08A
00=d4G@00W@24@9d0Q4017@A4G@24@05M14A4G@00a401g@AM7@AM1400g@00a5dM002M0034G@A00Ad
00<AM1401Q42M0034G@A00Id0a47M0034GAd015d000NM0034GAd00ad00<AM7@00a4:M0034GAd008A
0g@0215dM7@AM15d0Q400g@A4@0<4@9d00<AM1400W@01Q5d4G@AM08A00Ed4A4AM0034@07M15dM15d
4@03M0034GAd009d00@AM14A0g@00a5d4@064@03M15d009d00<AM7@00W@01A5dM7@A00Id00<AM7@0
4G@001id00<AM7@037@44@9d0Q48M0064GAd4G@A0g@0115dM142M0LA00=d4G@00Q42M08A00Md4A5d
4G@A00=d00DAM14AM0024@9d0a401G@A4G@A009d0a42M0034GAd00Ad0Q400g@A4@02M0034G@A00DA
00=d4G@00W@01A5dM7@A00Ad00<AM7@017@00a5dM00AM0007W@24@ed00<AM7@00Q43M08A1W@0115d
M142M0054GAdM1400W@00a5dM0024@9d0Q4017@AM7@24@03M15d008A00Ed4A5d4@03M0034G@A008A
0W@0115d4G@64@08M15d4G@AM146M08A0g@00a5dM0074@03M15d00=d0a45M0034GAd00Ed00<AM7@0
47@001id00<AM7@03G@00a5dM0034@=d00<AM7@00g@0115dM143M0054GAdM1400W@01A5dM15d00<A
00Id4A5d4G@24@03M14A009d0Q45M0044G@A4@=d00DAM14AM0074@04M14A4@Qd0Q43M0XA1G@00a5d
M006M0034GAd00Ad00<AM7@047@001id00<AM7@03G@0115dM142M0044GAdM08A0g@0115dM144M005
4GAdM1400W@00a5d4@024@07M15dM15d4@02M0HA00Ad4A4A0W@24@04M15d4@9d00@AM15d1A400g@A
M0054@Md0Q42M0@A00=d4A400Q400g@AM002M0<A27@00a5dM004M0034GAd011d000NM0034GAd00ed
00@AM7@A0g@24@=d0Q401G@AM7@A00Ed00HAM7Ad4G@24@04M15dM08A00Ad4G@A0W@64@04M15dM0<A
00Ad4A5d0Q42M0DA00Ed4A5d4@03M0034GAd00HA0W@34@Ad1Q42M08A0g@00a5dM005M0034GAd00Ed
00<AM7@03g@001id00<AM7@03G@0115dM145M08A0g@24@9d00<AM7@017@0215dM7@AM15d0Q42M003
4G@A009d00@AM15d0Q4017@AM143M0DA0W@24@03M14A008A00Id4A4AM142M0<A1g@54@Ed1A400g@A
M004M0034GAd00Ed00<AM7@01G@00a5dM00?M0007W@00a5dM00=M0044GAd4@Md0Q42M0@A1g@0115d
M7@54@9d00LAM7@AM15d00@A00=d4A4017@00a5d4@024@9d00@AM15d1a401g@AM7@AM1401g@34@9d
2a46M0034GAd00Id00<AM7@017@00a5dM00?M0007G@00a5dM00>M0044GAd4@Ud0a42M0034GAd00Id
00@AM7Ad0a402W@AM7@AM15d4G@24@05M14AM1400g@00a5d4@02M0044GAd4@9d00<AM1401Q42M004
4GAd4@Ed0Q43M0034GAd00Ed1a45M0034GAd00Ed00<AM7@01G@00a5dM00>M0007G@24A1d00<AM140
2g@00a5dM0034@Md00@AM15d0Q402W@A4G@AM15d4G@24@04M14AM08A0W@00a5d4@02M0<A00Md4G@A
M15d00DA0W@01A5dM7@A00=d00<AM7@00g@00a5dM005M0DA0W@84@Ed00<AM7@01G@00a5dM00>M000
7G@00a5dM00?M0034G@A00]d1142M08A1W@24@9d0Q400g@AM0084@03M14A00<A00Ad4G@A17@0115d
4A42M0034G@A00DA00=d4G@00g@0115d4A46M08A17@24@03M14A00<A1W@00a5dM0044@9d00<AM7@0
17@00a5dM00>M0007G@00a5dM00?M0044GAd4@Yd00<AM7@00Q43M0034GAd00Ad00<AM7@00Q401W@A
4G@AM0DA00Ad4A4A0W@34@Ed00DAM7Ad4@02M0TA17@24@Ud00DAM7Ad4@03M0HA1G@00a5dM004M0HA
17@00a5dM00=M0007G@00a5dM00?M0044GAd4@]d00<AM7@00Q43M08A17@24@03M14A00/A00=d4A40
0Q4017@AM145M08A0W@;4@Ad0a49M0@A0g@64@03M14A00=d00<AM7@01W@0115dM7@54@md000MM003
4GAd00md00@AM7@A2g@01A5dM15d008A0g@24@9d00<AM1400Q400g@A4@0@4@Id0Q43M0XA0W@24@9d
0Q48M08A1G@74@9d00DAM7Ad4@07M0034GAd00Ed00<AM7@03G@001ed00<AM7@047@00a5d4@0;M004
4GAd4@=d0Q43M0034G@A009d00DAM14AM0084@05M14A4G@01a43M0DA0W@94@Ad0Q47M0<A17@00a5d
4@064@9d00@AM7@A1g@00a5dM005M0034GAd00ed000MM0034GAd011d00<AM1402g@0115dM145M004
4GAdM08A0W@34@03M14A00<A00=d4A4021400g@AM002M0TA0W@74@Id00<AM7@017@00a5dM0024@=d
00<AM1401A4017@AM7@34@Qd00<AM7@01G@00a5dM00<M0007G@00a5dM00@M0034G@A00]d00@AM7@A
1W@24@9d11400g@AM00:4@03M14A00<A00=d4G@017@34@9d00<AM1402146M0034GAd009d0Q43M08A
0W@00a5dM0074@03M15d009d00<AM7@01W@00a5dM005M0034GAd00ad000LM0<A4G@00a5d4@0<M003
4G@A00Qd0a42M0054GAd4G@00Q400g@A4@044@04M14AM08A0W@00a5dM0034@03M14A009d00<AM7@0
31400g@A4@02M0034GAd00=d0Q42M0034GAd00HA00Ad4G@A0W@34@Id00<AM7@01G@00a5dM00<M000
77@00a5dM00AM0044GAd4@]d00<AM1402W@00a5dM0054@03M14A00HA00Id4A4AM142M0@A0g@24@9d
00<AM7@01a45M0LA1G@00a5d4@03M0DA00=d4A400W@00a5d4@02M0034GAd00=d00<AM7@01G@00a5d
M00<M00077@00a5dM00AM0044GAd4@]d00<AM1402W@44@9d0Q400g@A4@084@04M15dM0@A1G@24@9d
0a400g@A4@064@Ed00<AM7@00W@:4@04M14AM0@A00Id4G@AM143M0034GAd009d00<AM7@01G@00a5d
M00<M0001g@24@=d00<AM7@00Q43M0<A1G@00a5dM00BM0034G@A00]d00@AM7@A2G@00a5dM0024@05
M15d4G@02a42M0@A1G@01A5d4G@A00=d1a4017@AM7@34@Ud0Q43M0LA00Qd4G@AM15d4@=d0Q42M003
4GAd00Id00<AM7@02g@000Id00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@04W@00a5d4@034@Ud
00<AM1402G@0115dM7@44@03M14A00PA0W@34@=d00<AM7@00g@34@04M15dM0PA00=d4A400W@24@Qd
0a43M0034G@A00<A00Ad4G@A0W@24@Ed00@AM7@A1g@00a5dM00;M0001W@0115dM144M0044GAd4@=d
00<AM7@017@00a5dM00BM0hA00Ad4G@A2W@0115dM142M0034GAd00TA00=d4A400W@0115dM145M08A
0W@0115d4G@94@05M15dM14027@00a5d4@02M0034GAd008A00Md4A5d4G@A009d00<AM7@017@34@Md
00<AM7@02g@000Id00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@04W@0115dM144M10A17@0115d
M142M0<A00=d4A402A42M0044GAd4@=d0a401g@AM15d4G@02143M0<A27@24@04M15d4@9d0Q401g@A
4G@AM1400W@24@Md00<AM7@01G@00a5dM00;M0001W@0115dM144M0044GAd4@=d00<AM7@017@00a5d
M00CM0034G@A00]d00@AM15d6a43M0034G@A009d00@AM14A0g@24@03M14A009d1a400g@AM003M08A
1W@00a5d4@02M08A0W@03Q5d4A5d4G@AM15d4G@A1W@24@Md00<AM7@02W@000Id00@AM7@A17@0115d
M142M08A1W@00a5dM00CM0034G@A00ad00<AM1401W@;4@03M14A00/A0W@0115dM145M08A0W@00a5d
M0084@03M15d009d0a45M0034G@A009d0Q42M0044G@AM08A00Ad4GAd0Q42M0034GAd00=d00@AM14A
1G@00a5dM00:M0001g@24@Id0Q44M0034GAd00Ad00<AM7@04g@0115dM14;M0034G@A00Ud00DAM7Ad
4@02M2<A00Ad4A5d0Q42M0034GAd008A00=d4G@00W@0115dM143M0074GAd4G@AM0024@9d00@AM14A
0W@00a5dM003M0054GAdM14017@00a5dM00:M00077@00a5dM00CM0044GAd4@]d00<AM1402W@0115d
M143M0034GAd00TA0W@34@9d00<AM7@02Q400g@A4@064@9d00HAM15d4G@24@05M15dM1400g@24@0:
M15d4G@AM15d4@9d00DAM7Ad4@05M0054GAdM1400g@00a5dM00:M0006g@00a5dM00EM0034G@A00]d
00@AM7@A2G@0115dM143M0<A00=d4A401A4017@A4A42M0034G@A00Md00@AM15d1a4017@AM142M004
4G@A4@=d0Q42M0044GAdM08A00Qd4G@AM15d4@9d00@AM14A0g@00a5dM002M0034GAd009d00@AM7@A
37@001]d00<AM7@05G@00a5d4@0<M0034G@A00Ud00@AM7@A0W@34@03M14A00/A00Ad4G@A1g@00a5d
M0024@03M14A00<A00Ad4G@A0g@24@07M15dM15d4@02M0054GAd4G@00Q4017@AM7@24@9d00@AM14A
17@01A5dM7@A00Ed0Q400g@AM00:M0006g@00a5dM00EM0044GAd4@]d00<AM1402G@0115dM7@44@03
M15d00XA00Ad4A4A0W@00a5dM003M08A0W@24@05M15d4G@00Q4017@AM143M0054G@AM1400g@34@03
M15d009d00PAM7@AM15d4@9d00@AM7@A17@0115dM147M08A2g@001]d00<AM7@05G@0115dM14;M004
4GAd4@Ud1143M0/A00Ed4A4AM0044@Ed00@AM15d0Q401G@AM15d008A00Ad4G@A0g@34@03M15d00Ad
00<AM1400g@24@06M15d4G@A0W@0115dM145M0034G@A00Qd00<AM7@02G@001]d0Q4GM0034G@A00]d
00@AM7@A2G@44@=d00<AM1402A400g@A4@034@03M15d00=d00HAM7@AM142M0034G@A00HA00Id4GAd
4G@24@Id0a43M0094G@A4G@AM15d008A0g@00a5dM002M0034G@A00Qd00<AM7@02G@001]d00<AM7@0
5W@0115dM14;M0044GAd4@Id0a43M0034G@A00LA00Ed4A5d4@02M08A00=d4G@00a42M0034GAd00@A
00Ad4GAd1Q42M08A0g@00a5dM004M0044G@A4@9d00<AM7@00Q400g@AM0024@05M15dM1401G@00a5d
4@07M0034GAd00Ud000KM0034GAd01Id00@AM7@A2g@0115dM144M0<A0W@01a5dM15d4G@02Q401W@A
M7@AM0<A0W@24@=d114017@AM7@44@04M14AM08A0g@24@Ed00LAM15d4G@A009d00<AM1400a42M005
4GAdM1401G@24@Md00<AM7@02G@001]d00<AM7@05W@0115dM14;M0044GAd4@9d0a44M0064GAdM15d
2A401W@AM7@AM0<A00Md4A5d4G@A009d00HAM14AM142M0<A00Ad4A4A0W@01Q5dM15d4@Ed00<AM140
0W@24@9d00HAM7@AM143M0054GAdM1401G@00a5dM005M0034GAd00Ud000KM0034GAd01Md00@AM7@A
2W@0115dM7@34@Md00DAM14AM0094@04M14AM08A00Id4A5d4G@24@9d0a401G@A4G@A009d00@AM15d
0Q400g@AM0024@05M15dM14017@00a5d4@03M08A00Ed4A5d4@02M0044GAd4@=d00<AM7@00g@24@Md
00<AM7@027@001Yd00<AM7@067@0115dM14;M0@A2G@0115d4G@24@03M14A00<A00Ed4GAd4@02M0HA
00=d4G@00Q42M0HA0W@0115d4G@24@03M15d00<A0g@24@=d0Q44M0034G@A008A0W@00a5d4@03M005
4GAdM14017@00a5d4@06M0034GAd00Qd000JM0034GAd01Qd00@AM7@A2g@44@Yd00<AM140214017@A
M7@24@9d0a400g@A4@04M0034GAd00DA0W@01Q5d4A5d4@9d00@AM7@A17@24@=d00<AM7@00W@01A5d
M7@A009d00<AM1400g@01A5dM7@A00Ad00<AM1401W@00a5dM008M0006W@00a5dM00HM0044GAd4@Ud
0a43M0034GAd00Id0Q400g@AM0084@0;M15d4G@AM15d4G@00Q45M0<A0W@34@9d00@AM15d0Q4017@A
M7@24@=d00<AM1400W@00a5dM002M0054GAdM1400W@0115dM142M0034GAd009d00DAM7Ad4@02M003
4GAd00=d00<AM7@027@001Yd0Q4JM0044GAd4@Id0a42M0044GAd4@Qd00@AM15d2A4017@AM7@24@9d
11400g@AM005M0034GAd00<A0W@0115d4G@44@04M15d4@Ad0Q42M0034GAd009d00DAM7Ad4@02M004
4GAd4@=d00<AM7@00W@0115dM143M0034GAd009d00<AM7@027@001Yd00<AM7@06G@0115dM144M0<A
17@01A5dM7@A00Id00DAM7@AM0094@07M15dM15d4@02M0<A0W@00a5dM003M0DA00Ed4A4AM0024@04
M14AM08A0W@02A5dM7@AM15d4@04M0054GAdM1400g@00a5d4@03M0034GAd009d00@AM7@A17@01A5d
M7@A00Yd000JM0034GAd01Ud00@AM7@A0W@34@Md00@AM7@A1W@01a5d4A5d4G@01a400g@A4@02M003
4G@A00<A00Ed4GAd4@04M0034GAd008A0g@64@9d00DAM7Ad4@04M0044G@A4@Ad00DAM7Ad4@03M004
4GAd4@=d00<AM7@00W@00a5d4@04M0054GAdM1402W@001Yd00<AM7@06G@0115dM7@34@Ud00DAM7Ad
4@04M0074GAd4G@AM0064@03M15d008A0W@01A5d4A5d008A00Ed4GAd4@02M08A0W@44@03M15d00DA
00=d4A400g@01Q5dM7@AM0<A17@00a5dM0024@9d00@AM7@A0g@00a5dM002M0034G@A00Ed00@AM7@A
2W@001Yd00<AM7@06W@44@ad00@AM7@A17@00a5d4@02M0034G@A00DA00Ed4GAd4@02M0034GAd008A
00Ed4GAd4@02M0@A0W@24@9d0Q42M0@A00=d4A4017@0115dM7@44@Ad00DAM7Ad4@02M0044GAd4@Ad
00<AM7@00W@24@Id00@AM7@A2G@001Yd00<AM7@06W@0115dM14<M0044GAd4@=d00<AM1400g@00a5d
4@044@03M14A009d0Q42M08A00=d4G@00Q42M0044GAdM08A0g@0115dM7@84@9d00DAM7Ad4@03M0<A
00=d4G@00W@01A5dM7@A00=d00@AM7@A0g@00a5dM002M08A1g@00a5d4@09M0006W@00a5dM00JM005
4GAdM1402g@01a5dM7@AM1400W@0315dM7@AM15d4G@AM08A0W@24@9d00@AM14A0W@01A5dM7@A009d
0a42M0054GAdM1400W@54@9d00<AM7@00W@0115dM7@24@9d00@AM7@A0g@01A5dM7@A009d00<AM7@0
0W@00a5dM002M0034GAd00Ed00<AM1402G@001Ud00<AM7@077@0115dM14<M0084GAd4G@AM144M0<A
00Ed4G@AM0024@9d0Q42M0<A00Ed4GAd4@03M08A0W@0115dM144M0054G@A4G@00Q43M0034GAd009d
00<AM7@00Q43M0034G@A00=d00DAM7Ad4@02M0034GAd009d00<AM7@00W@24@Md0Q49M0006G@24Aed
00DAM7Ad4@0;M0054GAdM1400W@01Q5dM7@AM0@A00Ed4GAd4@02M0064G@A4G@A0g@0115d4A43M003
4GAd008A00=d4G@00g@01A5d4A5d008A0g@00a5dM002M0034GAd00<A0g@24@=d00DAM7Ad4@03M005
4GAdM14017@24@Qd00<AM7@01g@001Ud00<AM7@07G@0115dM14<M0064GAd4G@A17@00a5d4@054@9d
0Q42M0HA0g@00a5d4@03M08A00=d4G@00Q44M0044G@AM0@A0g@00a5dM002M0034G@A008A0g@24@=d
00<AM7@00W@0115dM144M0044GAd4@9d00<AM7@01G@00a5dM007M0006G@00a5dM00MM0054GAdM140
2g@0115d4G@24@Ad00<AM1401A42M08A00=d4A400a400g@AM002M0044GAd4@9d00@AM14A0W@00a5d
M002M0044G@AM0@A0g@00a5dM002M08A00Ad4G@A0g@0115dM7@24@=d00DAM7Ad4@03M0044GAd4@9d
00<AM7@01G@00a5dM007M0006G@00a5dM00NM0044GAd4@ad0Q400g@AM004M0034G@A00<A00Ad4A5d
1A400g@A4@02M0064GAdM15d0Q401G@AM7@A009d0Q43M0034GAd00<A00=d4G@00g@00a5dM002M003
4G@A009d00<AM7@00Q43M0054GAdM1400g@00a5dM002M0034G@A00=d00<AM7@017@00a5dM007M000
6G@00a5dM00NM0054GAdM1402g@01A5d4G@A00Ad00@AM15d0Q400g@AM0044@03M15d008A0W@00a5d
M002M0044G@A4@=d0Q4017@A4A42M0034GAd00<A00=d4A400g@00a5dM002M0<A0g@01A5d4G@A009d
00DAM7Ad4@03M0034GAd009d00<AM1400g@00a5dM004M0034GAd00Md000IM0034GAd01md00@AM7@A
2W@01Q5d4A5d4@Ad00@AM15d1A4017@A4A42M0<A0g@01Q5dM7@AM08A0g@00a5d4@024@04M15d4@9d
00<AM1400W@00a5dM002M0044GAdM0<A0g@00a5d4@02M0034G@A00Ad00DAM7Ad4@04M0034GAd00=d
00<AM7@00g@00a5dM007M0006G@00a5dM00OM0054GAdM1402G@00a5d4@03M0044GAd4@9d00HAM14A
M142M0064G@A4G@A0W@0115dM144M0044G@A4@9d00<AM7@00Q42M08A0W@01Q5d4A5d4@Ad00LAM7Ad
4G@A00Ad0Q43M08A17@01A5dM7@A00Ad00<AM7@00g@00a5dM003M0034GAd00Md000IM0034GAd021d
00@AM7@A27@00a5dM0024@9d00DAM7@AM0024@05M14AM1400W@01Q5d4A5d4@9d00DAM7Ad4@04M0@A
00Ad4GAd0Q43M0054GAd4G@00Q42M0034GAd009d00DAM7@AM0024@Ad00<AM7@00W@24@=d00DAM7Ad
4@04M0034GAd00Ad00<AM7@00W@00a5dM007M00067@34B5d00@AM7@A27@00a5d4@02M0074GAd4G@A
M0024@05M14AM1400g@24@04M15d4@9d00@AM7@A17@24@07M15d4G@AM0024@9d0Q400g@AM0024@9d
00<AM7@00W@01A5dM15d008A17@24@=d00<AM7@00W@00a5dM002M0064GAd4G@A1W@01A5dM7@A00Ud
000HM0034GAd025d00DAM7Ad4@06M0034G@A00=d00LAM7@AM15d008A00Ad4A5d0Q42M0064G@A4G@A
0g@0115dM144M0044GAd4@9d00DAM15d4@02M0034G@A009d00<AM7@00Q44M08A00Ed4GAd4@03M003
4G@A009d0Q44M0054GAdM1400W@00a5d4@06M0054GAdM1402G@001Qd00<AM7@08W@0115dM145M004
4GAd4@Ad00<AM7@00Q4017@A4G@24@03M14A009d00@AM15d0Q43M0044GAd4@=d00@AM15d0Q4017@A
M142M0034G@A008A0W@01A5dM7@A00Ad0Q400g@AM002M0044GAd4@9d1144M0074GAdM15d4@03M003
4GAd00Ad00@AM7@A2G@000=d0Q43M0034GAd008A0W@44@Ed00<AM7@08W@01A5dM7@A00Ad00<AM140
1G@00a5dM0024@04M14AM08A00=d4A400W@01a5d4G@AM1400g@0115dM142M0034GAd00DA00=d4G@0
0W@24@05M14AM1400g@24@Ad00<AM1400g@0115dM144M08A17@00a5dM002M08A0g@00a5dM004M004
4GAd4@Ud0002M0044GAd4@Ad00@AM7@A0W@00a5dM005M0034GAd02=d00@AM7@A0g@0115dM146M003
4G@A008A00=d4G@00Q400g@A4@02M0054GAd4G@00Q43M0074GAdM15d4@02M08A00Ed4A5d4@04M006
4GAd4G@A0g@24@Ad00<AM14017@00a5d4@04M0<A0g@0115dM7@24@Ed00<AM7@017@00a5d4@09M000
0W@0115dM144M0044GAd4@=d00<AM7@017@0115dM14RM0054GAdM1400W@00a5d4@08M0@A00Ad4G@A
0W@24@9d00DAM7@AM0024@Ad00HAM7@AM143M0064GAd4G@A17@24@03M14A008A0g@24@=d0Q46M08A
17@24@05M14A4G@00a400g@AM004M0034GAd00Ad00<AM1402G@0009d00@AM7@A17@0115dM143M003
4GAd00Ed00<AM1408g@0215dM15d4G@A2G@24@06M15d4G@A0W@24@9d00@AM7@A0W@24@=d00@AM7Ad
0Q43M08A00Ad4A4A17@01A5d4A5d008A0g@24@=d0Q46M08A17@24@Ad0Q44M0034GAd00=d00<AM7@0
17@24@Ud0002M0044GAd4@Ad00@AM7@A17@00a5dM005M08A8g@01A5dM7@A009d00<AM7@027@01a5d
4G@AM1400W@24@=d00@AM7@A0W@00a5dM002M0034GAd008A0W@01A5d4A5d008A17@01A5dM15d008A
17@24@9d0Q47M0034GAd009d00<AM14017@00a5dM002M0034GAd00=d00<AM7@017@24@Ud0002M004
4GAd4@Ad00HAM7@AM142M0034GAd00Md00<AM7@08G@01Q5dM15d4@]d00<AM1400Q401g@AM7@AM140
0W@0115dM142M0034GAd00=d00@AM7@A0W@0115dM142M08A17@0115d4G@24@Ad0Q401G@AM7@A00Id
00<AM7@00W@00a5d4@05M0054GAdM1401W@00a5dM004M0034GAd00Md0003M08A1W@24@=d0Q4;M003
4GAd021d00@AM15d0Q4;M08A00Ed4A5d4@03M08A0W@0115dM142M08A17@01Q5d4A5d4@9d00@AM15d
0a43M0074G@AM15d4@03M0044G@A4@9d00<AM7@017@24@=d00<AM1401G@00a5dM002M0034GAd00=d
00<AM7@017@00a5dM007M0007W@00a5d4@0PM08A00=d4G@02W@00a5d4@02M0044G@A4@9d0Q42M004
4GAd4@=d00<AM7@00g@24@03M14A009d00<AM7@00a402g@A4G@AM15d4G@A00Ad0a43M0034GAd00=d
00<AM1400W@00a5d4@05M0034GAd009d00<AM7@017@00a5dM003M0034GAd00Md000OM08A87@01A5d
M7@A00Yd00LAM14AM15d008A0W@24@9d00DAM7Ad4@02M08A17@24@05M15dM1400g@24@04M15dM08A
00Id4G@AM144M0034G@A00=d00<AM7@00g@00a5d4@02M0034G@A00Ed00<AM7@00g@00a5dM003M003
4GAd00=d00<AM7@01g@0025d00<AM7@07W@0115dM14:M0074G@A4G@AM0024@9d0Q42M0054GAdM140
0W@00a5d4@04M0064G@A4G@A17@0115dM142M0<A00Ad4G@A0W@34@9d00DAM7Ad4@05M0074G@AM15d
4@06M0034GAd009d00<AM7@017@00a5dM002M0034GAd00Md000RM0034GAd01ed00DAM7Ad4@09M005
4G@A4G@01142M08A0g@0115dM143M08A17@24@03M14A00Ed0Q401W@AM7@AM0@A00=d4A400g@0115d
M142M0034GAd00=d00<AM7@00Q42M0034GAd00=d00<AM7@00W@00a5dM004M0034GAd009d00<AM7@0
1g@002=d00<AM7@07G@01A5dM7@A00Md00<AM1400W@54@9d00<AM1400W@01A5dM7@A009d00<AM140
0g@24@9d00<AM7@00g@24@9d00PAM15d4G@AM08A17@01A5dM7@A009d00<AM7@00W@00a5dM0024@9d
00<AM7@00g@00a5dM003M0034GAd00Ad00DAM7Ad4@09M00057@24@=d00<AM7@00Q42M0LA7G@0115d
M147M0034G@A009d0Q400g@A4@02M0034G@A009d00DAM7Ad4@02M0044GAd4@9d00HAM14AM144M006
4G@AM15d0Q400g@AM002M0034GAd009d00DAM7Ad4@02M0034GAd009d00DAM7Ad4@02M0034GAd00=d
00<AM7@00g@00a5dM004M0044GAd4@Yd000CM0044GAd4@Ad00@AM7@A0W@00a5dM002M0034GAd01]d
00DAM7Ad4@06M0034G@A00=d00@AM14A0W@00a5d4@02M0054GAdM1400g@01Q5d4G@AM08A0W@00a5d
M002M00:4GAd4G@AM15d4@=d00<AM7@00g@01A5dM7@A009d00DAM7Ad4@03M0044GAd4@Id00<AM7@0
0W@00a5dM005M0034G@A00Yd000>M0@A00Ed4GAd4@04M0044GAd4@=d00<AM7@00W@00a5dM00KM005
4GAdM1401G@00a5d4@03M0044G@A4@9d00<AM1400W@00a5dM002M0054GAd4G@01142M0044GAd4@=d
00@AM7@A0W@24@03M15d00=d00<AM7@00W@00a5dM002M0034G@A00=d00DAM7Ad4@02M0034GAd00Ad
00<AM7@00g@00a5dM004M0034G@A00Yd000CM0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd01]d
00@AM7@A17@0115dM143M0044G@A4@9d00<AM1400W@00a5dM002M0034GAd008A00=d4A400g@0115d
M143M0064GAdM15d0Q400g@AM003M0034GAd009d00<AM7@00g@24@=d00@AM7@A0g@00a5dM004M003
4GAd00=d00<AM7@01G@24@Yd000CM0044GAd4@Ad00@AM7@A17@00a5dM003M0<A6W@01A5dM7@A00=d
00@AM7@A0g@54@04M15d4@9d00<AM7@00W@00a5dM0034@03M15d00=d00@AM7@A0W@00a5dM002M005
4G@AM14017@00a5dM003M0034GAd00=d0Q42M0044GAd4@Ad00<AM7@00g@00a5dM003M0034GAd00Ed
0Q4:M0004g@0115dM144M0064GAd4G@A0W@00a5dM005M0034GAd01Ud00@AM7@A0g@00a5d4@04M08A
00=d4G@00Q400g@AM002M0034GAd009d1143M0034GAd009d00HAM7@AM145M0@A17@00a5dM003M003
4GAd00Ad00@AM7@A0W@00a5dM002M0034GAd00Ad00<AM7@00g@00a5dM005M0034GAd00Qd000DM08A
1W@24@=d0Q49M0034GAd01Qd00DAM7Ad4@02M0034G@A00Ad00DAM14AM0024@9d00@AM7@A0g@34@9d
00DAM7Ad4@03M0064GAd4G@A1G@44@Ed00<AM7@00W@00a5dM004M08A00Ed4GAd4@04M0034GAd00Ad
00<AM7@00g@00a5dM004M0034GAd00Ud000]M0034GAd01Qd00@AM7Ad0Q42M0034GAd00=d0a42M0@A
0W@44@9d00@AM7@A0g@00a5dM002M0034GAd008A1W@00a5d4@05M0034GAd00=d00<AM7@017@01A5d
4G@A00Ed00<AM7@017@00a5dM003M0034GAd00Ad00<AM7@02G@002id0a4HM0034GAd008A0W@00a5d
M003M0034G@A00<A0W@54@Ad00DAM7Ad4@03M0034GAd009d00@AM14A1W@34@Ed00<AM7@00g@00a5d
M005M08A00=d4G@017@00a5dM004M0034GAd00Ad00<AM7@00W@00a5dM00:M000<7@00a5dM00FM005
4GAdM1400W@00a5dM003M0034G@A009d1A42M0034GAd00=d00DAM7Ad4@03M0054GAdM1400W@00a5d
M004M0<A1G@00a5dM003M0034GAd00Ed0Q400g@AM005M0034GAd00Ad00<AM7@00g@00a5dM002M003
4GAd00Yd000aM0034GAd01Id00<AM7@00a46M0044G@A4@9d00@AM7@A0W@00a5dM004M0044GAd4@Ad
00HAM7Ad4G@24@Ad00<AM1401W@00a5dM004M0034GAd00Ed0a46M0034GAd00Ad00<AM7@017@0115d
M14=M000<W@00a5dM00FM08A00=d4A401W@0115dM143M0034G@A00=d00<AM7@00g@01A5dM7@A00=d
00HAM7Ad4G@24@Ad00<AM1401g@00a5dM003M0034GAd00Ed1145M0034GAd00Ad00<AM7@017@0115d
M14=M000<g@34AEd0Q42M0034GAd00Ad00<AM7@00Q42M0044GAd4@9d00<AM7@017@01A5dM7@A00=d
00@AM7Ad0Q400g@AM002M0034G@A00Md00<AM7@017@00a5dM005M0044GAd4@Ad00<AM7@017@00a5d
M004M0034G@A00id000eM0034GAd01Ad00DAM7Ad4@05M0034GAd008A0g@00a5d4@03M0034GAd00Ad
00@AM7@A17@01a5dM7@AM1400g@00a5d4@07M0034GAd00Ad00<AM7@01G@01A5dM7@A00=d00<AM7@0
1G@00a5dM004M08A3W@003Id00<AM7@057@01A5dM7@A00Ad00HAM7@AM142M0044GAd4@9d00<AM7@0
17@01A5dM7@A00Ad00@AM7@A0W@0115d4G@24@Md00<AM7@017@00a5dM004M0034GAd00=d00@AM7@A
1g@00a5dM004M0034GAd00ed000gM0034GAd01Ad00DAM7Ad4@04M0054G@AM1400g@00a5d4@03M003
4GAd00Ad00DAM7Ad4@04M0044G@A4@9d0Q4017@AM147M0034GAd00Ad00<AM7@00g@00a5dM004M08A
00=d4G@01G@00a5dM002M08A47@003Qd0a4DM0054GAdM1400g@00a5d4@02M0044GAd4@9d00@AM7@A
1g@0115dM144M0064G@AM15d0Q4017@AM147M0034GAd00Ad00<AM7@00W@00a5dM007M08A1W@01A5d
M7@A019d000jM0034GAd01=d00DAM7Ad4@02M0064GAd4G@A0W@01A5dM7@A009d00<AM7@017@01A5d
M7@A00Ad0Q402G@AM7@AM15d4@07M0034GAd00Ad00<AM7@00W@00a5dM008M0@A17@34A=d000kM003
4GAd01=d00LAM7Ad4G@A009d00<AM1400g@0115dM143M0034GAd00Ad00@AM7@A1G@00a5dM0044@9d
00<AM7@01G@00a5dM005M0044GAd4@md1A4EM000?7@00a5dM00CM0064GAd4G@A0W@0115dM142M005
4GAdM1400W@00a5dM004M0054GAdM1401G@44@05M15dM1401g@00a5dM005M0044GAd4BUd000mM0<A
4W@0115dM7@24@9d00@AM7@A0g@0115dM143M0034GAd00Ad00DAM7Ad4@06M0<A0g@00a5dM006M003
4GAd00Ad00<AM140:W@003md00<AM7@04G@01A5dM7@A009d00DAM7Ad4@02M0054GAdM1400W@00a5d
M005M0044GAd4@Id0a43M0034GAd00Id00<AM7@01G@24BYd000`M08A0g@00a5dM0024@=d114CM003
4GAd008A00=d4G@00W@01A5dM7@A00=d00@AM7@A1W@01A5dM7@A00Ed1143M0034GAd00Ed00<AM7@0
1G@00a5dM00YM000;g@0115dM144M0044GAd4@=d00@AM7@A4g@00a5dM0024@03M15d009d00@AM7@A
0g@0115dM147M0054GAdM1400g@00a5d4@02M0044GAd4@Md00<AM7@00g@24Bad000YM0@A0W@0115d
M144M0044GAd4@=d00@AM7Ad0a4AM0044G@AM08A0g@0115dM144M0044GAd4@Md00@AM7@A0W@00a5d
4@04M0<A27@00a5dM0024Bid000_M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd011d0Q42M005
4GAdM1400g@01A5dM7@A00=d00<AM7@017@02A5dM7@AM15d4@06M0DA17@34C1d000_M0044GAd4@Ad
00@AM7@A0g@00a5dM004M0034GAd011d00@AM7Ad0Q42M0044GAd4@Ad00@AM7@A1g@01a5dM7@AM140
37@54C9d000_M0044GAd4@Ad00@AM7@A0W@24@Md00<AM7@047@24@=d00<AM1400g@01A5dM7@A00=d
00<AM7@01G@01Q5d4A5d4D=d000`M08A1W@24@Ad00<AM7@01W@00a5d4@0AM0044GAdM0<A0W@00a5d
M002M0044GAd4@Md00DAM15d4@14M000B7@24A9d0Q43M08A0W@00a5dM002M0044GAd4@Id1155M000
BW@00a5dM00AM08A0W@24@03M15d00=d00@AM7@A17@44DMd001;M0034G@A019d00@AM15d0a44M005
4GAd4G@01159M000C7@24A=d0a42M0HA0W@44D]d001=M08A57@=4Ded001?M0034GAd06]d001@M003
4G@A06Yd001AM08AJW@0059d0Q5YM000E7@00a5d4@1VM000EG@24FId001FM0034GAd06Ad001;M08A
2W@24FAd001:M0044GAd4@]d0Q5RM000BW@0115dM14<M0034GAd061d001:M0044GAd4@ed00<AM7@0
Gg@004Yd00@AM7@A3W@24@03M15d05ad001:M0044GAd4A1d0Q5MM000Bg@24A9d00<AM7@0Fg@0061d
00@AM7@AFG@0065d0a5IM000Hg@00a5dM01GM000I7@00a5dM01FM000IG@00a5d4@1EM000IW@24EEd
001XM0034GAd059d001YM0034G@A055d001ZM08ADG@006]d0Q5@M000Fg@24@=d00<AM7@00Q43M0<A
0W@00a5d4@1=M000FW@0115dM144M0044GAd4@=d00<AM7@00W@24Ded001JM0044GAd4@Ad00@AM7@A
0g@00a5dM003M0034GAd04]d001JM0044GAd4@Ad00@AM7@A0g@00a5dM004M0<ABW@005Yd00@AM7@A
17@0115dM143M0034GAd00Id00<AM7@0B7@005Yd00@AM7@A17@0115dM142M08A2G@0115dM156M000
Fg@24@Id0Q44M0034GAd00Qd00<AM140AW@007Ed0Q56M000Mg@00a5dM013M000N7@00a5dM012M000
_G@00;ed002mM000_G@00;ed002mM000Kg@24@=d00<AM7@00Q42M0@A?W@006id00@AM7@A17@0115d
M142M0034GAd03id001^M0044GAd4@Ad00@AM7@A0g@00a5dM00mM000KW@0115dM144M0044GAd4@=d
00<AM7@0?G@006id00@AM7@A17@0115dM144M0034GAd03ad001^M0044GAd4@Ad00HAM7@AM142M003
4GAd03ad001_M08A1W@24@=d0Q4oM000_G@00;ed002mM000_G@00;ed0000\
\>"],
  ImageRangeCache->{{{0, 188.75}, {287, 0}} -> {0.0637148, -0.0704175, 
  0.00383968, 0.00383968}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Systems", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Source Position", "SubsubsectionIcon"],

Cell["This is the orientation and position of the light source.", "Text"],

Cell["\<\
Clear[TwistAngleSource,PositionSource,
\tAngleXYSource,AngleYZSource,WavelengthSource,TiltVectorSource];
TwistAngleSource = 0;
PositionSource = {0,Deltax,Deltay};
AngleXYSource = 0 40.;
AngleYZSource = 0 20.;
WavelengthSource = 0.450;
TiltVectorSource={
\tSqrt[1-(Sin[AngleXYSource Pi/180.])^2-(Sin[AngleYZSource Pi/180.])^2],
\tSin[AngleXYSource Pi/180.],
\tSin[AngleYZSource Pi/180.]};\
\>", "Input",
  CellLabel->"In[59]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Lens Positions", "SubsubsectionIcon"],

Cell["The lens is oriented as follows.", "Text"],

Cell["\<\
Clear[TwistAngleLens,PositionLens,AngleXYLens,AngleYZLens,\
TiltVectorLens];
TwistAngleLens=0;
PositionLens={25,0,0} R0;
AngleXYLens=0 10.;
AngleYZLens=0 30.;
TiltVectorLens={
\tSqrt[1-(Sin[AngleXYLens Pi/180.])^2-(Sin[AngleYZLens Pi/180.])^2],
\tSin[AngleXYLens Pi/180.],
\tSin[AngleYZLens Pi/180.]};\
\>", "Input",
  CellLabel->"In[66]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Ray-Trace", "SubsubsectionIcon"],

Cell["\<\
Clear[PressureLensSystem,PressureLensSurfacesSystem];
PressureLensSystem := 
{
\tBoundary[{-2,-4,-3} R0,{35,9,12} R0, GraphicDesign -> Off],
\tMove3D[PointOfRays[3,
\t\tWaveLength->WavelengthSource,
\t\tNumberOfRays->3
\t],PositionSource,TiltVectorSource,TwistAngleSource],
\tMove3D[FlexibleLens,PositionLens,TiltVectorLens,TwistAngleLens],
\tBoundary[{-2,-4,-3} R0,{35,9,12} R0, GraphicDesign -> Off]
};
PressureLensSurfacesSystem := 
{
\tBoundary[{-2,-4,-3} R0,{35,9,12} R0, GraphicDesign -> Off],
\tMove3D[PointOfRays[3,
\t\tWaveLength->WavelengthSource,
\t\tNumberOfRays->3
\t],PositionSource,TiltVectorSource,TwistAngleSource],
\tMove3D[LensSurfaces,PositionLens,TiltVectorLens,TwistAngleLens],
\tBoundary[{-2,-4,-3} R0,{35,9,12} R0, GraphicDesign -> Off]
};\
\>", "Input",
  CellLabel->"In[72]:="],

Cell["\<\
Clear[PressureLensTraced,PressureLensSurfacesTraced];
PressureLensTraced = PropagateSystem[PressureLensSystem];
PressureLensSurfacesTraced = \
PropagateSystem[PressureLensSurfacesSystem];\
\>", "Input",
  CellLabel->"In[75]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Drawings", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["ShowSystem[PressureLensTraced, Axes->True];", "Input",
  CellLabel->"In[78]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .46345 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0452603 1.04526 -0.277379 1.04526 [
[.0304 .28899 -4.09187 -10.9375 ]
[.0304 .28899 4.90813 0 ]
[.26397 .21136 -7.88704 -10.9375 ]
[.26397 .21136 8.61296 0 ]
[.51208 .12891 -8.31006 -10.9375 ]
[.51208 .12891 8.18994 0 ]
[.77614 .04119 -8.77663 -10.9375 ]
[.77614 .04119 7.72337 0 ]
[.95422 -0.00237 0 -7.2795 ]
[.95422 -0.00237 28.4375 3.658 ]
[.9659 .0149 0 -7.26618 ]
[.9659 .0149 28.4375 3.67132 ]
[.97743 .03197 0 -7.25306 ]
[.97743 .03197 9 3.68444 ]
[.98883 .04883 0 -7.24013 ]
[.98883 .04883 21.5 3.69737 ]
[1.0001 .06549 0 -7.22738 ]
[1.0001 .06549 21.5 3.71012 ]
[1.00148 .06956 0 -7.22455 ]
[1.00148 .06956 28.4375 3.71295 ]
[1.00402 .09292 0 -7.20938 ]
[1.00402 .09292 28.4375 3.72812 ]
[1.00659 .11651 0 -7.19408 ]
[1.00659 .11651 9 3.74342 ]
[1.00918 .14033 0 -7.17863 ]
[1.00918 .14033 21.5 3.75887 ]
[1.0118 .1644 0 -7.16303 ]
[1.0118 .1644 21.5 3.77447 ]
[ 0 0 0 0 ]
[ 1 .46345 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00938 .30858 m
.94064 0 L
s
.02922 .302 m
.02863 .30851 L
s
gsave
.0304 .28899 -65.0919 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.26339 .22441 m
.26311 .23094 L
s
gsave
.26397 .21136 -68.887 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51218 .14197 m
.51222 .14851 L
s
gsave
.51208 .12891 -69.3101 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77697 .05423 m
.77739 .06075 L
s
gsave
.77614 .04119 -69.7766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07495 .28685 m
.07463 .29076 L
s
.12122 .27152 m
.12094 .27543 L
s
.16805 .256 m
.1678 .25992 L
s
.21543 .2403 m
.21522 .24422 L
s
.31194 .20832 m
.31181 .21224 L
s
.36108 .19204 m
.36098 .19596 L
s
.41082 .17556 m
.41077 .17948 L
s
.46119 .15887 m
.46117 .16279 L
s
.56381 .12487 m
.56388 .12879 L
s
.61609 .10754 m
.6162 .11146 L
s
.66903 .09 m
.66919 .09392 L
s
.72266 .07223 m
.72286 .07614 L
s
.83199 .036 m
.83229 .03991 L
s
.88773 .01753 m
.88807 .02144 L
s
.25 Mabswid
.94064 0 m
.98878 .07115 L
s
.94182 .00174 m
.93562 .00379 L
s
gsave
.95422 -0.00237 -61 -11.2795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.95348 .01898 m
.94728 .02102 L
s
gsave
.9659 .0149 -61 -11.2662 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.96501 .03602 m
.9588 .03805 L
s
gsave
.97743 .03197 -61 -11.2531 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9764 .05286 m
.97019 .05487 L
s
gsave
.98883 .04883 -61 -11.2401 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98766 .06949 m
.98144 .07149 L
s
gsave
1.0001 .06549 -61 -11.2274 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.94416 .0052 m
.94044 .00643 L
s
.9465 .00866 m
.94278 .00989 L
s
.94883 .01211 m
.94511 .01334 L
s
.95116 .01555 m
.94744 .01677 L
s
.9558 .02241 m
.95208 .02363 L
s
.95811 .02582 m
.95439 .02704 L
s
.96042 .02923 m
.95669 .03045 L
s
.96272 .03263 m
.95899 .03385 L
s
.9673 .0394 m
.96357 .04062 L
s
.96958 .04278 m
.96586 .04399 L
s
.97186 .04615 m
.96813 .04736 L
s
.97413 .04951 m
.97041 .05071 L
s
.97866 .0562 m
.97493 .05741 L
s
.98092 .05954 m
.97719 .06074 L
s
.98317 .06286 m
.97944 .06407 L
s
.98542 .06618 m
.98169 .06738 L
s
.25 Mabswid
.98878 .07115 m
1 .17453 L
s
.98904 .07356 m
.98282 .07555 L
s
gsave
1.00148 .06956 -61 -11.2246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99157 .09688 m
.98534 .09886 L
s
gsave
1.00402 .09292 -61 -11.2094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99413 .12044 m
.9879 .1224 L
s
gsave
1.00659 .11651 -61 -11.1941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99671 .14423 m
.99048 .14618 L
s
gsave
1.00918 .14033 -61 -11.1786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99932 .16826 m
.99308 .1702 L
s
gsave
1.0118 .1644 -61 -11.163 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98954 .0782 m
.98581 .0794 L
s
.99005 .08286 m
.98631 .08405 L
s
.99055 .08752 m
.98682 .08872 L
s
.99106 .0922 m
.98733 .09339 L
s
.99208 .10157 m
.98834 .10276 L
s
.99259 .10628 m
.98885 .10746 L
s
.9931 .11099 m
.98936 .11217 L
s
.99361 .11571 m
.98988 .11689 L
s
.99464 .12518 m
.9909 .12636 L
s
.99516 .12993 m
.99142 .1311 L
s
.99567 .13469 m
.99193 .13586 L
s
.99619 .13945 m
.99245 .14063 L
s
.99723 .14902 m
.99349 .15019 L
s
.99775 .15381 m
.99401 .15498 L
s
.99827 .15862 m
.99453 .15978 L
s
.9988 .16344 m
.99505 .1646 L
s
.99984 .1731 m
.9961 .17426 L
s
0 0 m
1 0 L
1 .46345 L
0 .46345 L
closepath
clip
newpath
.001 .092 .901 r
.5 Mabswid
.06311 .40741 m
.67214 .21474 L
s
.06311 .40741 m
.68513 .22337 L
s
.06311 .40741 m
.67115 .20515 L
s
.06311 .40741 m
.67168 .21844 L
s
.06311 .40741 m
.67769 .21933 L
s
0 g
.68825 .1704 m
.6827 .15664 L
s
.69217 .16914 m
.68825 .1704 L
s
.68825 .1704 m
.68275 .17397 L
s
.69267 .18488 m
.68825 .1704 L
s
.69569 .19913 m
.69267 .18488 L
s
.69267 .18488 m
.6966 .18363 L
s
.68572 .18367 m
.69267 .18488 L
s
.69217 .16914 m
.68663 .15538 L
s
.71121 .16303 m
.69217 .16914 L
s
.69217 .16914 m
.6867 .17271 L
s
.6966 .18363 m
.69217 .16914 L
s
.69962 .19788 m
.6966 .18363 L
s
.6966 .18363 m
.71565 .17755 L
s
.68966 .18241 m
.6966 .18363 L
s
.6827 .15664 m
.68663 .15538 L
s
.6827 .15664 m
.67639 .1445 L
s
.67904 .16476 m
.6827 .15664 L
s
.69569 .19913 m
.69962 .19788 L
s
.68773 .19322 m
.69569 .19913 L
s
.68663 .15538 m
.70566 .14923 L
s
.68663 .15538 m
.68032 .14322 L
s
.68298 .16349 m
.68663 .15538 L
s
.69962 .19788 m
.7187 .19183 L
s
.69168 .19196 m
.69962 .19788 L
s
.67639 .1445 m
.68032 .14322 L
s
.67481 .15664 m
.67639 .1445 L
s
.71121 .16303 m
.70566 .14923 L
s
.73099 .15668 m
.71121 .16303 L
s
.71121 .16303 m
.70581 .16658 L
s
.71565 .17755 m
.71121 .16303 L
s
.7187 .19183 m
.71565 .17755 L
s
.71565 .17755 m
.73544 .17123 L
s
.70879 .1763 m
.71565 .17755 L
s
.68032 .14322 m
.69938 .13704 L
s
.67875 .15537 m
.68032 .14322 L
s
.68866 .20197 m .70104 .21098 L .69709 .21222 L .656 .751 .92 r
F
0 g
.69678 .22328 m
.69709 .21222 L
s
.69569 .19913 m
.69661 .20776 L
s
.70566 .14923 m
.72545 .14284 L
s
.70566 .14923 m
.69938 .13704 L
s
.7021 .15733 m
.70566 .14923 L
s
.68866 .20197 m .69262 .20071 L .70104 .21098 L .656 .751 .92 r
F
0 g
.70073 .22204 m
.70104 .21098 L
s
.69962 .19788 m
.70104 .21098 L
s
.69709 .21222 m
.70104 .21098 L
s
.7187 .19183 m
.73852 .18554 L
s
.68572 .18367 m
.68275 .17397 L
s
.68275 .17397 m
.67904 .16476 L
s
.67721 .17758 m
.68275 .17397 L
s
.73099 .15668 m
.73544 .17123 L
s
.72545 .14284 m
.73099 .15668 L
s
.68773 .19322 m
.68572 .18367 L
s
.67869 .18245 m
.68572 .18367 L
s
.73544 .17123 m
.73852 .18554 L
s
.66973 .13478 m .6743 .14888 L .67035 .15016 L .544 .324 .532 r
F
.66973 .13478 m .67367 .1335 L .6743 .14888 L F
0 g
.67398 .14098 m
.67639 .1445 L
s
.67367 .1335 m
.68032 .14322 L
s
.66973 .13478 m
.67367 .1335 L
s
.66316 .12815 m
.66973 .13478 L
s
.69938 .13704 m
.71919 .13061 L
s
.68966 .18241 m
.6867 .17271 L
s
.6867 .17271 m
.68298 .16349 L
s
.68117 .17631 m
.6867 .17271 L
s
.69168 .19196 m
.68966 .18241 L
s
.68266 .18119 m
.68966 .18241 L
s
.67904 .16476 m
.67481 .15664 L
s
.67534 .17295 m
.67904 .16476 L
s
.6671 .12686 m
.67367 .1335 L
s
.71919 .13061 m
.72545 .14284 L
s
.68298 .16349 m
.67875 .15537 L
s
.6793 .17168 m
.68298 .16349 L
s
.71179 .19463 m .74002 .19867 L .72015 .20494 L .656 .751 .92 r
F
0 g
.71991 .21601 m
.72015 .20494 L
s
.7187 .19183 m
.71913 .19568 L
s
.70104 .21098 m
.72015 .20494 L
s
.69476 .23156 m
.69678 .22328 L
s
.69678 .22328 m
.70073 .22204 L
s
.68843 .20934 m
.69678 .22328 L
s
.69873 .23032 m
.70073 .22204 L
s
.70073 .22204 m
.71991 .21601 L
s
.6924 .20809 m
.70073 .22204 L
s
.67717 .16761 m
.67875 .15537 L
s
.68016 .19164 m .69262 .20071 L .68866 .20197 L .656 .751 .92 r
F
0 g
.68843 .20934 m
.68866 .20197 L
s
.68773 .19322 m
.68818 .19748 L
s
.68866 .20197 m
.69709 .21222 L
s
.70879 .1763 m
.70581 .16658 L
s
.70581 .16658 m
.7021 .15733 L
s
.70037 .17015 m
.70581 .16658 L
s
.68016 .19164 m .68413 .19037 L .69262 .20071 L .656 .751 .92 r
F
0 g
.6924 .20809 m
.69262 .20071 L
s
.69262 .20071 m
.70104 .21098 L
s
.6797 .18725 m
.68397 .19042 L
s
.68448 .1908 m
.68773 .19322 L
s
.69168 .19196 m
.69262 .20071 L
s
.68367 .18598 m
.69168 .19196 L
s
.71083 .18586 m
.70879 .1763 L
s
.70186 .17504 m
.70879 .1763 L
s
.69276 .12727 m .71337 .13622 L .69346 .14267 L .544 .324 .532 r
F
0 g
.69789 .14918 m
.6989 .14091 L
s
.69276 .12727 m .7126 .12081 L .71337 .13622 L .544 .324 .532 r
F
0 g
.67367 .1335 m
.69276 .12727 L
s
.7126 .12081 m
.71919 .13061 L
s
.69276 .12727 m
.7126 .12081 L
s
.68625 .1206 m
.69276 .12727 L
s
.7021 .15733 m
.69789 .14918 L
s
.71179 .19463 m .73172 .18831 L .74002 .19867 L .656 .751 .92 r
F
0 g
.73983 .20975 m
.74002 .19867 L
s
.73852 .18554 m
.74002 .19867 L
s
.72015 .20494 m
.74002 .19867 L
s
.71083 .18586 m
.7187 .19183 L
s
.67035 .15016 m .67494 .16436 L .67097 .16564 L .544 .324 .532 r
F
0 g
.67321 .16888 m
.67375 .16475 L
s
.67413 .16185 m
.67481 .15664 L
s
.67035 .15016 m .6743 .14888 L .67494 .16436 L .544 .324 .532 r
F
0 g
.66973 .13478 m
.67035 .15016 L
s
.67461 .15635 m
.67481 .15664 L
s
.6743 .14888 m
.67875 .15537 L
s
.66596 .14577 m
.67035 .15016 L
s
.67367 .1335 m
.6743 .14888 L
s
.66316 .12815 m
.6671 .12686 L
s
.66316 .12815 m
.65711 .12508 L
s
.66596 .14577 m
.66316 .12815 L
s
.66992 .14448 m
.6743 .14888 L
s
.71796 .22429 m
.71991 .21601 L
s
.71991 .21601 m
.73983 .20975 L
s
.71161 .20201 m
.71991 .21601 L
s
.6671 .12686 m
.68625 .1206 L
s
.6671 .12686 m
.66107 .12378 L
s
.66992 .14448 m
.6671 .12686 L
s
.68563 .2153 m
.68843 .20934 L
s
.67946 .19551 m
.68843 .20934 L
s
.68957 .21405 m
.6924 .20809 L
s
.6834 .19425 m
.6924 .20809 L
s
.69114 .23648 m
.69476 .23156 L
s
.69476 .23156 m
.69873 .23032 L
s
.68563 .2153 m
.69476 .23156 L
s
.67869 .18245 m
.67721 .17758 L
s
.67721 .17758 m
.67534 .17295 L
s
.70336 .18424 m .73172 .18831 L .71179 .19463 L .656 .751 .92 r
F
0 g
.71161 .20201 m
.71179 .19463 L
s
.71179 .19463 m
.72015 .20494 L
s
.69262 .20071 m
.71179 .19463 L
s
.6797 .18725 m
.67869 .18245 L
s
.69513 .23523 m
.69873 .23032 L
s
.69873 .23032 m
.71796 .22429 L
s
.68957 .21405 m
.69873 .23032 L
s
.67534 .17295 m
.67321 .16888 L
s
.70614 .11409 m
.7126 .12081 L
s
.68266 .18119 m
.68117 .17631 L
s
.68117 .17631 m
.6793 .17168 L
s
.68367 .18598 m
.68266 .18119 L
s
.6793 .17168 m
.67717 .16761 L
s
.66596 .14577 m
.66193 .14376 L
s
.66877 .16346 m
.66596 .14577 L
s
.6716 .18122 m .68413 .19037 L .68016 .19164 L .656 .751 .92 r
F
0 g
.67946 .19551 m
.68016 .19164 L
s
.68016 .19164 m
.68866 .20197 L
s
.66992 .14448 m
.6659 .14247 L
s
.66992 .14448 m
.67274 .16218 L
s
.69346 .14267 m .71413 .15173 L .69416 .15817 L .544 .324 .532 r
F
0 g
.69638 .16143 m
.69689 .15729 L
s
.6985 .16551 m
.7021 .15733 L
s
.69346 .14267 m .71337 .13622 L .71413 .15173 L .544 .324 .532 r
F
0 g
.69276 .12727 m
.69346 .14267 L
s
.6743 .14888 m
.69346 .14267 L
s
.7126 .12081 m
.71337 .13622 L
s
.68911 .13825 m
.69346 .14267 L
s
.68025 .21946 m
.68563 .2153 L
s
.67729 .19872 m
.68563 .2153 L
s
.73983 .20975 m
.73795 .21802 L
s
.68625 .1206 m
.70614 .11409 L
s
.68625 .1206 m
.68027 .11749 L
s
.68911 .13825 m
.68625 .1206 L
s
.6716 .18122 m .67558 .17995 L .68413 .19037 L .656 .751 .92 r
F
0 g
.6834 .19425 m
.68413 .19037 L
s
.68413 .19037 m
.69262 .20071 L
s
.67746 .18224 m
.67869 .18245 L
s
.68367 .18598 m
.68413 .19037 L
s
.67097 .16564 m .67558 .17995 L .6716 .18122 L .544 .324 .532 r
F
0 g
.67287 .17152 m
.67321 .16888 L
s
.67416 .17555 m
.67534 .17295 L
s
.67523 .17886 m
.67721 .17758 L
s
.67097 .16564 m .67494 .16436 L .67558 .17995 L .544 .324 .532 r
F
0 g
.67035 .15016 m
.67097 .16564 L
s
.67494 .16436 m
.67717 .16761 L
s
.66877 .16346 m
.67097 .16564 L
s
.6743 .14888 m
.67494 .16436 L
s
.68421 .21821 m
.68957 .21405 L
s
.68124 .19746 m
.68957 .21405 L
s
.71029 .20751 m
.71161 .20201 L
s
.67729 .19872 m
.67946 .19551 L
s
.67274 .16218 m
.67494 .16436 L
s
.70336 .18424 m .72334 .17787 L .73172 .18831 L .656 .751 .92 r
F
0 g
.70326 .18793 m
.71161 .20201 L
s
.73172 .18831 m
.74002 .19867 L
s
.70288 .17984 m
.70711 .18305 L
s
.65711 .12508 m
.66107 .12378 L
s
.65711 .12508 m
.652 .12581 L
s
.66193 .14376 m
.65711 .12508 L
s
.68124 .19746 m
.6834 .19425 L
s
.71443 .22919 m
.71796 .22429 L
s
.71796 .22429 m
.73795 .21802 L
s
.71029 .20751 m
.71796 .22429 L
s
.70186 .17504 m
.70037 .17015 L
s
.70037 .17015 m
.6985 .16551 L
s
.70288 .17984 m
.70186 .17504 L
s
.001 .092 .901 r
.68513 .22337 m
.68866 .22191 L
s
0 0 0 r
2 Mabswid
.68513 .22337 Mdot
0 g
.5 Mabswid
.66877 .16346 m
.66676 .16248 L
s
.66107 .12378 m
.68027 .11749 L
s
.66107 .12378 m
.65598 .12451 L
s
.6659 .14247 m
.66107 .12378 L
s
.67458 .20078 m
.67729 .19872 L
s
.6985 .16551 m
.69638 .16143 L
s
.66193 .14376 m
.65854 .1443 L
s
.66676 .16248 m
.66193 .14376 L
s
.67274 .16218 m
.67073 .16119 L
s
.001 .092 .901 r
.68866 .22191 m
.70907 .21342 L
s
0 0 0 r
2 Mabswid
.68866 .22191 Mdot
.001 .092 .901 r
.5 Mabswid
.68866 .22191 m
.68866 .22191 L
s
0 0 0 r
2 Mabswid
.68866 .22191 Mdot
0 g
.5 Mabswid
.67854 .19953 m
.68124 .19746 L
s
.68911 .13825 m
.68513 .13622 L
s
.69198 .15597 m
.68911 .13825 L
s
.67513 .22076 m
.68025 .21946 L
s
.68025 .21946 m
.69114 .23648 L
s
.67458 .20078 m
.68025 .21946 L
s
.68587 .23775 m
.69114 .23648 L
s
.69114 .23648 m
.69513 .23523 L
s
.6659 .14247 m
.66252 .14301 L
s
.67073 .16119 m
.6659 .14247 L
s
.70022 .11095 m
.70614 .11409 L
s
.69486 .17377 m .72334 .17787 L .70336 .18424 L .656 .751 .92 r
F
0 g
.70326 .18793 m
.70336 .18424 L
s
.70336 .18424 m
.71179 .19463 L
s
.68413 .19037 m
.70336 .18424 L
s
.67911 .21951 m
.68421 .21821 L
s
.68421 .21821 m
.69513 .23523 L
s
.67854 .19953 m
.68421 .21821 L
s
.68983 .23651 m
.69513 .23523 L
s
.69513 .23523 m
.71443 .22919 L
s
.67213 .20137 m
.67458 .20078 L
s
.66676 .16248 m
.66507 .16277 L
s
.70791 .21073 m
.71029 .20751 L
s
.70259 .19067 m
.71029 .20751 L
s
.001 .092 .901 r
.67769 .21933 m
.68135 .21788 L
s
0 0 0 r
2 Mabswid
.67769 .21933 Mdot
.69416 .15817 m .7149 .16735 L .69486 .17377 L .544 .324 .532 r
F
.69416 .15817 m .71413 .15173 L .7149 .16735 L F
0 g
.5 Mabswid
.69346 .14267 m
.69416 .15817 L
s
.67494 .16436 m
.69416 .15817 L
s
.69198 .15597 m
.69416 .15817 L
s
.71337 .13622 m
.71413 .15173 L
s
.6761 .20011 m
.67854 .19953 L
s
.67073 .16119 m
.66905 .16149 L
s
.70259 .19067 m
.70326 .18793 L
s
.73795 .21802 m
.73449 .22291 L
s
.001 .092 .901 r
.68135 .21788 m
.70503 .20849 L
s
0 0 0 r
2 Mabswid
.68135 .21788 Mdot
.001 .092 .901 r
.5 Mabswid
.68135 .21788 m
.68135 .21788 L
s
0 0 0 r
2 Mabswid
.68135 .21788 Mdot
.6716 .18122 m .6734 .19653 L .66944 .19779 L .544 .324 .532 r
F
0 g
.5 Mabswid
.67202 .19697 m
.67213 .20137 L
s
.67042 .20034 m
.6706 .19742 L
s
.001 .092 .901 r
.06311 .40741 m
.66971 .19568 L
s
.6716 .18122 m .67558 .17995 L .6734 .19653 L .544 .324 .532 r
F
0 g
.67489 .18522 m
.68016 .19164 L
s
.67468 .18681 m
.67946 .19551 L
s
.67432 .18957 m
.67729 .19872 L
s
.67365 .19467 m
.67458 .20078 L
s
.66297 .17073 m .67558 .17995 L .6716 .18122 L .656 .751 .92 r
F
0 g
.66877 .19405 m
.6716 .18122 L
s
.66774 .1896 m
.6716 .18122 L
s
.66594 .1849 m
.6716 .18122 L
s
.66444 .17998 m
.6716 .18122 L
s
.66507 .16277 m
.6696 .17558 L
s
.6716 .18122 m
.6716 .18122 L
s
.66676 .16248 m
.67027 .17606 L
s
.66877 .16346 m
.67085 .17649 L
s
.67097 .16564 m
.67143 .17691 L
s
.68027 .11749 m
.70022 .11095 L
s
.68027 .11749 m
.67524 .1182 L
s
.68513 .13622 m
.68027 .11749 L
s
.67042 .20034 m
.67213 .20137 L
s
.67213 .20137 m
.67513 .22076 L
s
.66507 .16277 m
.65854 .1443 L
s
.66507 .16277 m
.66383 .16432 L
s
.66297 .17073 m .66696 .16944 L .67558 .17995 L .656 .751 .92 r
F
0 g
.67558 .17995 m
.6761 .20011 L
s
.67438 .19908 m
.67558 .17995 L
s
.67274 .19279 m
.67558 .17995 L
s
.6717 .18834 m
.67558 .17995 L
s
.66994 .18362 m
.67558 .17995 L
s
.66843 .1787 m
.67558 .17995 L
s
.66742 .17386 m
.67558 .17995 L
s
.6671 .16575 m
.67558 .17995 L
s
.66781 .16304 m
.67558 .17995 L
s
.66905 .16149 m
.67558 .17995 L
s
.67558 .17995 m
.67558 .17995 L
s
.66383 .16432 m
.66628 .16966 L
s
.66311 .16704 m
.66494 .17009 L
s
.66342 .17514 m
.6716 .18122 L
s
.67073 .16119 m
.67558 .17995 L
s
.67558 .17995 m
.67854 .19953 L
s
.67558 .17995 m
.68124 .19746 L
s
.67274 .16218 m
.67558 .17995 L
s
.67558 .17995 m
.6834 .19425 L
s
.67494 .16436 m
.67558 .17995 L
s
.67558 .17995 m
.68117 .17631 L
s
.67558 .17995 m
.68266 .18119 L
s
.67558 .17995 m
.6793 .17168 L
s
.67558 .17995 m
.68367 .18598 L
s
.67558 .17995 m
.67717 .16761 L
s
.67558 .17995 m
.68413 .19037 L
s
.69198 .15597 m
.68999 .15498 L
s
.67438 .19908 m
.6761 .20011 L
s
.6761 .20011 m
.67911 .21951 L
s
.001 .092 .901 r
.67366 .19459 m
.67591 .19419 L
s
.67115 .20515 m
.67511 .20435 L
s
0 g
.65854 .1443 m
.652 .12581 L
s
.65854 .1443 m
.65603 .14737 L
s
.66905 .16149 m
.66252 .14301 L
s
.66905 .16149 m
.66781 .16304 L
s
.6718 .21871 m
.67513 .22076 L
s
.67513 .22076 m
.68587 .23775 L
s
.70139 .19226 m
.70259 .19067 L
s
.68513 .13622 m
.68179 .13674 L
s
.68999 .15498 m
.68513 .13622 L
s
.001 .092 .901 r
.67214 .21474 m
.67612 .21348 L
s
.69486 .17377 m .7149 .16735 L .72334 .17787 L .656 .751 .92 r
F
0 g
.72334 .17787 m
.73172 .18831 L
s
.001 .092 .901 r
.67591 .19419 m
.69846 .19023 L
s
0 0 0 r
2 Mabswid
.67591 .19419 Mdot
.001 .092 .901 r
.5 Mabswid
.67591 .19419 m
.67591 .19419 L
s
0 0 0 r
2 Mabswid
.67591 .19419 Mdot
.001 .092 .901 r
.5 Mabswid
.67511 .20435 m
.70078 .19921 L
s
0 0 0 r
2 Mabswid
.67511 .20435 Mdot
.001 .092 .901 r
.5 Mabswid
.67511 .20435 m
.67511 .20435 L
s
0 0 0 r
2 Mabswid
.67511 .20435 Mdot
0 g
.5 Mabswid
.652 .12581 m
.6482 .13035 L
s
.65598 .12451 m
.652 .12581 L
s
.70953 .23034 m
.71443 .22919 L
s
.71443 .22919 m
.73449 .22291 L
s
.70791 .21073 m
.71443 .22919 L
s
.66252 .14301 m
.65598 .12451 L
s
.66252 .14301 m
.66001 .14607 L
s
.67579 .21746 m
.67911 .21951 L
s
.67911 .21951 m
.68983 .23651 L
s
.001 .092 .901 r
.67612 .21348 m
.70233 .20518 L
s
0 0 0 r
2 Mabswid
.67612 .21348 Mdot
.001 .092 .901 r
.5 Mabswid
.67612 .21348 m
.67612 .21348 L
s
0 0 0 r
2 Mabswid
.67612 .21348 Mdot
.001 .092 .901 r
.5 Mabswid
.70907 .21342 m
.72784 .20551 L
s
.70907 .21342 m
.70907 .21342 L
s
0 g
.66383 .16432 m
.65603 .14737 L
s
.66383 .16432 m
.66311 .16704 L
s
.70463 .21145 m
.70791 .21073 L
s
.70139 .19226 m
.70791 .21073 L
s
.65598 .12451 m
.67524 .1182 L
s
.65598 .12451 m
.65219 .12904 L
s
.68999 .15498 m
.68833 .15526 L
s
.67438 .19908 m
.67579 .21746 L
s
.66781 .16304 m
.6671 .16575 L
s
.69974 .1926 m
.70139 .19226 L
s
.69527 .11163 m
.70022 .11095 L
s
.68005 .23501 m
.68587 .23775 L
s
.68587 .23775 m
.68983 .23651 L
s
.69486 .17377 m .71568 .18307 L .69557 .18947 L .544 .324 .532 r
F
0 g
.69868 .18848 m
.69974 .1926 L
s
.69732 .18891 m
.69776 .19165 L
s
.69992 .18809 m
.70139 .19226 L
s
.70281 .18717 m
.70326 .18793 L
s
.70122 .18767 m
.70259 .19067 L
s
.69486 .17377 m .7149 .16735 L .71568 .18307 L .544 .324 .532 r
F
.6863 .16322 m .7149 .16735 L .69486 .17377 L .656 .751 .92 r
F
0 g
.69333 .18622 m
.69486 .17377 L
s
.69119 .18211 m
.69486 .17377 L
s
.6893 .17742 m
.69486 .17377 L
s
.68779 .17248 m
.69486 .17377 L
s
.68677 .16764 m
.69486 .17377 L
s
.68711 .15681 m
.6903 .16379 L
s
.68833 .15526 m
.6914 .16395 L
s
.69486 .17377 m
.69486 .17377 L
s
.68999 .15498 m
.69235 .16409 L
s
.69416 .15817 m
.69444 .16439 L
s
.67558 .17995 m
.69486 .17377 L
s
.69198 .15597 m
.69332 .16423 L
s
.66944 .19779 m .67404 .21232 L .67006 .21358 L .544 .324 .532 r
F
0 g
.67042 .20034 m
.67047 .20106 L
s
.67138 .21316 m
.6718 .21871 L
s
.66944 .19779 m .6734 .19653 L .67404 .21232 L .544 .324 .532 r
F
0 g
.66944 .19779 m
.6716 .18122 L
s
.6734 .19653 m
.67438 .19908 L
s
.66877 .19405 m
.66944 .19779 L
s
.6734 .19653 m
.67558 .17995 L
s
.68403 .23376 m
.68983 .23651 L
s
.68983 .23651 m
.70953 .23034 L
s
.68833 .15526 m
.68179 .13674 L
s
.68833 .15526 m
.68711 .15681 L
s
.67274 .19279 m
.6734 .19653 L
s
.001 .092 .901 r
.70503 .20849 m
.70503 .20849 L
s
0 g
.65603 .14737 m
.6482 .13035 L
s
.65603 .14737 m
.65457 .15277 L
s
.001 .092 .901 r
.67168 .21844 m
.67563 .21703 L
s
0 g
.69776 .19165 m
.69974 .1926 L
s
.69974 .1926 m
.70463 .21145 L
s
.68179 .13674 m
.67524 .1182 L
s
.68179 .13674 m
.67933 .13979 L
s
.73449 .22291 m
.72966 .22404 L
s
.65427 .16015 m .66696 .16944 L .66297 .17073 L .656 .751 .92 r
F
0 g
.66297 .17073 m
.66342 .17514 L
s
.66001 .14607 m
.66781 .16304 L
s
.66297 .17073 m
.6716 .18122 L
s
0 0 0 r
2 Mabswid
.67563 .21703 Mdot
.001 .092 .901 r
.5 Mabswid
.67563 .21703 m
.67563 .21703 L
s
0 0 0 r
2 Mabswid
.67563 .21703 Mdot
0 g
.5 Mabswid
.66001 .14607 m
.65219 .12904 L
s
.66001 .14607 m
.65856 .15147 L
s
.66774 .1896 m
.66877 .19405 L
s
.66877 .19405 m
.66807 .2063 L
s
.001 .092 .901 r
.69846 .19023 m
.69846 .19023 L
s
0 g
.67524 .1182 m
.69527 .11163 L
s
.67524 .1182 m
.67152 .12272 L
s
.65427 .16015 m .65828 .15886 L .66696 .16944 L .656 .751 .92 r
F
0 g
.66696 .16944 m
.66742 .17386 L
s
.66696 .16944 m
.67558 .17995 L
s
.65457 .15277 m
.65822 .15887 L
s
.65856 .15147 m
.6671 .16575 L
s
.66696 .16944 m
.6671 .16575 L
s
.001 .092 .901 r
.70078 .19921 m
.70078 .19921 L
s
0 g
.6717 .18834 m
.67274 .19279 L
s
.67205 .20504 m
.67274 .19279 L
s
.70067 .2096 m
.70463 .21145 L
s
.70463 .21145 m
.70953 .23034 L
s
.001 .092 .901 r
.72784 .20551 m
.93792 .10344 L
s
0 0 0 r
2 Mabswid
.72784 .20551 Mdot
0 g
.5 Mabswid
.65517 .16901 m
.66342 .17514 L
s
.66342 .17514 m
.66444 .17998 L
s
.001 .092 .901 r
.70233 .20518 m
.70233 .20518 L
s
0 g
.66594 .1849 m
.66774 .1896 L
s
.66774 .1896 m
.66402 .198 L
s
.66444 .17998 m
.6572 .17872 L
s
.66444 .17998 m
.66594 .1849 L
s
.66594 .1849 m
.66022 .18862 L
s
.65918 .16771 m
.66742 .17386 L
s
.66742 .17386 m
.66843 .1787 L
s
.6863 .16322 m .7064 .15675 L .7149 .16735 L .656 .751 .92 r
F
0 g
.68642 .15952 m
.68711 .15681 L
s
.67933 .13979 m
.68711 .15681 L
s
.7149 .16735 m
.72334 .17787 L
s
.68642 .15952 m
.68824 .16259 L
s
.71413 .15173 m
.7149 .16735 L
s
.66994 .18362 m
.6717 .18834 L
s
.66804 .19672 m
.6717 .18834 L
s
.6482 .13035 m
.65219 .12904 L
s
.6482 .13035 m
.64598 .13842 L
s
.70359 .22763 m
.70953 .23034 L
s
.70953 .23034 m
.72966 .22404 L
s
.66843 .1787 m
.66121 .17743 L
s
.66843 .1787 m
.66994 .18362 L
s
.66994 .18362 m
.66423 .18733 L
s
.65219 .12904 m
.67152 .12272 L
s
.65219 .12904 m
.64998 .13711 L
s
.69557 .18947 m .71646 .19889 L .69629 .20527 L .544 .324 .532 r
F
0 g
.69979 .20417 m
.70067 .2096 L
s
.001 .092 .901 r
.70503 .20849 m
.72406 .20084 L
s
.69557 .18947 m .71568 .18307 L .71646 .19889 L .544 .324 .532 r
F
0 g
.69486 .17377 m
.69557 .18947 L
s
.6734 .19653 m
.69557 .18947 L
s
.001 .092 .901 r
.71589 .1873 m
.71928 .18673 L
s
.71633 .19619 m
.72149 .19519 L
s
.70233 .20518 m
.72243 .19881 L
s
0 g
.69333 .18622 m
.69557 .18947 L
s
.7149 .16735 m
.71568 .18307 L
s
.67006 .21358 m .67753 .22731 L .67351 .22857 L .544 .324 .532 r
F
0 g
.67634 .22768 m
.68005 .23501 L
s
.67006 .21358 m .67404 .21232 L .67753 .22731 L .544 .324 .532 r
F
.001 .092 .901 r
.06311 .40741 m
.67199 .22195 L
s
0 g
.66944 .19779 m
.67006 .21358 L
s
.001 .092 .901 r
.67563 .21703 m
.70118 .20788 L
s
0 g
.67404 .21232 m
.67579 .21746 L
s
.67579 .21746 m
.68403 .23376 L
s
.66807 .2063 m
.67006 .21358 L
s
.67006 .21358 m
.67351 .22857 L
s
.6734 .19653 m
.67404 .21232 L
s
.001 .092 .901 r
.70118 .20788 m
.72175 .20046 L
s
.70118 .20788 m
.70118 .20788 L
s
0 g
.67933 .13979 m
.67152 .12272 L
s
.67933 .13979 m
.67792 .14519 L
s
.001 .092 .901 r
.67596 .22056 m
.67697 .22019 L
s
.72406 .20084 m
.93835 .10405 L
s
0 0 0 r
2 Mabswid
.72406 .20084 Mdot
0 g
.5 Mabswid
.67351 .22857 m
.68005 .23501 L
s
.68005 .23501 m
.68403 .23376 L
s
.69161 .11614 m
.69527 .11163 L
s
.001 .092 .901 r
.71928 .18673 m
.96412 .16453 L
s
0 0 0 r
2 Mabswid
.71928 .18673 Mdot
0 g
.5 Mabswid
.67205 .20504 m
.67404 .21232 L
s
.67404 .21232 m
.67753 .22731 L
s
.001 .092 .901 r
.67697 .22019 m
.69945 .21193 L
s
0 0 0 r
2 Mabswid
.67697 .22019 Mdot
.001 .092 .901 r
.5 Mabswid
.67697 .22019 m
.67697 .22019 L
s
0 0 0 r
2 Mabswid
.67697 .22019 Mdot
.67767 .15258 m .7064 .15675 L .6863 .16322 L .656 .751 .92 r
F
0 g
.5 Mabswid
.6863 .16322 m
.68677 .16764 L
s
.67792 .14519 m
.68274 .15332 L
s
.6863 .16322 m
.69486 .17377 L
s
.66696 .16944 m
.6863 .16322 L
s
.67753 .22731 m
.68403 .23376 L
s
.68403 .23376 m
.70359 .22763 L
s
.69119 .18211 m
.69333 .18622 L
s
.69333 .18622 m
.69179 .19877 L
s
.001 .092 .901 r
.72149 .19519 m
.96383 .16347 L
s
0 0 0 r
2 Mabswid
.72149 .19519 Mdot
0 g
.5 Mabswid
.70067 .2096 m
.70359 .22763 L
s
.001 .092 .901 r
.72243 .19881 m
.95352 .12555 L
s
0 0 0 r
2 Mabswid
.72243 .19881 Mdot
0 g
.5 Mabswid
.6786 .16145 m
.68677 .16764 L
s
.68677 .16764 m
.68779 .17248 L
s
.6893 .17742 m
.69119 .18211 L
s
.69119 .18211 m
.68749 .19052 L
s
.72966 .22404 m
.72378 .22129 L
s
.68779 .17248 m
.68065 .17119 L
s
.68779 .17248 m
.6893 .17742 L
s
.64551 .14949 m .65828 .15886 L .65427 .16015 L .656 .751 .92 r
F
0 g
.65427 .16015 m
.65517 .16901 L
s
.65444 .15604 m
.65457 .15277 L
s
.65427 .16015 m
.66297 .17073 L
s
.6893 .17742 m
.68369 .18111 L
s
.001 .092 .901 r
.72175 .20046 m
.95838 .10966 L
s
0 0 0 r
2 Mabswid
.72175 .20046 Mdot
0 g
.5 Mabswid
.67152 .12272 m
.69161 .11614 L
s
.67152 .12272 m
.66937 .13078 L
s
.66402 .198 m
.66807 .2063 L
s
.66807 .2063 m
.66669 .21887 L
s
.64551 .14949 m .64952 .14819 L .65828 .15886 L .656 .751 .92 r
F
0 g
.65828 .15886 m
.65918 .16771 L
s
.64952 .14819 m
.65828 .15886 L
s
.65828 .15886 m
.66696 .16944 L
s
.64598 .13842 m
.65457 .15277 L
s
.64998 .13711 m
.65856 .15147 L
s
.65828 .15886 m
.65856 .15147 L
s
.64551 .14949 m
.65427 .16015 L
s
.001 .092 .901 r
.69945 .21193 m
.69945 .21193 L
s
0 g
.66804 .19672 m
.67205 .20504 L
s
.67072 .21759 m
.67205 .20504 L
s
.64598 .13842 m
.64998 .13711 L
s
.64551 .14949 m
.64598 .13842 L
s
.67767 .15258 m .69783 .14606 L .7064 .15675 L .656 .751 .92 r
F
0 g
.7064 .15675 m
.7149 .16735 L
s
.70359 .22763 m
.72378 .22129 L
s
.65517 .16901 m
.64684 .16281 L
s
.65517 .16901 m
.6572 .17872 L
s
.64998 .13711 m
.66937 .13078 L
s
.64952 .14819 m
.64998 .13711 L
s
.69629 .20527 m .71725 .21481 L .69701 .22118 L .544 .324 .532 r
F
0 g
.69701 .22118 m
.70359 .22763 L
s
.69629 .20527 m .71646 .19889 L .71725 .21481 L .544 .324 .532 r
F
0 g
.69557 .18947 m
.69629 .20527 L
s
.67404 .21232 m
.69629 .20527 L
s
.001 .092 .901 r
.71679 .20551 m
.72016 .20426 L
s
0 g
.69179 .19877 m
.69629 .20527 L
s
.69629 .20527 m
.69701 .22118 L
s
.71568 .18307 m
.71646 .19889 L
s
.66022 .18862 m
.66402 .198 L
s
.66402 .198 m
.66018 .20651 L
s
.65918 .16771 m
.65086 .16151 L
s
.65918 .16771 m
.66121 .17743 L
s
.66669 .21887 m
.67351 .22857 L
s
.67351 .22857 m
.67753 .22731 L
s
.66423 .18733 m
.66804 .19672 L
s
.66804 .19672 m
.66421 .20523 L
s
.6572 .17872 m
.64989 .17745 L
s
.6572 .17872 m
.66022 .18862 L
s
.66022 .18862 m
.65444 .19237 L
s
.001 .092 .901 r
.72016 .20426 m
.95852 .10921 L
s
0 0 0 r
2 Mabswid
.72016 .20426 Mdot
0 g
.5 Mabswid
.67072 .21759 m
.67753 .22731 L
s
.67753 .22731 m
.69701 .22118 L
s
.68953 .1242 m
.69161 .11614 L
s
.66121 .17743 m
.65392 .17616 L
s
.66121 .17743 m
.66423 .18733 L
s
.66897 .14186 m .69783 .14606 L .67767 .15258 L .656 .751 .92 r
F
0 g
.67767 .15258 m
.6786 .16145 L
s
.67767 .15258 m
.6863 .16322 L
s
.65828 .15886 m
.67767 .15258 L
s
.66937 .13078 m
.6766 .14297 L
s
.66423 .18733 m
.65847 .19108 L
s
.68749 .19052 m
.69179 .19877 L
s
.69179 .19877 m
.69023 .21143 L
s
.71725 .21481 m
.72378 .22129 L
s
.66937 .13078 m
.68953 .1242 L
s
.71646 .19889 m
.71725 .21481 L
s
.64551 .14949 m
.64952 .14819 L
s
.64551 .14949 m
.64684 .16281 L
s
.67036 .1552 m
.6786 .16145 L
s
.6786 .16145 m
.68065 .17119 L
s
.64952 .14819 m
.65086 .16151 L
s
.68369 .18111 m
.68749 .19052 L
s
.68749 .19052 m
.68375 .19902 L
s
.66018 .20651 m
.66669 .21887 L
s
.66669 .21887 m
.67072 .21759 L
s
.69023 .21143 m
.69701 .22118 L
s
.69701 .22118 m
.71725 .21481 L
s
.68065 .17119 m
.67344 .16988 L
s
.68065 .17119 m
.68369 .18111 L
s
.68369 .18111 m
.67801 .18484 L
s
.66421 .20523 m
.67072 .21759 L
s
.67072 .21759 m
.69023 .21143 L
s
.66897 .14186 m .68919 .13529 L .69783 .14606 L .656 .751 .92 r
F
0 g
.68919 .13529 m
.69783 .14606 L
s
.64952 .14819 m
.66897 .14186 L
s
.66897 .14186 m
.66937 .13078 L
s
.69783 .14606 m
.7064 .15675 L
s
.66897 .14186 m
.67767 .15258 L
s
.64684 .16281 m
.65086 .16151 L
s
.64684 .16281 m
.64989 .17745 L
s
.68919 .13529 m
.68953 .1242 L
s
.65444 .19237 m
.66018 .20651 L
s
.66018 .20651 m
.66421 .20523 L
s
.65086 .16151 m
.67036 .1552 L
s
.65086 .16151 m
.65392 .17616 L
s
.66897 .14186 m
.68919 .13529 L
s
.66897 .14186 m
.67036 .1552 L
s
.65847 .19108 m
.66421 .20523 L
s
.66421 .20523 m
.68375 .19902 L
s
.71052 .20502 m
.71725 .21481 L
s
.64989 .17745 m
.65392 .17616 L
s
.64989 .17745 m
.65444 .19237 L
s
.65444 .19237 m
.65847 .19108 L
s
.68375 .19902 m
.69023 .21143 L
s
.69023 .21143 m
.71052 .20502 L
s
.65392 .17616 m
.67344 .16988 L
s
.65392 .17616 m
.65847 .19108 L
s
.65847 .19108 m
.67801 .18484 L
s
.67036 .1552 m
.69062 .14865 L
s
.67036 .1552 m
.67344 .16988 L
s
.68919 .13529 m
.69062 .14865 L
s
.67801 .18484 m
.68375 .19902 L
s
.68375 .19902 m
.70405 .19257 L
s
.71052 .20502 m
.70405 .19257 L
s
.67344 .16988 m
.69374 .16335 L
s
.67344 .16988 m
.67801 .18484 L
s
.67801 .18484 m
.69832 .17834 L
s
.69374 .16335 m
.69062 .14865 L
s
.70405 .19257 m
.69832 .17834 L
s
.69832 .17834 m
.69374 .16335 L
s
0 0 0 r
2 Mabswid
.95852 .10921 Mdot
.95838 .10966 Mdot
.95352 .12555 Mdot
.96383 .16347 Mdot
.96412 .16453 Mdot
.93835 .10405 Mdot
.93792 .10344 Mdot
0 g
.25 Mabswid
.00938 .30858 m
.94064 0 L
s
.02922 .302 m
.02863 .30851 L
s
gsave
.0304 .28899 -65.0919 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.26339 .22441 m
.26311 .23094 L
s
gsave
.26397 .21136 -68.887 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51218 .14197 m
.51222 .14851 L
s
gsave
.51208 .12891 -69.3101 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77697 .05423 m
.77739 .06075 L
s
gsave
.77614 .04119 -69.7766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07495 .28685 m
.07463 .29076 L
s
.12122 .27152 m
.12094 .27543 L
s
.16805 .256 m
.1678 .25992 L
s
.21543 .2403 m
.21522 .24422 L
s
.31194 .20832 m
.31181 .21224 L
s
.36108 .19204 m
.36098 .19596 L
s
.41082 .17556 m
.41077 .17948 L
s
.46119 .15887 m
.46117 .16279 L
s
.56381 .12487 m
.56388 .12879 L
s
.61609 .10754 m
.6162 .11146 L
s
.66903 .09 m
.66919 .09392 L
s
.72266 .07223 m
.72286 .07614 L
s
.83199 .036 m
.83229 .03991 L
s
.88773 .01753 m
.88807 .02144 L
s
.25 Mabswid
.98878 .07115 m
1 .17453 L
s
.98904 .07356 m
.98282 .07555 L
s
gsave
1.00148 .06956 -61 -11.2246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99157 .09688 m
.98534 .09886 L
s
gsave
1.00402 .09292 -61 -11.2094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99413 .12044 m
.9879 .1224 L
s
gsave
1.00659 .11651 -61 -11.1941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99671 .14423 m
.99048 .14618 L
s
gsave
1.00918 .14033 -61 -11.1786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99932 .16826 m
.99308 .1702 L
s
gsave
1.0118 .1644 -61 -11.163 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98954 .0782 m
.98581 .0794 L
s
.99005 .08286 m
.98631 .08405 L
s
.99055 .08752 m
.98682 .08872 L
s
.99106 .0922 m
.98733 .09339 L
s
.99208 .10157 m
.98834 .10276 L
s
.99259 .10628 m
.98885 .10746 L
s
.9931 .11099 m
.98936 .11217 L
s
.99361 .11571 m
.98988 .11689 L
s
.99464 .12518 m
.9909 .12636 L
s
.99516 .12993 m
.99142 .1311 L
s
.99567 .13469 m
.99193 .13586 L
s
.99619 .13945 m
.99245 .14063 L
s
.99723 .14902 m
.99349 .15019 L
s
.99775 .15381 m
.99401 .15498 L
s
.99827 .15862 m
.99453 .15978 L
s
.9988 .16344 m
.99505 .1646 L
s
.99984 .1731 m
.9961 .17426 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{299.688, 138.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000RPP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md;7@00?md;7@00?md;7@00?md;7@00?md
;7@00?md;7@00?md;7@00?md2g@24@=d00<AM7@00Q42M0@A4G@00?md2W@0115dM144M0044GAd4@9d
00<AM7@04G@00?md17@44@9d00@AM7@A17@0115dM143M0034GAd011d003lM08A2g@0115dM144M004
4GAd4@=d00<AM7@047@00?Ud1Q4:M0044GAd4@Ad00@AM7@A17@00a5dM00?M000mW@34@Ad0Q4:M003
4GAd00<A0W@24@04M14A4@9d114>M000lg@34@Md00<AM1402W@34@9d00<AM7@00a42M08A0W@00a5d
M00=M000l7@34@]d00<AM1401G@44@9d00@AM7@A17@0115dM143M0034GAd00ed003;M08A0g@00a5d
4@024AQd0a4?M08A2g@0115dM144M0044GAd4@=d00<AM7@03G@00<Yd00@AM7@A1g@00a5dM00BM0<A
0W@00a5dM00<M0044GAd4@Yd00@AM7@A17@0115dM143M0034GAd00ed003:M0044GAd4@Md00<AM7@0
3g@34AId0a47M0<A0W@00a5dM002M0044GAd4@9d0Q4?M000bW@0115dM145M08A3g@34AYd0Q46M003
4GAd00<A1W@24@Ad00<AM7@03G@00<Yd00@AM7@A1g@00a5dM009M0<A7W@24@Ed00@AM7@A7W@00<Yd
00@AM7@A17@0115dM148M0<A8G@34@Ad00@AM7@A7W@00<]d0Q46M08A1W@34@9d00<AM7@087@34@=d
00<AM7@00a43M0034GAd008A0g@34@id003HM0<A:7@34@=d00@AM7@A0W@00a5dM002M0044GAd4@=d
00<AM7@03G@00=Ed0a4/M0<A0g@34@9d00<AM7@00W@0115dM143M0034GAd00ed003BM0<A<7@34@Ad
00@AM7@A17@0115dM143M0034GAd00ed003?M0<A<g@00a5d4@04M0044GAd4@Ad00@AM7@A0g@00a5d
M00=M000c7@34@9d00<AM7@0<W@34@=d00<AM7@00a42M08A00=d4A401a4;M000bG@34C]d0a43M0<A
0W@00a5dM0044@03M14A008A00=d4A400W@44@Ad0036M0<A?g@24@Ed00@AM7@A0g@24@03M14A00=d
00@AM7@A0W@00a5dM004M000`g@34D9d0a44M0DA0W@24@03M14A00=d00@AM7@A0g@00a5dM003M000
`7@34DEd0a44M0044GAd4@=d0Q400g@A4@03M08A00=d4G@00W@00a5dM003M000_7@44@9d00<AM7@0
AG@00a5dM002M0044GAd4@=d0Q401W@A4G@AM08A00=d4G@00g@00a5dM002M000^G@34Ded0Q45M08A
17@0115d4A43M08A0W@00a5d4@02M0034GAd009d002fM0<AD7@24@ad0a43M0034G@A008A0W@44@=d
002cM0<ADg@34@]d00@AM7@A17@0115dM143M0034GAd009d002`M0<A00=d4G@0Dg@34@Ed1142M004
4GAd4@Ad00@AM7@A0g@00a5dM002M000[G@34EYd0Q4;M0044GAd4@Ad00@AM7@A0g@00a5dM002M000
ZW@34Did0Q4<M0034G@A00]d00@AM7@A17@0115dM143M0034GAd009d002WM0<ADG@00a@A4@0<M08A
2g@0115dM144M0044GAd4@9d0Q44M000Q7@24@=d00<AM1400a4EM0<ADW@01A@HM7@A00=d0Q47M08A
37@24@Id0Q44M0034GAd009d0023M0044GAd4@Ed00<AM7@04W@34@03M15d01=d0a4jM00351=d00Id
00<C51401g@24@Ed0Q4HM000Pg@0115dM146M0034GAd00id0a4FM0@A0W@24CId00<D67@01W@00aPD
600:M0034GAd009d00@AM7@A5g@008=d00@AM7@A1W@00a5dM00;M0<A5W@54@06M14A4G@A<g@00a<D
4`06M00451<D4`]d0Q44M0044GAd4AMd0023M0044GAd4@Md00<AM7@01g@34AId2A43M0<A<7@00aPD
6005M00461@H50Ad0Q47M0<A17@0115dM14GM000Pg@0115dM144M0044GAd4@Id0a4GM0hA00@o?Q4A
;G@00a<D4`05M0034a@C00Id00<D4a4027@34@=d00@AM7@A5g@008Ad0Q46M08A17@34@9d00<AM7@0
57@=4@04?ULnE`<A:W@00aPD6004M00451PD60Ed00<H51P02g@34@=d00@AM7@A5g@008md0a4LM0dA
00Do?Sln?`024BQd00<C51<00g@011<D4a@5M00351<D00md0Q44M0<A0g@00a5dM0024@=d0a49M000
S7@34Aid3Q4023iG?ULn4G@A97@011@H51P3M00461@H50Ad00<H51P04G@00a5d4@04M0044GAd4@Ad
00@AM7@A0g@00a5dM008M000RG@34B5d2Q4035a74A4o4Cln?a5d4B9d00<D4a@00g@011@C51<4M003
51<D01Ed0Q44M0044GAd4@Ad00@AM7@A0g@00a5dM008M000QW@44B=d2Q42G0074E`AEciG?P044Amd
00<D61@00g@00a@H5003M00451PD61Md0a44M0044GAd4@Ad00@AM7@A0g@00a5dM008M000Pg@34@=d
00<AM7@08G@94@0;Ae`A4DML4Cln?a400W@00a5dM00KM00351<D009d00@C51<D0W@00a<D4`0MM003
4GAd009d00@AM7@A17@0115dM143M0034GAd00Qd0020M0<A:W@;4@03G15L009L00@AEchA0g@00a5d
M00GM00961@H57@D61@H009d00<D61@07g@24@Ad00@AM7@A17@0115dM142M08A2W@007ed0a4]M0/A
00U74DMLAe`A?a400W@24AMd00dC51<DM1@C51=d4a@C029d0Q45M0<A0g@00a5d4@024@9d1148M000
NW@34C5d2Q42G0034EaL009L11400g@AM00DM00<61@H51PD61Ad51PD9G@34@Ad00@AM7@A17@0115d
M142M0034GAd00Qd001gM0<A0W@00a5dM00_M0dA00ALAea70Q43M0034GAd015d00/C51<D4a@CM1<D
4`0KM0044a@C50<A1W@34@Ad00@AM7@A17@0115dM143M0034GAd00Md001dM0<A=g@=4@EL00<AM7@0
0W@00a5dM00=M00;51PD61@H51PD61@04g@03A@H51PD61@H51PD61@00g@24@Md0Q44M0044GAd4@Ad
00@AM7@A0g@00a5dM007M000LG@34CYd3A401Ea7G3ho008A0W@24@ed00XD4a@C51<D4a@C2g@04A<D
4a@C51<D4a@C51<D4a@C019d00<AM14017@0115dM144M0044GAd4@Ad00<AM7@01W@006id0a4mM003
4G@A00/A00AG?ULn11400g@AM00:M00951PD61@H51PD00=d00/D61@H51PD61@H5002M00761@H51PD
600KM08A17@0115dM144M0064GAd4G@A0W@00a5dM006M000Jg@44Cmd3Q401cho?SlAG1400W@00a5d
M007M00>51<D4a@C51<D4a@C51<6M00751<D4a@C500YM08A1W@24@=d0Q49M000J7@34D=d00<AM140
2a401ELnEchA009L014AM7@A51PD61@H51PD61@H5008M00761@H51PD6018M000IG@34DMd3Q400cln
?`034@0451<D4`=d00HC51<D4a@5M00751<D4a@C501?M000@W@24@=d00<AM7@00a4EM0<ABW@00a5d
4@054@03G14A00<A01PnEchAG15L4G@AM1PD61@H51PD61@H51QFM000@G@0115dM146M0034GAd015d
0a5>M0hA00<n?a400Q402Ua74A<D4a@C51=NM000@G@0115dM146M0034GAd00id0a42M0034GAd04ad
314015Ln4Ch34@0651PD61@HHW@0045d00@AM7@A1W@00a5dM00;M0<AE7@00a4D4@094@04?SlA?`<A
00DD4a@C4@1SM000@G@0115dM146M0034GAd00Qd0a5DM00451PDM0HA00<D4A400Q400eLn4@064@9d
00<AM7@0HG@0045d00@AM7@A1G@24@Md0a5DM0034a@C00=d00<C4A401a402a<A4A4n?a4D4G@A009d
00<AM7@0HG@0049d0Q47M0034GAd009d115DM00361Ad009d00<D61@00W@54@03514A008A00AG?ULn
0Q42M0@AHg@004ed0a5EM00351<D009d00<C51<01G@64@084a@A4Cho?Sl44@=d00<AM7@0HG@004Yd
0a5EM00361@H009d00<D61@01W@00aPD60044@03514A008A00=G4A400a43M08AI7@004Md0a5EM003
51<D009d00<C51<01W@01a@C51<D4a@04Q5UM000A7@34EEd00<H51P00W@00a@H5005M00;51PD61@H
51PD61@0415WM000@7@44@9d00<AM7@0D7@00a@C5002M0034a@C00Ed00dC51<D4a@C51<D4a@C009d
3A5YM000?G@34EId00<H51P00W@00a@H5005M00=51PD61@H51PDM1@H5006M0PAKG@003Yd0a5FM003
51<D009d00<C51<01G@03A<D4a@C51<D4a@C51<02g@34G1d000gM0<AEg@01a@HM7@D61@01G@031@H
51PD61@H51PD689d000dM0<A0W@00a5dM01BM0074a@CM1<D4`05M00<4a@C51<D4aAd51<DQG@0035d
0a5GM00751PDM1@H5005M00<51PD61@H51PD61@HR7@002id0a5GM0074a@CM1<D4`04M00<51<D4a@C
51<D4a@CS7@002]d0a5GM00751PDM1@H5004M00<61@H51PD61@H51PDSg@002Qd0a42M0034GAd059d
00LC51=d4a@C00Ad00`D4a@C51<D4a@C51>BM0009G@34EMd00LD61Ad51PD00Ad00/H51PD61@H51PD
602FM0001g@24AUd0a5GM0074a@CM1<D4`04M00;51<D4a@C51<D4a@0VG@000Id00@AM7@A5G@34EQd
00HH57@D61@4M00:61@H51PD61@H59ed0006M0044GAd4A9d0a400g@AM01EM00651<D4a@C0g@02a<D
4a@C51<D4a@C0:1d0006M0044GAd4@md0a5HM00661@H51PD0g@02a@H51PD61@H51PD0:=d0006M004
4GAd4@ad0a5HM00651<D4a@C0g@02Q<D4a@C51<D4aBWM0001W@0115dM149M0<AF7@01QPD61@H50=d
00XD61@H51PD61@HZW@000Md0Q47M0<A00=d4G@0EG@01Q@C51<D4`=d00XC51<D4a@C51<D[G@000ed
0a5HM00661@H51PD0g@02A@H51PD61@H502aM0002W@34EQd00HD4a@C51<3M0094a@C51<D4a@C0;Ad
0007M0<AF7@01QPD61@H509d00XH51PD61@H51PD]g@000Ad115HM0054a@C51<00W@02A@C51<D4a@C
502kM0000W@24@=d00<AM7@0Dg@01A@H51PD009d00TH51PD61@H51P0_W@005Yd010C51<D4aAd51<D
4a@C51<D`G@005Md00lD61@H51Qd61@H51PD61@0aG@005Ad00lC51<D4aAd51<D4a@C51<0b7@0055d
00hD61@H51PD61@H51PD6<ad001>M00>4a@C51<D4a@C51<D4aC?M000Bg@03Q@H51PD61@H51PD61@H
dW@004Ud00`D4a@C51<D4a@C51?FM000AW@031PD61@H51PD61@H5=Ud0013M00<51<D4a@C51<D4a@C
g7@0041d00/H51PD61@H51PD603PM000?G@02a@C51<D4a@C51<D0>=d000jM00;61@H51PD61@H51P0
iW@003Md00XD4a@C51<D4a@CjW@003Ad00XH51PD61@H51PDkG@0039d00PC51<D4a@C5?5d000_M008
51PD61@H51SdM000;7@021<D4a@C51<Dmg@002Ud00LD61@H51PD0?]d000VM0074a@C51<D4`3nM000
8g@01a@H51PD61@0og@2M00087@01Q<D4a@C5?md1W@001ed00HD61@H51SoM0Ud000KM00551<D4a@0
og@<M00067@011PD61CoM11d000EM00451<D4omd4g@0019d00@H51PDog@FM00047@00a<DM03oM1Ud
003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad
003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad0000\
\>"],
  ImageRangeCache->{{{0, 298.688}, {137.875, 0}} -> {0.0432957, 0.227963, 
  0.00355432, 0.00355432}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[PressureLensSurfacesTraced, Axes->True];", "Input",
  CellLabel->"In[79]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .46357 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0452609 1.04526 -0.277318 1.04526 [
[.03041 .28899 -4.09187 -10.9375 ]
[.03041 .28899 4.90813 0 ]
[.26397 .21136 -7.88704 -10.9375 ]
[.26397 .21136 8.61296 0 ]
[.51208 .12891 -8.31006 -10.9375 ]
[.51208 .12891 8.18994 0 ]
[.77613 .04119 -8.77663 -10.9375 ]
[.77613 .04119 7.72337 0 ]
[.95421 -0.00237 0 -7.27954 ]
[.95421 -0.00237 28.4375 3.65796 ]
[.96588 .0149 0 -7.26622 ]
[.96588 .0149 28.4375 3.67128 ]
[.97742 .03197 0 -7.2531 ]
[.97742 .03197 9 3.6844 ]
[.98882 .04883 0 -7.24017 ]
[.98882 .04883 21.5 3.69733 ]
[1.00008 .06549 0 -7.22742 ]
[1.00008 .06549 21.5 3.71008 ]
[1.00146 .06957 0 -7.22459 ]
[1.00146 .06957 28.4375 3.71291 ]
[1.00401 .09292 0 -7.20942 ]
[1.00401 .09292 28.4375 3.72808 ]
[1.00657 .11651 0 -7.19412 ]
[1.00657 .11651 9 3.74338 ]
[1.00917 .14033 0 -7.17867 ]
[1.00917 .14033 21.5 3.75883 ]
[1.01179 .16439 0 -7.16308 ]
[1.01179 .16439 21.5 3.77442 ]
[ 0 0 0 0 ]
[ 1 .46357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00939 .30858 m
.94063 0 L
s
.02923 .302 m
.02864 .30851 L
s
gsave
.03041 .28899 -65.0919 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.2634 .22441 m
.26311 .23093 L
s
gsave
.26397 .21136 -68.887 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51217 .14197 m
.51222 .14851 L
s
gsave
.51208 .12891 -69.3101 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77696 .05423 m
.77738 .06075 L
s
gsave
.77613 .04119 -69.7766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07496 .28685 m
.07464 .29076 L
s
.12123 .27152 m
.12095 .27543 L
s
.16805 .256 m
.16781 .25991 L
s
.21544 .2403 m
.21523 .24421 L
s
.31194 .20832 m
.31181 .21224 L
s
.36108 .19204 m
.36099 .19596 L
s
.41083 .17556 m
.41077 .17948 L
s
.46119 .15887 m
.46117 .16279 L
s
.5638 .12487 m
.56387 .12879 L
s
.61608 .10754 m
.6162 .11146 L
s
.66903 .09 m
.66919 .09392 L
s
.72265 .07223 m
.72285 .07614 L
s
.83198 .036 m
.83228 .03991 L
s
.88771 .01753 m
.88806 .02144 L
s
.25 Mabswid
.94063 0 m
.98876 .07115 L
s
.9418 .00174 m
.9356 .00379 L
s
gsave
.95421 -0.00237 -61 -11.2795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.95347 .01898 m
.94726 .02102 L
s
gsave
.96588 .0149 -61 -11.2662 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.965 .03602 m
.95879 .03805 L
s
gsave
.97742 .03197 -61 -11.2531 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97639 .05286 m
.97017 .05487 L
s
gsave
.98882 .04883 -61 -11.2402 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98764 .06949 m
.98142 .07149 L
s
gsave
1.00008 .06549 -61 -11.2274 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.94415 .0052 m
.94043 .00643 L
s
.94649 .00866 m
.94277 .00989 L
s
.94882 .01211 m
.9451 .01334 L
s
.95115 .01555 m
.94743 .01677 L
s
.95579 .02241 m
.95206 .02363 L
s
.9581 .02582 m
.95437 .02704 L
s
.9604 .02923 m
.95668 .03045 L
s
.9627 .03263 m
.95898 .03385 L
s
.96729 .0394 m
.96356 .04062 L
s
.96957 .04278 m
.96584 .04399 L
s
.97185 .04615 m
.96812 .04736 L
s
.97412 .04951 m
.97039 .05071 L
s
.97865 .0562 m
.97492 .05741 L
s
.98091 .05953 m
.97718 .06074 L
s
.98316 .06286 m
.97943 .06407 L
s
.9854 .06618 m
.98167 .06738 L
s
.25 Mabswid
.98876 .07115 m
1 .17466 L
s
.98902 .07356 m
.9828 .07556 L
s
gsave
1.00146 .06957 -61 -11.2246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99156 .09688 m
.98533 .09886 L
s
gsave
1.00401 .09292 -61 -11.2094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99411 .12044 m
.98788 .1224 L
s
gsave
1.00657 .11651 -61 -11.1941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9967 .14423 m
.99046 .14618 L
s
gsave
1.00917 .14033 -61 -11.1787 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99931 .16826 m
.99307 .17019 L
s
gsave
1.01179 .16439 -61 -11.1631 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98953 .07821 m
.9858 .0794 L
s
.99003 .08286 m
.9863 .08406 L
s
.99054 .08753 m
.98681 .08872 L
s
.99105 .0922 m
.98731 .09339 L
s
.99207 .10158 m
.98833 .10276 L
s
.99258 .10628 m
.98884 .10746 L
s
.99309 .11099 m
.98935 .11217 L
s
.9936 .11571 m
.98986 .11689 L
s
.99463 .12518 m
.99089 .12636 L
s
.99514 .12993 m
.9914 .1311 L
s
.99566 .13469 m
.99192 .13586 L
s
.99618 .13945 m
.99244 .14063 L
s
.99722 .14902 m
.99347 .15019 L
s
.99774 .15381 m
.99399 .15498 L
s
.99826 .15862 m
.99452 .15978 L
s
.99878 .16344 m
.99504 .1646 L
s
.99983 .1731 m
.99609 .17425 L
s
0 0 m
1 0 L
1 .46357 L
0 .46357 L
closepath
clip
newpath
.001 .092 .901 r
.5 Mabswid
.06312 .40741 m
.67213 .21474 L
s
.06312 .40741 m
.672 .19488 L
s
.06312 .40741 m
.67307 .22162 L
s
.06312 .40741 m
.68512 .22337 L
s
.06312 .40741 m
.67115 .20515 L
s
.06312 .40741 m
.67168 .21844 L
s
.06312 .40741 m
.67769 .21933 L
s
0 g
.68824 .17041 m
.69267 .18488 L
s
.68275 .17398 m
.68824 .17041 L
s
.68269 .15665 m
.68824 .17041 L
s
.69267 .18488 m
.69568 .19913 L
s
.68571 .18367 m
.69267 .18488 L
s
.69021 .16978 m
.69463 .18426 L
s
.68472 .17334 m
.69021 .16978 L
s
.68466 .15601 m
.69021 .16978 L
s
.69463 .18426 m
.69765 .19851 L
s
.68769 .18304 m
.69463 .18426 L
s
.67903 .16476 m
.68269 .15665 L
s
.67639 .1445 m
.68269 .15665 L
s
.681 .16413 m
.68466 .15601 L
s
.67835 .14387 m
.68466 .15601 L
s
.69568 .19913 m
.69709 .21222 L
s
.68773 .19322 m
.69568 .19913 L
s
.69765 .19851 m
.69906 .2116 L
s
.6897 .19259 m
.69765 .19851 L
s
.70923 .16367 m
.71367 .17818 L
s
.70383 .16721 m
.70923 .16367 L
s
.70369 .14987 m
.70923 .16367 L
s
.71367 .17818 m
.71672 .19246 L
s
.7068 .17694 m
.71367 .17818 L
s
.6748 .15664 m
.67639 .1445 L
s
.66972 .13478 m
.67639 .1445 L
s
.67678 .156 m
.67835 .14387 L
s
.67169 .13414 m
.67835 .14387 L
s
.70011 .15797 m
.70369 .14987 L
s
.6974 .13768 m
.70369 .14987 L
s
.69709 .21222 m
.68865 .20197 L
s
.69709 .21222 m
.69677 .22328 L
s
.69709 .21222 m
.69709 .21222 L
s
.69906 .2116 m
.69063 .20134 L
s
.69906 .2116 m
.69875 .22266 L
s
.69906 .2116 m
.69906 .2116 L
s
.71672 .19246 m
.71817 .20557 L
s
.70884 .1865 m
.71672 .19246 L
s
.729 .15732 m
.73345 .17187 L
s
.72368 .16084 m
.729 .15732 L
s
.72346 .14348 m
.729 .15732 L
s
.68571 .18367 m
.68275 .17398 L
s
.68275 .17398 m
.67903 .16476 L
s
.6772 .17758 m
.68275 .17398 L
s
.73345 .17187 m
.73653 .18617 L
s
.72667 .17059 m
.73345 .17187 L
s
.68773 .19322 m
.68571 .18367 L
s
.67869 .18245 m
.68571 .18367 L
s
.6959 .14982 m
.6974 .13768 L
s
.69078 .12792 m
.6974 .13768 L
s
.68769 .18304 m
.68472 .17334 L
s
.68472 .17334 m
.681 .16413 L
s
.67918 .17695 m
.68472 .17334 L
s
.6897 .19259 m
.68769 .18304 L
s
.68067 .18182 m
.68769 .18304 L
s
.67034 .15016 m
.66972 .13478 L
s
.66315 .12815 m
.66972 .13478 L
s
.66972 .13478 m
.66972 .13478 L
s
.67903 .16476 m
.6748 .15664 L
s
.67533 .17295 m
.67903 .16476 L
s
.67232 .14952 m
.67169 .13414 L
s
.66512 .12751 m
.67169 .13414 L
s
.67169 .13414 m
.67169 .13414 L
s
.71997 .15158 m
.72346 .14348 L
s
.71719 .13126 m
.72346 .14348 L
s
.681 .16413 m
.67678 .156 L
s
.67731 .17232 m
.681 .16413 L
s
.68865 .20197 m
.68773 .19322 L
s
.6797 .18725 m
.68773 .19322 L
s
.71817 .20557 m
.7098 .19526 L
s
.71817 .20557 m
.71791 .21664 L
s
.71817 .20557 m
.71817 .20557 L
s
.69063 .20134 m
.6897 .19259 L
s
.68168 .18661 m
.6897 .19259 L
s
.73653 .18617 m
.73802 .1993 L
s
.72872 .18017 m
.73653 .18617 L
s
.69677 .22328 m
.69475 .23156 L
s
.68843 .20934 m
.69677 .22328 L
s
.69875 .22266 m
.69674 .23094 L
s
.69041 .20872 m
.69875 .22266 L
s
.6748 .15664 m
.67034 .15016 L
s
.67321 .16888 m
.6748 .15664 L
s
.67678 .156 m
.67232 .14952 L
s
.67519 .16824 m
.67678 .156 L
s
.68843 .20934 m
.68865 .20197 L
s
.68865 .20197 m
.68016 .19164 L
s
.68865 .20197 m
.68865 .20197 L
s
.70383 .16721 m
.70011 .15797 L
s
.70383 .16721 m
.69837 .17079 L
s
.7068 .17694 m
.70383 .16721 L
s
.69041 .20872 m
.69063 .20134 L
s
.69063 .20134 m
.68214 .191 L
s
.69063 .20134 m
.69063 .20134 L
s
.71577 .1434 m
.71719 .13126 L
s
.71061 .12146 m
.71719 .13126 L
s
.70884 .1865 m
.7068 .17694 L
s
.69986 .17568 m
.7068 .17694 L
s
.69147 .14332 m
.69078 .12792 L
s
.68426 .12125 m
.69078 .12792 L
s
.69078 .12792 m
.69078 .12792 L
s
.70011 .15797 m
.6959 .14982 L
s
.6965 .16615 m
.70011 .15797 L
s
.73802 .1993 m
.72971 .18894 L
s
.73802 .1993 m
.73783 .21037 L
s
.73802 .1993 m
.73802 .1993 L
s
.7098 .19526 m
.70884 .1865 L
s
.70088 .18048 m
.70884 .1865 L
s
.67034 .15016 m
.66595 .14577 L
s
.67097 .16564 m
.67034 .15016 L
s
.67034 .15016 m
.67034 .15016 L
s
.66595 .14577 m
.66315 .12815 L
s
.6571 .12508 m
.66315 .12815 L
s
.67232 .14952 m
.66793 .14512 L
s
.67295 .165 m
.67232 .14952 L
s
.67232 .14952 m
.67232 .14952 L
s
.71791 .21664 m
.71596 .22491 L
s
.70961 .20264 m
.71791 .21664 L
s
.66793 .14512 m
.66512 .12751 L
s
.65908 .12443 m
.66512 .12751 L
s
.68562 .2153 m
.68843 .20934 L
s
.67946 .19551 m
.68843 .20934 L
s
.6959 .14982 m
.69147 .14332 L
s
.69438 .16207 m
.6959 .14982 L
s
.68758 .21468 m
.69041 .20872 L
s
.68141 .19489 m
.69041 .20872 L
s
.70961 .20264 m
.7098 .19526 L
s
.7098 .19526 m
.70136 .18488 L
s
.7098 .19526 m
.7098 .19526 L
s
.69475 .23156 m
.69114 .23648 L
s
.68562 .2153 m
.69475 .23156 L
s
.72368 .16084 m
.71997 .15158 L
s
.72368 .16084 m
.71831 .1644 L
s
.72667 .17059 m
.72368 .16084 L
s
.72872 .18017 m
.72667 .17059 L
s
.71981 .1693 m
.72667 .17059 L
s
.67869 .18245 m
.6772 .17758 L
s
.6772 .17758 m
.67533 .17295 L
s
.6716 .18122 m
.6772 .17758 L
s
.69674 .23094 m
.69313 .23586 L
s
.68758 .21468 m
.69674 .23094 L
s
.6797 .18725 m
.67869 .18245 L
s
.6716 .18122 m
.67869 .18245 L
s
.71136 .13687 m
.71061 .12146 L
s
.70414 .11475 m
.71061 .12146 L
s
.71061 .12146 m
.71061 .12146 L
s
.68067 .18182 m
.67918 .17695 L
s
.67918 .17695 m
.67731 .17232 L
s
.67358 .18059 m
.67918 .17695 L
s
.68168 .18661 m
.68067 .18182 L
s
.67358 .18059 m
.68067 .18182 L
s
.67533 .17295 m
.67321 .16888 L
s
.6716 .18122 m
.67533 .17295 L
s
.71997 .15158 m
.71577 .1434 L
s
.71645 .15975 m
.71997 .15158 L
s
.68016 .19164 m
.6797 .18725 L
s
.6716 .18122 m
.6797 .18725 L
s
.67731 .17232 m
.67519 .16824 L
s
.67358 .18059 m
.67731 .17232 L
s
.68214 .191 m
.68168 .18661 L
s
.67358 .18059 m
.68168 .18661 L
s
.72971 .18894 m
.72872 .18017 L
s
.72084 .17411 m
.72872 .18017 L
s
.66595 .14577 m
.66193 .14376 L
s
.66877 .16346 m
.66595 .14577 L
s
.67321 .16888 m
.67097 .16564 L
s
.6716 .18122 m
.67321 .16888 L
s
.66793 .14512 m
.66391 .14312 L
s
.67075 .16282 m
.66793 .14512 L
s
.69147 .14332 m
.68711 .13889 L
s
.69216 .15881 m
.69147 .14332 L
s
.69147 .14332 m
.69147 .14332 L
s
.67519 .16824 m
.67295 .165 L
s
.67358 .18059 m
.67519 .16824 L
s
.67946 .19551 m
.68016 .19164 L
s
.68016 .19164 m
.6716 .18122 L
s
.68016 .19164 m
.68016 .19164 L
s
.73783 .21037 m
.73594 .21865 L
s
.72956 .19633 m
.73783 .21037 L
s
.68711 .13889 m
.68426 .12125 L
s
.67827 .11814 m
.68426 .12125 L
s
.68024 .21946 m
.68562 .2153 L
s
.67728 .19872 m
.68562 .2153 L
s
.68141 .19489 m
.68214 .191 L
s
.68214 .191 m
.67358 .18059 L
s
.68214 .191 m
.68214 .191 L
s
.68221 .21884 m
.68758 .21468 L
s
.67925 .19809 m
.68758 .21468 L
s
.71577 .1434 m
.71136 .13687 L
s
.71434 .15565 m
.71577 .1434 L
s
.70829 .20814 m
.70961 .20264 L
s
.70126 .18857 m
.70961 .20264 L
s
.6716 .18122 m
.67097 .16564 L
s
.67097 .16564 m
.67097 .16564 L
s
.67097 .16564 m
.66877 .16346 L
s
.67358 .18059 m
.67295 .165 L
s
.67295 .165 m
.67295 .165 L
s
.67295 .165 m
.67075 .16282 L
s
.67728 .19872 m
.67946 .19551 L
s
.6716 .18122 m
.67946 .19551 L
s
.72956 .19633 m
.72971 .18894 L
s
.72971 .18894 m
.72133 .17851 L
s
.72971 .18894 m
.72971 .18894 L
s
.67925 .19809 m
.68141 .19489 L
s
.67358 .18059 m
.68141 .19489 L
s
.71596 .22491 m
.71242 .22982 L
s
.70829 .20814 m
.71596 .22491 L
s
.66193 .14376 m
.6571 .12508 L
s
.652 .12581 m
.6571 .12508 L
s
.69986 .17568 m
.69837 .17079 L
s
.69837 .17079 m
.6965 .16615 L
s
.69286 .17441 m
.69837 .17079 L
s
.70088 .18048 m
.69986 .17568 L
s
.69286 .17441 m
.69986 .17568 L
s
.66391 .14312 m
.65908 .12443 L
s
.65398 .12516 m
.65908 .12443 L
s
.6965 .16615 m
.69438 .16207 L
s
.69286 .17441 m
.6965 .16615 L
s
.001 .092 .901 r
.68512 .22337 m
.68688 .22264 L
s
0 0 0 r
2 Mabswid
.68512 .22337 Mdot
0 g
.5 Mabswid
.66877 .16346 m
.66676 .16248 L
s
.6716 .18122 m
.66877 .16346 L
s
.70136 .18488 m
.70088 .18048 L
s
.69286 .17441 m
.70088 .18048 L
s
.67457 .20078 m
.67728 .19872 L
s
.6716 .18122 m
.67728 .19872 L
s
.67075 .16282 m
.66874 .16184 L
s
.67358 .18059 m
.67075 .16282 L
s
.001 .092 .901 r
.68688 .22264 m
.70719 .2142 L
s
0 0 0 r
2 Mabswid
.68688 .22264 Mdot
0 g
.5 Mabswid
.67654 .20016 m
.67925 .19809 L
s
.67358 .18059 m
.67925 .19809 L
s
.66193 .14376 m
.65854 .1443 L
s
.66676 .16248 m
.66193 .14376 L
s
.68711 .13889 m
.68313 .13687 L
s
.68998 .15661 m
.68711 .13889 L
s
.69438 .16207 m
.69216 .15881 L
s
.69286 .17441 m
.69438 .16207 L
s
.71136 .13687 m
.70704 .13242 L
s
.71212 .15238 m
.71136 .13687 L
s
.71136 .13687 m
.71136 .13687 L
s
.66391 .14312 m
.66052 .14365 L
s
.66874 .16184 m
.66391 .14312 L
s
.70704 .13242 m
.70414 .11475 L
s
.69822 .11161 m
.70414 .11475 L
s
.67512 .22076 m
.68024 .21946 L
s
.68024 .21946 m
.69114 .23648 L
s
.67457 .20078 m
.68024 .21946 L
s
.69114 .23648 m
.68586 .23775 L
s
.70126 .18857 m
.70136 .18488 L
s
.70136 .18488 m
.69286 .17441 L
s
.70136 .18488 m
.70136 .18488 L
s
.67711 .22014 m
.68221 .21884 L
s
.68221 .21884 m
.69313 .23586 L
s
.67654 .20016 m
.68221 .21884 L
s
.69313 .23586 m
.68783 .23714 L
s
.70591 .21136 m
.70829 .20814 L
s
.70059 .1913 m
.70829 .20814 L
s
.72829 .20182 m
.72956 .19633 L
s
.72125 .1822 m
.72956 .19633 L
s
.67213 .20137 m
.67457 .20078 L
s
.6716 .18122 m
.67457 .20078 L
s
.66676 .16248 m
.66507 .16277 L
s
.6716 .18122 m
.66676 .16248 L
s
.69286 .17441 m
.69216 .15881 L
s
.69216 .15881 m
.69216 .15881 L
s
.69216 .15881 m
.68998 .15661 L
s
.6741 .20075 m
.67654 .20016 L
s
.67358 .18059 m
.67654 .20016 L
s
.66874 .16184 m
.66706 .16213 L
s
.67358 .18059 m
.66874 .16184 L
s
.001 .092 .901 r
.67769 .21933 m
.67951 .21861 L
s
0 0 0 r
2 Mabswid
.67769 .21933 Mdot
0 g
.5 Mabswid
.70059 .1913 m
.70126 .18857 L
s
.69286 .17441 m
.70126 .18857 L
s
.73594 .21865 m
.73247 .22354 L
s
.72829 .20182 m
.73594 .21865 L
s
.001 .092 .901 r
.67951 .21861 m
.70312 .20924 L
s
0 0 0 r
2 Mabswid
.67951 .21861 Mdot
0 g
.5 Mabswid
.71981 .1693 m
.71831 .1644 L
s
.71831 .1644 m
.71645 .15975 L
s
.71289 .16799 m
.71831 .1644 L
s
.72084 .17411 m
.71981 .1693 L
s
.71289 .16799 m
.71981 .1693 L
s
.68313 .13687 m
.67827 .11814 L
s
.67324 .11885 m
.67827 .11814 L
s
.6716 .18122 m
.6716 .18122 L
s
.6716 .18122 m
.66507 .16277 L
s
.6716 .18122 m
.66382 .16433 L
s
.6716 .18122 m
.6631 .16704 L
s
.6716 .18122 m
.66297 .17073 L
s
.6716 .18122 m
.66342 .17514 L
s
.6716 .18122 m
.66443 .17998 L
s
.6716 .18122 m
.66593 .1849 L
s
.6716 .18122 m
.66773 .1896 L
s
.6716 .18122 m
.66877 .19405 L
s
.6716 .18122 m
.66943 .19779 L
s
.6716 .18122 m
.67041 .20034 L
s
.6716 .18122 m
.67213 .20137 L
s
.71645 .15975 m
.71434 .15565 L
s
.71289 .16799 m
.71645 .15975 L
s
.67358 .18059 m
.67358 .18059 L
s
.67358 .18059 m
.66706 .16213 L
s
.67358 .18059 m
.66581 .16368 L
s
.67358 .18059 m
.6651 .1664 L
s
.67358 .18059 m
.66496 .17009 L
s
.67358 .18059 m
.66541 .1745 L
s
.67358 .18059 m
.66643 .17934 L
s
.67358 .18059 m
.66793 .18426 L
s
.67358 .18059 m
.66969 .18897 L
s
.67358 .18059 m
.67074 .19342 L
s
.67358 .18059 m
.6714 .19717 L
s
.67358 .18059 m
.67239 .19972 L
s
.67358 .18059 m
.6741 .20075 L
s
.72133 .17851 m
.72084 .17411 L
s
.71289 .16799 m
.72084 .17411 L
s
.67041 .20034 m
.67213 .20137 L
s
.67213 .20137 m
.67512 .22076 L
s
.68998 .15661 m
.68799 .15562 L
s
.69286 .17441 m
.68998 .15661 L
s
.66507 .16277 m
.65854 .1443 L
s
.66507 .16277 m
.66382 .16433 L
s
.67239 .19972 m
.6741 .20075 L
s
.6741 .20075 m
.67711 .22014 L
s
.70704 .13242 m
.7031 .13037 L
s
.70996 .15017 m
.70704 .13242 L
s
.66706 .16213 m
.66052 .14365 L
s
.66706 .16213 m
.66581 .16368 L
s
.71434 .15565 m
.71212 .15238 L
s
.71289 .16799 m
.71434 .15565 L
s
.69939 .1929 m
.70059 .1913 L
s
.69286 .17441 m
.70059 .1913 L
s
.68313 .13687 m
.67979 .13739 L
s
.68799 .15562 m
.68313 .13687 L
s
.001 .092 .901 r
.672 .19488 m
.67394 .19453 L
s
0 0 0 r
2 Mabswid
.672 .19488 Mdot
.001 .092 .901 r
.5 Mabswid
.67115 .20515 m
.67312 .20475 L
s
0 0 0 r
2 Mabswid
.67115 .20515 Mdot
0 g
.5 Mabswid
.65854 .1443 m
.65602 .14737 L
s
.652 .12581 m
.65854 .1443 L
s
.6718 .21871 m
.67512 .22076 L
s
.67512 .22076 m
.68586 .23775 L
s
.72125 .1822 m
.72133 .17851 L
s
.72133 .17851 m
.71289 .16799 L
s
.72133 .17851 m
.72133 .17851 L
s
.001 .092 .901 r
.67394 .19453 m
.69638 .19059 L
s
0 0 0 r
2 Mabswid
.67394 .19453 Mdot
.001 .092 .901 r
.5 Mabswid
.67312 .20475 m
.69872 .19962 L
s
0 0 0 r
2 Mabswid
.67312 .20475 Mdot
.001 .092 .901 r
.5 Mabswid
.67213 .21474 m
.67412 .21411 L
s
0 0 0 r
2 Mabswid
.67213 .21474 Mdot
0 g
.5 Mabswid
.71242 .22982 m
.70752 .23097 L
s
.70591 .21136 m
.71242 .22982 L
s
.66052 .14365 m
.65801 .14672 L
s
.65398 .12516 m
.66052 .14365 L
s
.67378 .21809 m
.67711 .22014 L
s
.67711 .22014 m
.68783 .23714 L
s
.001 .092 .901 r
.70719 .2142 m
.72594 .20629 L
s
0 0 0 r
2 Mabswid
.70719 .2142 Mdot
.001 .092 .901 r
.5 Mabswid
.67412 .21411 m
.70032 .20581 L
s
0 0 0 r
2 Mabswid
.67412 .21411 Mdot
0 g
.5 Mabswid
.6482 .13035 m
.652 .12581 L
s
.72595 .20504 m
.72829 .20182 L
s
.7206 .18494 m
.72829 .20182 L
s
.70262 .21209 m
.70591 .21136 L
s
.69939 .1929 m
.70591 .21136 L
s
.65019 .1297 m
.65398 .12516 L
s
.66943 .19779 m
.67041 .20034 L
s
.67041 .20034 m
.6718 .21871 L
s
.71289 .16799 m
.71212 .15238 L
s
.71212 .15238 m
.71212 .15238 L
s
.71212 .15238 m
.70996 .15017 L
s
.68799 .15562 m
.68632 .15591 L
s
.69286 .17441 m
.68799 .15562 L
s
.66382 .16433 m
.65602 .14737 L
s
.66382 .16433 m
.6631 .16704 L
s
.6714 .19717 m
.67239 .19972 L
s
.67239 .19972 m
.67378 .21809 L
s
.7206 .18494 m
.72125 .1822 L
s
.71289 .16799 m
.72125 .1822 L
s
.66581 .16368 m
.65801 .14672 L
s
.66581 .16368 m
.6651 .1664 L
s
.69774 .19323 m
.69939 .1929 L
s
.69286 .17441 m
.69939 .1929 L
s
.7031 .13037 m
.69822 .11161 L
s
.69325 .11229 m
.69822 .11161 L
s
.69286 .17441 m
.69286 .17441 L
s
.69286 .17441 m
.68632 .15591 L
s
.69286 .17441 m
.6851 .15746 L
s
.69286 .17441 m
.68441 .16017 L
s
.69286 .17441 m
.68429 .16386 L
s
.69286 .17441 m
.68476 .16828 L
s
.69286 .17441 m
.68578 .17313 L
s
.69286 .17441 m
.68729 .17806 L
s
.69286 .17441 m
.68918 .18275 L
s
.69286 .17441 m
.69132 .18686 L
s
.69286 .17441 m
.69356 .19011 L
s
.69286 .17441 m
.69575 .19228 L
s
.69286 .17441 m
.69774 .19323 L
s
.68586 .23775 m
.68005 .23501 L
s
.70996 .15017 m
.70799 .14917 L
s
.71289 .16799 m
.70996 .15017 L
s
.68783 .23714 m
.68202 .23439 L
s
.66877 .19405 m
.66943 .19779 L
s
.66943 .19779 m
.67006 .21358 L
s
.66943 .19779 m
.66943 .19779 L
s
.6631 .16704 m
.65456 .15277 L
s
.6631 .16704 m
.66297 .17073 L
s
.68632 .15591 m
.67979 .13739 L
s
.68632 .15591 m
.6851 .15746 L
s
.67074 .19342 m
.6714 .19717 L
s
.6714 .19717 m
.67204 .21295 L
s
.6714 .19717 m
.6714 .19717 L
s
.71942 .18653 m
.7206 .18494 L
s
.71289 .16799 m
.7206 .18494 L
s
.6651 .1664 m
.65656 .15212 L
s
.6651 .1664 m
.66496 .17009 L
s
.7031 .13037 m
.6998 .13088 L
s
.70799 .14917 m
.7031 .13037 L
s
.001 .092 .901 r
.70312 .20924 m
.72214 .2016 L
s
0 0 0 r
2 Mabswid
.70312 .20924 Mdot
0 g
.5 Mabswid
.69575 .19228 m
.69774 .19323 L
s
.69774 .19323 m
.70262 .21209 L
s
.67979 .13739 m
.67732 .14045 L
s
.67324 .11885 m
.67979 .13739 L
s
.65602 .14737 m
.6482 .13035 L
s
.65602 .14737 m
.65456 .15277 L
s
.73247 .22354 m
.72764 .22467 L
s
.72595 .20504 m
.73247 .22354 L
s
.67006 .21358 m
.6718 .21871 L
s
.6718 .21871 m
.68005 .23501 L
s
.001 .092 .901 r
.67168 .21844 m
.67365 .21774 L
s
0 0 0 r
2 Mabswid
.67168 .21844 Mdot
0 g
.5 Mabswid
.65801 .14672 m
.65019 .1297 L
s
.65801 .14672 m
.65656 .15212 L
s
.001 .092 .901 r
.69638 .19059 m
.7172 .1871 L
s
0 0 0 r
2 Mabswid
.69638 .19059 Mdot
.001 .092 .901 r
.5 Mabswid
.67365 .21774 m
.69913 .20861 L
s
0 0 0 r
2 Mabswid
.67365 .21774 Mdot
0 g
.5 Mabswid
.67204 .21295 m
.67378 .21809 L
s
.67378 .21809 m
.68202 .23439 L
s
.66297 .17073 m
.65427 .16015 L
s
.66297 .17073 m
.66342 .17514 L
s
.66297 .17073 m
.66297 .17073 L
s
.66951 .12337 m
.67324 .11885 L
s
.72271 .20575 m
.72595 .20504 L
s
.71942 .18653 m
.72595 .20504 L
s
.66773 .1896 m
.66877 .19405 L
s
.66877 .19405 m
.66807 .2063 L
s
.70799 .14917 m
.70635 .14944 L
s
.71289 .16799 m
.70799 .14917 L
s
.66496 .17009 m
.65627 .1595 L
s
.66496 .17009 m
.66541 .1745 L
s
.66496 .17009 m
.66496 .17009 L
s
.001 .092 .901 r
.69872 .19962 m
.71941 .19561 L
s
0 0 0 r
2 Mabswid
.69872 .19962 Mdot
0 g
.5 Mabswid
.66969 .18897 m
.67074 .19342 L
s
.67074 .19342 m
.67004 .20567 L
s
.69865 .21023 m
.70262 .21209 L
s
.70262 .21209 m
.70752 .23097 L
s
.6851 .15746 m
.67732 .14045 L
s
.6851 .15746 m
.68441 .16017 L
s
.001 .092 .901 r
.72594 .20629 m
.93784 .10334 L
s
0 0 0 r
2 Mabswid
.72594 .20629 Mdot
0 g
.5 Mabswid
.7178 .18685 m
.71942 .18653 L
s
.71289 .16799 m
.71942 .18653 L
s
.001 .092 .901 r
.70032 .20581 m
.72041 .19945 L
s
0 0 0 r
2 Mabswid
.70032 .20581 Mdot
0 g
.5 Mabswid
.66342 .17514 m
.65516 .16901 L
s
.66342 .17514 m
.66443 .17998 L
s
.69356 .19011 m
.69575 .19228 L
s
.69575 .19228 m
.69865 .21023 L
s
.66593 .1849 m
.66773 .1896 L
s
.66773 .1896 m
.66402 .198 L
s
.66541 .1745 m
.65717 .16836 L
s
.66541 .1745 m
.66643 .17934 L
s
.71289 .16799 m
.71289 .16799 L
s
.71289 .16799 m
.70635 .14944 L
s
.71289 .16799 m
.70515 .15099 L
s
.71289 .16799 m
.70448 .1537 L
s
.71289 .16799 m
.70438 .15739 L
s
.71289 .16799 m
.70486 .16182 L
s
.71289 .16799 m
.7059 .16668 L
s
.71289 .16799 m
.70741 .17162 L
s
.71289 .16799 m
.7093 .17632 L
s
.71289 .16799 m
.71143 .18044 L
s
.71289 .16799 m
.71366 .18371 L
s
.71289 .16799 m
.71583 .18589 L
s
.71289 .16799 m
.7178 .18685 L
s
.66793 .18426 m
.66969 .18897 L
s
.66969 .18897 m
.66602 .19736 L
s
.66443 .17998 m
.65719 .17872 L
s
.66443 .17998 m
.66593 .1849 L
s
.66593 .1849 m
.66021 .18862 L
s
.70752 .23097 m
.70157 .22826 L
s
.66643 .17934 m
.6592 .17808 L
s
.66643 .17934 m
.66793 .18426 L
s
.64597 .13842 m
.6482 .13035 L
s
.66793 .18426 m
.66222 .18798 L
s
.70635 .14944 m
.6998 .13088 L
s
.70635 .14944 m
.70515 .15099 L
s
.68441 .16017 m
.67591 .14585 L
s
.68441 .16017 m
.68429 .16386 L
s
.64797 .13777 m
.65019 .1297 L
s
.71583 .18589 m
.7178 .18685 L
s
.7178 .18685 m
.72271 .20575 L
s
.69132 .18686 m
.69356 .19011 L
s
.69356 .19011 m
.69427 .20591 L
s
.69356 .19011 m
.69356 .19011 L
s
.6998 .13088 m
.69739 .13392 L
s
.69325 .11229 m
.6998 .13088 L
s
.65456 .15277 m
.64597 .13842 L
s
.65456 .15277 m
.65427 .16015 L
s
.67732 .14045 m
.66951 .12337 L
s
.67732 .14045 m
.67591 .14585 L
s
.001 .092 .901 r
.69913 .20861 m
.71969 .20119 L
s
0 0 0 r
2 Mabswid
.69913 .20861 Mdot
.001 .092 .901 r
.5 Mabswid
.72214 .2016 m
.93827 .10396 L
s
0 0 0 r
2 Mabswid
.72214 .2016 Mdot
0 g
.5 Mabswid
.65656 .15212 m
.64797 .13777 L
s
.65656 .15212 m
.65627 .1595 L
s
.66807 .2063 m
.67006 .21358 L
s
.67006 .21358 m
.6735 .22857 L
s
.67006 .21358 m
.67006 .21358 L
s
.68959 .1168 m
.69325 .11229 L
s
.001 .092 .901 r
.7172 .1871 m
.96416 .1647 L
s
0 0 0 r
2 Mabswid
.7172 .1871 Mdot
.001 .092 .901 r
.5 Mabswid
.67307 .22162 m
.67501 .22091 L
s
0 0 0 r
2 Mabswid
.67307 .22162 Mdot
0 g
.5 Mabswid
.68005 .23501 m
.6735 .22857 L
s
.67004 .20567 m
.67204 .21295 L
s
.67204 .21295 m
.67551 .22794 L
s
.67204 .21295 m
.67204 .21295 L
s
.68429 .16386 m
.67565 .15323 L
s
.68429 .16386 m
.68476 .16828 L
s
.68429 .16386 m
.68429 .16386 L
s
.001 .092 .901 r
.67501 .22091 m
.69738 .21269 L
s
0 0 0 r
2 Mabswid
.67501 .22091 Mdot
0 g
.5 Mabswid
.68202 .23439 m
.67551 .22794 L
s
.71879 .20387 m
.72271 .20575 L
s
.72271 .20575 m
.72764 .22467 L
s
.70515 .15099 m
.69739 .13392 L
s
.70515 .15099 m
.70448 .1537 L
s
.68918 .18275 m
.69132 .18686 L
s
.69132 .18686 m
.68977 .19941 L
s
.001 .092 .901 r
.71941 .19561 m
.96386 .16363 L
s
0 0 0 r
2 Mabswid
.71941 .19561 Mdot
0 g
.5 Mabswid
.69427 .20591 m
.69865 .21023 L
s
.69865 .21023 m
.70157 .22826 L
s
.001 .092 .901 r
.72041 .19945 m
.9535 .12555 L
s
0 0 0 r
2 Mabswid
.72041 .19945 Mdot
0 g
.5 Mabswid
.71366 .18371 m
.71583 .18589 L
s
.71583 .18589 m
.71879 .20387 L
s
.68476 .16828 m
.67658 .1621 L
s
.68476 .16828 m
.68578 .17313 L
s
.68729 .17806 m
.68918 .18275 L
s
.68918 .18275 m
.68547 .19117 L
s
.72764 .22467 m
.72175 .22193 L
s
.68578 .17313 m
.67863 .17183 L
s
.68578 .17313 m
.68729 .17806 L
s
.68729 .17806 m
.68167 .18176 L
s
.66736 .13144 m
.66951 .12337 L
s
.65427 .16015 m
.6455 .14949 L
s
.65427 .16015 m
.65516 .16901 L
s
.65427 .16015 m
.65427 .16015 L
s
.001 .092 .901 r
.71969 .20119 m
.95839 .10959 L
s
0 0 0 r
2 Mabswid
.71969 .20119 Mdot
0 g
.5 Mabswid
.70448 .1537 m
.69602 .13932 L
s
.70448 .1537 m
.70438 .15739 L
s
.65627 .1595 m
.64751 .14884 L
s
.65627 .1595 m
.65717 .16836 L
s
.65627 .1595 m
.65627 .1595 L
s
.71143 .18044 m
.71366 .18371 L
s
.71366 .18371 m
.71443 .19953 L
s
.71366 .18371 m
.71366 .18371 L
s
.66402 .198 m
.66807 .2063 L
s
.66807 .2063 m
.66669 .21887 L
s
.001 .092 .901 r
.69738 .21269 m
.71809 .20502 L
s
0 0 0 r
2 Mabswid
.69738 .21269 Mdot
0 g
.5 Mabswid
.67591 .14585 m
.66736 .13144 L
s
.67591 .14585 m
.67565 .15323 L
s
.69739 .13392 m
.68959 .1168 L
s
.69739 .13392 m
.69602 .13932 L
s
.66602 .19736 m
.67004 .20567 L
s
.67004 .20567 m
.6687 .21823 L
s
.6455 .14949 m
.64597 .13842 L
s
.70438 .15739 m
.6958 .14671 L
s
.70438 .15739 m
.70486 .16182 L
s
.70438 .15739 m
.70438 .15739 L
s
.70157 .22826 m
.69498 .22182 L
s
.64751 .14884 m
.64797 .13777 L
s
.68977 .19941 m
.69427 .20591 L
s
.69427 .20591 m
.69498 .22182 L
s
.69427 .20591 m
.69427 .20591 L
s
.7093 .17632 m
.71143 .18044 L
s
.71143 .18044 m
.70996 .193 L
s
.71443 .19953 m
.71879 .20387 L
s
.71879 .20387 m
.72175 .22193 L
s
.65516 .16901 m
.64683 .16281 L
s
.65516 .16901 m
.65719 .17872 L
s
.65717 .16836 m
.64884 .16216 L
s
.65717 .16836 m
.6592 .17808 L
s
.70486 .16182 m
.69676 .15559 L
s
.70486 .16182 m
.7059 .16668 L
s
.66021 .18862 m
.66402 .198 L
s
.66402 .198 m
.66018 .20651 L
s
.70741 .17162 m
.7093 .17632 L
s
.7093 .17632 m
.70567 .18473 L
s
.6735 .22857 m
.66669 .21887 L
s
.6735 .22857 m
.6735 .22857 L
s
.66222 .18798 m
.66602 .19736 L
s
.66602 .19736 m
.66219 .20587 L
s
.7059 .16668 m
.69883 .16535 L
s
.7059 .16668 m
.70741 .17162 L
s
.70741 .17162 m
.70188 .17529 L
s
.001 .092 .901 r
.71809 .20502 m
.95852 .10914 L
s
0 0 0 r
2 Mabswid
.71809 .20502 Mdot
0 g
.5 Mabswid
.67551 .22794 m
.6687 .21823 L
s
.67551 .22794 m
.67551 .22794 L
s
.65719 .17872 m
.64988 .17745 L
s
.65719 .17872 m
.66021 .18862 L
s
.66021 .18862 m
.65444 .19237 L
s
.68751 .12486 m
.68959 .1168 L
s
.6592 .17808 m
.6519 .1768 L
s
.6592 .17808 m
.66222 .18798 L
s
.67565 .15323 m
.66695 .14252 L
s
.67565 .15323 m
.67658 .1621 L
s
.67565 .15323 m
.67565 .15323 L
s
.66222 .18798 m
.65645 .19173 L
s
.69602 .13932 m
.68751 .12486 L
s
.69602 .13932 m
.6958 .14671 L
s
.68547 .19117 m
.68977 .19941 L
s
.68977 .19941 m
.6882 .21206 L
s
.72175 .22193 m
.71521 .21545 L
s
.66695 .14252 m
.66736 .13144 L
s
.70996 .193 m
.71443 .19953 L
s
.71443 .19953 m
.71521 .21545 L
s
.71443 .19953 m
.71443 .19953 L
s
.64683 .16281 m
.6455 .14949 L
s
.6455 .14949 m
.6455 .14949 L
s
.67658 .1621 m
.66833 .15586 L
s
.67658 .1621 m
.67863 .17183 L
s
.64884 .16216 m
.64751 .14884 L
s
.64751 .14884 m
.64751 .14884 L
s
.68167 .18176 m
.68547 .19117 L
s
.68547 .19117 m
.68172 .19967 L
s
.69498 .22182 m
.6882 .21206 L
s
.69498 .22182 m
.69498 .22182 L
s
.66669 .21887 m
.66018 .20651 L
s
.67863 .17183 m
.67141 .17053 L
s
.67863 .17183 m
.68167 .18176 L
s
.68167 .18176 m
.67598 .18548 L
s
.6687 .21823 m
.66219 .20587 L
s
.6958 .14671 m
.68716 .13595 L
s
.6958 .14671 m
.69676 .15559 L
s
.6958 .14671 m
.6958 .14671 L
s
.70567 .18473 m
.70996 .193 L
s
.70996 .193 m
.70848 .20566 L
s
.68716 .13595 m
.68751 .12486 L
s
.64988 .17745 m
.64683 .16281 L
s
.6519 .1768 m
.64884 .16216 L
s
.69676 .15559 m
.68858 .1493 L
s
.69676 .15559 m
.69883 .16535 L
s
.66833 .15586 m
.66695 .14252 L
s
.66695 .14252 m
.66695 .14252 L
s
.66018 .20651 m
.65444 .19237 L
s
.70188 .17529 m
.70567 .18473 L
s
.70567 .18473 m
.70201 .19322 L
s
.66219 .20587 m
.65645 .19173 L
s
.71521 .21545 m
.70848 .20566 L
s
.71521 .21545 m
.71521 .21545 L
s
.69883 .16535 m
.6917 .164 L
s
.69883 .16535 m
.70188 .17529 L
s
.6882 .21206 m
.68172 .19967 L
s
.65444 .19237 m
.64988 .17745 L
s
.70188 .17529 m
.69628 .17899 L
s
.65645 .19173 m
.6519 .1768 L
s
.67141 .17053 m
.66833 .15586 L
s
.68858 .1493 m
.68716 .13595 L
s
.68716 .13595 m
.68716 .13595 L
s
.68172 .19967 m
.67598 .18548 L
s
.70848 .20566 m
.70201 .19322 L
s
.67598 .18548 m
.67141 .17053 L
s
.6917 .164 m
.68858 .1493 L
s
.70201 .19322 m
.69628 .17899 L
s
.69628 .17899 m
.6917 .164 L
s
0 0 0 r
2 Mabswid
.95852 .10914 Mdot
.95839 .10959 Mdot
.9535 .12555 Mdot
.96386 .16363 Mdot
.96416 .1647 Mdot
.93827 .10396 Mdot
.93784 .10334 Mdot
0 g
.25 Mabswid
.00939 .30858 m
.94063 0 L
s
.02923 .302 m
.02864 .30851 L
s
gsave
.03041 .28899 -65.0919 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.2634 .22441 m
.26311 .23093 L
s
gsave
.26397 .21136 -68.887 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51217 .14197 m
.51222 .14851 L
s
gsave
.51208 .12891 -69.3101 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77696 .05423 m
.77738 .06075 L
s
gsave
.77613 .04119 -69.7766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07496 .28685 m
.07464 .29076 L
s
.12123 .27152 m
.12095 .27543 L
s
.16805 .256 m
.16781 .25991 L
s
.21544 .2403 m
.21523 .24421 L
s
.31194 .20832 m
.31181 .21224 L
s
.36108 .19204 m
.36099 .19596 L
s
.41083 .17556 m
.41077 .17948 L
s
.46119 .15887 m
.46117 .16279 L
s
.5638 .12487 m
.56387 .12879 L
s
.61608 .10754 m
.6162 .11146 L
s
.66903 .09 m
.66919 .09392 L
s
.72265 .07223 m
.72285 .07614 L
s
.83198 .036 m
.83228 .03991 L
s
.88771 .01753 m
.88806 .02144 L
s
.25 Mabswid
.98876 .07115 m
1 .17466 L
s
.98902 .07356 m
.9828 .07556 L
s
gsave
1.00146 .06957 -61 -11.2246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99156 .09688 m
.98533 .09886 L
s
gsave
1.00401 .09292 -61 -11.2094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99411 .12044 m
.98788 .1224 L
s
gsave
1.00657 .11651 -61 -11.1941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9967 .14423 m
.99046 .14618 L
s
gsave
1.00917 .14033 -61 -11.1787 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99931 .16826 m
.99307 .17019 L
s
gsave
1.01179 .16439 -61 -11.1631 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98953 .07821 m
.9858 .0794 L
s
.99003 .08286 m
.9863 .08406 L
s
.99054 .08753 m
.98681 .08872 L
s
.99105 .0922 m
.98731 .09339 L
s
.99207 .10158 m
.98833 .10276 L
s
.99258 .10628 m
.98884 .10746 L
s
.99309 .11099 m
.98935 .11217 L
s
.9936 .11571 m
.98986 .11689 L
s
.99463 .12518 m
.99089 .12636 L
s
.99514 .12993 m
.9914 .1311 L
s
.99566 .13469 m
.99192 .13586 L
s
.99618 .13945 m
.99244 .14063 L
s
.99722 .14902 m
.99347 .15019 L
s
.99774 .15381 m
.99399 .15498 L
s
.99826 .15862 m
.99452 .15978 L
s
.99878 .16344 m
.99504 .1646 L
s
.99983 .1731 m
.99609 .17425 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[79]:=",
  ImageSize->{299.688, 138.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000RPP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md;7@00?md;7@00?md;7@00?md;7@00?md
;7@00?md;7@00?md;7@00?md2g@24@=d00<AM7@00Q42M0@A4G@00?md2W@0115dM144M0044GAd4@9d
00<AM7@04G@00?md17@44@9d00@AM7@A17@0115dM143M0034GAd011d003lM08A2g@0115dM144M004
4GAd4@=d00<AM7@047@00?Ud1Q4:M0044GAd4@Ad00@AM7@A17@00a5dM00?M000mW@34@Ad0Q4:M003
4GAd00<A0W@24@04M14A4@9d114>M000lg@34@Md00<AM1402W@34@9d00<AM7@00a42M08A0W@00a5d
M00=M000l7@34@]d00<AM1401G@44@9d00@AM7@A17@0115dM143M0034GAd00ed003;M08A0g@00a5d
4@024AQd0a4?M08A2g@0115dM144M0044GAd4@=d00<AM7@03G@00<Yd00@AM7@A1g@00a5dM00BM0<A
0W@00a5dM00<M0044G@A4@Yd00@AM7@A17@0115dM143M0034GAd00ed003:M0044GAd4@Md00<AM7@0
3g@34AId0a47M0<A0W@00a5dM002M0044GAd4@9d0Q4?M000bW@0115dM145M08A3g@34AYd0Q46M003
4GAd00<A1W@24@Ad00<AM7@03G@00<Yd00@AM7@A1g@00a5dM009M0<A7W@24@Ed00@AM7@A7W@00<Yd
00@AM7@A17@0115dM148M0<A8G@34@Ad00@AM7@A7W@00<]d0Q46M08A1W@34@9d00<AM7@087@34@=d
00<AM7@00a43M0034GAd008A0g@34@id003HM0<A:7@34@=d00@AM7@A0W@00a5dM002M0044GAd4@=d
00<AM7@03G@00=Ed0a4/M0<A0g@34@9d00<AM7@00W@0115dM143M0034GAd00ed003BM0<A<7@34@Ad
00@AM7@A17@0115dM143M0034GAd00ed003?M0<A<g@00a5d4@04M0044GAd4@Ad00@AM7@A0g@00a5d
M00=M000c7@34@9d00<AM7@0<W@34@=d00<AM7@00a42M08A00=d4A401a4;M000bG@34C]d0a43M0<A
0W@00a5dM0044@03M14A008A00=d4A400W@44@Ad0036M0<A?g@24@Ed00@AM7@A0g@24@03M14A00=d
00@AM7@A0W@00a5dM004M000`g@34D9d0a44M0DA0W@24@03M14A00=d00@AM7@A0g@00a5dM003M000
`7@34DEd0a44M0044GAd4@=d0Q400g@A4@03M08A00=d4G@00W@00a5dM003M000_7@44@9d00<AM7@0
AG@00a5dM002M0044GAd4@=d0Q401W@A4G@AM08A00=d4G@00g@00a5dM002M000^G@34Ded0Q45M08A
17@0115d4A43M08A0W@00a5d4@02M0034GAd009d002fM0<AD7@24@ad0a43M0034G@A008A0W@44@=d
002cM0<ADg@34@]d00@AM7@A17@0115dM143M0034GAd009d002`M0<A00=d4G@0Dg@34@Ed1142M004
4GAd4@Ad00@AM7@A0g@00a5dM002M000[G@34EYd0Q4;M0044GAd4@Ad00@AM7@A0g@00a5dM002M000
ZW@34Did0Q4<M0034G@A00]d00@AM7@A17@0115dM143M0034GAd009d002WM0<ADG@00a@A4@0<M08A
2g@0115dM144M0044GAd4@9d0Q44M000Q7@24@=d00<AM1400a4EM0<ADW@01A@HM7@A00=d0Q47M08A
1G@24@Ed0Q46M08A17@00a5dM002M000Pg@0115dM145M0034GAd019d0a400g@AM00CM08A>g@00a@C
M006M0034a@A00Md0Q44M0044GAd4AMd0023M0044GAd4@Id00<AM7@03W@34AUd114gM00351Qd00Ed
00@D61@H2W@00a5dM002M0044GAd4AMd0023M0044GAd4@Id00<AM7@02g@34AMd0Q42M0034G@A00<A
<g@00a<D4`06M00451<D4`]d0Q44M0044GAd4AMd0023M0044GAd4@Md00<AM7@01g@34AUd1Q401W@A
4A5d4C1d00<H51P01G@011PD61@4M08A1g@34@Ad00@AM7@A5g@008=d00@AM7@A17@0115dM146M0<A
5g@84@05M14A4G@01A4]M0034a@C00Ad00@D4a@C1W@00a@C4@08M0<A0g@0115dM14GM000Q7@24@Id
0Q44M0<A0W@00a5dM00DM0HA00=d4A4011400g@A4@024@03M15d02Ud00<H51P017@011@H51P5M003
61@H00]d0a44M08A67@008md0a4LM18A00=d4G@09g@00a<D4`03M0044a@C50Ed00<D4a@03g@24@Ed
0Q43M0034GAd008A0g@34@Ud002<M0<A7W@?4@06M14A4G@A9G@011@H51P2M00551PD61@00g@011@H
51PAM0034G@A00Ad00@AM7@A17@0115dM143M0034GAd00Qd0029M0<A8G@D4@03M15d025d00@D4a@C
0W@011@C51<3M0034a@C01Id0Q44M0044GAd4@Ad00@AM7@A0g@00a5dM008M000QW@44B=d41401W@A
4A5d4B1d00TD61@HM1PD61@00g@00a@H500HM0<A17@0115dM144M0044GAd4@=d00<AM7@027@008=d
0a43M0034GAd025d51400g@A4@0MM00951<D4a@C51<D009d00<C51<07G@00a5dM002M0044GAd4@Ad
00@AM7@A0g@00a5dM008M000P7@34BYd5A400g@AM00IM00961@H51PD61@H009d00<D61@07g@24@Ad
00@AM7@A17@0115dM142M08A2W@007ed0a4]M1DA00=d4A405g@03A<DM1@C51<D4g@C51<08W@24@Ed
0a43M0034G@A008A0W@44@Qd001jM0<A<G@00a5d4@0@4@04M15d4AEd00`H57@D61@H57@D61@UM0<A
17@0115dM144M0044GAd4@9d00<AM7@027@007Md0a42M0034GAd02md00<AM1402Q400g@A4@054@03
M15d019d00/C57@D4a@C51<D4`0KM0044a@C50<A1W@34@Ad00@AM7@A17@0115dM143M0034GAd00Md
001dM0<A=g@D4@04M15d4@md00XD61@H51PD61@H57@03A@H51PD61@H51PD61@00g@24@Md0Q44M004
4GAd4@Ad00@AM7@A0g@00a5dM007M000LG@34CYd00<AM1405A4=M00951<D4a@C51<D00ad010C51<D
4a@C51<D4a@C51<D4g@00a5d4@04M0044GAd4@Ad00@AM7@A17@00a5dM006M000KW@34Ced3a400g@A
4@044@03M15d00Yd00PD61@H51PD60Ad00/D61@H51PD61@H5002M00761@H51PD600KM08A17@0115d
M144M0064GAd4G@A0W@00a5dM006M000Jg@44Cmd6149M00>51<D4a@C51<D4a@C51<5M0084a@C51<D
4a@YM08A1W@24@=d0Q49M000J7@34D=d5a403W@A51PD61@H51PD61@H27@01a@H51PD61@0BG@006Ed
0a57M0034G@A00`A00TC4A4A4a@C51<00g@01a<D4a@C51<00g@01a<D4a@C51<0D7@0049d0Q43M003
4GAd00<A5G@34DYd2Q400a@A4@094@0?M15d61@H51PD61@H51PD05Md0011M0044GAd4@Id00<AM7@0
4G@34Did1a400a@A4@0;4@0851<D4a@C51=NM000@G@0115dM146M0034GAd00id0a42M0034GAd04ad
00<AM1402a400g@A4@024@0851PD61Ad51QPM000@G@0115dM146M0034GAd00]d0a5DM1<A00HD4g@A
51=RM000@G@0115dM146M0034GAd00Qd0a5DM00451PDM0DA00<H51401Q4011@A4AP24@0351Qd06=d
0011M0044GAd4@Ed0Q47M0<AE7@00a<D4`03M0034a4A00XA00<D4a4011400a<A4@1TM000@W@24@Md
00<AM7@00W@44EAd00<H57@00W@00a@H5002M0DA00<D61402A4017@A4A5TM000CG@34EEd00<D4a@0
0W@00a<D4`05M0@A00@C51<D1A4021@A4A5d4G@AI7@004Yd0a5EM00361@H009d00<D61@01W@00aPD
60044@0357@A00HA00Ed4A4AM0024FAd0017M0<AEG@00a@C5002M0034a@C00Id00TD4a@C51<D4A@0
1a401G@A4A5d00@AIG@004Ad0a5EM00361@H009d00<D61@01G@02a@H51PD61@H51PD00TA00Ad4A4A
0W@00a5dM01UM000@7@44@9d00<AM7@0D7@00a@C5002M0034a@C00Ed00dC51<D4a@C51<D4a@C009d
0Q4017@A4G@54F]d000mM0<AEW@00aPD6002M00351PD00Ed00dD61@H51PD61@H51PD00Id11400g@A
M01^M000>W@34EId00<D4a@00W@00a<D4`05M00=4a@C51<D4a@C51<D4`0;M0<AL7@003Md0a5GM007
51QdM1@H5005M00<51PD61@H51PD61@HPW@003Ad0a42M0034GAd059d00LC51=d4a@C00Ed00`C51<D
4a@C51<D4aB5M000<G@34EMd00LD61Ad51PD00Ed00`D61@H51PD61@H51R8M000;W@34EMd00LC51=d
4a@C00Ad00`D4a@C51<D4a@C51><M000:g@34EMd00LD61Ad51PD00Ad00`H51PD61@H51PD61B?M000
:7@34@9d00<AM7@0DW@01a<D4g@C51<017@031@C51<D4a@C51<D4i9d000UM0<AEg@01a@H57@D61@0
17@02aPD61@H51PD61@H09Id0007M08A6G@34EMd00LC51=d4a@C00Ad00/D4a@C51<D4a@C502IM000
1W@0115dM14EM0<AF7@01QPDM1@H50Ad00XH51PD61@H51PDWG@000Id00@AM7@A4W@34@03M15d05Ed
00HD4a@C51<3M00;4a@C51<D4a@C51<0X7@000Id00@AM7@A3g@34EQd00HH51PD61@3M00;51PD61@H
51PD61@0Xg@000Id00@AM7@A37@34EQd00HD4a@C51<3M00:4a@C51<D4a@C5:Md0006M0044GAd4@Ud
0a5HM00661@H51PD0g@02Q@H51PD61@H51RZM0001g@24@Md0a400g@AM01EM00651<D4a@C0g@02Q<D
4a@C51<D4aB]M0003G@34EQd00HH51PD61@3M00951PD61@H51PD0;5d000:M0<AF7@01Q@C51<D4`=d
00TC51<D4a@C51<0]7@000Md0a5HM00661@H51PD0W@02QPD61@H51PD61BgM00017@44EQd00DC51<D
4`02M00951<D4a@C51<D0;]d0002M08A0g@00a5dM01CM00551PD61@00W@02APD61@H51PD602nM000
FW@041<D4a@C57@D4a@C51<D4aC1M000Eg@03a@H51PD67@H51PD61@H5035M000E7@03a<D4a@C57@D
4a@C51<D4`38M000DG@03Q@H51PD61@H51PD61@Hc7@004id00hC51<D4a@C51<D4a@C5<md001;M00>
51PD61@H51PD61@H51SBM000BG@031@C51<D4a@C51<D4mId0016M00<61@H51PD61@H51PDfG@004=d
00`D4a@C51<D4a@C51?LM000@7@02aPD61@H51PD61@H0>1d000mM00;51<D4a@C51<D4a@0hg@003Yd
00/H51PD61@H51PD603VM000=g@02Q@C51<D4a@C51?ZM000=7@02QPD61@H51PD61C]M000<W@021<D
4a@C51<DlG@002md00PD61@H51PD6?Ad000/M0084a@C51<D4aCgM000:G@01a@H51PD61@0ng@002Id
00LC51<D4a@C0?id000SM00751PD61@H503oM09d000PM0064a@C51<Dog@6M0007G@01Q@H51PD6?md
2G@001]d00DD4a@C503oM0ad000HM00461@H5?md47@001Ed00@D4a@Cog@CM0004W@011PD61CoM1Id
000@M0034aAd0?md6G@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md
;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00001
\
\>"],
  ImageRangeCache->{{{0, 298.688}, {137.875, 0}} -> {0.0432963, 0.227965, 
  0.00355429, 0.00355429}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[PressureLensSurfacesTraced, PlotType -> TopView, 
\tShowLabels -> False, PlotRange -> {{0.24, 0.3}, {-0.025, 0.025}},
\tRayPointSize -> 6];\
\>", "Input",
  CellLabel->"In[84]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-4 16.6667 0.416667 16.6667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .08333 m
.16667 .08333 L
.16667 .19444 L
.16667 .19444 L
.16667 .08333 L
s
.16667 .19444 m
.16667 .19444 L
.16667 .30556 L
.16667 .30556 L
.16667 .19444 L
s
.16667 .30556 m
.16667 .30556 L
.16667 .41667 L
.16667 .41667 L
.16667 .30556 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .52778 L
.16667 .52778 L
.16667 .41667 L
s
.16667 .52778 m
.16667 .52778 L
.16667 .63889 L
.16667 .63889 L
.16667 .52778 L
s
.16667 .63889 m
.16667 .63889 L
.16667 .75 L
.16667 .75 L
.16667 .63889 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.14914 .41667 L
.14914 .41667 L
.16667 .41667 L
s
.14914 .41667 m
.14914 .41667 L
.14914 .41667 L
.14914 .41667 L
.14914 .41667 L
s
.14914 .41667 m
.14914 .41667 L
.16667 .41667 L
.16667 .41667 L
.14914 .41667 L
s
.17917 .08333 m
.17917 .08333 L
.17917 .19444 L
.17917 .19444 L
.17917 .08333 L
s
.17917 .19444 m
.17917 .19444 L
.17917 .30556 L
.17917 .30556 L
.17917 .19444 L
s
.17917 .30556 m
.17917 .30556 L
.17917 .41667 L
.17917 .41667 L
.17917 .30556 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .52778 L
.17917 .52778 L
.17917 .41667 L
s
.17917 .52778 m
.17917 .52778 L
.17917 .63889 L
.17917 .63889 L
.17917 .52778 L
s
.17917 .63889 m
.17917 .63889 L
.17917 .75 L
.17917 .75 L
.17917 .63889 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .41667 L
.1615 .41667 L
.1615 .41667 L
.17917 .41667 L
s
.1615 .41667 m
.1615 .41667 L
.1615 .41667 L
.1615 .41667 L
.1615 .41667 L
s
.1615 .41667 m
.1615 .41667 L
.17917 .41667 L
.17917 .41667 L
.1615 .41667 L
s
.3 .08333 m
.3 .08333 L
.3 .19444 L
.3 .19444 L
.3 .08333 L
s
.3 .19444 m
.3 .19444 L
.3 .30556 L
.3 .30556 L
.3 .19444 L
s
.3 .30556 m
.3 .30556 L
.3 .41667 L
.3 .41667 L
.3 .30556 L
s
.3 .41667 m
.3 .41667 L
.3 .52778 L
.3 .52778 L
.3 .41667 L
s
.3 .52778 m
.3 .52778 L
.3 .63889 L
.3 .63889 L
.3 .52778 L
s
.3 .63889 m
.3 .63889 L
.3 .75 L
.3 .75 L
.3 .63889 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.425 .08333 m
.425 .08333 L
.425 .19444 L
.425 .19444 L
.425 .08333 L
s
.425 .19444 m
.425 .19444 L
.425 .30556 L
.425 .30556 L
.425 .19444 L
s
.425 .30556 m
.425 .30556 L
.425 .41667 L
.425 .41667 L
.425 .30556 L
s
.425 .41667 m
.425 .41667 L
.425 .52778 L
.425 .52778 L
.425 .41667 L
s
.425 .52778 m
.425 .52778 L
.425 .63889 L
.425 .63889 L
.425 .52778 L
s
.425 .63889 m
.425 .63889 L
.425 .75 L
.425 .75 L
.425 .63889 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.16667 .41667 m
.16667 .52778 L
.16302 .52399 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16302 .52399 L
.15372 .51289 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.15372 .51289 L
.14439 .49523 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14439 .49523 L
.13957 .47222 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.13957 .47222 L
.14143 .44542 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14143 .44542 L
.14914 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14914 .41667 L
.15912 .38791 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.15912 .38791 L
.16608 .36111 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16608 .36111 L
.16667 .3381 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .3381 L
.16667 .32044 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .32044 L
.16667 .30934 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30934 L
.16667 .30556 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30556 L
.16667 .30934 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30934 L
.16667 .32044 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .32044 L
.16667 .3381 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .3381 L
.16667 .36111 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .36111 L
.16667 .38791 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .38791 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .44542 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .44542 L
.16667 .47222 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .47222 L
.16667 .49523 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .49523 L
.16667 .51289 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .51289 L
.16667 .52399 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .52399 L
.16667 .52778 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .52778 m
.16667 .63889 L
.16667 .63132 L
.16302 .52399 L
.16667 .52778 L
s
.16302 .52399 m
.16667 .63132 L
.15762 .60912 L
.15372 .51289 L
.16302 .52399 L
s
.15372 .51289 m
.15762 .60912 L
.13908 .5738 L
.14439 .49523 L
.15372 .51289 L
s
.14439 .49523 m
.13908 .5738 L
.12793 .52778 L
.13957 .47222 L
.14439 .49523 L
s
.13957 .47222 m
.12793 .52778 L
.13232 .47418 L
.14143 .44542 L
.13957 .47222 L
s
.14143 .44542 m
.13232 .47418 L
.14914 .41667 L
.14914 .41667 L
.14143 .44542 L
s
.14914 .41667 m
.14914 .41667 L
.16499 .35915 L
.15912 .38791 L
.14914 .41667 L
s
.15912 .38791 m
.16499 .35915 L
.16667 .30556 L
.16608 .36111 L
.15912 .38791 L
s
.16608 .36111 m
.16667 .30556 L
.16667 .25953 L
.16667 .3381 L
.16608 .36111 L
s
.16667 .3381 m
.16667 .25953 L
.16667 .22422 L
.16667 .32044 L
.16667 .3381 L
s
.16667 .32044 m
.16667 .22422 L
.16667 .20202 L
.16667 .30934 L
.16667 .32044 L
s
.16667 .30934 m
.16667 .20202 L
.16667 .19444 L
.16667 .30556 L
.16667 .30934 L
s
.16667 .30556 m
.16667 .19444 L
.16667 .20202 L
.16667 .30934 L
.16667 .30556 L
s
.16667 .30934 m
.16667 .20202 L
.16667 .22422 L
.16667 .32044 L
.16667 .30934 L
s
.16667 .32044 m
.16667 .22422 L
.16667 .25953 L
.16667 .3381 L
.16667 .32044 L
s
.16667 .3381 m
.16667 .25953 L
.16667 .30556 L
.16667 .36111 L
.16667 .3381 L
s
.16667 .36111 m
.16667 .30556 L
.16667 .35915 L
.16667 .38791 L
.16667 .36111 L
s
.16667 .38791 m
.16667 .35915 L
.16667 .41667 L
.16667 .41667 L
.16667 .38791 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .47418 L
.16667 .44542 L
.16667 .41667 L
s
.16667 .44542 m
.16667 .47418 L
.16667 .52778 L
.16667 .47222 L
.16667 .44542 L
s
.16667 .47222 m
.16667 .52778 L
.16667 .5738 L
.16667 .49523 L
.16667 .47222 L
s
.16667 .49523 m
.16667 .5738 L
.16667 .60912 L
.16667 .51289 L
.16667 .49523 L
s
.16667 .51289 m
.16667 .60912 L
.16667 .63132 L
.16667 .52399 L
.16667 .51289 L
s
.16667 .52399 m
.16667 .63132 L
.16667 .63889 L
.16667 .52778 L
.16667 .52399 L
s
.16667 .63889 m
.16667 .75 L
.16667 .73864 L
.16667 .63132 L
.16667 .63889 L
s
.16667 .63132 m
.16667 .73864 L
.16667 .70534 L
.15762 .60912 L
.16667 .63132 L
s
.15762 .60912 m
.16667 .70534 L
.16667 .65237 L
.13908 .5738 L
.15762 .60912 L
s
.13908 .5738 m
.16667 .65237 L
.16479 .58333 L
.12793 .52778 L
.13908 .5738 L
s
.12793 .52778 m
.16479 .58333 L
.16603 .50294 L
.13232 .47418 L
.12793 .52778 L
s
.13232 .47418 m
.16603 .50294 L
.16667 .41667 L
.14914 .41667 L
.13232 .47418 L
s
.14914 .41667 m
.16667 .41667 L
.16667 .33039 L
.16499 .35915 L
.14914 .41667 L
s
.16499 .35915 m
.16667 .33039 L
.16667 .25 L
.16667 .30556 L
.16499 .35915 L
s
.16667 .30556 m
.16667 .25 L
.16667 .18096 L
.16667 .25953 L
.16667 .30556 L
s
.16667 .25953 m
.16667 .18096 L
.16667 .12799 L
.16667 .22422 L
.16667 .25953 L
s
.16667 .22422 m
.16667 .12799 L
.16667 .09469 L
.16667 .20202 L
.16667 .22422 L
s
.16667 .20202 m
.16667 .09469 L
.16667 .08333 L
.16667 .19444 L
.16667 .20202 L
s
.16667 .19444 m
.16667 .08333 L
.16667 .09469 L
.16667 .20202 L
.16667 .19444 L
s
.16667 .20202 m
.16667 .09469 L
.16667 .12799 L
.16667 .22422 L
.16667 .20202 L
s
.16667 .22422 m
.16667 .12799 L
.16667 .18096 L
.16667 .25953 L
.16667 .22422 L
s
.16667 .25953 m
.16667 .18096 L
.16667 .25 L
.16667 .30556 L
.16667 .25953 L
s
.16667 .30556 m
.16667 .25 L
.16667 .33039 L
.16667 .35915 L
.16667 .30556 L
s
.16667 .35915 m
.16667 .33039 L
.16667 .41667 L
.16667 .41667 L
.16667 .35915 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .50294 L
.16667 .47418 L
.16667 .41667 L
s
.16667 .47418 m
.16667 .50294 L
.16667 .58333 L
.16667 .52778 L
.16667 .47418 L
s
.16667 .52778 m
.16667 .58333 L
.16667 .65237 L
.16667 .5738 L
.16667 .52778 L
s
.16667 .5738 m
.16667 .65237 L
.16667 .70534 L
.16667 .60912 L
.16667 .5738 L
s
.16667 .60912 m
.16667 .70534 L
.16667 .73864 L
.16667 .63132 L
.16667 .60912 L
s
.16667 .63132 m
.16667 .73864 L
.16667 .75 L
.16667 .63889 L
.16667 .63132 L
s
.17917 .41667 m
.17917 .52778 L
.17533 .52399 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17533 .52399 L
.16607 .51289 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.16607 .51289 L
.15677 .49523 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.15677 .49523 L
.15197 .47222 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.15197 .47222 L
.15382 .44542 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.15382 .44542 L
.1615 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.1615 .41667 L
.17144 .38791 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17144 .38791 L
.17837 .36111 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17837 .36111 L
.17917 .3381 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .3381 L
.17917 .32044 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .32044 L
.17917 .30934 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .30934 L
.17917 .30556 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .30556 L
.17917 .30934 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .30934 L
.17917 .32044 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .32044 L
.17917 .3381 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .3381 L
.17917 .36111 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .36111 L
.17917 .38791 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .38791 L
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .44542 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .44542 L
.17917 .47222 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .47222 L
.17917 .49523 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .49523 L
.17917 .51289 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .51289 L
.17917 .52399 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .52399 L
.17917 .52778 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .52778 m
.17917 .63889 L
.17917 .63132 L
.17533 .52399 L
.17917 .52778 L
s
.17533 .52399 m
.17917 .63132 L
.16995 .60912 L
.16607 .51289 L
.17533 .52399 L
s
.16607 .51289 m
.16995 .60912 L
.15148 .5738 L
.15677 .49523 L
.16607 .51289 L
s
.15677 .49523 m
.15148 .5738 L
.14038 .52778 L
.15197 .47222 L
.15677 .49523 L
s
.15197 .47222 m
.14038 .52778 L
.14475 .47418 L
.15382 .44542 L
.15197 .47222 L
s
.15382 .44542 m
.14475 .47418 L
.1615 .41667 L
.1615 .41667 L
.15382 .44542 L
s
.1615 .41667 m
.1615 .41667 L
.17729 .35915 L
.17144 .38791 L
.1615 .41667 L
s
.17144 .38791 m
.17729 .35915 L
.17917 .30556 L
.17837 .36111 L
.17144 .38791 L
s
.17837 .36111 m
.17917 .30556 L
.17917 .25953 L
.17917 .3381 L
.17837 .36111 L
s
.17917 .3381 m
.17917 .25953 L
.17917 .22422 L
.17917 .32044 L
.17917 .3381 L
s
.17917 .32044 m
.17917 .22422 L
.17917 .20202 L
.17917 .30934 L
.17917 .32044 L
s
.17917 .30934 m
.17917 .20202 L
.17917 .19444 L
.17917 .30556 L
.17917 .30934 L
s
.17917 .30556 m
.17917 .19444 L
.17917 .20202 L
.17917 .30934 L
.17917 .30556 L
s
.17917 .30934 m
.17917 .20202 L
.17917 .22422 L
.17917 .32044 L
.17917 .30934 L
s
.17917 .32044 m
.17917 .22422 L
.17917 .25953 L
.17917 .3381 L
.17917 .32044 L
s
.17917 .3381 m
.17917 .25953 L
.17917 .30556 L
.17917 .36111 L
.17917 .3381 L
s
.17917 .36111 m
.17917 .30556 L
.17917 .35915 L
.17917 .38791 L
.17917 .36111 L
s
.17917 .38791 m
.17917 .35915 L
.17917 .41667 L
.17917 .41667 L
.17917 .38791 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .47418 L
.17917 .44542 L
.17917 .41667 L
s
.17917 .44542 m
.17917 .47418 L
.17917 .52778 L
.17917 .47222 L
.17917 .44542 L
s
.17917 .47222 m
.17917 .52778 L
.17917 .5738 L
.17917 .49523 L
.17917 .47222 L
s
.17917 .49523 m
.17917 .5738 L
.17917 .60912 L
.17917 .51289 L
.17917 .49523 L
s
.17917 .51289 m
.17917 .60912 L
.17917 .63132 L
.17917 .52399 L
.17917 .51289 L
s
.17917 .52399 m
.17917 .63132 L
.17917 .63889 L
.17917 .52778 L
.17917 .52399 L
s
.17917 .63889 m
.17917 .75 L
.17917 .73864 L
.17917 .63132 L
.17917 .63889 L
s
.17917 .63132 m
.17917 .73864 L
.17917 .70534 L
.16995 .60912 L
.17917 .63132 L
s
.16995 .60912 m
.17917 .70534 L
.17917 .65237 L
.15148 .5738 L
.16995 .60912 L
s
.15148 .5738 m
.17917 .65237 L
.17709 .58333 L
.14038 .52778 L
.15148 .5738 L
s
.14038 .52778 m
.17709 .58333 L
.17832 .50294 L
.14475 .47418 L
.14038 .52778 L
s
.14475 .47418 m
.17832 .50294 L
.17917 .41667 L
.1615 .41667 L
.14475 .47418 L
s
.1615 .41667 m
.17917 .41667 L
.17917 .33039 L
.17729 .35915 L
.1615 .41667 L
s
.17729 .35915 m
.17917 .33039 L
.17917 .25 L
.17917 .30556 L
.17729 .35915 L
s
.17917 .30556 m
.17917 .25 L
.17917 .18096 L
.17917 .25953 L
.17917 .30556 L
s
.17917 .25953 m
.17917 .18096 L
.17917 .12799 L
.17917 .22422 L
.17917 .25953 L
s
.17917 .22422 m
.17917 .12799 L
.17917 .09469 L
.17917 .20202 L
.17917 .22422 L
s
.17917 .20202 m
.17917 .09469 L
.17917 .08333 L
.17917 .19444 L
.17917 .20202 L
s
.17917 .19444 m
.17917 .08333 L
.17917 .09469 L
.17917 .20202 L
.17917 .19444 L
s
.17917 .20202 m
.17917 .09469 L
.17917 .12799 L
.17917 .22422 L
.17917 .20202 L
s
.17917 .22422 m
.17917 .12799 L
.17917 .18096 L
.17917 .25953 L
.17917 .22422 L
s
.17917 .25953 m
.17917 .18096 L
.17917 .25 L
.17917 .30556 L
.17917 .25953 L
s
.17917 .30556 m
.17917 .25 L
.17917 .33039 L
.17917 .35915 L
.17917 .30556 L
s
.17917 .35915 m
.17917 .33039 L
.17917 .41667 L
.17917 .41667 L
.17917 .35915 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .50294 L
.17917 .47418 L
.17917 .41667 L
s
.17917 .47418 m
.17917 .50294 L
.17917 .58333 L
.17917 .52778 L
.17917 .47418 L
s
.17917 .52778 m
.17917 .58333 L
.17917 .65237 L
.17917 .5738 L
.17917 .52778 L
s
.17917 .5738 m
.17917 .65237 L
.17917 .70534 L
.17917 .60912 L
.17917 .5738 L
s
.17917 .60912 m
.17917 .70534 L
.17917 .73864 L
.17917 .63132 L
.17917 .60912 L
s
.17917 .63132 m
.17917 .73864 L
.17917 .75 L
.17917 .63889 L
.17917 .63132 L
s
.3 .41667 m
.3 .52778 L
.3 .52399 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .52399 L
.3 .51289 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .51289 L
.3 .49523 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .49523 L
.3 .47222 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .47222 L
.3 .44542 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .44542 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .38791 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .38791 L
.3 .36111 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .36111 L
.3 .3381 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .3381 L
.3 .32044 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .32044 L
.3 .30934 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .30934 L
.3 .30556 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .30556 L
.3 .30934 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .30934 L
.3 .32044 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .32044 L
.3 .3381 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .3381 L
.3 .36111 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .36111 L
.3 .38791 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .38791 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .44542 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .44542 L
.3 .47222 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .47222 L
.3 .49523 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .49523 L
.3 .51289 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .51289 L
.3 .52399 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .52399 L
.3 .52778 L
.3 .41667 L
.3 .41667 L
s
.3 .52778 m
.3 .63889 L
.3 .63132 L
.3 .52399 L
.3 .52778 L
s
.3 .52399 m
.3 .63132 L
.3 .60912 L
.3 .51289 L
.3 .52399 L
s
.3 .51289 m
.3 .60912 L
.3 .5738 L
.3 .49523 L
.3 .51289 L
s
.3 .49523 m
.3 .5738 L
.3 .52778 L
.3 .47222 L
.3 .49523 L
s
.3 .47222 m
.3 .52778 L
.3 .47418 L
.3 .44542 L
.3 .47222 L
s
.3 .44542 m
.3 .47418 L
.3 .41667 L
.3 .41667 L
.3 .44542 L
s
.3 .41667 m
.3 .41667 L
.3 .35915 L
.3 .38791 L
.3 .41667 L
s
.3 .38791 m
.3 .35915 L
.3 .30556 L
.3 .36111 L
.3 .38791 L
s
.3 .36111 m
.3 .30556 L
.3 .25953 L
.3 .3381 L
.3 .36111 L
s
.3 .3381 m
.3 .25953 L
.3 .22422 L
.3 .32044 L
.3 .3381 L
s
.3 .32044 m
.3 .22422 L
.3 .20202 L
.3 .30934 L
.3 .32044 L
s
.3 .30934 m
.3 .20202 L
.3 .19444 L
.3 .30556 L
.3 .30934 L
s
.3 .30556 m
.3 .19444 L
.3 .20202 L
.3 .30934 L
.3 .30556 L
s
.3 .30934 m
.3 .20202 L
.3 .22422 L
.3 .32044 L
.3 .30934 L
s
.3 .32044 m
.3 .22422 L
.3 .25953 L
.3 .3381 L
.3 .32044 L
s
.3 .3381 m
.3 .25953 L
.3 .30556 L
.3 .36111 L
.3 .3381 L
s
.3 .36111 m
.3 .30556 L
.3 .35915 L
.3 .38791 L
.3 .36111 L
s
.3 .38791 m
.3 .35915 L
.3 .41667 L
.3 .41667 L
.3 .38791 L
s
.3 .41667 m
.3 .41667 L
.3 .47418 L
.3 .44542 L
.3 .41667 L
s
.3 .44542 m
.3 .47418 L
.3 .52778 L
.3 .47222 L
.3 .44542 L
s
.3 .47222 m
.3 .52778 L
.3 .5738 L
.3 .49523 L
.3 .47222 L
s
.3 .49523 m
.3 .5738 L
.3 .60912 L
.3 .51289 L
.3 .49523 L
s
.3 .51289 m
.3 .60912 L
.3 .63132 L
.3 .52399 L
.3 .51289 L
s
.3 .52399 m
.3 .63132 L
.3 .63889 L
.3 .52778 L
.3 .52399 L
s
.3 .63889 m
.3 .75 L
.3 .73864 L
.3 .63132 L
.3 .63889 L
s
.3 .63132 m
.3 .73864 L
.3 .70534 L
.3 .60912 L
.3 .63132 L
s
.3 .60912 m
.3 .70534 L
.3 .65237 L
.3 .5738 L
.3 .60912 L
s
.3 .5738 m
.3 .65237 L
.3 .58333 L
.3 .52778 L
.3 .5738 L
s
.3 .52778 m
.3 .58333 L
.3 .50294 L
.3 .47418 L
.3 .52778 L
s
.3 .47418 m
.3 .50294 L
.3 .41667 L
.3 .41667 L
.3 .47418 L
s
.3 .41667 m
.3 .41667 L
.3 .33039 L
.3 .35915 L
.3 .41667 L
s
.3 .35915 m
.3 .33039 L
.3 .25 L
.3 .30556 L
.3 .35915 L
s
.3 .30556 m
.3 .25 L
.3 .18096 L
.3 .25953 L
.3 .30556 L
s
.3 .25953 m
.3 .18096 L
.3 .12799 L
.3 .22422 L
.3 .25953 L
s
.3 .22422 m
.3 .12799 L
.3 .09469 L
.3 .20202 L
.3 .22422 L
s
.3 .20202 m
.3 .09469 L
.3 .08333 L
.3 .19444 L
.3 .20202 L
s
.3 .19444 m
.3 .08333 L
.3 .09469 L
.3 .20202 L
.3 .19444 L
s
.3 .20202 m
.3 .09469 L
.3 .12799 L
.3 .22422 L
.3 .20202 L
s
.3 .22422 m
.3 .12799 L
.3 .18096 L
.3 .25953 L
.3 .22422 L
s
.3 .25953 m
.3 .18096 L
.3 .25 L
.3 .30556 L
.3 .25953 L
s
.3 .30556 m
.3 .25 L
.3 .33039 L
.3 .35915 L
.3 .30556 L
s
.3 .35915 m
.3 .33039 L
.3 .41667 L
.3 .41667 L
.3 .35915 L
s
.3 .41667 m
.3 .41667 L
.3 .50294 L
.3 .47418 L
.3 .41667 L
s
.3 .47418 m
.3 .50294 L
.3 .58333 L
.3 .52778 L
.3 .47418 L
s
.3 .52778 m
.3 .58333 L
.3 .65237 L
.3 .5738 L
.3 .52778 L
s
.3 .5738 m
.3 .65237 L
.3 .70534 L
.3 .60912 L
.3 .5738 L
s
.3 .60912 m
.3 .70534 L
.3 .73864 L
.3 .63132 L
.3 .60912 L
s
.3 .63132 m
.3 .73864 L
.3 .75 L
.3 .63889 L
.3 .63132 L
s
.425 .41667 m
.425 .52778 L
.425 .52399 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .52399 L
.425 .51289 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .51289 L
.425 .49523 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .49523 L
.425 .47222 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .47222 L
.425 .44542 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .44542 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .38791 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .38791 L
.425 .36111 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .36111 L
.425 .3381 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .3381 L
.425 .32044 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .32044 L
.425 .30934 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .30934 L
.425 .30556 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .30556 L
.425 .30934 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .30934 L
.425 .32044 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .32044 L
.425 .3381 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .3381 L
.425 .36111 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .36111 L
.425 .38791 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .38791 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .44542 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .44542 L
.425 .47222 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .47222 L
.425 .49523 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .49523 L
.425 .51289 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .51289 L
.425 .52399 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .52399 L
.425 .52778 L
.425 .41667 L
.425 .41667 L
s
.425 .52778 m
.425 .63889 L
.425 .63132 L
.425 .52399 L
.425 .52778 L
s
.425 .52399 m
.425 .63132 L
.425 .60912 L
.425 .51289 L
.425 .52399 L
s
.425 .51289 m
.425 .60912 L
.425 .5738 L
.425 .49523 L
.425 .51289 L
s
.425 .49523 m
.425 .5738 L
.425 .52778 L
.425 .47222 L
.425 .49523 L
s
.425 .47222 m
.425 .52778 L
.425 .47418 L
.425 .44542 L
.425 .47222 L
s
.425 .44542 m
.425 .47418 L
.425 .41667 L
.425 .41667 L
.425 .44542 L
s
.425 .41667 m
.425 .41667 L
.425 .35915 L
.425 .38791 L
.425 .41667 L
s
.425 .38791 m
.425 .35915 L
.425 .30556 L
.425 .36111 L
.425 .38791 L
s
.425 .36111 m
.425 .30556 L
.425 .25953 L
.425 .3381 L
.425 .36111 L
s
.425 .3381 m
.425 .25953 L
.425 .22422 L
.425 .32044 L
.425 .3381 L
s
.425 .32044 m
.425 .22422 L
.425 .20202 L
.425 .30934 L
.425 .32044 L
s
.425 .30934 m
.425 .20202 L
.425 .19444 L
.425 .30556 L
.425 .30934 L
s
.425 .30556 m
.425 .19444 L
.425 .20202 L
.425 .30934 L
.425 .30556 L
s
.425 .30934 m
.425 .20202 L
.425 .22422 L
.425 .32044 L
.425 .30934 L
s
.425 .32044 m
.425 .22422 L
.425 .25953 L
.425 .3381 L
.425 .32044 L
s
.425 .3381 m
.425 .25953 L
.425 .30556 L
.425 .36111 L
.425 .3381 L
s
.425 .36111 m
.425 .30556 L
.425 .35915 L
.425 .38791 L
.425 .36111 L
s
.425 .38791 m
.425 .35915 L
.425 .41667 L
.425 .41667 L
.425 .38791 L
s
.425 .41667 m
.425 .41667 L
.425 .47418 L
.425 .44542 L
.425 .41667 L
s
.425 .44542 m
.425 .47418 L
.425 .52778 L
.425 .47222 L
.425 .44542 L
s
.425 .47222 m
.425 .52778 L
.425 .5738 L
.425 .49523 L
.425 .47222 L
s
.425 .49523 m
.425 .5738 L
.425 .60912 L
.425 .51289 L
.425 .49523 L
s
.425 .51289 m
.425 .60912 L
.425 .63132 L
.425 .52399 L
.425 .51289 L
s
.425 .52399 m
.425 .63132 L
.425 .63889 L
.425 .52778 L
.425 .52399 L
s
.425 .63889 m
.425 .75 L
.425 .73864 L
.425 .63132 L
.425 .63889 L
s
.425 .63132 m
.425 .73864 L
.425 .70534 L
.425 .60912 L
.425 .63132 L
s
.425 .60912 m
.425 .70534 L
.425 .65237 L
.425 .5738 L
.425 .60912 L
s
.425 .5738 m
.425 .65237 L
.425 .58333 L
.425 .52778 L
.425 .5738 L
s
.425 .52778 m
.425 .58333 L
.425 .50294 L
.425 .47418 L
.425 .52778 L
s
.425 .47418 m
.425 .50294 L
.425 .41667 L
.425 .41667 L
.425 .47418 L
s
.425 .41667 m
.425 .41667 L
.425 .33039 L
.425 .35915 L
.425 .41667 L
s
.425 .35915 m
.425 .33039 L
.425 .25 L
.425 .30556 L
.425 .35915 L
s
.425 .30556 m
.425 .25 L
.425 .18096 L
.425 .25953 L
.425 .30556 L
s
.425 .25953 m
.425 .18096 L
.425 .12799 L
.425 .22422 L
.425 .25953 L
s
.425 .22422 m
.425 .12799 L
.425 .09469 L
.425 .20202 L
.425 .22422 L
s
.425 .20202 m
.425 .09469 L
.425 .08333 L
.425 .19444 L
.425 .20202 L
s
.425 .19444 m
.425 .08333 L
.425 .09469 L
.425 .20202 L
.425 .19444 L
s
.425 .20202 m
.425 .09469 L
.425 .12799 L
.425 .22422 L
.425 .20202 L
s
.425 .22422 m
.425 .12799 L
.425 .18096 L
.425 .25953 L
.425 .22422 L
s
.425 .25953 m
.425 .18096 L
.425 .25 L
.425 .30556 L
.425 .25953 L
s
.425 .30556 m
.425 .25 L
.425 .33039 L
.425 .35915 L
.425 .30556 L
s
.425 .35915 m
.425 .33039 L
.425 .41667 L
.425 .41667 L
.425 .35915 L
s
.425 .41667 m
.425 .41667 L
.425 .50294 L
.425 .47418 L
.425 .41667 L
s
.425 .47418 m
.425 .50294 L
.425 .58333 L
.425 .52778 L
.425 .47418 L
s
.425 .52778 m
.425 .58333 L
.425 .65237 L
.425 .5738 L
.425 .52778 L
s
.425 .5738 m
.425 .65237 L
.425 .70534 L
.425 .60912 L
.425 .5738 L
s
.425 .60912 m
.425 .70534 L
.425 .73864 L
.425 .63132 L
.425 .60912 L
s
.425 .63132 m
.425 .73864 L
.425 .75 L
.425 .63889 L
.425 .63132 L
s
.001 .092 .901 r
0 .55236 m
.1322 .55409 L
s
0 0 0 r
6 Mabswid
.1322 .55409 Mdot
.001 .092 .901 r
.5 Mabswid
0 .47382 m
.1322 .47295 L
s
0 0 0 r
6 Mabswid
.1322 .47295 Mdot
.001 .092 .901 r
.5 Mabswid
0 .47382 m
.1322 .47295 L
s
0 0 0 r
6 Mabswid
.1322 .47295 Mdot
.001 .092 .901 r
.5 Mabswid
0 .60474 m
.15252 .60874 L
s
0 0 0 r
6 Mabswid
.15252 .60874 Mdot
.001 .092 .901 r
.5 Mabswid
0 .44764 m
.15252 .44564 L
s
0 0 0 r
6 Mabswid
.15252 .44564 Mdot
.001 .092 .901 r
.5 Mabswid
0 .44764 m
.15252 .44564 L
s
0 0 0 r
6 Mabswid
.15252 .44564 Mdot
.001 .092 .901 r
.5 Mabswid
0 .5 m
.12356 .5 L
s
0 0 0 r
6 Mabswid
.12356 .5 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .55409 m
.14426 .55284 L
s
0 0 0 r
6 Mabswid
.14426 .55284 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .47295 m
.14426 .47358 L
s
0 0 0 r
6 Mabswid
.14426 .47358 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .47295 m
.14426 .47358 L
s
0 0 0 r
6 Mabswid
.14426 .47358 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .60874 m
.16429 .60724 L
s
0 0 0 r
6 Mabswid
.16429 .60724 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .44564 m
.16429 .44639 L
s
0 0 0 r
6 Mabswid
.16429 .44639 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .44564 m
.16429 .44639 L
s
0 0 0 r
6 Mabswid
.16429 .44639 Mdot
.001 .092 .901 r
.5 Mabswid
.12356 .5 m
.13606 .5 L
s
0 0 0 r
6 Mabswid
.13606 .5 Mdot
.001 .092 .901 r
.5 Mabswid
.14426 .55284 m
.3 .53651 L
s
0 0 0 r
6 Mabswid
.3 .53651 Mdot
.001 .092 .901 r
.5 Mabswid
.14426 .47358 m
.3 .48174 L
s
0 0 0 r
6 Mabswid
.3 .48174 Mdot
.001 .092 .901 r
.5 Mabswid
.14426 .47358 m
.3 .48174 L
s
0 0 0 r
6 Mabswid
.3 .48174 Mdot
.001 .092 .901 r
.5 Mabswid
.16429 .60724 m
.3 .58976 L
s
0 0 0 r
6 Mabswid
.3 .58976 Mdot
.001 .092 .901 r
.5 Mabswid
.16429 .44639 m
.3 .45513 L
s
0 0 0 r
6 Mabswid
.3 .45513 Mdot
.001 .092 .901 r
.5 Mabswid
.16429 .44639 m
.3 .45513 L
s
0 0 0 r
6 Mabswid
.3 .45513 Mdot
.001 .092 .901 r
.5 Mabswid
.13606 .5 m
.3 .49996 L
s
0 0 0 r
6 Mabswid
.3 .49996 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .53651 m
.425 .52267 L
s
0 0 0 r
6 Mabswid
.425 .52267 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .48174 m
.425 .48867 L
s
0 0 0 r
6 Mabswid
.425 .48867 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .48174 m
.425 .48867 L
s
0 0 0 r
6 Mabswid
.425 .48867 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .58976 m
.425 .57274 L
s
0 0 0 r
6 Mabswid
.425 .57274 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .45513 m
.425 .46364 L
s
0 0 0 r
6 Mabswid
.425 .46364 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .45513 m
.425 .46364 L
s
0 0 0 r
6 Mabswid
.425 .46364 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .49996 m
.425 .49992 L
s
0 0 0 r
6 Mabswid
.425 .49992 Mdot
.001 .092 .901 r
.5 Mabswid
.425 .52267 m
0 0 rlineto s
.425 .52267 m
1 .42474 L
s
.425 .48867 m
0 0 rlineto s
.425 .48867 m
1 .53763 L
s
.425 .48867 m
0 0 rlineto s
.425 .48867 m
1 .53763 L
s
.425 .57274 m
0 0 rlineto s
.425 .57274 m
1 .45186 L
s
.425 .46364 m
0 0 rlineto s
.425 .46364 m
1 .52407 L
s
.425 .46364 m
0 0 rlineto s
.425 .46364 m
1 .52407 L
s
.425 .49992 m
0 0 rlineto s
.425 .49992 m
1 .49969 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[84]:=",
  ImageSize->{288, 239.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000k`P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@002md0Q42M003
4GAd021d00<AM7@087@24JEd000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M08A0W@00a5d
M00PM0034GAd021d0Q6UM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@24@9d00<AM7@0
87@00a5dM00PM08AYG@002md00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM003
4GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM003
4GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM003
4GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002id0Q42M08A8W@00a5d
M00PM0034GAd0:Ad000^M08A00Ad4A4A8W@00a5dM00PM0034GAd0:Ad000^M08A00Ad4A4A8W@00a5d
M00PM0034GAd0:Ad000]M0<A00Ad4A4A8W@00a5dM00PM0034GAd0:Ad000]M0<A00Ad4A4A8W@00a5d
M00PM0034GAd0:Ad000]M0034G@A008A00=d4G@08G@00a5dM00PM0034GAd0:Ad000]M0034G@A008A
00=d4G@08G@00a5dM00PM0034GAd0:Ad000/M08A00Id4A4AM14RM0034GAd021d00<AM7@0Y7@002ad
0Q401W@A4A5d4B9d00<AM7@087@00a5dM02TM000;7@00a5d4@024@03M14A029d00<AM7@087@00a5d
M02TM000:g@24@05M14A4G@00Q4RM0034GAd021d00<AM7@0Y7@002]d00<AM7@00Q42M08A8W@00a5d
M00PM0034GAd0:Ad000[M0034GAd008A0W@24B9d00<AM7@087@00a5dM02TM000:W@0115dM7@24@=d
00<AM7@087@00a5dM00PM0034GAd0:Ad000ZM0XA8W@00a5dM00PM08AYG@002Yd00@AM7Ad0Q42M08A
8W@00a5dM00PM0034GAd0:Ad000ZM0034GAd00<A00Ad4A4A8W@00a5dM00PM0034GAd0:1d00<C51<0
0G@002Ud00<AM7@01A400g@A4@0RM0034GAd021d00<AM7@0VW@01QPD61@H50Ad000YM0034GAd00PA
8W@00a5dM00PM0034GAd09Ad00HC51<D4a@:M000:G@0115d4G@34@04M14A4B9d00<AM7@087@00a5d
M02>M00661@H51PD47@002Ud2a4RM0034GAd021d00<AM7@0R7@01Q<D4a@C51Id000XM0`A8W@00a5d
M00PM0034GAd089d00HH51PD61@LM0005W@04a<D4a@C51<D4a@C51<D4a@C51<00Q400a@A4@064B9d
00<AM7@087@00a5dM01lM0064a@C51<D8W@0000F61@H51PD61@H51PD61@H51PD61@H519d00<AM140
11402Q@H51PD61@H51PKM0DA87@00a5dM01fM00661@H51PD:7@002Qd00<AM1402A45M00D51<D4a@C
51<D4a@C51<D4a@C51<7M0DA87@00a5dM01`M0064a@C51<D:W@00a<D4`01M0009g@24@05M14A4G@0
11400g@AM00HM00651PD61@H0a402APD61@H51PD600IM0DAJW@01A@H51PD02]d00DD61@H5004M000
9g@24@03M14A00HA00=d4G@07g@54@Id018D4a@C51<D4a@C51<D4a@C51<7M0DAI7@01Q@C51<D4bad
00@D4a@C2G@002Md2a400g@AM00OM0DA67@01Q@H51PD608A00DD61@H501MM00651PD61@H;G@01APD
61@H00ed000TM0TA00Md4A5d4G@A029d00<AM7@07g@54@0:M1<D4a@C51<D4did00HD4a@C51<^M005
51<D4a@04W@002Ad2Q401W@AM15d4B9d00<AM7@07g@54@Yd00TD61@H51PD61@0?g@01Q@H51PD631d
00@D61@H5g@0000S4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<00a402a<A4A@C51<D
4a@C00<A87@54B1d0Q4EM00:4a@C51<D4a@C52md00HD4a@C51<aM0054a@C51<06g@002Ad314047@D
61@H51PD61@H51PD61@DM0DA87@00a5dM00NM00961@H51PD61@H021d00HD61@H51PbM00551PD61@0
87@002Ad3A400g@A4@0<M00?4a@C51<D4a@C51<D4a@C00Ad1Q4OM0DA9W@02A@C51<D4a@C500AM006
51<D4a@C<g@01A<D4a@C02Ed000VM0/A00=d4A406g@01A@H51PD008A00TH51PD61@H51P06G@54Bmd
00TH51PD61@H51P00W@01Q@H51PD63Ed00@H51PD:W@002Id0Q4017@A4G@54@03M14A021d1A46M00B
51<D4a@C51<D4a@C51<D4a@C1W@64CAd00dD4a@C51<D4a@C51<D02md00DD4a@C500^M0008W@?4@03
M14A021d1A4HM00>51PD61@H514D61@H51P]M00561@H51P03G@02APD61@H51PD600QM00561@H51P0
<g@0029d2A400g@A4@034@03M14A021d1A4OM0DA0W@031@C51<D4a@C51<D4a]d00HC51<D4a@KM00:
51<D4a@C51<D4a=d00@C51<D>7@0025d2Q42M0LA7g@64Aid1Q4>M00<51PD61@H51PD61@H2G@01QPD
61@H52]d00TD61@H51PD61@01G@01A@H51PD03ad00009A<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@A51<00Q40;A@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C
50024@394a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C514D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C005d000RM0TA00=d4A400Q42M08A87@54Amd1A4GM006
61@H51PD2G@031@H51PD61@H51PD62Id00DD61@H5009M00951PD61@H51PD03Ad000TM0HA00=d4A40
0a42M08A8W@00a5dM00PM08A4g@01Q<D4a@C51]d00/D4a@C51<D4a@C500GM00451<D4aMd00TC51<D
4a@C51<0:g@002Ed00<AM7@00Q400g@A4@034@9d0Q4RM0034GAd021d00<AM7@037@01QPD61@H52ad
00`H51PD61@H51PD61@6M00561@H51P097@02A@H51PD61@H500RM0009G@00a5dM0024@9d1142M08A
8W@00a5dM00OM0DA1G@01Q<D4a@C53id00`C51<D4a@C51<D4a@/M00:4a@C51<D4a@C51Qd000TM08A
0W@24@9d1A400g@A4@0RM0034GAd01md11401QPD61@H545d00@D61@H2g@031PD61@H51PD61@H52Yd
00TH51PD61@H51P03g@002Ad0Q42M08A0W@44@04M14A4B9d00<AM7@077@021@C4A4D4a@A@G@01A<D
4a@C01]d00/C51<D4a@C51<D4`0XM00951<D4a@C51<D00Id000TM0044GAdM08A0W@0115d4A42M08A
8W@00a5dM00CM00961@H51PD61@H00=d1A4lM00551PD61@0:g@031@H51PD61@H51PD62Ed00DH51PD
6001M00097@0115dM7@24@9d00<AM1400Q400g@A4@0PM0DA2g@021<D4a@C51<D37@54CMd00DC51<D
4`0lM00<51<D4a@C51<D4a@C7g@002Ad0Q42M08A0W@0115d4A42M08A87@54@9d00TD61@H51PD61@0
5G@24CEd00@H51PDCG@031@H51PD61@H51PD61=d000UM0034GAd008A0W@0115d4A42M08A7W@02A<A
4A4C51<D4`0NM0034GAd02md00DD4a@C501MM00<51<D4a@C51<D4a@C1g@002Ed0Q401g@A4A5d4G@0
0Q42M08A5G@02A@H51PD61@H5002M0DA87@00a5dM00ZM00561@H51P0KW@01Q@H51PD605d000UM003
4G@A00<A00=d4G@00Q42M08A37@02A<D4a@C51<D4`0;M0DA87@00a5dM00VM0044a@C57Yd000TM0TA
00=d4A400W@24@=d00TD61@H51PD61@05W@00a5dM00PM0034GAd025d00DD61@H501nM00097@94@0:
M1<D4a@C51<D4amd00<AM7@087@00a5dM00LM0054a@C51<0Pg@0000S61@H51PD61@H51PD61@H51PD
61@H51PD61@H51PD61@H51P00a4021PA4A@H51PD0Q42M08A8W@00a5dM00PM0034GAd01Md00DD61@H
5028M00097@<4@9d0Q4RM0034GAd021d00<AM7@04g@011@C51>=M00097@94@03M14A009d0Q4RM003
4GAd021d00<AM7@03W@01APD61@H095d000VM0<A00Ad4A5d11400g@A4@0RM0034GAd01md1A48M005
51<D4a@0UW@002Md0Q42M0HA00=d4A408W@00a5dM00OM0DA17@011@H51RKM000:7@00a5dM0064@03
M14A029d00<AM7@07W@54@054a@C51<0Wg@002Qd00DAM7@AM0044@03M14A029d00<AM7@07G@01aPD
4A@H5140Xg@002Qd00DAM7@AM0074B9d00<AM7@05W@01a@C51<D4a@00W@54J=d000YM0034GAd00PA
87@54@md00LH51PD61@H00Yd0Q6UM000:G@00a5dM0024@04M14AM08A87@54@Qd00LD4a@C51<D015d
00<AM7@0Y7@002Ud0Q4017@A4G@24@03M14A01md1Q4027@H51PD61@H67@00a5dM02TM000:W@01A5d
M15d008A00=d4A407g@01a@A4A<D4a@07g@00a5dM02TM000:W@24@03M14A008A00=d4A405g@02A@H
51PD61@HM0054B1d00<AM7@0Y7@002Yd0Q400g@A4@054@md00PD4a@C51<D4`]d00<AM7@087@00a5d
M02TM000:W@:4@Md00PD61@H51PD61=d00<AM7@087@00a5dM02TM00001HC51<D4a@C51<D4a@C51<D
4a@C51<D57@94@0851<D4a@C51<KM0034GAd021d00<AM7@0Y7@001Id01<H51PD61@H51PD61@H51PD
61@H008A00TD614A51PD61408W@00a5dM00PM0034GAd0:Ad000ZM0XA8W@00a5dM00PM0034GAd0:Ad
000ZM0XA8W@00a5dM00PM0034GAd0:Ad000/M0PA8W@00a5dM00PM0034GAd0:Ad000/M0DA00=d4A40
8W@00a5dM00PM0034GAd0:Ad000]M0LA8W@00a5dM00PM0034GAd0:Ad000]M0074G@AM15d4@0RM003
4GAd021d00<AM7@0Y7@002ed00LAM15d4G@A029d00<AM7@087@00a5dM02TM000;G@54@03M15d025d
00<AM7@087@24JEd000^M08A00Ad4A4A8W@00a5dM00PM0034GAd0:Ad000^M08A00Ad4A4A8W@00a5d
M00PM0034GAd0:Ad000^M08A00Ad4A4A8W@00a5dM00PM0034GAd0:Ad000^M08A00Ad4G@A8W@00a5d
M00PM0034GAd0:Ad000^M08A00Ad4G@A8W@00a5dM00PM0034GAd0:Ad000^M08A00Ad4G@A8W@00a5d
M00PM0034GAd0:Ad000^M08A0W@24B9d00<AM7@087@00a5dM02TM000;W@24@9d0Q4RM0034GAd021d
00<AM7@0Y7@002id0Q42M08A8W@00a5dM00PM0034GAd0:Ad000^M08A0W@24B9d00<AM7@087@00a5d
M02TM000;W@24@9d0Q4RM0034GAd021d00<AM7@0Y7@002id0Q42M08A8W@00a5dM00PM0034GAd0:Ad
000^M08A0W@24B9d00<AM7@087@00a5dM02TM000;g@00a5dM0024B9d00<AM7@087@00a5dM02TM000
;g@00a5dM0024B9d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@24@9d00<AM7@087@00a5dM00PM08AYG@002md
00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00001\
\>"],
  ImageRangeCache->{{{0, 287}, {238.938, 0}} -> {0.239971, -0.025, 
  0.000209258, 0.000209258}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[PressureLensTraced, PlotType -> TopView, 
\tShowLabels -> False, PlotRange -> {{0.24, 0.3}, {-0.025, 0.025}},
\tRayPointSize -> 6];\
\>", "Input",
  CellLabel->"In[85]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-4 16.6667 0.416667 16.6667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
.5 g
.16667 .08333 m
.19167 .08333 L
.19167 .19444 L
.16667 .19444 L
.16667 .08333 L
F
.16667 .19444 m
.19167 .19444 L
.19167 .30556 L
.16667 .30556 L
.16667 .19444 L
F
.16667 .30556 m
.19167 .30556 L
.19167 .41667 L
.16667 .41667 L
.16667 .30556 L
F
.16667 .41667 m
.19167 .41667 L
.19167 .52778 L
.16667 .52778 L
.16667 .41667 L
F
.16667 .52778 m
.19167 .52778 L
.19167 .63889 L
.16667 .63889 L
.16667 .52778 L
F
.16667 .63889 m
.19167 .63889 L
.19167 .75 L
.16667 .75 L
.16667 .63889 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .08333 m
.16667 .19444 L
.16667 .30556 L
.16667 .41667 L
.16667 .52778 L
.16667 .63889 L
.16667 .75 L
.19167 .75 L
.19167 .63889 L
.19167 .52778 L
.19167 .41667 L
.19167 .30556 L
.19167 .19444 L
.19167 .08333 L
.16667 .08333 L
s
.5 g
.16667 .41667 m
.19167 .41667 L
.19167 .41667 L
.16667 .41667 L
.16667 .41667 L
F
.16667 .41667 m
.19167 .41667 L
.19167 .41667 L
.16667 .41667 L
.16667 .41667 L
F
.16667 .41667 m
.19167 .41667 L
.19167 .41667 L
.16667 .41667 L
.16667 .41667 L
F
.16667 .41667 m
.19167 .41667 L
.174 .41667 L
.14914 .41667 L
.16667 .41667 L
F
.14914 .41667 m
.174 .41667 L
.174 .41667 L
.14914 .41667 L
.14914 .41667 L
F
.14914 .41667 m
.174 .41667 L
.19167 .41667 L
.16667 .41667 L
.14914 .41667 L
F
0 g
.16667 .41667 m
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
.14914 .41667 L
.14914 .41667 L
.16667 .41667 L
.19167 .41667 L
.174 .41667 L
.174 .41667 L
.19167 .41667 L
.19167 .41667 L
.19167 .41667 L
.19167 .41667 L
.16667 .41667 L
s
.19167 .08333 m
.3125 .08333 L
.3125 .19444 L
.19167 .19444 L
.19167 .08333 L
s
.19167 .19444 m
.3125 .19444 L
.3125 .30556 L
.19167 .30556 L
.19167 .19444 L
s
.19167 .30556 m
.3125 .30556 L
.3125 .41667 L
.19167 .41667 L
.19167 .30556 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .52778 L
.19167 .52778 L
.19167 .41667 L
s
.19167 .52778 m
.3125 .52778 L
.3125 .63889 L
.19167 .63889 L
.19167 .52778 L
s
.19167 .63889 m
.3125 .63889 L
.3125 .75 L
.19167 .75 L
.19167 .63889 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .41667 L
.174 .41667 L
.19167 .41667 L
s
.174 .41667 m
.3125 .41667 L
.3125 .41667 L
.174 .41667 L
.174 .41667 L
s
.174 .41667 m
.3125 .41667 L
.3125 .41667 L
.19167 .41667 L
.174 .41667 L
s
.5 g
.3125 .08333 m
.4375 .08333 L
.4375 .19444 L
.3125 .19444 L
.3125 .08333 L
F
.3125 .19444 m
.4375 .19444 L
.4375 .30556 L
.3125 .30556 L
.3125 .19444 L
F
.3125 .30556 m
.4375 .30556 L
.4375 .41667 L
.3125 .41667 L
.3125 .30556 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .52778 L
.3125 .52778 L
.3125 .41667 L
F
.3125 .52778 m
.4375 .52778 L
.4375 .63889 L
.3125 .63889 L
.3125 .52778 L
F
.3125 .63889 m
.4375 .63889 L
.4375 .75 L
.3125 .75 L
.3125 .63889 L
F
0 g
.3125 .08333 m
.3125 .19444 L
.3125 .30556 L
.3125 .41667 L
.3125 .52778 L
.3125 .63889 L
.3125 .75 L
.4375 .75 L
.4375 .63889 L
.4375 .52778 L
.4375 .41667 L
.4375 .30556 L
.4375 .19444 L
.4375 .08333 L
.3125 .08333 L
s
.5 g
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
0 g
.3125 .41667 m
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
s
.16667 .41667 m
.16667 .52778 L
.16302 .52399 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16302 .52399 L
.15372 .51289 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.15372 .51289 L
.14439 .49523 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14439 .49523 L
.13957 .47222 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.13957 .47222 L
.14143 .44542 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14143 .44542 L
.14914 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14914 .41667 L
.15912 .38791 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.15912 .38791 L
.16608 .36111 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16608 .36111 L
.16667 .3381 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .3381 L
.16667 .32044 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .32044 L
.16667 .30934 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30934 L
.16667 .30556 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30556 L
.16667 .30934 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30934 L
.16667 .32044 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .32044 L
.16667 .3381 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .3381 L
.16667 .36111 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .36111 L
.16667 .38791 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .38791 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .44542 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .44542 L
.16667 .47222 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .47222 L
.16667 .49523 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .49523 L
.16667 .51289 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .51289 L
.16667 .52399 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .52399 L
.16667 .52778 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .52778 m
.16667 .63889 L
.16667 .63132 L
.16302 .52399 L
.16667 .52778 L
s
.16302 .52399 m
.16667 .63132 L
.15762 .60912 L
.15372 .51289 L
.16302 .52399 L
s
.15372 .51289 m
.15762 .60912 L
.13908 .5738 L
.14439 .49523 L
.15372 .51289 L
s
.14439 .49523 m
.13908 .5738 L
.12793 .52778 L
.13957 .47222 L
.14439 .49523 L
s
.13957 .47222 m
.12793 .52778 L
.13232 .47418 L
.14143 .44542 L
.13957 .47222 L
s
.14143 .44542 m
.13232 .47418 L
.14914 .41667 L
.14914 .41667 L
.14143 .44542 L
s
.14914 .41667 m
.14914 .41667 L
.16499 .35915 L
.15912 .38791 L
.14914 .41667 L
s
.15912 .38791 m
.16499 .35915 L
.16667 .30556 L
.16608 .36111 L
.15912 .38791 L
s
.16608 .36111 m
.16667 .30556 L
.16667 .25953 L
.16667 .3381 L
.16608 .36111 L
s
.16667 .3381 m
.16667 .25953 L
.16667 .22422 L
.16667 .32044 L
.16667 .3381 L
s
.16667 .32044 m
.16667 .22422 L
.16667 .20202 L
.16667 .30934 L
.16667 .32044 L
s
.16667 .30934 m
.16667 .20202 L
.16667 .19444 L
.16667 .30556 L
.16667 .30934 L
s
.16667 .30556 m
.16667 .19444 L
.16667 .20202 L
.16667 .30934 L
.16667 .30556 L
s
.16667 .30934 m
.16667 .20202 L
.16667 .22422 L
.16667 .32044 L
.16667 .30934 L
s
.16667 .32044 m
.16667 .22422 L
.16667 .25953 L
.16667 .3381 L
.16667 .32044 L
s
.16667 .3381 m
.16667 .25953 L
.16667 .30556 L
.16667 .36111 L
.16667 .3381 L
s
.16667 .36111 m
.16667 .30556 L
.16667 .35915 L
.16667 .38791 L
.16667 .36111 L
s
.16667 .38791 m
.16667 .35915 L
.16667 .41667 L
.16667 .41667 L
.16667 .38791 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .47418 L
.16667 .44542 L
.16667 .41667 L
s
.16667 .44542 m
.16667 .47418 L
.16667 .52778 L
.16667 .47222 L
.16667 .44542 L
s
.16667 .47222 m
.16667 .52778 L
.16667 .5738 L
.16667 .49523 L
.16667 .47222 L
s
.16667 .49523 m
.16667 .5738 L
.16667 .60912 L
.16667 .51289 L
.16667 .49523 L
s
.16667 .51289 m
.16667 .60912 L
.16667 .63132 L
.16667 .52399 L
.16667 .51289 L
s
.16667 .52399 m
.16667 .63132 L
.16667 .63889 L
.16667 .52778 L
.16667 .52399 L
s
.16667 .63889 m
.16667 .75 L
.16667 .73864 L
.16667 .63132 L
.16667 .63889 L
s
.16667 .63132 m
.16667 .73864 L
.16667 .70534 L
.15762 .60912 L
.16667 .63132 L
s
.15762 .60912 m
.16667 .70534 L
.16667 .65237 L
.13908 .5738 L
.15762 .60912 L
s
.13908 .5738 m
.16667 .65237 L
.16479 .58333 L
.12793 .52778 L
.13908 .5738 L
s
.12793 .52778 m
.16479 .58333 L
.16603 .50294 L
.13232 .47418 L
.12793 .52778 L
s
.13232 .47418 m
.16603 .50294 L
.16667 .41667 L
.14914 .41667 L
.13232 .47418 L
s
.14914 .41667 m
.16667 .41667 L
.16667 .33039 L
.16499 .35915 L
.14914 .41667 L
s
.16499 .35915 m
.16667 .33039 L
.16667 .25 L
.16667 .30556 L
.16499 .35915 L
s
.16667 .30556 m
.16667 .25 L
.16667 .18096 L
.16667 .25953 L
.16667 .30556 L
s
.16667 .25953 m
.16667 .18096 L
.16667 .12799 L
.16667 .22422 L
.16667 .25953 L
s
.16667 .22422 m
.16667 .12799 L
.16667 .09469 L
.16667 .20202 L
.16667 .22422 L
s
.16667 .20202 m
.16667 .09469 L
.16667 .08333 L
.16667 .19444 L
.16667 .20202 L
s
.16667 .19444 m
.16667 .08333 L
.16667 .09469 L
.16667 .20202 L
.16667 .19444 L
s
.16667 .20202 m
.16667 .09469 L
.16667 .12799 L
.16667 .22422 L
.16667 .20202 L
s
.16667 .22422 m
.16667 .12799 L
.16667 .18096 L
.16667 .25953 L
.16667 .22422 L
s
.16667 .25953 m
.16667 .18096 L
.16667 .25 L
.16667 .30556 L
.16667 .25953 L
s
.16667 .30556 m
.16667 .25 L
.16667 .33039 L
.16667 .35915 L
.16667 .30556 L
s
.16667 .35915 m
.16667 .33039 L
.16667 .41667 L
.16667 .41667 L
.16667 .35915 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .50294 L
.16667 .47418 L
.16667 .41667 L
s
.16667 .47418 m
.16667 .50294 L
.16667 .58333 L
.16667 .52778 L
.16667 .47418 L
s
.16667 .52778 m
.16667 .58333 L
.16667 .65237 L
.16667 .5738 L
.16667 .52778 L
s
.16667 .5738 m
.16667 .65237 L
.16667 .70534 L
.16667 .60912 L
.16667 .5738 L
s
.16667 .60912 m
.16667 .70534 L
.16667 .73864 L
.16667 .63132 L
.16667 .60912 L
s
.16667 .63132 m
.16667 .73864 L
.16667 .75 L
.16667 .63889 L
.16667 .63132 L
s
.19167 .41667 m
.19167 .52778 L
.18783 .52399 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.18783 .52399 L
.17857 .51289 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.17857 .51289 L
.16927 .49523 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16927 .49523 L
.16447 .47222 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16447 .47222 L
.16632 .44542 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16632 .44542 L
.174 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.174 .41667 L
.18394 .38791 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.18394 .38791 L
.19087 .36111 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19087 .36111 L
.19167 .3381 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .3381 L
.19167 .32044 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .32044 L
.19167 .30934 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30934 L
.19167 .30556 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30556 L
.19167 .30934 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30934 L
.19167 .32044 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .32044 L
.19167 .3381 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .3381 L
.19167 .36111 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .36111 L
.19167 .38791 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .38791 L
.19167 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .44542 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .44542 L
.19167 .47222 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .47222 L
.19167 .49523 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .49523 L
.19167 .51289 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .51289 L
.19167 .52399 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .52399 L
.19167 .52778 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .52778 m
.19167 .63889 L
.19167 .63132 L
.18783 .52399 L
.19167 .52778 L
s
.18783 .52399 m
.19167 .63132 L
.18245 .60912 L
.17857 .51289 L
.18783 .52399 L
s
.17857 .51289 m
.18245 .60912 L
.16398 .5738 L
.16927 .49523 L
.17857 .51289 L
s
.16927 .49523 m
.16398 .5738 L
.15288 .52778 L
.16447 .47222 L
.16927 .49523 L
s
.16447 .47222 m
.15288 .52778 L
.15725 .47418 L
.16632 .44542 L
.16447 .47222 L
s
.16632 .44542 m
.15725 .47418 L
.174 .41667 L
.174 .41667 L
.16632 .44542 L
s
.174 .41667 m
.174 .41667 L
.18979 .35915 L
.18394 .38791 L
.174 .41667 L
s
.18394 .38791 m
.18979 .35915 L
.19167 .30556 L
.19087 .36111 L
.18394 .38791 L
s
.19087 .36111 m
.19167 .30556 L
.19167 .25953 L
.19167 .3381 L
.19087 .36111 L
s
.19167 .3381 m
.19167 .25953 L
.19167 .22422 L
.19167 .32044 L
.19167 .3381 L
s
.19167 .32044 m
.19167 .22422 L
.19167 .20202 L
.19167 .30934 L
.19167 .32044 L
s
.19167 .30934 m
.19167 .20202 L
.19167 .19444 L
.19167 .30556 L
.19167 .30934 L
s
.19167 .30556 m
.19167 .19444 L
.19167 .20202 L
.19167 .30934 L
.19167 .30556 L
s
.19167 .30934 m
.19167 .20202 L
.19167 .22422 L
.19167 .32044 L
.19167 .30934 L
s
.19167 .32044 m
.19167 .22422 L
.19167 .25953 L
.19167 .3381 L
.19167 .32044 L
s
.19167 .3381 m
.19167 .25953 L
.19167 .30556 L
.19167 .36111 L
.19167 .3381 L
s
.19167 .36111 m
.19167 .30556 L
.19167 .35915 L
.19167 .38791 L
.19167 .36111 L
s
.19167 .38791 m
.19167 .35915 L
.19167 .41667 L
.19167 .41667 L
.19167 .38791 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .47418 L
.19167 .44542 L
.19167 .41667 L
s
.19167 .44542 m
.19167 .47418 L
.19167 .52778 L
.19167 .47222 L
.19167 .44542 L
s
.19167 .47222 m
.19167 .52778 L
.19167 .5738 L
.19167 .49523 L
.19167 .47222 L
s
.19167 .49523 m
.19167 .5738 L
.19167 .60912 L
.19167 .51289 L
.19167 .49523 L
s
.19167 .51289 m
.19167 .60912 L
.19167 .63132 L
.19167 .52399 L
.19167 .51289 L
s
.19167 .52399 m
.19167 .63132 L
.19167 .63889 L
.19167 .52778 L
.19167 .52399 L
s
.19167 .63889 m
.19167 .75 L
.19167 .73864 L
.19167 .63132 L
.19167 .63889 L
s
.19167 .63132 m
.19167 .73864 L
.19167 .70534 L
.18245 .60912 L
.19167 .63132 L
s
.18245 .60912 m
.19167 .70534 L
.19167 .65237 L
.16398 .5738 L
.18245 .60912 L
s
.16398 .5738 m
.19167 .65237 L
.18959 .58333 L
.15288 .52778 L
.16398 .5738 L
s
.15288 .52778 m
.18959 .58333 L
.19082 .50294 L
.15725 .47418 L
.15288 .52778 L
s
.15725 .47418 m
.19082 .50294 L
.19167 .41667 L
.174 .41667 L
.15725 .47418 L
s
.174 .41667 m
.19167 .41667 L
.19167 .33039 L
.18979 .35915 L
.174 .41667 L
s
.18979 .35915 m
.19167 .33039 L
.19167 .25 L
.19167 .30556 L
.18979 .35915 L
s
.19167 .30556 m
.19167 .25 L
.19167 .18096 L
.19167 .25953 L
.19167 .30556 L
s
.19167 .25953 m
.19167 .18096 L
.19167 .12799 L
.19167 .22422 L
.19167 .25953 L
s
.19167 .22422 m
.19167 .12799 L
.19167 .09469 L
.19167 .20202 L
.19167 .22422 L
s
.19167 .20202 m
.19167 .09469 L
.19167 .08333 L
.19167 .19444 L
.19167 .20202 L
s
.19167 .19444 m
.19167 .08333 L
.19167 .09469 L
.19167 .20202 L
.19167 .19444 L
s
.19167 .20202 m
.19167 .09469 L
.19167 .12799 L
.19167 .22422 L
.19167 .20202 L
s
.19167 .22422 m
.19167 .12799 L
.19167 .18096 L
.19167 .25953 L
.19167 .22422 L
s
.19167 .25953 m
.19167 .18096 L
.19167 .25 L
.19167 .30556 L
.19167 .25953 L
s
.19167 .30556 m
.19167 .25 L
.19167 .33039 L
.19167 .35915 L
.19167 .30556 L
s
.19167 .35915 m
.19167 .33039 L
.19167 .41667 L
.19167 .41667 L
.19167 .35915 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .50294 L
.19167 .47418 L
.19167 .41667 L
s
.19167 .47418 m
.19167 .50294 L
.19167 .58333 L
.19167 .52778 L
.19167 .47418 L
s
.19167 .52778 m
.19167 .58333 L
.19167 .65237 L
.19167 .5738 L
.19167 .52778 L
s
.19167 .5738 m
.19167 .65237 L
.19167 .70534 L
.19167 .60912 L
.19167 .5738 L
s
.19167 .60912 m
.19167 .70534 L
.19167 .73864 L
.19167 .63132 L
.19167 .60912 L
s
.19167 .63132 m
.19167 .73864 L
.19167 .75 L
.19167 .63889 L
.19167 .63132 L
s
.16667 .75 m
.19167 .75 L
.19167 .73864 L
.16667 .73864 L
.16667 .75 L
s
.16667 .73864 m
.19167 .73864 L
.19167 .70534 L
.16667 .70534 L
.16667 .73864 L
s
.16667 .70534 m
.19167 .70534 L
.19167 .65237 L
.16667 .65237 L
.16667 .70534 L
s
.16667 .65237 m
.19167 .65237 L
.18959 .58333 L
.16479 .58333 L
.16667 .65237 L
s
.16479 .58333 m
.18959 .58333 L
.19082 .50294 L
.16603 .50294 L
.16479 .58333 L
s
.16603 .50294 m
.19082 .50294 L
.19167 .41667 L
.16667 .41667 L
.16603 .50294 L
s
.16667 .41667 m
.19167 .41667 L
.19167 .33039 L
.16667 .33039 L
.16667 .41667 L
s
.16667 .33039 m
.19167 .33039 L
.19167 .25 L
.16667 .25 L
.16667 .33039 L
s
.16667 .25 m
.19167 .25 L
.19167 .18096 L
.16667 .18096 L
.16667 .25 L
s
.16667 .18096 m
.19167 .18096 L
.19167 .12799 L
.16667 .12799 L
.16667 .18096 L
s
.16667 .12799 m
.19167 .12799 L
.19167 .09469 L
.16667 .09469 L
.16667 .12799 L
s
.16667 .09469 m
.19167 .09469 L
.19167 .08333 L
.16667 .08333 L
.16667 .09469 L
s
.16667 .08333 m
.19167 .08333 L
.19167 .09469 L
.16667 .09469 L
.16667 .08333 L
s
.16667 .09469 m
.19167 .09469 L
.19167 .12799 L
.16667 .12799 L
.16667 .09469 L
s
.16667 .12799 m
.19167 .12799 L
.19167 .18096 L
.16667 .18096 L
.16667 .12799 L
s
.16667 .18096 m
.19167 .18096 L
.19167 .25 L
.16667 .25 L
.16667 .18096 L
s
.16667 .25 m
.19167 .25 L
.19167 .33039 L
.16667 .33039 L
.16667 .25 L
s
.16667 .33039 m
.19167 .33039 L
.19167 .41667 L
.16667 .41667 L
.16667 .33039 L
s
.16667 .41667 m
.19167 .41667 L
.19167 .50294 L
.16667 .50294 L
.16667 .41667 L
s
.16667 .50294 m
.19167 .50294 L
.19167 .58333 L
.16667 .58333 L
.16667 .50294 L
s
.16667 .58333 m
.19167 .58333 L
.19167 .65237 L
.16667 .65237 L
.16667 .58333 L
s
.16667 .65237 m
.19167 .65237 L
.19167 .70534 L
.16667 .70534 L
.16667 .65237 L
s
.16667 .70534 m
.19167 .70534 L
.19167 .73864 L
.16667 .73864 L
.16667 .70534 L
s
.16667 .73864 m
.19167 .73864 L
.19167 .75 L
.16667 .75 L
.16667 .73864 L
s
.19167 .41667 m
.19167 .52778 L
.18783 .52399 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.18783 .52399 L
.17857 .51289 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.17857 .51289 L
.16927 .49523 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16927 .49523 L
.16447 .47222 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16447 .47222 L
.16632 .44542 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16632 .44542 L
.174 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.174 .41667 L
.18394 .38791 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.18394 .38791 L
.19087 .36111 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19087 .36111 L
.19167 .3381 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .3381 L
.19167 .32044 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .32044 L
.19167 .30934 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30934 L
.19167 .30556 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30556 L
.19167 .30934 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30934 L
.19167 .32044 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .32044 L
.19167 .3381 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .3381 L
.19167 .36111 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .36111 L
.19167 .38791 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .38791 L
.19167 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .44542 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .44542 L
.19167 .47222 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .47222 L
.19167 .49523 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .49523 L
.19167 .51289 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .51289 L
.19167 .52399 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .52399 L
.19167 .52778 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .52778 m
.19167 .63889 L
.19167 .63132 L
.18783 .52399 L
.19167 .52778 L
s
.18783 .52399 m
.19167 .63132 L
.18245 .60912 L
.17857 .51289 L
.18783 .52399 L
s
.17857 .51289 m
.18245 .60912 L
.16398 .5738 L
.16927 .49523 L
.17857 .51289 L
s
.16927 .49523 m
.16398 .5738 L
.15288 .52778 L
.16447 .47222 L
.16927 .49523 L
s
.16447 .47222 m
.15288 .52778 L
.15725 .47418 L
.16632 .44542 L
.16447 .47222 L
s
.16632 .44542 m
.15725 .47418 L
.174 .41667 L
.174 .41667 L
.16632 .44542 L
s
.174 .41667 m
.174 .41667 L
.18979 .35915 L
.18394 .38791 L
.174 .41667 L
s
.18394 .38791 m
.18979 .35915 L
.19167 .30556 L
.19087 .36111 L
.18394 .38791 L
s
.19087 .36111 m
.19167 .30556 L
.19167 .25953 L
.19167 .3381 L
.19087 .36111 L
s
.19167 .3381 m
.19167 .25953 L
.19167 .22422 L
.19167 .32044 L
.19167 .3381 L
s
.19167 .32044 m
.19167 .22422 L
.19167 .20202 L
.19167 .30934 L
.19167 .32044 L
s
.19167 .30934 m
.19167 .20202 L
.19167 .19444 L
.19167 .30556 L
.19167 .30934 L
s
.19167 .30556 m
.19167 .19444 L
.19167 .20202 L
.19167 .30934 L
.19167 .30556 L
s
.19167 .30934 m
.19167 .20202 L
.19167 .22422 L
.19167 .32044 L
.19167 .30934 L
s
.19167 .32044 m
.19167 .22422 L
.19167 .25953 L
.19167 .3381 L
.19167 .32044 L
s
.19167 .3381 m
.19167 .25953 L
.19167 .30556 L
.19167 .36111 L
.19167 .3381 L
s
.19167 .36111 m
.19167 .30556 L
.19167 .35915 L
.19167 .38791 L
.19167 .36111 L
s
.19167 .38791 m
.19167 .35915 L
.19167 .41667 L
.19167 .41667 L
.19167 .38791 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .47418 L
.19167 .44542 L
.19167 .41667 L
s
.19167 .44542 m
.19167 .47418 L
.19167 .52778 L
.19167 .47222 L
.19167 .44542 L
s
.19167 .47222 m
.19167 .52778 L
.19167 .5738 L
.19167 .49523 L
.19167 .47222 L
s
.19167 .49523 m
.19167 .5738 L
.19167 .60912 L
.19167 .51289 L
.19167 .49523 L
s
.19167 .51289 m
.19167 .60912 L
.19167 .63132 L
.19167 .52399 L
.19167 .51289 L
s
.19167 .52399 m
.19167 .63132 L
.19167 .63889 L
.19167 .52778 L
.19167 .52399 L
s
.19167 .63889 m
.19167 .75 L
.19167 .73864 L
.19167 .63132 L
.19167 .63889 L
s
.19167 .63132 m
.19167 .73864 L
.19167 .70534 L
.18245 .60912 L
.19167 .63132 L
s
.18245 .60912 m
.19167 .70534 L
.19167 .65237 L
.16398 .5738 L
.18245 .60912 L
s
.16398 .5738 m
.19167 .65237 L
.18959 .58333 L
.15288 .52778 L
.16398 .5738 L
s
.15288 .52778 m
.18959 .58333 L
.19082 .50294 L
.15725 .47418 L
.15288 .52778 L
s
.15725 .47418 m
.19082 .50294 L
.19167 .41667 L
.174 .41667 L
.15725 .47418 L
s
.174 .41667 m
.19167 .41667 L
.19167 .33039 L
.18979 .35915 L
.174 .41667 L
s
.18979 .35915 m
.19167 .33039 L
.19167 .25 L
.19167 .30556 L
.18979 .35915 L
s
.19167 .30556 m
.19167 .25 L
.19167 .18096 L
.19167 .25953 L
.19167 .30556 L
s
.19167 .25953 m
.19167 .18096 L
.19167 .12799 L
.19167 .22422 L
.19167 .25953 L
s
.19167 .22422 m
.19167 .12799 L
.19167 .09469 L
.19167 .20202 L
.19167 .22422 L
s
.19167 .20202 m
.19167 .09469 L
.19167 .08333 L
.19167 .19444 L
.19167 .20202 L
s
.19167 .19444 m
.19167 .08333 L
.19167 .09469 L
.19167 .20202 L
.19167 .19444 L
s
.19167 .20202 m
.19167 .09469 L
.19167 .12799 L
.19167 .22422 L
.19167 .20202 L
s
.19167 .22422 m
.19167 .12799 L
.19167 .18096 L
.19167 .25953 L
.19167 .22422 L
s
.19167 .25953 m
.19167 .18096 L
.19167 .25 L
.19167 .30556 L
.19167 .25953 L
s
.19167 .30556 m
.19167 .25 L
.19167 .33039 L
.19167 .35915 L
.19167 .30556 L
s
.19167 .35915 m
.19167 .33039 L
.19167 .41667 L
.19167 .41667 L
.19167 .35915 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .50294 L
.19167 .47418 L
.19167 .41667 L
s
.19167 .47418 m
.19167 .50294 L
.19167 .58333 L
.19167 .52778 L
.19167 .47418 L
s
.19167 .52778 m
.19167 .58333 L
.19167 .65237 L
.19167 .5738 L
.19167 .52778 L
s
.19167 .5738 m
.19167 .65237 L
.19167 .70534 L
.19167 .60912 L
.19167 .5738 L
s
.19167 .60912 m
.19167 .70534 L
.19167 .73864 L
.19167 .63132 L
.19167 .60912 L
s
.19167 .63132 m
.19167 .73864 L
.19167 .75 L
.19167 .63889 L
.19167 .63132 L
s
.3125 .41667 m
.3125 .52778 L
.3125 .52399 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .52399 L
.3125 .51289 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .51289 L
.3125 .49523 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .49523 L
.3125 .47222 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .47222 L
.3125 .44542 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .44542 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .38791 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .38791 L
.3125 .36111 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .36111 L
.3125 .3381 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .3381 L
.3125 .32044 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .32044 L
.3125 .30934 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .30934 L
.3125 .30556 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .30556 L
.3125 .30934 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .30934 L
.3125 .32044 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .32044 L
.3125 .3381 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .3381 L
.3125 .36111 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .36111 L
.3125 .38791 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .38791 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .44542 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .44542 L
.3125 .47222 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .47222 L
.3125 .49523 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .49523 L
.3125 .51289 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .51289 L
.3125 .52399 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .52399 L
.3125 .52778 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .52778 m
.3125 .63889 L
.3125 .63132 L
.3125 .52399 L
.3125 .52778 L
s
.3125 .52399 m
.3125 .63132 L
.3125 .60912 L
.3125 .51289 L
.3125 .52399 L
s
.3125 .51289 m
.3125 .60912 L
.3125 .5738 L
.3125 .49523 L
.3125 .51289 L
s
.3125 .49523 m
.3125 .5738 L
.3125 .52778 L
.3125 .47222 L
.3125 .49523 L
s
.3125 .47222 m
.3125 .52778 L
.3125 .47418 L
.3125 .44542 L
.3125 .47222 L
s
.3125 .44542 m
.3125 .47418 L
.3125 .41667 L
.3125 .41667 L
.3125 .44542 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .35915 L
.3125 .38791 L
.3125 .41667 L
s
.3125 .38791 m
.3125 .35915 L
.3125 .30556 L
.3125 .36111 L
.3125 .38791 L
s
.3125 .36111 m
.3125 .30556 L
.3125 .25953 L
.3125 .3381 L
.3125 .36111 L
s
.3125 .3381 m
.3125 .25953 L
.3125 .22422 L
.3125 .32044 L
.3125 .3381 L
s
.3125 .32044 m
.3125 .22422 L
.3125 .20202 L
.3125 .30934 L
.3125 .32044 L
s
.3125 .30934 m
.3125 .20202 L
.3125 .19444 L
.3125 .30556 L
.3125 .30934 L
s
.3125 .30556 m
.3125 .19444 L
.3125 .20202 L
.3125 .30934 L
.3125 .30556 L
s
.3125 .30934 m
.3125 .20202 L
.3125 .22422 L
.3125 .32044 L
.3125 .30934 L
s
.3125 .32044 m
.3125 .22422 L
.3125 .25953 L
.3125 .3381 L
.3125 .32044 L
s
.3125 .3381 m
.3125 .25953 L
.3125 .30556 L
.3125 .36111 L
.3125 .3381 L
s
.3125 .36111 m
.3125 .30556 L
.3125 .35915 L
.3125 .38791 L
.3125 .36111 L
s
.3125 .38791 m
.3125 .35915 L
.3125 .41667 L
.3125 .41667 L
.3125 .38791 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .47418 L
.3125 .44542 L
.3125 .41667 L
s
.3125 .44542 m
.3125 .47418 L
.3125 .52778 L
.3125 .47222 L
.3125 .44542 L
s
.3125 .47222 m
.3125 .52778 L
.3125 .5738 L
.3125 .49523 L
.3125 .47222 L
s
.3125 .49523 m
.3125 .5738 L
.3125 .60912 L
.3125 .51289 L
.3125 .49523 L
s
.3125 .51289 m
.3125 .60912 L
.3125 .63132 L
.3125 .52399 L
.3125 .51289 L
s
.3125 .52399 m
.3125 .63132 L
.3125 .63889 L
.3125 .52778 L
.3125 .52399 L
s
.3125 .63889 m
.3125 .75 L
.3125 .73864 L
.3125 .63132 L
.3125 .63889 L
s
.3125 .63132 m
.3125 .73864 L
.3125 .70534 L
.3125 .60912 L
.3125 .63132 L
s
.3125 .60912 m
.3125 .70534 L
.3125 .65237 L
.3125 .5738 L
.3125 .60912 L
s
.3125 .5738 m
.3125 .65237 L
.3125 .58333 L
.3125 .52778 L
.3125 .5738 L
s
.3125 .52778 m
.3125 .58333 L
.3125 .50294 L
.3125 .47418 L
.3125 .52778 L
s
.3125 .47418 m
.3125 .50294 L
.3125 .41667 L
.3125 .41667 L
.3125 .47418 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .33039 L
.3125 .35915 L
.3125 .41667 L
s
.3125 .35915 m
.3125 .33039 L
.3125 .25 L
.3125 .30556 L
.3125 .35915 L
s
.3125 .30556 m
.3125 .25 L
.3125 .18096 L
.3125 .25953 L
.3125 .30556 L
s
.3125 .25953 m
.3125 .18096 L
.3125 .12799 L
.3125 .22422 L
.3125 .25953 L
s
.3125 .22422 m
.3125 .12799 L
.3125 .09469 L
.3125 .20202 L
.3125 .22422 L
s
.3125 .20202 m
.3125 .09469 L
.3125 .08333 L
.3125 .19444 L
.3125 .20202 L
s
.3125 .19444 m
.3125 .08333 L
.3125 .09469 L
.3125 .20202 L
.3125 .19444 L
s
.3125 .20202 m
.3125 .09469 L
.3125 .12799 L
.3125 .22422 L
.3125 .20202 L
s
.3125 .22422 m
.3125 .12799 L
.3125 .18096 L
.3125 .25953 L
.3125 .22422 L
s
.3125 .25953 m
.3125 .18096 L
.3125 .25 L
.3125 .30556 L
.3125 .25953 L
s
.3125 .30556 m
.3125 .25 L
.3125 .33039 L
.3125 .35915 L
.3125 .30556 L
s
.3125 .35915 m
.3125 .33039 L
.3125 .41667 L
.3125 .41667 L
.3125 .35915 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .50294 L
.3125 .47418 L
.3125 .41667 L
s
.3125 .47418 m
.3125 .50294 L
.3125 .58333 L
.3125 .52778 L
.3125 .47418 L
s
.3125 .52778 m
.3125 .58333 L
.3125 .65237 L
.3125 .5738 L
.3125 .52778 L
s
.3125 .5738 m
.3125 .65237 L
.3125 .70534 L
.3125 .60912 L
.3125 .5738 L
s
.3125 .60912 m
.3125 .70534 L
.3125 .73864 L
.3125 .63132 L
.3125 .60912 L
s
.3125 .63132 m
.3125 .73864 L
.3125 .75 L
.3125 .63889 L
.3125 .63132 L
s
.19167 .75 m
.3125 .75 L
.3125 .73864 L
.19167 .73864 L
.19167 .75 L
s
.19167 .73864 m
.3125 .73864 L
.3125 .70534 L
.19167 .70534 L
.19167 .73864 L
s
.19167 .70534 m
.3125 .70534 L
.3125 .65237 L
.19167 .65237 L
.19167 .70534 L
s
.19167 .65237 m
.3125 .65237 L
.3125 .58333 L
.18959 .58333 L
.19167 .65237 L
s
.18959 .58333 m
.3125 .58333 L
.3125 .50294 L
.19082 .50294 L
.18959 .58333 L
s
.19082 .50294 m
.3125 .50294 L
.3125 .41667 L
.19167 .41667 L
.19082 .50294 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .33039 L
.19167 .33039 L
.19167 .41667 L
s
.19167 .33039 m
.3125 .33039 L
.3125 .25 L
.19167 .25 L
.19167 .33039 L
s
.19167 .25 m
.3125 .25 L
.3125 .18096 L
.19167 .18096 L
.19167 .25 L
s
.19167 .18096 m
.3125 .18096 L
.3125 .12799 L
.19167 .12799 L
.19167 .18096 L
s
.19167 .12799 m
.3125 .12799 L
.3125 .09469 L
.19167 .09469 L
.19167 .12799 L
s
.19167 .09469 m
.3125 .09469 L
.3125 .08333 L
.19167 .08333 L
.19167 .09469 L
s
.19167 .08333 m
.3125 .08333 L
.3125 .09469 L
.19167 .09469 L
.19167 .08333 L
s
.19167 .09469 m
.3125 .09469 L
.3125 .12799 L
.19167 .12799 L
.19167 .09469 L
s
.19167 .12799 m
.3125 .12799 L
.3125 .18096 L
.19167 .18096 L
.19167 .12799 L
s
.19167 .18096 m
.3125 .18096 L
.3125 .25 L
.19167 .25 L
.19167 .18096 L
s
.19167 .25 m
.3125 .25 L
.3125 .33039 L
.19167 .33039 L
.19167 .25 L
s
.19167 .33039 m
.3125 .33039 L
.3125 .41667 L
.19167 .41667 L
.19167 .33039 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .50294 L
.19167 .50294 L
.19167 .41667 L
s
.19167 .50294 m
.3125 .50294 L
.3125 .58333 L
.19167 .58333 L
.19167 .50294 L
s
.19167 .58333 m
.3125 .58333 L
.3125 .65237 L
.19167 .65237 L
.19167 .58333 L
s
.19167 .65237 m
.3125 .65237 L
.3125 .70534 L
.19167 .70534 L
.19167 .65237 L
s
.19167 .70534 m
.3125 .70534 L
.3125 .73864 L
.19167 .73864 L
.19167 .70534 L
s
.19167 .73864 m
.3125 .73864 L
.3125 .75 L
.19167 .75 L
.19167 .73864 L
s
.3125 .75 m
.4375 .75 L
.4375 .73864 L
.3125 .73864 L
.3125 .75 L
s
.3125 .73864 m
.4375 .73864 L
.4375 .70534 L
.3125 .70534 L
.3125 .73864 L
s
.3125 .70534 m
.4375 .70534 L
.4375 .65237 L
.3125 .65237 L
.3125 .70534 L
s
.3125 .65237 m
.4375 .65237 L
.4375 .58333 L
.3125 .58333 L
.3125 .65237 L
s
.3125 .58333 m
.4375 .58333 L
.4375 .50294 L
.3125 .50294 L
.3125 .58333 L
s
.3125 .50294 m
.4375 .50294 L
.4375 .41667 L
.3125 .41667 L
.3125 .50294 L
s
.3125 .41667 m
.4375 .41667 L
.4375 .33039 L
.3125 .33039 L
.3125 .41667 L
s
.3125 .33039 m
.4375 .33039 L
.4375 .25 L
.3125 .25 L
.3125 .33039 L
s
.3125 .25 m
.4375 .25 L
.4375 .18096 L
.3125 .18096 L
.3125 .25 L
s
.3125 .18096 m
.4375 .18096 L
.4375 .12799 L
.3125 .12799 L
.3125 .18096 L
s
.3125 .12799 m
.4375 .12799 L
.4375 .09469 L
.3125 .09469 L
.3125 .12799 L
s
.3125 .09469 m
.4375 .09469 L
.4375 .08333 L
.3125 .08333 L
.3125 .09469 L
s
.3125 .08333 m
.4375 .08333 L
.4375 .09469 L
.3125 .09469 L
.3125 .08333 L
s
.3125 .09469 m
.4375 .09469 L
.4375 .12799 L
.3125 .12799 L
.3125 .09469 L
s
.3125 .12799 m
.4375 .12799 L
.4375 .18096 L
.3125 .18096 L
.3125 .12799 L
s
.3125 .18096 m
.4375 .18096 L
.4375 .25 L
.3125 .25 L
.3125 .18096 L
s
.3125 .25 m
.4375 .25 L
.4375 .33039 L
.3125 .33039 L
.3125 .25 L
s
.3125 .33039 m
.4375 .33039 L
.4375 .41667 L
.3125 .41667 L
.3125 .33039 L
s
.3125 .41667 m
.4375 .41667 L
.4375 .50294 L
.3125 .50294 L
.3125 .41667 L
s
.3125 .50294 m
.4375 .50294 L
.4375 .58333 L
.3125 .58333 L
.3125 .50294 L
s
.3125 .58333 m
.4375 .58333 L
.4375 .65237 L
.3125 .65237 L
.3125 .58333 L
s
.3125 .65237 m
.4375 .65237 L
.4375 .70534 L
.3125 .70534 L
.3125 .65237 L
s
.3125 .70534 m
.4375 .70534 L
.4375 .73864 L
.3125 .73864 L
.3125 .70534 L
s
.3125 .73864 m
.4375 .73864 L
.4375 .75 L
.3125 .75 L
.3125 .73864 L
s
.001 .092 .901 r
0 .55236 m
.1322 .55409 L
s
0 0 0 r
6 Mabswid
.1322 .55409 Mdot
.001 .092 .901 r
.5 Mabswid
0 .47382 m
.1322 .47295 L
s
0 0 0 r
6 Mabswid
.1322 .47295 Mdot
.001 .092 .901 r
.5 Mabswid
0 .47382 m
.1322 .47295 L
s
0 0 0 r
6 Mabswid
.1322 .47295 Mdot
.001 .092 .901 r
.5 Mabswid
0 .60474 m
.15252 .60874 L
s
0 0 0 r
6 Mabswid
.15252 .60874 Mdot
.001 .092 .901 r
.5 Mabswid
0 .44764 m
.15252 .44564 L
s
0 0 0 r
6 Mabswid
.15252 .44564 Mdot
.001 .092 .901 r
.5 Mabswid
0 .44764 m
.15252 .44564 L
s
0 0 0 r
6 Mabswid
.15252 .44564 Mdot
.001 .092 .901 r
.5 Mabswid
0 .5 m
.12356 .5 L
s
0 0 0 r
6 Mabswid
.12356 .5 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .55409 m
.15639 .55159 L
s
0 0 0 r
6 Mabswid
.15639 .55159 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .47295 m
.15639 .47421 L
s
0 0 0 r
6 Mabswid
.15639 .47421 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .47295 m
.15639 .47421 L
s
0 0 0 r
6 Mabswid
.15639 .47421 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .60874 m
.1762 .60572 L
s
0 0 0 r
6 Mabswid
.1762 .60572 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .44564 m
.1762 .44715 L
s
0 0 0 r
6 Mabswid
.1762 .44715 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .44564 m
.1762 .44715 L
s
0 0 0 r
6 Mabswid
.1762 .44715 Mdot
.001 .092 .901 r
.5 Mabswid
.12356 .5 m
.14856 .49999 L
s
0 0 0 r
6 Mabswid
.14856 .49999 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .55159 m
.15639 .55159 L
s
0 0 0 r
6 Mabswid
.15639 .55159 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .47421 m
.15639 .47421 L
s
0 0 0 r
6 Mabswid
.15639 .47421 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .47421 m
.15639 .47421 L
s
0 0 0 r
6 Mabswid
.15639 .47421 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .60572 m
.1762 .60572 L
s
0 0 0 r
6 Mabswid
.1762 .60572 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .44715 m
.1762 .44715 L
s
0 0 0 r
6 Mabswid
.1762 .44715 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .44715 m
.1762 .44715 L
s
0 0 0 r
6 Mabswid
.1762 .44715 Mdot
.001 .092 .901 r
.5 Mabswid
.14856 .49999 m
.14856 .49999 L
s
0 0 0 r
6 Mabswid
.14856 .49999 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .55159 m
.3125 .53522 L
s
0 0 0 r
6 Mabswid
.3125 .53522 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .47421 m
.3125 .48239 L
s
0 0 0 r
6 Mabswid
.3125 .48239 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .47421 m
.3125 .48239 L
s
0 0 0 r
6 Mabswid
.3125 .48239 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .60572 m
.3125 .58816 L
s
0 0 0 r
6 Mabswid
.3125 .58816 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .44715 m
.3125 .45593 L
s
0 0 0 r
6 Mabswid
.3125 .45593 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .44715 m
.3125 .45593 L
s
0 0 0 r
6 Mabswid
.3125 .45593 Mdot
.001 .092 .901 r
.5 Mabswid
.14856 .49999 m
.3125 .49995 L
s
0 0 0 r
6 Mabswid
.3125 .49995 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .53522 m
.3125 .53522 L
s
0 0 0 r
6 Mabswid
.3125 .53522 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .48239 m
.3125 .48239 L
s
0 0 0 r
6 Mabswid
.3125 .48239 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .48239 m
.3125 .48239 L
s
0 0 0 r
6 Mabswid
.3125 .48239 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .58816 m
.3125 .58816 L
s
0 0 0 r
6 Mabswid
.3125 .58816 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .45593 m
.3125 .45593 L
s
0 0 0 r
6 Mabswid
.3125 .45593 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .45593 m
.3125 .45593 L
s
0 0 0 r
6 Mabswid
.3125 .45593 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .49995 m
.3125 .49995 L
s
0 0 0 r
6 Mabswid
.3125 .49995 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .53522 m
.4375 .52138 L
s
0 0 0 r
6 Mabswid
.4375 .52138 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .48239 m
.4375 .48931 L
s
0 0 0 r
6 Mabswid
.4375 .48931 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .48239 m
.4375 .48931 L
s
0 0 0 r
6 Mabswid
.4375 .48931 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .58816 m
.4375 .57115 L
s
0 0 0 r
6 Mabswid
.4375 .57115 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .45593 m
.4375 .46443 L
s
0 0 0 r
6 Mabswid
.4375 .46443 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .45593 m
.4375 .46443 L
s
0 0 0 r
6 Mabswid
.4375 .46443 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .49995 m
.4375 .49992 L
s
0 0 0 r
6 Mabswid
.4375 .49992 Mdot
.001 .092 .901 r
.5 Mabswid
.4375 .52138 m
0 0 rlineto s
.4375 .52138 m
1 .42562 L
s
.4375 .48931 m
0 0 rlineto s
.4375 .48931 m
1 .53719 L
s
.4375 .48931 m
0 0 rlineto s
.4375 .48931 m
1 .53719 L
s
.4375 .57115 m
0 0 rlineto s
.4375 .57115 m
1 .45288 L
s
.4375 .46443 m
0 0 rlineto s
.4375 .46443 m
1 .52356 L
s
.4375 .46443 m
0 0 rlineto s
.4375 .46443 m
1 .52356 L
s
.4375 .49992 m
0 0 rlineto s
.4375 .49992 m
1 .49969 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 239.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000k`P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@002mdCa6RM000
;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000
;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000
;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000
;gA?4J9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d8A0:9d000_M4lAXW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002mdCa6RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02152@d93@T=28a409493@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=24J9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M4lAXW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00PA@T=2@d93@R<A02A2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@Q6RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM000;gA?4J9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000_M0074D93@T=2@`024B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000_M0074D93@T=2@`024B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000_M0074D93@T=2@`024B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000_M0074D93@T=2@`024B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000^M08A00I2@d93@T<24B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000^M08A00E3@T=2@`034B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000^M08A00E2@d93@P034B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000]M0<A00E3@T=2@`034B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000]M0<A00E2@d93@P034B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000]M0094G@A@d93@Q52008A8G@09A53@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002ed00TAM152@d934D<00Q4QM00U4D93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;7@24@0:M153@T=24D934B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000/M08A00Id4D93@T<24@03@Q5d021d
02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000/M00<4G@A4D=2@a534D<A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002]d0Q402g@A4D93@Q52
4D8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000[M0034GAd008A
00I3@T<A@d824B5d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000[M003
4GAd008A00I2@d8A@T<24B5d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d
000ZM0034GAd009d00TA@d8A@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@a40XW@002YdE16RM000:W@0115dM7@24@06@d8A@T=20Q4QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000:W@00a5dM0034@05@Q52@d800a4QM00U4D93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000:G@01A5dM15d008A00I34D=24D824B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A09id00<H51P00G@002Ud00<AM7@011401D8A
@Q5200<A8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40V7@01Q<D4a@C50Ad
000YM0044G@AM0HA00=2@a400Q4QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
4@2BM00661@H51PD2W@002Ud3a4QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
4@2<M0064a@C51<D47@002Qd414QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
4@26M00661@H51PD5W@001Id01<C51<D4a@C51<D4a@C51<D4a@C008A00@D4a@C2A4QM00U4D93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@20M0064a@C51<D77@0000F61@H51PD61@H51PD
61@H51PD61@H519d00<AM14011403A@H4APD61@H51PD61@077@54@0Q@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A07Yd00HH51PD61@RM000:7@00a5d4@054@03@Q4A00DA17@051<D4a@C51<D
4a@C51<D4a@C51<D27@54@0Q@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A07Ad00HC51<D
4a@TM0034a@C005d000WM08A00Ed4G@AM0024@03@d8A00DA67@01aPD61@H51P00Q408a@H51PD6493
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=200DAJg@01QPD61@H52Ed00DD61@H5004M0009g@24@05
M15d4G@00Q401D8A@Q5200<A87@54@0O@d8D4a@C51<D4a@C51=3@T=2@d93@T=2@d93@T=2@`054FEd
00HC51<D4a@WM00451<D4`Ud000WM0<A0W@02A5d4A534D<A@`034B1d1A407T93@T=2@d93@T=2@d93
51PD61@H51PD61@H@T=2@`HAGg@01QPD61@H52Qd00DH51PD600=M00097@64@03M14A00@A00A3@Q52
0a4QM08A02M3@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=251<D4a@A51<D4a@0F7@01Q<D4a@C52Ud
00DD4a@C500BM00097@54@9d1Q40148A@T<34B5d02<A@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@P054@0;M1PD61@H51PD61@0B7@01QPD61@H52Yd00DH51PD600GM00002<C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4`034@044a@CM0HA00E2@a53@P034B1d1A4084=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=20Q4=M0094a@C51<D4a@C03Ud00HC51<D4a@/M0044a@C51ad
000TM0DA00lD614H51PD61@H51PD61@087@54@0Q@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A01Md00XD61@H51PD61@H:G@01QPD61@H52ed00DD61@H500PM00097@54@03M14A00@A00I2@a53
4D<24@0F4a@C51<D4a@C51<D4a@C51<D4a@C50Ud1Q407d=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T<01A4NM00951<D4a@C51<D01Yd00HC51<D4a@^M0054a@C51<09G@002Id0a4017@AM7@34@06
@a53@Q520Q4FM00^61@H51PD61@H514D61@H51PD61A3@T=2@d93@T=2@d93@T=2@d93@T=2@d93@PDA
9g@02QPD61@H51PD61@:M00661@H51PD<7@011PD61@ZM0009W@24@03M14A009d1A4014934D<24B1d
1A407T=2@d934a@C51<D4a@C51<D4a@C51<D@T=2@d93@PHA<G@02Q<D4a@C51<D4a@aM00551<D4a@0
;W@0029d1Q400g@A4@084@03@Q52008A87@54@0V@T=2@d93@T=2@d93@T=2@d93@T=2@d8H51PD61@H
514D61@H51P]M00661@H51PD1G@02Q@H51PD61@H51PSM00561@H51P0<g@0029d1Q400g@A4@064@05
@d8A4D<00Q4PM0DA01m3@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d9300DA0W@031@C51<D4a@C
51<D4a]d00HC51<D4a@EM00951<D4a@C51<D01Ed00DD4a@C500hM0008G@64@03M14A00LA00E2@d8A
@P024Amd1Q407T93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@`HA3W@02a@H51PD61@H51PD00Yd
00HH51PD61@TM00961@H51PD61@H00Qd00@D61@H?G@0003o4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C514D4a@C51<A4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C514D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C514D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C000P4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@1M0008W@54@9dF14GM00661@H51PD27@02aPD61@H51PD
61@H02Ad00DD61@H5007M00951PD61@H51PD03Id000TM0<A0W@00a5d4@054@04@a4A@P<A8G@24@0R
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@P8A4g@01Q<D4a@C51Ud00`D4a@C51<D4a@C
51<CM0054a@C51<05G@02Q<D4a@C51<D4a@/M0009G@01Q5dM7@AM08A00Ed4A4A@P024@04@a4A4B5d
02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A00id00HH51PD61@[M00;51PD61@H
51PD61@017@011PD61@TM00961@H51PD61@H02=d000UM0054GAdM1400W@00a5d4@024@04@d8A@P<A
8G@08a52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d9300DA1G@01Q<D4a@C53]d00dD4a@C
51<D4a@C51<D02Ud00XD4a@C51<D4a@C6G@002Ad0Q43M0034G@A00DA00=2@a40114QM00S4D=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8011401QPD61@H53ad00DH51PD600=M00;61@H51PD
61@H51P0:7@02A@H51PD61@H500@M00097@24@=d00<AM1401A400d=24@044B5d028A@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q@C0Q4011@C514lM00551<D4a@07G@031@C51<D4a@C51<D4bEd
00XC51<D4a@C51<D1W@002Ad00<AM7@00W@01A5d4A5d00<A00A2@a530a4QM00S4D=2@d93@T=2@d93
@T=2@d93@T=2@d8H51PD61@H51Q2@d801A4hM00451PD62id00/D61@H51PD61@H500TM00561@H51P0
0G@002Ad00<AM7@00W@01A5d4A5d00<A00A3@Q52:1407d=2@d93@T=2@d8D4a@C51<D4aA2@d93@T=2
@d93@T<01A4cM0054a@C51<0?G@031<D4a@C51<D4a@C51id000TM08A0g@01A5d4A5d00<A00A2@a53
0a4PM0DA021261@H51PD61@H@T=2@d93@T=2@d93@T=2@d93@T=2@`8A<7@01A@H51PD04id00/H51PD
61@H51PD600CM0009G@01A5dM7@A009d00<AM1400Q4014=24D834Aed02TD4a4A51<D4aA2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=24@0/M0054a@C51<0GW@031@C51<D4a@C51<D4`Md000UM08A
00=d4G@00W@44@05@d934D<00a4DM00961@H51PD61@H00=d1A408D93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d934@0XM00461@H56md00HD61@H51P1M0009G@0115d4A42M0DA00E2@d8A@P034@]d
00TD4a@C51<D4a@037@54@0Q@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A02=d00DD4a@C
501jM00097@54@9d1A401D=2@a5300<A0W@02APD61@H51PD600FM08A02=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@0NM00561@H51P0Og@002Ad1A400g@A4@044@0:@Q@C51<D4a@C51md
02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A01Yd00@C51<DQ7@0000S61@H51PD
61@H51PD61@H51PD61@H51PD61@H51PD61@H51P00a4041PD61@H4APD61@H@T<A@d824B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A01Ed00DD61@H5028M00097@64@03M14A00@A
00E3@Q52@`024B5d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A011d00DC51<D
4`2=M00097@54@03M15d00@A00I34D<A@d824B5d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T<A00]d00DD61@H502BM0009W@34@9d00<AM1400Q401T934D<A@`8A8G@08a52@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d9300DA17@011@C51>GM0009g@24@=d11400d=2@`024@03
@Q4A025d02<A@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@P044@0561@H51P0Vg@002Qd
00@AM7Ad11400d93@P024@03@a4A025d028A@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<C
0Q4011@C516OM000:7@00a5dM002M0<A00I3@T=24D824B5d02<A@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@a@H51PD61A3@P054Imd000XM0034GAd009d0a401493@T<44B5d02<A@T=2@d93@T=2@d93@T=2
@d8D4a@C51<D4d=2@d93@T=2@`054Imd000YM0044GAdM0@A00=2@d80114PM0DA0212@d93@T=261@H
51PD6493@T=2@d93@T=2@d93@T=2@`8AXG@002Ud00HAM7Ad4G@^4@0751<D4a@C500J4J9d000YM08A
0W@00a5d4@024@04@d8A@P8A7W@0:1PA4A@H51Q2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@a6RM000:W@0315dM15d4D8A@T<A@`8A5W@021<D4a@C51<D0W@54@0Q@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000ZM08A00Ed4G@A@`024@03@Q52008A3W@021PD61@H51PD2W@54@0Q
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000ZM08A00Ed4G@A@P074@Id00PC51<D
4a@C51=d0Q408d=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000ZM0HA00=34A40
0a4021PD61@H51PD6g@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@0000F
4a@C51<D4a@C51<D4a@C51<D4a@C51Ad1A401a@A4A<D4a@00Q4QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM0005W@04aPD61@H51PD61@H51PD61@H51P00Q401Q@H51PA@`LA
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002Yd1Q400d8A4@054B5d
02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000ZM0HA00=3@T<01A4QM00U
4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;7@44@04@T=2@`@A8G@09A52
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002ad11401T=2@d8A@P8A8G@09A53
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002ed0a401493@T<44B5d02DA@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000]M00;4G@A@d93@T<A@a408G@09A53
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002ed00/AM152@d93@Q524@0QM00U
4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;G@34@08@d93@T<A@a4QM00U
4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;W@24@05@T=2@d809A409493
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24J9d000^M08A00E3@T=2@`034B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000^M08A00E2@d93@P034B5d02DA@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000^M08A00Q3@T=2@a534B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000^M50AXW@002id0Q4024=2@d934D<A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002id0Q401T93@T=2@`8A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002id0Q401T=2@d93@P8A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002id0Q401T93@T=2@`8A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002id0Q401T=2@d93@P8A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002id0Q401T93@T=2@`8A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002id0Q401T=2@d93@P8A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002id0Q401T93@T=2@`8A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00LA@d93@T=2008A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00LA@T=2@d93008A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a40
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q40
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a40
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q40
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002mdCa6RM000;g@02A52
@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53
@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52
@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53
@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52
@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53
@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52
@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53
@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;gA?4J9d
000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d
000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d
000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d
000_M4lAXW@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00001\
\>"],
  ImageRangeCache->{{{0, 287}, {238.938, 0}} -> {0.239971, -0.025, 
  0.000209258, 0.000209258}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1002, 683},
WindowMargins->{{25, Automatic}, {Automatic, 67}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 42, 0, 81, "Chapter"],
Cell[1821, 55, 755, 13, 128, "Text"],
Cell[2579, 70, 133, 4, 45, "Input"],
Cell[2715, 76, 110, 4, 45, "Input"],

Cell[CellGroupData[{
Cell[2850, 84, 74, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[2949, 88, 56, 0, 24, "SubsubsectionIcon"],
Cell[3008, 90, 118, 3, 24, "Text"],
Cell[3129, 95, 307, 8, 113, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3473, 108, 74, 0, 20, "SubsubsectionIcon"],
Cell[3550, 110, 198, 4, 40, "Text"],
Cell[3751, 116, 180, 8, 113, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3968, 129, 64, 0, 20, "SubsubsectionIcon"],
Cell[4035, 131, 95, 3, 24, "Text"],
Cell[4133, 136, 140, 7, 96, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4310, 148, 91, 1, 20, "SubsubsectionIcon"],
Cell[4404, 151, 118, 3, 24, "Text"],
Cell[4525, 156, 321, 9, 130, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4895, 171, 112, 4, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[5032, 179, 35, 0, 24, "SubsubsectionIcon"],
Cell[5070, 181, 156, 3, 40, "Text"],
Cell[5229, 186, 106, 4, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5372, 195, 43, 0, 20, "SubsubsectionIcon"],
Cell[5418, 197, 119, 3, 24, "Text"],
Cell[5540, 202, 300, 7, 96, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5877, 214, 44, 0, 20, "SubsubsectionIcon"],
Cell[5924, 216, 75, 0, 24, "Text"],
Cell[6002, 218, 212, 6, 62, "Input"],
Cell[6217, 226, 115, 3, 24, "Text"],
Cell[6335, 231, 209, 6, 79, "Input"],
Cell[6547, 239, 124, 5, 24, "Text"],
Cell[6674, 246, 285, 7, 96, "Input"],
Cell[6962, 255, 310, 5, 40, "Text"],
Cell[7275, 262, 118, 5, 62, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7430, 272, 42, 0, 20, "SubsubsectionIcon"],
Cell[7475, 274, 247, 6, 24, "Text"],
Cell[7725, 282, 1021, 32, 521, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8783, 319, 35, 0, 20, "SubsubsectionIcon"],
Cell[8821, 321, 306, 7, 40, "Text"],
Cell[9130, 330, 642, 21, 334, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9821, 357, 55, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[9901, 361, 34, 0, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[9960, 365, 98, 1, 28, "Input"],
Cell[10061, 368, 56753, 2475, 269, 37794, 2236, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[66863, 2849, 59, 0, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[66947, 2853, 467, 14, 198, "Input"],
Cell[67417, 2869, 57814, 3488, 150, 44971, 3324, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[125280, 6363, 44, 0, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[125349, 6367, 79, 1, 28, "Input"],
Cell[125431, 6370, 77201, 3340, 294, 46108, 2951, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[202669, 9715, 79, 1, 28, "Input"],
Cell[202751, 9718, 80070, 3519, 294, 45877, 3092, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[282882, 13244, 33, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[282940, 13248, 44, 0, 24, "SubsubsectionIcon"],
Cell[282987, 13250, 73, 0, 24, "Text"],
Cell[283063, 13252, 437, 13, 198, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[283537, 13270, 43, 0, 20, "SubsubsectionIcon"],
Cell[283583, 13272, 48, 0, 24, "Text"],
Cell[283634, 13274, 351, 12, 164, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[284022, 13291, 38, 0, 20, "SubsubsectionIcon"],
Cell[284063, 13293, 813, 23, 368, "Input"],
Cell[284879, 13318, 237, 6, 62, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[285165, 13330, 34, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[285224, 13334, 85, 1, 28, "Input"],
Cell[285312, 13337, 57692, 3373, 145, 49492, 3267, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[343041, 16715, 93, 1, 28, "Input"],
Cell[343137, 16718, 56897, 3481, 145, 48838, 3376, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[400071, 20204, 200, 5, 62, "Input"],
Cell[400274, 20211, 40520, 2469, 246, 28437, 2315, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[440831, 22685, 192, 5, 62, "Input"],
Cell[441026, 22692, 56525, 3098, 246, 37500, 2858, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

