(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    518757,      16202]*)
(*NotebookOutlinePosition[    519960,      16239]*)
(*  CellTagsIndexPosition[    519824,      16232]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Definition of a Symmetric Transmission Hologram (without \
refraction)\
\>", "ExampleSection"],

Cell[CellGroupData[{

Cell["Source", "ExampleSubsection"],

Cell["\<\
First we define the light source. To suppress the effect of \
refraction, we set the intrinsic medium to the same figure we use for the \
grating medium. The Birthpoint is placed to hit the grating at the origin \
with an angle of 30 degree.\
\>", "ExampleText",
  FormatType->InputForm],

Cell["wavelength = 0.5;", "Input",
  CellLabel->"In[3]:="],

Cell["\<\
lightsource = WedgeOfRays[
\t2,
\tNumberOfRays -> 30,
\tIntrinsicMedium -> 1.52,
\tWaveLength -> wavelength,
\tPolarization -> {1,0,0},
\tBirthPoint -> {-10.,-10.*Tan[30*Degree],0}
];\
\>", "Input",
  CellLabel->"In[4]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get Best Grating Thickness", "ExampleSubsection"],

Cell[CellGroupData[{

Cell["\<\
Block[{gratingstrength, n1, d, wavelength, recangle, sigangle},
gratingstrength = Pi*n1*d/wavelength/Sqrt[Cos[recangle]*Cos[sigangle]];
d = d/.Solve[gratingstrength==Pi/2, d][[1]];
recangle=30*Degree;
sigangle=30*Degree;
n1=0.02;
wavelength=0.5;
Print[\"grating thickness in microns for full efficiency: \",d];
Print[\"gratingstrength/Pi: \",gratingstrength/Pi];
]\
\>", "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    InterpretationBox[\("grating thickness in microns for full efficiency: "\
\[InvisibleSpace]10.825317547305483`\),
      SequenceForm[ 
      "grating thickness in microns for full efficiency: ", 
        10.825317547305483],
      Editable->False]], "Print",
  CellLabel->"From In[5]:="],

Cell[BoxData[
    InterpretationBox[\("gratingstrength/Pi: "\[InvisibleSpace]0.5`\),
      SequenceForm[ "gratingstrength/Pi: ", 0.5],
      Editable->False]], "Print",
  CellLabel->"From In[5]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define Grating", "ExampleSubsection"],

Cell[CellGroupData[{

Cell["?CoupledWaveTheory", "Input",
  CellLabel->"In[21]:=",
  FormatType->InputForm],

Cell[BoxData[
    \("CoupledWaveTheory->True/False is an option that indicates whether a \
specialized form of couple-wave theory is used for calculating the \
diffraction efficiency of gratings. \n\nCoupledWaveTheory->True accurately \
describes the polarization-dependent behavior of a volumetic phase grating \
with a cosine index profile and two deflected waves without absorption. The \
present implementation of CoupledWaveTheory->True can only model the zero and \
first diffracted orders and cannot be applied to higher order terms of \
diffraction. Otherwise, CoupledWaveTheory->False can be used to model any \
combination of diffracted orders. The diffraction efficiency of diffracted \
terms in CoupledWaveTheory->False is based on the combined settings of the \
DiffractedOrders and EfficiencyFunction options. Although \
CoupledWaveTheory->False accurately models optical path length and \
diffraction directions, it does not incorporate polarization effects or model \
diffraction efficiency in the precise manner of CoupledWaveTheory->True. \n\n\
See also: DiffractedOrders, EfficiencyFunction, Diffraction and Grating."\)], \
"Print",
  CellTags->"Info3255628639-2770075"]
}, Open  ]],

Cell["\<\
The rays are directed in -x direction, the grating must be taken \
negative.\
\>", "ExampleText"],

Cell["\<\
transmissiongrating = Grating[
\t-1000/wavelength*1.52,
\t50,
\t.1,
\tComponentMedium -> 1.52,
\tVacuumFrequency -> False,
\tCoupledWaveTheory -> True,
\tGratingMedium -> 1.52,
\tGratingThickness -> 10.8253,
\tGratingModulation -> {{0.02,#1&,#1&,#1&}},
\tGratingRotationMatrix -> {{1,0,0},{0,1,0},{0,0,1}}
];\
\>", "Input",
  CellLabel->"In[6]:="],

Cell[CellGroupData[{

Cell["?GratingModulation", "Input",
  CellLabel->"In[22]:=",
  FormatType->InputForm],

Cell[BoxData[
    \("GratingModulation is an option that indicates the modulation of the \
grating. A single value, or the first value in a list, refers to the given \
grating function, from the second value on, harmonics of the grating function \
are specified. For phase gratings, each entry in the list is a list of two \
values: the medium used for modelling and two functions describing the \
modulation of the refractive and attenuation index. The attenuation is yet \
not used in Optica. The Function is compiled internally and may take \
additional arguments in the same order as used by the indices returned by \
GetMaterialRules, for example WaveLength, Intensity, Polarization, \
Temperature, Tension, MaterialRotationMatrix, SurfaceCoordinates, WaveTilt, \
SurfaceNormalMatrix. An example: {BK7, Function[0.02*#1*(1-(#5-20)/1000)], \
Function[#1], Function[#1]} for a modulation with 2% of the refractive index \
of BK7, slightly depending on temperature.\n\nSee also: Diffraction, \
Grating."\)], "Print",
  CellTags->"Info3255628694-9596816"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[Grating]", "Input",
  CellLabel->"In[23]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({Labels \[Rule] "G", LabelPositions \[Rule] Automatic, 
      ComponentDescription \[Rule] Automatic, OffAxis \[Rule] {0, 0}, 
      SurfaceNormalCalculations \[Rule] Automatic, 
      SurfaceRayIntersections \[Rule] Automatic, 
      ExtrapolateSurfaceFunction \[Rule] Automatic, 
      SwitchDirectionOnReflection \[Rule] False, 
      DoubleSubstrate \[Rule] False, OpticaVersion \[Rule] 2, 
      ComponentMedium \[Rule] BK7, Transmittance \[Rule] Transmittance, 
      Reflectance \[Rule] Reflectance, 
      DiffractedOrders \[Rule] {{\(-1\), 0}, {0, 0.2`}, {1, 0.8`}}, 
      MismatchCutOff \[Rule] 1.`*^10, EfficiencyFunction \[Rule] \((1 &)\), 
      VacuumFrequency \[Rule] False, FollowContour \[Rule] False, 
      SurfaceGrating \[Rule] Automatic, GratingMedium \[Rule] BK7, 
      CoupledWaveTheory \[Rule] False, GratingThickness \[Rule] 7.5`, 
      GratingModulation \[Rule] {{BK7, 0.028`\ #1 &}}, 
      GratingRotationMatrix \[Rule] {{1.`, 0.`, 0.`}, {0.`, 1.`, 0.`}, {0.`, 
            0.`, 1.`}}, Temperature \[Rule] Temperature, 
      Tension \[Rule] Tension, GraphicDesign \[Rule] Automatic, 
      Automatic \[Rule] {SurfaceRendering \[Rule] Trace, 
          EdgeRendering \[Rule] Mesh, 
          CrossRendering \[Rule] {{Fill, Trace}}}, 
      Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
          EdgeRendering \[Rule] Trace, 
          CrossRendering \[Rule] {{Fill, Trace}}}, 
      Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
          EdgeRendering \[Rule] Mesh, 
          CrossRendering \[Rule] {{Fill, Trace}}}, 
      Solid \[Rule] {SurfaceRendering \[Rule] {{Fill, Trace}}, 
          EdgeRendering \[Rule] Fill, 
          CrossRendering \[Rule] Empty}}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define System", "ExampleSubsection"],

Cell["\<\
system = {
\tlightsource,
\ttransmissiongrating,
\tMove[Screen[25],{30,12.5}],
\tMove[Screen[25],{30,-12.5}]
};\
\>", "Input",
  CellLabel->"In[7]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trace System", "ExampleSubsection"],

Cell["\<\
tracedsystem = PropagateSystem[system, ThresholdIntensity -> \
0];\
\>", "Input",
  CellLabel->"In[21]:="],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[tracedsystem, PlotType -> TopView, AspectRatio -> 1, \
Axes->True];\
\>", "Input",
  CellLabel->"In[9]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.0238095 0.516547 0.0183857 [
[.02381 .50405 -9 -9 ]
[.02381 .50405 9 0 ]
[.5 .50405 -6 -9 ]
[.5 .50405 6 0 ]
[.7381 .50405 -6 -9 ]
[.7381 .50405 6 0 ]
[.97619 .50405 -6 -9 ]
[.97619 .50405 6 0 ]
[.2494 .14883 -18 -4.5 ]
[.2494 .14883 0 4.5 ]
[.2494 .33269 -18 -4.5 ]
[.2494 .33269 0 4.5 ]
[.2494 .7004 -12 -4.5 ]
[.2494 .7004 0 4.5 ]
[.2494 .88426 -12 -4.5 ]
[.2494 .88426 0 4.5 ]
[.26178 .02381 -3 -4.5 ]
[.26178 .02381 3 4.5 ]
[.97619 .48345 -6 -4.5 ]
[.97619 .48345 6 4.5 ]
[.97619 .02381 -6 -4.5 ]
[.97619 .02381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .51655 m
.02381 .5228 L
s
[(-10)] .02381 .50405 0 1 Mshowa
.5 .51655 m
.5 .5228 L
s
[(10)] .5 .50405 0 1 Mshowa
.7381 .51655 m
.7381 .5228 L
s
[(20)] .7381 .50405 0 1 Mshowa
.97619 .51655 m
.97619 .5228 L
s
[(30)] .97619 .50405 0 1 Mshowa
.125 Mabswid
.07143 .51655 m
.07143 .5203 L
s
.11905 .51655 m
.11905 .5203 L
s
.16667 .51655 m
.16667 .5203 L
s
.21429 .51655 m
.21429 .5203 L
s
.30952 .51655 m
.30952 .5203 L
s
.35714 .51655 m
.35714 .5203 L
s
.40476 .51655 m
.40476 .5203 L
s
.45238 .51655 m
.45238 .5203 L
s
.54762 .51655 m
.54762 .5203 L
s
.59524 .51655 m
.59524 .5203 L
s
.64286 .51655 m
.64286 .5203 L
s
.69048 .51655 m
.69048 .5203 L
s
.78571 .51655 m
.78571 .5203 L
s
.83333 .51655 m
.83333 .5203 L
s
.88095 .51655 m
.88095 .5203 L
s
.92857 .51655 m
.92857 .5203 L
s
.25 Mabswid
0 .51655 m
1 .51655 L
s
.2619 .14883 m
.26815 .14883 L
s
[(-20)] .2494 .14883 1 0 Mshowa
.2619 .33269 m
.26815 .33269 L
s
[(-10)] .2494 .33269 1 0 Mshowa
.2619 .7004 m
.26815 .7004 L
s
[(10)] .2494 .7004 1 0 Mshowa
.2619 .88426 m
.26815 .88426 L
s
[(20)] .2494 .88426 1 0 Mshowa
.125 Mabswid
.2619 .1856 m
.26565 .1856 L
s
.2619 .22238 m
.26565 .22238 L
s
.2619 .25915 m
.26565 .25915 L
s
.2619 .29592 m
.26565 .29592 L
s
.2619 .36946 m
.26565 .36946 L
s
.2619 .40623 m
.26565 .40623 L
s
.2619 .443 m
.26565 .443 L
s
.2619 .47978 m
.26565 .47978 L
s
.2619 .55332 m
.26565 .55332 L
s
.2619 .59009 m
.26565 .59009 L
s
.2619 .62686 m
.26565 .62686 L
s
.2619 .66363 m
.26565 .66363 L
s
.2619 .73718 m
.26565 .73718 L
s
.2619 .77395 m
.26565 .77395 L
s
.2619 .81072 m
.26565 .81072 L
s
.2619 .84749 m
.26565 .84749 L
s
.2619 .11206 m
.26565 .11206 L
s
.2619 .07529 m
.26565 .07529 L
s
.2619 .03852 m
.26565 .03852 L
s
.2619 .00175 m
.26565 .00175 L
s
.2619 .92103 m
.26565 .92103 L
s
.2619 .9578 m
.26565 .9578 L
s
.2619 .99458 m
.26565 .99458 L
s
.25 Mabswid
.2619 0 m
.2619 1 L
s
.5 g
.26165 .0569 m
.2619 .0569 L
.2619 .21012 L
.26165 .21012 L
.26165 .0569 L
F
.26165 .21012 m
.2619 .21012 L
.2619 .36333 L
.26165 .36333 L
.26165 .21012 L
F
.26165 .36333 m
.2619 .36333 L
.2619 .51655 L
.26165 .51655 L
.26165 .36333 L
F
.26165 .51655 m
.2619 .51655 L
.2619 .66976 L
.26165 .66976 L
.26165 .51655 L
F
.26165 .66976 m
.2619 .66976 L
.2619 .82298 L
.26165 .82298 L
.26165 .66976 L
F
.26165 .82298 m
.2619 .82298 L
.2619 .97619 L
.26165 .97619 L
.26165 .82298 L
F
0 g
.5 Mabswid
.26165 .0569 m
.26165 .21012 L
.26165 .36333 L
.26165 .51655 L
.26165 .66976 L
.26165 .82298 L
.26165 .97619 L
.2619 .97619 L
.2619 .82298 L
.2619 .66976 L
.2619 .51655 L
.2619 .36333 L
.2619 .21012 L
.2619 .0569 L
.26165 .0569 L
s
.5 g
.26165 .51655 m
.2619 .51655 L
.2619 .51655 L
.26165 .51655 L
.26165 .51655 L
F
.26165 .51655 m
.2619 .51655 L
.2619 .51655 L
.26165 .51655 L
.26165 .51655 L
F
.26165 .51655 m
.2619 .51655 L
.2619 .51655 L
.26165 .51655 L
.26165 .51655 L
F
.26165 .51655 m
.2619 .51655 L
.2619 .51655 L
.26165 .51655 L
.26165 .51655 L
F
.26165 .51655 m
.2619 .51655 L
.2619 .51655 L
.26165 .51655 L
.26165 .51655 L
F
.26165 .51655 m
.2619 .51655 L
.2619 .51655 L
.26165 .51655 L
.26165 .51655 L
F
0 g
.26165 .51655 m
.26165 .51655 L
.26165 .51655 L
.26165 .51655 L
.26165 .51655 L
.26165 .51655 L
.26165 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.26165 .51655 L
s
.5 g
.2619 .0569 m
.2619 .0569 L
.2619 .21012 L
.2619 .21012 L
.2619 .0569 L
F
.2619 .21012 m
.2619 .21012 L
.2619 .36333 L
.2619 .36333 L
.2619 .21012 L
F
.2619 .36333 m
.2619 .36333 L
.2619 .51655 L
.2619 .51655 L
.2619 .36333 L
F
.2619 .51655 m
.2619 .51655 L
.2619 .66976 L
.2619 .66976 L
.2619 .51655 L
F
.2619 .66976 m
.2619 .66976 L
.2619 .82298 L
.2619 .82298 L
.2619 .66976 L
F
.2619 .82298 m
.2619 .82298 L
.2619 .97619 L
.2619 .97619 L
.2619 .82298 L
F
0 g
.2619 .0569 m
.2619 .21012 L
.2619 .36333 L
.2619 .51655 L
.2619 .66976 L
.2619 .82298 L
.2619 .97619 L
.2619 .97619 L
.2619 .82298 L
.2619 .66976 L
.2619 .51655 L
.2619 .36333 L
.2619 .21012 L
.2619 .0569 L
.2619 .0569 L
s
.5 g
.2619 .51655 m
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
F
0 g
.2619 .51655 m
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
s
.5 g
.2619 .0569 m
.26429 .0569 L
.26429 .21012 L
.2619 .21012 L
.2619 .0569 L
F
.2619 .21012 m
.26429 .21012 L
.26429 .36333 L
.2619 .36333 L
.2619 .21012 L
F
.2619 .36333 m
.26429 .36333 L
.26429 .51655 L
.2619 .51655 L
.2619 .36333 L
F
.2619 .51655 m
.26429 .51655 L
.26429 .66976 L
.2619 .66976 L
.2619 .51655 L
F
.2619 .66976 m
.26429 .66976 L
.26429 .82298 L
.2619 .82298 L
.2619 .66976 L
F
.2619 .82298 m
.26429 .82298 L
.26429 .97619 L
.2619 .97619 L
.2619 .82298 L
F
0 g
.2619 .0569 m
.2619 .21012 L
.2619 .36333 L
.2619 .51655 L
.2619 .66976 L
.2619 .82298 L
.2619 .97619 L
.26429 .97619 L
.26429 .82298 L
.26429 .66976 L
.26429 .51655 L
.26429 .36333 L
.26429 .21012 L
.26429 .0569 L
.2619 .0569 L
s
.5 g
.2619 .51655 m
.26429 .51655 L
.26429 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.26429 .51655 L
.26429 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.26429 .51655 L
.26429 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.26429 .51655 L
.26429 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.26429 .51655 L
.26429 .51655 L
.2619 .51655 L
.2619 .51655 L
F
.2619 .51655 m
.26429 .51655 L
.26429 .51655 L
.2619 .51655 L
.2619 .51655 L
F
0 g
.2619 .51655 m
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.2619 .51655 L
.26429 .51655 L
.26429 .51655 L
.26429 .51655 L
.26429 .51655 L
.26429 .51655 L
.26429 .51655 L
.26429 .51655 L
.2619 .51655 L
s
.26165 .97619 m
.26165 .96053 L
.26165 .91461 L
.26165 .84156 L
.26165 .74637 L
.26165 .63551 L
.26165 .51655 L
.26165 .39758 L
.26165 .28673 L
.26165 .19153 L
.26165 .11848 L
.26165 .07257 L
.26165 .0569 L
.26165 .07257 L
.26165 .11848 L
.26165 .19153 L
.26165 .28673 L
.26165 .39758 L
.26165 .51655 L
.26165 .63551 L
.26165 .74637 L
.26165 .84156 L
.26165 .91461 L
.26165 .96053 L
.26165 .97619 L
s
.2619 .97619 m
.2619 .96053 L
.2619 .91461 L
.2619 .84156 L
.2619 .74637 L
.2619 .63551 L
.2619 .51655 L
.2619 .39758 L
.2619 .28673 L
.2619 .19153 L
.2619 .11848 L
.2619 .07257 L
.2619 .0569 L
.2619 .07257 L
.2619 .11848 L
.2619 .19153 L
.2619 .28673 L
.2619 .39758 L
.2619 .51655 L
.2619 .63551 L
.2619 .74637 L
.2619 .84156 L
.2619 .91461 L
.2619 .96053 L
.2619 .97619 L
s
.2619 .97619 m
.2619 .96053 L
.2619 .91461 L
.2619 .84156 L
.2619 .74637 L
.2619 .63551 L
.2619 .51655 L
.2619 .39758 L
.2619 .28673 L
.2619 .19153 L
.2619 .11848 L
.2619 .07257 L
.2619 .0569 L
.2619 .07257 L
.2619 .11848 L
.2619 .19153 L
.2619 .28673 L
.2619 .39758 L
.2619 .51655 L
.2619 .63551 L
.2619 .74637 L
.2619 .84156 L
.2619 .91461 L
.2619 .96053 L
.2619 .97619 L
s
.26429 .97619 m
.26429 .96053 L
.26429 .91461 L
.26429 .84156 L
.26429 .74637 L
.26429 .63551 L
.26429 .51655 L
.26429 .39758 L
.26429 .28673 L
.26429 .19153 L
.26429 .11848 L
.26429 .07257 L
.26429 .0569 L
.26429 .07257 L
.26429 .11848 L
.26429 .19153 L
.26429 .28673 L
.26429 .39758 L
.26429 .51655 L
.26429 .63551 L
.26429 .74637 L
.26429 .84156 L
.26429 .91461 L
.26429 .96053 L
.26429 .97619 L
s
.26165 .97619 m
.2619 .97619 L
.2619 .96053 L
.26165 .96053 L
.26165 .97619 L
s
.26165 .96053 m
.2619 .96053 L
.2619 .91461 L
.26165 .91461 L
.26165 .96053 L
s
.26165 .91461 m
.2619 .91461 L
.2619 .84156 L
.26165 .84156 L
.26165 .91461 L
s
.26165 .84156 m
.2619 .84156 L
.2619 .74637 L
.26165 .74637 L
.26165 .84156 L
s
.26165 .74637 m
.2619 .74637 L
.2619 .63551 L
.26165 .63551 L
.26165 .74637 L
s
.26165 .63551 m
.2619 .63551 L
.2619 .51655 L
.26165 .51655 L
.26165 .63551 L
s
.26165 .51655 m
.2619 .51655 L
.2619 .39758 L
.26165 .39758 L
.26165 .51655 L
s
.26165 .39758 m
.2619 .39758 L
.2619 .28673 L
.26165 .28673 L
.26165 .39758 L
s
.26165 .28673 m
.2619 .28673 L
.2619 .19153 L
.26165 .19153 L
.26165 .28673 L
s
.26165 .19153 m
.2619 .19153 L
.2619 .11848 L
.26165 .11848 L
.26165 .19153 L
s
.26165 .11848 m
.2619 .11848 L
.2619 .07257 L
.26165 .07257 L
.26165 .11848 L
s
.26165 .07257 m
.2619 .07257 L
.2619 .0569 L
.26165 .0569 L
.26165 .07257 L
s
.26165 .0569 m
.2619 .0569 L
.2619 .07257 L
.26165 .07257 L
.26165 .0569 L
s
.26165 .07257 m
.2619 .07257 L
.2619 .11848 L
.26165 .11848 L
.26165 .07257 L
s
.26165 .11848 m
.2619 .11848 L
.2619 .19153 L
.26165 .19153 L
.26165 .11848 L
s
.26165 .19153 m
.2619 .19153 L
.2619 .28673 L
.26165 .28673 L
.26165 .19153 L
s
.26165 .28673 m
.2619 .28673 L
.2619 .39758 L
.26165 .39758 L
.26165 .28673 L
s
.26165 .39758 m
.2619 .39758 L
.2619 .51655 L
.26165 .51655 L
.26165 .39758 L
s
.26165 .51655 m
.2619 .51655 L
.2619 .63551 L
.26165 .63551 L
.26165 .51655 L
s
.26165 .63551 m
.2619 .63551 L
.2619 .74637 L
.26165 .74637 L
.26165 .63551 L
s
.26165 .74637 m
.2619 .74637 L
.2619 .84156 L
.26165 .84156 L
.26165 .74637 L
s
.26165 .84156 m
.2619 .84156 L
.2619 .91461 L
.26165 .91461 L
.26165 .84156 L
s
.26165 .91461 m
.2619 .91461 L
.2619 .96053 L
.26165 .96053 L
.26165 .91461 L
s
.26165 .96053 m
.2619 .96053 L
.2619 .97619 L
.26165 .97619 L
.26165 .96053 L
s
.2619 .97619 m
.2619 .97619 L
.2619 .96053 L
.2619 .96053 L
.2619 .97619 L
s
.2619 .96053 m
.2619 .96053 L
.2619 .91461 L
.2619 .91461 L
.2619 .96053 L
s
.2619 .91461 m
.2619 .91461 L
.2619 .84156 L
.2619 .84156 L
.2619 .91461 L
s
.2619 .84156 m
.2619 .84156 L
.2619 .74637 L
.2619 .74637 L
.2619 .84156 L
s
.2619 .74637 m
.2619 .74637 L
.2619 .63551 L
.2619 .63551 L
.2619 .74637 L
s
.2619 .63551 m
.2619 .63551 L
.2619 .51655 L
.2619 .51655 L
.2619 .63551 L
s
.2619 .51655 m
.2619 .51655 L
.2619 .39758 L
.2619 .39758 L
.2619 .51655 L
s
.2619 .39758 m
.2619 .39758 L
.2619 .28673 L
.2619 .28673 L
.2619 .39758 L
s
.2619 .28673 m
.2619 .28673 L
.2619 .19153 L
.2619 .19153 L
.2619 .28673 L
s
.2619 .19153 m
.2619 .19153 L
.2619 .11848 L
.2619 .11848 L
.2619 .19153 L
s
.2619 .11848 m
.2619 .11848 L
.2619 .07257 L
.2619 .07257 L
.2619 .11848 L
s
.2619 .07257 m
.2619 .07257 L
.2619 .0569 L
.2619 .0569 L
.2619 .07257 L
s
.2619 .0569 m
.2619 .0569 L
.2619 .07257 L
.2619 .07257 L
.2619 .0569 L
s
.2619 .07257 m
.2619 .07257 L
.2619 .11848 L
.2619 .11848 L
.2619 .07257 L
s
.2619 .11848 m
.2619 .11848 L
.2619 .19153 L
.2619 .19153 L
.2619 .11848 L
s
.2619 .19153 m
.2619 .19153 L
.2619 .28673 L
.2619 .28673 L
.2619 .19153 L
s
.2619 .28673 m
.2619 .28673 L
.2619 .39758 L
.2619 .39758 L
.2619 .28673 L
s
.2619 .39758 m
.2619 .39758 L
.2619 .51655 L
.2619 .51655 L
.2619 .39758 L
s
.2619 .51655 m
.2619 .51655 L
.2619 .63551 L
.2619 .63551 L
.2619 .51655 L
s
.2619 .63551 m
.2619 .63551 L
.2619 .74637 L
.2619 .74637 L
.2619 .63551 L
s
.2619 .74637 m
.2619 .74637 L
.2619 .84156 L
.2619 .84156 L
.2619 .74637 L
s
.2619 .84156 m
.2619 .84156 L
.2619 .91461 L
.2619 .91461 L
.2619 .84156 L
s
.2619 .91461 m
.2619 .91461 L
.2619 .96053 L
.2619 .96053 L
.2619 .91461 L
s
.2619 .96053 m
.2619 .96053 L
.2619 .97619 L
.2619 .97619 L
.2619 .96053 L
s
.2619 .97619 m
.26429 .97619 L
.26429 .96053 L
.2619 .96053 L
.2619 .97619 L
s
.2619 .96053 m
.26429 .96053 L
.26429 .91461 L
.2619 .91461 L
.2619 .96053 L
s
.2619 .91461 m
.26429 .91461 L
.26429 .84156 L
.2619 .84156 L
.2619 .91461 L
s
.2619 .84156 m
.26429 .84156 L
.26429 .74637 L
.2619 .74637 L
.2619 .84156 L
s
.2619 .74637 m
.26429 .74637 L
.26429 .63551 L
.2619 .63551 L
.2619 .74637 L
s
.2619 .63551 m
.26429 .63551 L
.26429 .51655 L
.2619 .51655 L
.2619 .63551 L
s
.2619 .51655 m
.26429 .51655 L
.26429 .39758 L
.2619 .39758 L
.2619 .51655 L
s
.2619 .39758 m
.26429 .39758 L
.26429 .28673 L
.2619 .28673 L
.2619 .39758 L
s
.2619 .28673 m
.26429 .28673 L
.26429 .19153 L
.2619 .19153 L
.2619 .28673 L
s
.2619 .19153 m
.26429 .19153 L
.26429 .11848 L
.2619 .11848 L
.2619 .19153 L
s
.2619 .11848 m
.26429 .11848 L
.26429 .07257 L
.2619 .07257 L
.2619 .11848 L
s
.2619 .07257 m
.26429 .07257 L
.26429 .0569 L
.2619 .0569 L
.2619 .07257 L
s
.2619 .0569 m
.26429 .0569 L
.26429 .07257 L
.2619 .07257 L
.2619 .0569 L
s
.2619 .07257 m
.26429 .07257 L
.26429 .11848 L
.2619 .11848 L
.2619 .07257 L
s
.2619 .11848 m
.26429 .11848 L
.26429 .19153 L
.2619 .19153 L
.2619 .11848 L
s
.2619 .19153 m
.26429 .19153 L
.26429 .28673 L
.2619 .28673 L
.2619 .19153 L
s
.2619 .28673 m
.26429 .28673 L
.26429 .39758 L
.2619 .39758 L
.2619 .28673 L
s
.2619 .39758 m
.26429 .39758 L
.26429 .51655 L
.2619 .51655 L
.2619 .39758 L
s
.2619 .51655 m
.26429 .51655 L
.26429 .63551 L
.2619 .63551 L
.2619 .51655 L
s
.2619 .63551 m
.26429 .63551 L
.26429 .74637 L
.2619 .74637 L
.2619 .63551 L
s
.2619 .74637 m
.26429 .74637 L
.26429 .84156 L
.2619 .84156 L
.2619 .74637 L
s
.2619 .84156 m
.26429 .84156 L
.26429 .91461 L
.2619 .91461 L
.2619 .84156 L
s
.2619 .91461 m
.26429 .91461 L
.26429 .96053 L
.2619 .96053 L
.2619 .91461 L
s
.2619 .96053 m
.26429 .96053 L
.26429 .97619 L
.2619 .97619 L
.2619 .96053 L
s
.97619 .51655 m
.97619 .59315 L
.97619 .66976 L
.97619 .74637 L
.97619 .82298 L
.97619 .89958 L
.97619 .97619 L
.97619 .97619 L
.97619 .89958 L
.97619 .82298 L
.97619 .74637 L
.97619 .66976 L
.97619 .59315 L
.97619 .51655 L
.97619 .51655 L
s
.97619 .74637 m
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
.97619 .74637 L
s
.97619 .97619 m
.97619 .96836 L
.97619 .9454 L
.97619 .90888 L
.97619 .86128 L
.97619 .80585 L
.97619 .74637 L
.97619 .68689 L
.97619 .63146 L
.97619 .58386 L
.97619 .54734 L
.97619 .52438 L
.97619 .51655 L
.97619 .52438 L
.97619 .54734 L
.97619 .58386 L
.97619 .63146 L
.97619 .68689 L
.97619 .74637 L
.97619 .80585 L
.97619 .86128 L
.97619 .90888 L
.97619 .9454 L
.97619 .96836 L
.97619 .97619 L
s
.97619 .0569 m
.97619 .13351 L
.97619 .21012 L
.97619 .28673 L
.97619 .36333 L
.97619 .43994 L
.97619 .51655 L
.97619 .51655 L
.97619 .43994 L
.97619 .36333 L
.97619 .28673 L
.97619 .21012 L
.97619 .13351 L
.97619 .0569 L
.97619 .0569 L
s
.97619 .28673 m
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
.97619 .28673 L
s
.97619 .51655 m
.97619 .50872 L
.97619 .48576 L
.97619 .44923 L
.97619 .40164 L
.97619 .34621 L
.97619 .28673 L
.97619 .22724 L
.97619 .17181 L
.97619 .12422 L
.97619 .08769 L
.97619 .06473 L
.97619 .0569 L
.97619 .06473 L
.97619 .08769 L
.97619 .12422 L
.97619 .17181 L
.97619 .22724 L
.97619 .28673 L
.97619 .34621 L
.97619 .40164 L
.97619 .44923 L
.97619 .48576 L
.97619 .50872 L
.97619 .51655 L
s
.009 .837 .111 r
.02381 .4104 m
.26165 .49807 L
s
0 0 0 r
2 Mabswid
.26165 .49807 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .49933 L
s
0 0 0 r
2 Mabswid
.26165 .49933 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .5006 L
s
0 0 0 r
2 Mabswid
.26165 .5006 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .50187 L
s
0 0 0 r
2 Mabswid
.26165 .50187 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .50313 L
s
0 0 0 r
2 Mabswid
.26165 .50313 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .5044 L
s
0 0 0 r
2 Mabswid
.26165 .5044 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .50567 L
s
0 0 0 r
2 Mabswid
.26165 .50567 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .50693 L
s
0 0 0 r
2 Mabswid
.26165 .50693 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .5082 L
s
0 0 0 r
2 Mabswid
.26165 .5082 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .50947 L
s
0 0 0 r
2 Mabswid
.26165 .50947 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .51073 L
s
0 0 0 r
2 Mabswid
.26165 .51073 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .512 L
s
0 0 0 r
2 Mabswid
.26165 .512 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .51327 L
s
0 0 0 r
2 Mabswid
.26165 .51327 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .51453 L
s
0 0 0 r
2 Mabswid
.26165 .51453 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .5158 L
s
0 0 0 r
2 Mabswid
.26165 .5158 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .51707 L
s
0 0 0 r
2 Mabswid
.26165 .51707 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .51833 L
s
0 0 0 r
2 Mabswid
.26165 .51833 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .5196 L
s
0 0 0 r
2 Mabswid
.26165 .5196 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .52087 L
s
0 0 0 r
2 Mabswid
.26165 .52087 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .52213 L
s
0 0 0 r
2 Mabswid
.26165 .52213 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .5234 L
s
0 0 0 r
2 Mabswid
.26165 .5234 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .52467 L
s
0 0 0 r
2 Mabswid
.26165 .52467 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .52593 L
s
0 0 0 r
2 Mabswid
.26165 .52593 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .5272 L
s
0 0 0 r
2 Mabswid
.26165 .5272 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .52847 L
s
0 0 0 r
2 Mabswid
.26165 .52847 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .52973 L
s
0 0 0 r
2 Mabswid
.26165 .52973 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .531 L
s
0 0 0 r
2 Mabswid
.26165 .531 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .53226 L
s
0 0 0 r
2 Mabswid
.26165 .53226 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .53353 L
s
0 0 0 r
2 Mabswid
.26165 .53353 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .4104 m
.26165 .5348 L
s
0 0 0 r
2 Mabswid
.26165 .5348 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .49807 m
.2619 .49816 L
s
0 0 0 r
2 Mabswid
.2619 .49816 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .49933 m
.2619 .49943 L
s
0 0 0 r
2 Mabswid
.2619 .49943 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5006 m
.2619 .5007 L
s
0 0 0 r
2 Mabswid
.2619 .5007 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50187 m
.2619 .50197 L
s
0 0 0 r
2 Mabswid
.2619 .50197 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50313 m
.2619 .50323 L
s
0 0 0 r
2 Mabswid
.2619 .50323 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5044 m
.2619 .5045 L
s
0 0 0 r
2 Mabswid
.2619 .5045 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50567 m
.2619 .50577 L
s
0 0 0 r
2 Mabswid
.2619 .50577 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50693 m
.2619 .50704 L
s
0 0 0 r
2 Mabswid
.2619 .50704 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5082 m
.2619 .50831 L
s
0 0 0 r
2 Mabswid
.2619 .50831 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50947 m
.2619 .50957 L
s
0 0 0 r
2 Mabswid
.2619 .50957 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51073 m
.2619 .51084 L
s
0 0 0 r
2 Mabswid
.2619 .51084 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .512 m
.2619 .51211 L
s
0 0 0 r
2 Mabswid
.2619 .51211 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51327 m
.2619 .51338 L
s
0 0 0 r
2 Mabswid
.2619 .51338 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51453 m
.2619 .51465 L
s
0 0 0 r
2 Mabswid
.2619 .51465 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5158 m
.2619 .51591 L
s
0 0 0 r
2 Mabswid
.2619 .51591 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51707 m
.2619 .51718 L
s
0 0 0 r
2 Mabswid
.2619 .51718 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51833 m
.2619 .51845 L
s
0 0 0 r
2 Mabswid
.2619 .51845 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5196 m
.2619 .51972 L
s
0 0 0 r
2 Mabswid
.2619 .51972 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .52087 m
.2619 .52099 L
s
0 0 0 r
2 Mabswid
.2619 .52099 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .52213 m
.2619 .52225 L
s
0 0 0 r
2 Mabswid
.2619 .52225 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5234 m
.2619 .52352 L
s
0 0 0 r
2 Mabswid
.2619 .52352 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .52467 m
.2619 .52479 L
s
0 0 0 r
2 Mabswid
.2619 .52479 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .52593 m
.2619 .52606 L
s
0 0 0 r
2 Mabswid
.2619 .52606 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5272 m
.2619 .52733 L
s
0 0 0 r
2 Mabswid
.2619 .52733 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .52847 m
.2619 .52859 L
s
0 0 0 r
2 Mabswid
.2619 .52859 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .52973 m
.2619 .52986 L
s
0 0 0 r
2 Mabswid
.2619 .52986 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .531 m
.2619 .53113 L
s
0 0 0 r
2 Mabswid
.2619 .53113 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .53226 m
.2619 .5324 L
s
0 0 0 r
2 Mabswid
.2619 .5324 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .53353 m
.2619 .53366 L
s
0 0 0 r
2 Mabswid
.2619 .53366 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5348 m
.2619 .53493 L
s
0 0 0 r
2 Mabswid
.2619 .53493 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49816 m
.2619 .49816 L
s
0 0 0 r
2 Mabswid
.2619 .49816 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49816 m
.2619 .49816 L
s
0 0 0 r
2 Mabswid
.2619 .49816 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49943 m
.2619 .49943 L
s
0 0 0 r
2 Mabswid
.2619 .49943 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49943 m
.2619 .49943 L
s
0 0 0 r
2 Mabswid
.2619 .49943 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5007 m
.2619 .5007 L
s
0 0 0 r
2 Mabswid
.2619 .5007 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5007 m
.2619 .5007 L
s
0 0 0 r
2 Mabswid
.2619 .5007 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50197 m
.2619 .50197 L
s
0 0 0 r
2 Mabswid
.2619 .50197 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50197 m
.2619 .50197 L
s
0 0 0 r
2 Mabswid
.2619 .50197 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50323 m
.2619 .50323 L
s
0 0 0 r
2 Mabswid
.2619 .50323 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50323 m
.2619 .50323 L
s
0 0 0 r
2 Mabswid
.2619 .50323 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5045 m
.2619 .5045 L
s
0 0 0 r
2 Mabswid
.2619 .5045 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5045 m
.2619 .5045 L
s
0 0 0 r
2 Mabswid
.2619 .5045 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50577 m
.2619 .50577 L
s
0 0 0 r
2 Mabswid
.2619 .50577 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50577 m
.2619 .50577 L
s
0 0 0 r
2 Mabswid
.2619 .50577 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50704 m
.2619 .50704 L
s
0 0 0 r
2 Mabswid
.2619 .50704 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50704 m
.2619 .50704 L
s
0 0 0 r
2 Mabswid
.2619 .50704 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50831 m
.2619 .50831 L
s
0 0 0 r
2 Mabswid
.2619 .50831 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50831 m
.2619 .50831 L
s
0 0 0 r
2 Mabswid
.2619 .50831 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50957 m
.2619 .50957 L
s
0 0 0 r
2 Mabswid
.2619 .50957 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50957 m
.2619 .50957 L
s
0 0 0 r
2 Mabswid
.2619 .50957 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51084 m
.2619 .51084 L
s
0 0 0 r
2 Mabswid
.2619 .51084 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51084 m
.2619 .51084 L
s
0 0 0 r
2 Mabswid
.2619 .51084 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51211 m
.2619 .51211 L
s
0 0 0 r
2 Mabswid
.2619 .51211 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51211 m
.2619 .51211 L
s
0 0 0 r
2 Mabswid
.2619 .51211 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51338 m
.2619 .51338 L
s
0 0 0 r
2 Mabswid
.2619 .51338 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51338 m
.2619 .51338 L
s
0 0 0 r
2 Mabswid
.2619 .51338 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51465 m
.2619 .51465 L
s
0 0 0 r
2 Mabswid
.2619 .51465 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51465 m
.2619 .51465 L
s
0 0 0 r
2 Mabswid
.2619 .51465 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51591 m
.2619 .51591 L
s
0 0 0 r
2 Mabswid
.2619 .51591 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51591 m
.2619 .51591 L
s
0 0 0 r
2 Mabswid
.2619 .51591 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51718 m
.2619 .51718 L
s
0 0 0 r
2 Mabswid
.2619 .51718 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51718 m
.2619 .51718 L
s
0 0 0 r
2 Mabswid
.2619 .51718 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51845 m
.2619 .51845 L
s
0 0 0 r
2 Mabswid
.2619 .51845 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51845 m
.2619 .51845 L
s
0 0 0 r
2 Mabswid
.2619 .51845 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51972 m
.2619 .51972 L
s
0 0 0 r
2 Mabswid
.2619 .51972 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51972 m
.2619 .51972 L
s
0 0 0 r
2 Mabswid
.2619 .51972 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52099 m
.2619 .52099 L
s
0 0 0 r
2 Mabswid
.2619 .52099 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52099 m
.2619 .52099 L
s
0 0 0 r
2 Mabswid
.2619 .52099 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52225 m
.2619 .52225 L
s
0 0 0 r
2 Mabswid
.2619 .52225 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52225 m
.2619 .52225 L
s
0 0 0 r
2 Mabswid
.2619 .52225 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52352 m
.2619 .52352 L
s
0 0 0 r
2 Mabswid
.2619 .52352 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52352 m
.2619 .52352 L
s
0 0 0 r
2 Mabswid
.2619 .52352 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52479 m
.2619 .52479 L
s
0 0 0 r
2 Mabswid
.2619 .52479 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52479 m
.2619 .52479 L
s
0 0 0 r
2 Mabswid
.2619 .52479 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52606 m
.2619 .52606 L
s
0 0 0 r
2 Mabswid
.2619 .52606 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52606 m
.2619 .52606 L
s
0 0 0 r
2 Mabswid
.2619 .52606 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52733 m
.2619 .52733 L
s
0 0 0 r
2 Mabswid
.2619 .52733 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52733 m
.2619 .52733 L
s
0 0 0 r
2 Mabswid
.2619 .52733 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52859 m
.2619 .52859 L
s
0 0 0 r
2 Mabswid
.2619 .52859 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52859 m
.2619 .52859 L
s
0 0 0 r
2 Mabswid
.2619 .52859 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52986 m
.2619 .52986 L
s
0 0 0 r
2 Mabswid
.2619 .52986 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52986 m
.2619 .52986 L
s
0 0 0 r
2 Mabswid
.2619 .52986 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53113 m
.2619 .53113 L
s
0 0 0 r
2 Mabswid
.2619 .53113 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53113 m
.2619 .53113 L
s
0 0 0 r
2 Mabswid
.2619 .53113 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5324 m
.2619 .5324 L
s
0 0 0 r
2 Mabswid
.2619 .5324 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5324 m
.2619 .5324 L
s
0 0 0 r
2 Mabswid
.2619 .5324 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53366 m
.2619 .53366 L
s
0 0 0 r
2 Mabswid
.2619 .53366 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53366 m
.2619 .53366 L
s
0 0 0 r
2 Mabswid
.2619 .53366 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53493 m
.2619 .53493 L
s
0 0 0 r
2 Mabswid
.2619 .53493 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53493 m
.2619 .53493 L
s
0 0 0 r
2 Mabswid
.2619 .53493 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49816 m
.26429 .49689 L
s
0 0 0 r
2 Mabswid
.26429 .49689 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49816 m
.26429 .49904 L
s
0 0 0 r
2 Mabswid
.26429 .49904 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49943 m
.26429 .49817 L
s
0 0 0 r
2 Mabswid
.26429 .49817 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49943 m
.26429 .50032 L
s
0 0 0 r
2 Mabswid
.26429 .50032 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5007 m
.26429 .49946 L
s
0 0 0 r
2 Mabswid
.26429 .49946 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5007 m
.26429 .5016 L
s
0 0 0 r
2 Mabswid
.26429 .5016 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50197 m
.26429 .50074 L
s
0 0 0 r
2 Mabswid
.26429 .50074 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50197 m
.26429 .50288 L
s
0 0 0 r
2 Mabswid
.26429 .50288 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50323 m
.26429 .50202 L
s
0 0 0 r
2 Mabswid
.26429 .50202 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50323 m
.26429 .50416 L
s
0 0 0 r
2 Mabswid
.26429 .50416 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5045 m
.26429 .50331 L
s
0 0 0 r
2 Mabswid
.26429 .50331 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5045 m
.26429 .50544 L
s
0 0 0 r
2 Mabswid
.26429 .50544 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50577 m
.26429 .50459 L
s
0 0 0 r
2 Mabswid
.26429 .50459 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50577 m
.26429 .50672 L
s
0 0 0 r
2 Mabswid
.26429 .50672 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50704 m
.26429 .50587 L
s
0 0 0 r
2 Mabswid
.26429 .50587 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50704 m
.26429 .508 L
s
0 0 0 r
2 Mabswid
.26429 .508 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50831 m
.26429 .50716 L
s
0 0 0 r
2 Mabswid
.26429 .50716 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50831 m
.26429 .50928 L
s
0 0 0 r
2 Mabswid
.26429 .50928 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50957 m
.26429 .50844 L
s
0 0 0 r
2 Mabswid
.26429 .50844 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50957 m
.26429 .51057 L
s
0 0 0 r
2 Mabswid
.26429 .51057 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51084 m
.26429 .50972 L
s
0 0 0 r
2 Mabswid
.26429 .50972 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51084 m
.26429 .51185 L
s
0 0 0 r
2 Mabswid
.26429 .51185 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51211 m
.26429 .511 L
s
0 0 0 r
2 Mabswid
.26429 .511 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51211 m
.26429 .51313 L
s
0 0 0 r
2 Mabswid
.26429 .51313 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51338 m
.26429 .51228 L
s
0 0 0 r
2 Mabswid
.26429 .51228 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51338 m
.26429 .51441 L
s
0 0 0 r
2 Mabswid
.26429 .51441 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51465 m
.26429 .51356 L
s
0 0 0 r
2 Mabswid
.26429 .51356 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51465 m
.26429 .51569 L
s
0 0 0 r
2 Mabswid
.26429 .51569 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51591 m
.26429 .51485 L
s
0 0 0 r
2 Mabswid
.26429 .51485 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51591 m
.26429 .51697 L
s
0 0 0 r
2 Mabswid
.26429 .51697 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51718 m
.26429 .51613 L
s
0 0 0 r
2 Mabswid
.26429 .51613 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51718 m
.26429 .51825 L
s
0 0 0 r
2 Mabswid
.26429 .51825 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51845 m
.26429 .51741 L
s
0 0 0 r
2 Mabswid
.26429 .51741 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51845 m
.26429 .51953 L
s
0 0 0 r
2 Mabswid
.26429 .51953 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51972 m
.26429 .51869 L
s
0 0 0 r
2 Mabswid
.26429 .51869 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51972 m
.26429 .52081 L
s
0 0 0 r
2 Mabswid
.26429 .52081 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52099 m
.26429 .51997 L
s
0 0 0 r
2 Mabswid
.26429 .51997 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52099 m
.26429 .52209 L
s
0 0 0 r
2 Mabswid
.26429 .52209 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52225 m
.26429 .52125 L
s
0 0 0 r
2 Mabswid
.26429 .52125 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52225 m
.26429 .52337 L
s
0 0 0 r
2 Mabswid
.26429 .52337 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52352 m
.26429 .52253 L
s
0 0 0 r
2 Mabswid
.26429 .52253 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52352 m
.26429 .52465 L
s
0 0 0 r
2 Mabswid
.26429 .52465 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52479 m
.26429 .52381 L
s
0 0 0 r
2 Mabswid
.26429 .52381 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52479 m
.26429 .52593 L
s
0 0 0 r
2 Mabswid
.26429 .52593 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52606 m
.26429 .52508 L
s
0 0 0 r
2 Mabswid
.26429 .52508 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52606 m
.26429 .52721 L
s
0 0 0 r
2 Mabswid
.26429 .52721 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52733 m
.26429 .52636 L
s
0 0 0 r
2 Mabswid
.26429 .52636 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52733 m
.26429 .52849 L
s
0 0 0 r
2 Mabswid
.26429 .52849 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52859 m
.26429 .52764 L
s
0 0 0 r
2 Mabswid
.26429 .52764 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52859 m
.26429 .52977 L
s
0 0 0 r
2 Mabswid
.26429 .52977 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52986 m
.26429 .52892 L
s
0 0 0 r
2 Mabswid
.26429 .52892 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .52986 m
.26429 .53106 L
s
0 0 0 r
2 Mabswid
.26429 .53106 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53113 m
.26429 .5302 L
s
0 0 0 r
2 Mabswid
.26429 .5302 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53113 m
.26429 .53234 L
s
0 0 0 r
2 Mabswid
.26429 .53234 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5324 m
.26429 .53148 L
s
0 0 0 r
2 Mabswid
.26429 .53148 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5324 m
.26429 .53362 L
s
0 0 0 r
2 Mabswid
.26429 .53362 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53366 m
.26429 .53276 L
s
0 0 0 r
2 Mabswid
.26429 .53276 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53366 m
.26429 .5349 L
s
0 0 0 r
2 Mabswid
.26429 .5349 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53493 m
.26429 .53403 L
s
0 0 0 r
2 Mabswid
.26429 .53403 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .53493 m
.26429 .53618 L
s
0 0 0 r
2 Mabswid
.26429 .53618 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49689 m
.97619 .1163 L
s
0 0 0 r
2 Mabswid
.97619 .1163 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49904 m
.97619 .76145 L
s
0 0 0 r
2 Mabswid
.97619 .76145 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49817 m
.97619 .12255 L
s
0 0 0 r
2 Mabswid
.97619 .12255 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50032 m
.97619 .76653 L
s
0 0 0 r
2 Mabswid
.97619 .76653 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49946 m
.97619 .12869 L
s
0 0 0 r
2 Mabswid
.97619 .12869 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .5016 m
.97619 .7716 L
s
0 0 0 r
2 Mabswid
.97619 .7716 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50074 m
.97619 .13474 L
s
0 0 0 r
2 Mabswid
.97619 .13474 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50288 m
.97619 .77667 L
s
0 0 0 r
2 Mabswid
.97619 .77667 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50202 m
.97619 .14069 L
s
0 0 0 r
2 Mabswid
.97619 .14069 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50416 m
.97619 .78174 L
s
0 0 0 r
2 Mabswid
.97619 .78174 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50331 m
.97619 .14655 L
s
0 0 0 r
2 Mabswid
.97619 .14655 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50544 m
.97619 .78681 L
s
0 0 0 r
2 Mabswid
.97619 .78681 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50459 m
.97619 .15232 L
s
0 0 0 r
2 Mabswid
.97619 .15232 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50672 m
.97619 .79189 L
s
0 0 0 r
2 Mabswid
.97619 .79189 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50587 m
.97619 .158 L
s
0 0 0 r
2 Mabswid
.97619 .158 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .508 m
.97619 .79696 L
s
0 0 0 r
2 Mabswid
.97619 .79696 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50716 m
.97619 .1636 L
s
0 0 0 r
2 Mabswid
.97619 .1636 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50928 m
.97619 .80203 L
s
0 0 0 r
2 Mabswid
.97619 .80203 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50844 m
.97619 .16912 L
s
0 0 0 r
2 Mabswid
.97619 .16912 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51057 m
.97619 .8071 L
s
0 0 0 r
2 Mabswid
.97619 .8071 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50972 m
.97619 .17455 L
s
0 0 0 r
2 Mabswid
.97619 .17455 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51185 m
.97619 .81217 L
s
0 0 0 r
2 Mabswid
.97619 .81217 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .511 m
.97619 .17991 L
s
0 0 0 r
2 Mabswid
.97619 .17991 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51313 m
.97619 .81725 L
s
0 0 0 r
2 Mabswid
.97619 .81725 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51228 m
.97619 .1852 L
s
0 0 0 r
2 Mabswid
.97619 .1852 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51441 m
.97619 .82232 L
s
0 0 0 r
2 Mabswid
.97619 .82232 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51356 m
.97619 .19041 L
s
0 0 0 r
2 Mabswid
.97619 .19041 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51569 m
.97619 .82739 L
s
0 0 0 r
2 Mabswid
.97619 .82739 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51485 m
.97619 .19555 L
s
0 0 0 r
2 Mabswid
.97619 .19555 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51697 m
.97619 .83246 L
s
0 0 0 r
2 Mabswid
.97619 .83246 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51613 m
.97619 .20062 L
s
0 0 0 r
2 Mabswid
.97619 .20062 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51825 m
.97619 .83753 L
s
0 0 0 r
2 Mabswid
.97619 .83753 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51741 m
.97619 .20563 L
s
0 0 0 r
2 Mabswid
.97619 .20563 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51953 m
.97619 .84261 L
s
0 0 0 r
2 Mabswid
.97619 .84261 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51869 m
.97619 .21057 L
s
0 0 0 r
2 Mabswid
.97619 .21057 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52081 m
.97619 .84768 L
s
0 0 0 r
2 Mabswid
.97619 .84768 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51997 m
.97619 .21544 L
s
0 0 0 r
2 Mabswid
.97619 .21544 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52209 m
.97619 .85275 L
s
0 0 0 r
2 Mabswid
.97619 .85275 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52125 m
.97619 .22026 L
s
0 0 0 r
2 Mabswid
.97619 .22026 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52337 m
.97619 .85782 L
s
0 0 0 r
2 Mabswid
.97619 .85782 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52253 m
.97619 .22501 L
s
0 0 0 r
2 Mabswid
.97619 .22501 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52465 m
.97619 .86289 L
s
0 0 0 r
2 Mabswid
.97619 .86289 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52381 m
.97619 .2297 L
s
0 0 0 r
2 Mabswid
.97619 .2297 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52593 m
.97619 .86796 L
s
0 0 0 r
2 Mabswid
.97619 .86796 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52508 m
.97619 .23434 L
s
0 0 0 r
2 Mabswid
.97619 .23434 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52721 m
.97619 .87304 L
s
0 0 0 r
2 Mabswid
.97619 .87304 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52636 m
.97619 .23892 L
s
0 0 0 r
2 Mabswid
.97619 .23892 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52849 m
.97619 .87811 L
s
0 0 0 r
2 Mabswid
.97619 .87811 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52764 m
.97619 .24344 L
s
0 0 0 r
2 Mabswid
.97619 .24344 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52977 m
.97619 .88318 L
s
0 0 0 r
2 Mabswid
.97619 .88318 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52892 m
.97619 .24792 L
s
0 0 0 r
2 Mabswid
.97619 .24792 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .53106 m
.97619 .88825 L
s
0 0 0 r
2 Mabswid
.97619 .88825 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .5302 m
.97619 .25233 L
s
0 0 0 r
2 Mabswid
.97619 .25233 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .53234 m
.97619 .89332 L
s
0 0 0 r
2 Mabswid
.97619 .89332 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .53148 m
.97619 .2567 L
s
0 0 0 r
2 Mabswid
.97619 .2567 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .53362 m
.97619 .8984 L
s
0 0 0 r
2 Mabswid
.97619 .8984 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .53276 m
.97619 .26102 L
s
0 0 0 r
2 Mabswid
.97619 .26102 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .5349 m
.97619 .90347 L
s
0 0 0 r
2 Mabswid
.97619 .90347 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .53403 m
.97619 .26529 L
s
0 0 0 r
2 Mabswid
.97619 .26529 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .53618 m
.97619 .90854 L
s
0 0 0 r
2 Mabswid
.97619 .90854 Mdot
[(G)] .26178 .02381 0 0 Mshowa
[(S2)] .97619 .48345 0 0 Mshowa
[(S1)] .97619 .02381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[9]:=",
  ImageSize->{438.062, 438.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006f0001]R000`400?l00000o`00003oLP3oool0
0`000000oooo0?ooo`3o0?oood80oooo001b0?ooo`<00000o`3ooom20?ooo`00LP3oool00`000000
oooo0?ooo`3o0?oood80oooo001b0?ooo`030000003oool0oooo0?l0oooo@P3oool00780oooo00<0
00000?ooo`3oool0o`3ooom20?ooo`00LP3oool00`000000oooo0?ooo`3o0?oood80oooo001b0?oo
o`030000003oool0oooo0?l0oooo@P3oool00780oooo00<000000?ooo`3oool0o`3ooom20?ooo`00
L03oool300000?l0oooo<`3oool010000000oooo0000000000030?ooo`<000001`3oool006l0oooo
00<000000?ooo`3oool00P00003o0?oooc80oooo0P0000020?ooo`050000003oool0oooo0?ooo`00
0000203oool006h0oooo00@000000?ooo`3oool0oooo0P00003o0?oooc80oooo00<000000?ooo`3o
ool00P0000030?ooo`030000003oool0oooo00H0oooo001^0?ooo`030000003oool0oooo00<00000
o`3ooolc0?ooo`<00000103oool00`000000oooo0?ooo`060?ooo`00KP3oool01@000000oooo0?oo
o`3oool000000?l0oooo<`3oool200000080oooo00D000000?ooo`3oool0oooo000000080?ooo`00
K`3oool00`000000oooo0?ooo`0200000?l0oooo<P3oool00`000000oooo0?ooo`0200000080oooo
0P0000080?ooo`00L03oool400000?l0oooo<`3oool2000000030?ooo`000000oooo0080oooo00<0
00000?ooo`3oool01P3oool00780oooo00<000000?ooo`3oool0o`3ooom20?ooo`00LP3oool00`00
0000oooo0?ooo`3o0?oood80oooo001b0?ooo`<00000o`3ooom20?ooo`00LP3oool00`000000oooo
0?ooo`3o0?oood80oooo001b0?ooo`030000003oool0oooo0?l0oooo@P3oool00780oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`00LP3oool00`000000oooo0?ooo`3o0?oood80oooo001b0?ooo`03
0000003oool0oooo0?l0oooo@P3oool00780oooo00<000000?ooo`3oool0o`3ooom20?ooo`00LP3o
ool00`000000oooo0?ooo`3o0?oood80oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0
oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`80
0000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000
003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b
0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?oo
o`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0
oooo001b0?ooo`<00000o`3ooolf0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3o
oolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0
oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`80
0000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000
003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b
0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?oo
o`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0
oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3o
oolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0
oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`80
0000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000
003oool0oooo00T0oooo001b0?ooo`<00000o`3ooolf0?ooo`030000003oool0oooo00T0oooo001b
0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolf0?oo
o`0300;F70000000000000X0oooo001b0?ooo`800000o`3ooold0?ooo`800]HL00<0oooo00000000
00002P3oool00780oooo0P00003o0?oooc80oooo0P02eQ`30?ooo`8000002P3oool00780oooo0P00
003o0?oooc00oooo0P02eQ`40?ooo`0300;F70000000000000X0oooo001b0?ooo`800000o`3oool_
0?ooo`0300;F703oool0oooo0080oooo0P02eQ`00`3oool000000?ooo`0:0?ooo`00LP3oool20000
0?l0oooo;@3oool200;F70<0oooo0P02eQ`30?ooo`8000002P3oool00780oooo0P00003o0?ooob/0
oooo0P02eQ`30?ooo`800]HL103oool00`02eQ`000000000000:0?ooo`00LP3oool200000?l0oooo
:@3oool200;F70<0oooo0P02eQ`40?ooo`800]HL00<0oooo0000003oool02P3oool00780oooo0P00
003o0?ooobL0oooo0P02eQ`40?ooo`0300;F703oool0oooo0080oooo0P02eQ`20?ooo`0300;F7000
0000000000X0oooo001b0?ooo`800000o`3ooolU0?ooo`800]HL103oool200;F70<0oooo0P02eQ`2
0?ooo`800]HL00<0oooo0000000000002P3oool00780oooo0P00003o0?ooob<0oooo0P02eQ`40?oo
o`800]HL0`3oool200;F7080oooo0P02eQ`30?ooo`8000002P3oool00780oooo0P00003o0?ooob80
oooo00<00]HL0?ooo`3oool00P3oool200;F70<0oooo0P02eQ`20?ooo`800]HL103oool00`02eQ`0
00000000000:0?ooo`00H`3oool400000080oooo0P0000070?ooo`800000o`3ooolP0?ooo`800]HL
0`3oool200;F70@0oooo00<00]HL0?ooo`3oool00P02eQ`40?ooo`800]HL00<0oooo0000003oool0
2P3oool006<0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00@0
oooo0P00003o0?oooah0oooo0P02eQ`30?ooo`800]HL103oool200;F70030?ooo`02eQ`00]HL00@0
oooo0P02eQ`20?ooo`0300;F70000000000000X0oooo001P0?ooo`<0000000<0oooo0000003oool0
0P3oool010000000oooo0?ooo`0000060?ooo`@00000o`3ooolJ0?ooo`800]HL0`3oool200;F70@0
oooo0P02eQ`00`3oool00]HL00;F70040?ooo`800]HL0P3oool200;F70030?ooo`000000000000X0
oooo001U0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool200000?l0
oooo6P3oool200;F70<0oooo0P02eQ`40?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F7080
oooo0P02eQ`30?ooo`030000003oool0oooo00T0oooo001V0?ooo`030000003oool000000080oooo
00<000000?ooo`3oool0103oool200000?l0oooo603oool200;F70<0oooo0P02eQ`40?ooo`800]HL
00<0oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`40?ooo`0300;F70000000000000X0oooo
001S0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`040?ooo`80
0000o`3ooolF0?ooo`800]HL103oool00`02eQ`0oooo0?ooo`020?ooo`800]HL0P3oool00`02eQ`0
oooo0?ooo`020?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`00`3oool000000000000:0?ooo`00
I03oool2000000<0oooo0P0000070?ooo`800000o`3ooolE0?ooo`0300;F703oool0oooo0080oooo
0P02eQ`30?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`20?ooo`800]HL103oool200;F7080oooo
00<00]HL0000000000002P3oool00780oooo0P00003o0?oooa<0oooo0P02eQ`30?ooo`800]HL0`3o
ool200;F7080oooo0P02eQ`30?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL00<0
oooo0000000000002P3oool00780oooo0P00003o0?oooa40oooo0P02eQ`30?ooo`800]HL0`3oool2
00;F7080oooo0P02eQ`30?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0`3oool2
000000X0oooo001b0?ooo`800000o`3oool?0?ooo`800]HL0`3oool200;F70<0oooo0P02eQ`20?oo
o`800]HL0`3oool200;F7080oooo0P02eQ`40?ooo`800]HL0P3oool200;F70@0oooo00<00]HL0000
000000002P3oool00780oooo0P00003o0?ooo`d0oooo0P02eQ`30?ooo`800]HL0`3oool200;F7080
oooo0P02eQ`30?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL103oool200;F7003
0?ooo`000000oooo00X0oooo001b0?ooo`800000o`3oool;0?ooo`800]HL0`3oool200;F70<0oooo
0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0P02eQ`40?ooo`800]HL0P3oool200;F70@0oooo
0P02eQ`20?ooo`0300;F70000000000000X0oooo001b0?ooo`800000o`3oool90?ooo`800]HL0`3o
ool200;F70<0oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0P02eQ`40?ooo`800]HL0P3o
ool200;F70@0oooo0P02eQ`20?ooo`800]HL00<0oooo0000000000002P3oool00780oooo0P00003o
0?ooo`P0oooo00@00]HL0?ooo`3oool0oooo0P02eQ`40?ooo`0300;F703oool0oooo00800]HL0`3o
ool200;F7080oooo0P02eQ`40?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0`3o
ool2000000X0oooo001b0?ooo`800000o`3oool60?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`0
0`3oool00]HL00;F70030?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL103oool2
00;F7080oooo0P02eQ`40?ooo`0300;F70000000000000X0oooo001b0?ooo`800000o`3oool40?oo
o`800]HL0`3oool00`02eQ`0oooo0?ooo`020?ooo`800]HL00<0oooo00;F7002eQ`0103oool00`02
eQ`0oooo0?ooo`0200;F70@0oooo0P02eQ`20?ooo`800]HL103oool200;F7080oooo0P02eQ`40?oo
o`800]HL00<0oooo0000003oool02P3oool00780oooo0P00003o0?ooo`80oooo0P02eQ`30?ooo`80
0]HL0`3oool200;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`00`3oool00]HL00;F70040?ooo`80
0]HL0P3oool200;F70<0oooo0`02eQ`20?ooo`800]HL103oool200;F7080oooo00<00]HL00000000
00002P3oool00780oooo0P00003o0?ooo`800]HL0`3oool200;F70<0oooo0P02eQ`00`3oool00]HL
00;F70040?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`30?ooo`800]HL
0P3oool300;F70@0oooo0P02eQ`20?ooo`800]HL00<0oooo0000000000002P3oool00780oooo0P00
003m0?ooo`800]HL0`3oool200;F70<0oooo0P02eQ`00`3oool00]HL00;F70040?ooo`800]HL00<0
oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`30?ooo`800]HL0P3oool200;F70@0oooo0`02
eQ`20?ooo`800]HL0P3oool00`02eQ`000000000000:0?ooo`00LP3oool300000?X0oooo0P02eQ`3
0?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`00`3oool00]HL00;F7004
0?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`20?ooo`800]HL103oool200;F7080oooo0`02eQ`2
0?ooo`800]HL00<0oooo0000000000002P3oool00780oooo0P00003i0?ooo`800]HL0`3oool200;F
70<0oooo0P02eQ`00`3oool00]HL00;F70040?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F
7080oooo0P02eQ`30?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0`3oool200;F
70<0oooo0P00000:0?ooo`00LP3oool200000?P0oooo00@00]HL0?ooo`3oool0oooo0P02eQ`30?oo
o`800]HL00<0oooo00;F7002eQ`0103oool200;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`0103o
ool00]HL00;F7002eQ`30?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool3
00;F70@0oooo00<00]HL0000000000002P3oool00780oooo0P00003f0?ooo`800]HL0P3oool200;F
70<0oooo0P02eQ`00`3oool00]HL00;F70040?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F
70030?ooo`02eQ`00]HL00@0oooo0P02eQ`20?ooo`800]HL103oool200;F7080oooo0P02eQ`20?oo
o`800]HL1@3oool200;F70030?ooo`000000000000X0oooo001b0?ooo`800000m03oool200;F7080
oooo0P02eQ`30?ooo`800]HL0P3oool00`02eQ`0oooo0?ooo`020?ooo`800]HL00<0oooo00;F7002
eQ`0103oool200;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`20?ooo`800]HL103oool200;F7080
oooo0P02eQ`20?ooo`800]HL103oool300;F7080oooo00<00]HL0000000000002P3oool00780oooo
0P00003b0?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`20?ooo`800]HL0`3oool200;F70030?oo
o`02eQ`00]HL00@0oooo0P02eQ`00`3oool00]HL00;F70040?ooo`800]HL0P3oool200;F70@0oooo
0P02eQ`20?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`30?ooo`800]HL00<0oooo0000003oool0
2P3oool00780oooo0P00003`0?ooo`800]HL0`3oool00`02eQ`0oooo0?ooo`020?ooo`0300;F703o
ool0oooo00800]HL0`3oool200;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`00`3oool00]HL00;F
70040?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool200;F70@0oooo0P02
eQ`20?ooo`<00]HL0P3oool00`02eQ`000000000000:0?ooo`00LP3oool200000>h0oooo0P02eQ`3
0?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`00`3oool00]HL00;F7004
0?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`30?ooo`<00]HL00@0oooo
00;F7002eQ`00]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0`3oool200;F70030?ooo`00
0000000000X0oooo001b0?ooo`800000k03oool200;F70<0oooo0P02eQ`30?ooo`800]HL00<0oooo
00;F7002eQ`00`3oool200;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`00`3oool00]HL00;F7004
0?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`20?ooo`800]HL0P3oool300;F70@0oooo0P02eQ`2
0?ooo`800]HL0P3oool300;F7080oooo00<00]HL0000000000002P3oool00780oooo0P00003[0?oo
o`0400;F703oool0oooo0?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`0
0`3oool00]HL00;F70040?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F70040?ooo`02eQ`0
0]HL00;F70<0oooo0P02eQ`20?ooo`800]HL0P3oool200;F70@0oooo0`02eQ`20?ooo`800]HL0P3o
ool200;F70<0oooo0P02eQ`00`3oool000000000000:0?ooo`00LP3oool200000>T0oooo0P02eQ`2
0?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`00`3oool00]HL00;F7004
0?ooo`800]HL00<0oooo00;F7002eQ`00`3oool300;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`2
0?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`<00]HL0P3oool200;F7080oooo0`02eQ`2
0?ooo`0300;F70000000000000X0oooo001b0?ooo`800000i`3oool200;F7080oooo0P02eQ`30?oo
o`800]HL00<0oooo00;F7002eQ`00`3oool200;F70030?ooo`02eQ`00]HL00<0oooo0`02eQ`00`3o
ool00]HL00;F70030?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool200;F
70@0oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0P02eQ`30?ooo`800]HL00<0oooo0000
000000002P3oool00780oooo0P00003U0?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`00`3oool0
0]HL00;F70030?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F7080oooo0P02eQ`30?ooo`80
0]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`80
0]HL0P3oool300;F7080oooo0P02eQ`20?ooo`<00]HL0`3oool2000000X0oooo001b0?ooo`800000
h`3oool200;F7080oooo0P02eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F70030?oo
o`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0P02eQ`40?ooo`800]HL
0P3oool200;F70040?ooo`02eQ`00]HL00;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool200;F70<0
oooo0P02eQ`20?ooo`800]HL1@3oool00`02eQ`000000000000:0?ooo`00LP3oool200000>40oooo
0P02eQ`20?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`00`3oool00]HL
00;F70030?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`20?ooo`800]HL0`3oool300;F70050?oo
o`02eQ`00]HL00;F703oool00P02eQ`40?ooo`<00]HL0P3oool200;F7080oooo0P02eQ`20?ooo`<0
0]HL0P3oool200;F70@0oooo0`02eQ`00`3oool000000000000:0?ooo`00LP3oool200000=l0oooo
0P02eQ`30?ooo`0400;F703oool0oooo0?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F7003
0?ooo`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0P02eQ`30?ooo`80
0]HL0P3oool200;F7080oooo0P02eQ`40?ooo`800]HL0P3oool300;F7080oooo0P02eQ`20?ooo`80
0]HL0P3oool300;F70@0oooo0P02eQ`30?ooo`0300;F70000000000000X0oooo001b0?ooo`<00000
g@3oool01002eQ`0oooo0?ooo`3oool200;F7080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`80
0]HL00<0oooo00;F7002eQ`00`3oool200;F7080oooo0P02eQ`30?ooo`800]HL0P3oool200;F70<0
oooo0P02eQ`20?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool300;F7080
oooo0P02eQ`20?ooo`800]HL1@3oool200;F7080oooo0`02eQ`00`3oool000000000000:0?ooo`00
LP3oool200000=`0oooo0P02eQ`20?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL00<0oooo
0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`20?ooo`800]HL
0`3oool200;F7080oooo0P02eQ`20?ooo`800]HL103oool200;F7080oooo0P02eQ`20?ooo`800]HL
0P3oool300;F7080oooo0P02eQ`40?ooo`<00]HL0P3oool200;F70<0oooo00<00]HL000000000000
2P3oool00780oooo0P00003J0?ooo`800]HL0P3oool200;F7080oooo0P02eQ`00`3oool00]HL00;F
70030?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F7080oooo0P02eQ`30?ooo`800]HL0P3o
ool200;F70<0oooo0P02eQ`20?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0P3o
ool200;F7080oooo0P02eQ`20?ooo`<00]HL103oool200;F70<0oooo0P02eQ`20?ooo`<00]HL00<0
oooo0000000000002P3oool00780oooo0P00003H0?ooo`800]HL0P3oool200;F70<0oooo00@00]HL
0?ooo`02eQ`00]HL0`3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL0`3o
ool200;F7080oooo0P02eQ`30?ooo`800]HL0P3oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo
0`02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`50?ooo`80
0]HL0P3oool300;F7080oooo0P02eQ`30?ooo`0300;F70000000000000X0oooo001b0?ooo`800000
eP3oool200;F7080oooo0P02eQ`30?ooo`@00]HL0`3oool200;F70030?ooo`02eQ`00]HL00<0oooo
0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0P02eQ`30?ooo`800]HL0P3oool200;F70030?oo
o`02eQ`00]HL00@0oooo0P02eQ`20?ooo`800]HL0P3oool300;F7080oooo0P02eQ`20?ooo`800]HL
103oool300;F7080oooo0P02eQ`30?ooo`800]HL0P3oool300;F70030?ooo`000000000000X0oooo
001b0?ooo`800000e03oool200;F7080oooo0P02eQ`30?ooo`800]HL00<0oooo00;F703oool00P3o
ool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL0`3oool200;F70040?ooo`02
eQ`00]HL00;F70<0oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL103oool200;F7080
oooo0P02eQ`20?ooo`800]HL0P3oool300;F7080oooo0P02eQ`40?ooo`800]HL0`3oool200;F7080
oooo0`02eQ`20?ooo`800]HL0`3oool00`02eQ`000000000000:0?ooo`00LP3oool200000=80oooo
0P02eQ`20?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL
00;F70030?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`00`3oool00]HL00;F70030?ooo`<00]HL
00<0oooo00;F7002eQ`00P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo
0P02eQ`20?ooo`<00]HL103oool200;F7080oooo0`02eQ`20?ooo`800]HL0P3oool300;F7080oooo
0`02eQ`00`3oool000000000000:0?ooo`00LP3oool200000=40oooo00<00]HL0?ooo`3oool00P02
eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02
eQ`20?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL0P3o
ool200;F70@0oooo0P02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL0P3oool200;F7080oooo
0P02eQ`40?ooo`<00]HL0P3oool200;F7080oooo0`02eQ`20?ooo`800]HL0`3oool200;F70<0oooo
00<00]HL0000000000002P3oool00780oooo0P00003?0?ooo`800]HL00<0oooo00;F7002eQ`00`3o
ool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL0P3o
ool200;F7080oooo0`02eQ`00`3oool00]HL00;F70030?ooo`800]HL0P3oool200;F7080oooo0P02
eQ`30?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool300;F7080oooo0P02eQ`20?ooo`800]HL103o
ool200;F7080oooo0`02eQ`20?ooo`800]HL0`3oool200;F7080oooo0`02eQ`20?ooo`<00]HL00<0
oooo0000000000002P3oool00780oooo0P00003=0?ooo`800]HL0P3oool01002eQ`0oooo0?ooo`3o
ool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL0P3o
ool200;F7080oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0P02eQ`0103oool00]HL00;F
7002eQ`30?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`<00]HL00@0oooo00;F7002eQ`0
0]HL103oool200;F7080oooo0P02eQ`30?ooo`800]HL0P3oool300;F7080oooo0P02eQ`30?ooo`80
0]HL0`3oool00`02eQ`000000000000:0?ooo`00LP3oool200000</0oooo0P02eQ`20?ooo`800]HL
0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL
0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0P02eQ`00`3oool00]HL
00;F70040?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool200;F70@0oooo
0`02eQ`20?ooo`800]HL0P3oool300;F7080oooo0P02eQ`30?ooo`800]HL0P3oool300;F7080oooo
0`02eQ`00`3oool000000000000:0?ooo`00LP3oool200000<T0oooo0P02eQ`20?ooo`800]HL0P3o
ool200;F70030?ooo`02eQ`00]HL00<0oooo00@00]HL0?ooo`02eQ`00]HL0`3oool200;F7080oooo
0P02eQ`20?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`0
103oool200;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`20?ooo`800]HL0P3oool200;F70@0
oooo0P02eQ`20?ooo`<00]HL0P3oool200;F7080oooo0`02eQ`20?ooo`<00]HL0P3oool200;F70<0
oooo0P02eQ`30?ooo`0300;F70000000000000X0oooo001b0?ooo`800000a`3oool200;F7080oooo
0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`3oool400;F70<0oooo0P02eQ`20?ooo`800]HL
0P3oool200;F7080oooo0P02eQ`30?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70@0
oooo0P02eQ`00`3oool00]HL00;F70020?ooo`<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F
70@0oooo0P02eQ`20?ooo`800]HL0P3oool300;F7080oooo0P02eQ`30?ooo`800]HL0P3oool300;F
7080oooo0`02eQ`20?ooo`<00]HL00<0oooo0000000000002P3oool00780oooo0P0000350?ooo`80
0]HL0P3oool200;F7080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`@00]HL0`3oool200;F7080
oooo0P02eQ`20?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`80
0]HL0`3oool300;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL0P3oool200;F70@0
oooo0`02eQ`20?ooo`800]HL0P3oool200;F7080oooo0`02eQ`20?ooo`<00]HL0P3oool200;F70<0
oooo0P02eQ`30?ooo`800]HL0`3oool00`02eQ`000000000000:0?ooo`00LP3oool200000<<0oooo
0P02eQ`20?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL00<0oooo1002eQ`30?ooo`800]HL
0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool300;F70040?ooo`02eQ`00]HL0?ooo`<0
0]HL0`3oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`40?ooo`80
0]HL0P3oool300;F7080oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0`02eQ`20?ooo`<0
0]HL0P3oool300;F7080oooo0`02eQ`00`3oool000000000000:0?ooo`00LP3oool200000<80oooo
00<00]HL0?ooo`3oool00P02eQ`30?ooo`0400;F703oool00]HL00;F70<0oooo1002eQ`30?ooo`80
0]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`00`3oool0
0]HL00;F70040?ooo`800]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F7080oooo0P02eQ`0103o
ool00]HL00;F7002eQ`40?ooo`800]HL0P3oool200;F7080oooo0`02eQ`20?ooo`800]HL0P3oool3
00;F7080oooo0P02eQ`30?ooo`800]HL0`3oool200;F70<0oooo0P02eQ`30?ooo`0300;F70000000
000000X0oooo001b0?ooo`<00000_`3oool200;F70030?ooo`02eQ`00]HL00<0oooo1002eQ`30?oo
o`@00]HL0`3oool200;F7080oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`00]HL0P3oool2
00;F7080oooo0P02eQ`00`3oool00]HL00;F70040?ooo`800]HL00<0oooo00;F7002eQ`00P3oool3
00;F70050?ooo`02eQ`00]HL00;F703oool00P02eQ`40?ooo`<00]HL00@0oooo00;F7002eQ`00]HL
0P3oool200;F7080oooo0`02eQ`20?ooo`800]HL0P3oool300;F7080oooo0`02eQ`20?ooo`<00]HL
0P3oool300;F7080oooo0`02eQ`00`3oool000000000000:0?ooo`00LP3oool200000;h0oooo0P02
eQ`00`3oool00]HL00;F70030?ooo`@00]HL0`3oool400;F70<0oooo0P02eQ`0103oool00]HL00;F
7002eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F7080oooo0P02eQ`00`3oool00]HL
00;F70040?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`20?ooo`800]HL
103oool200;F7080oooo0P02eQ`30?ooo`800]HL0P3oool200;F7080oooo0`02eQ`20?ooo`800]HL
0`3oool200;F70<0oooo0P02eQ`20?ooo`<00]HL0`3oool200;F70<0oooo00<00]HL000000000000
2P3oool00780oooo0P00002l0?ooo`800]HL00<0oooo00;F7002eQ`00`3oool400;F70<0oooo1002
eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02
eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`3oool300;F70030?ooo`02eQ`00]HL0080oooo0P02
eQ`20?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool300;F70040?ooo`02
eQ`00]HL00;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool300;F7080oooo0`02eQ`20?ooo`800]HL
0`3oool300;F7080oooo1002eQ`2000000X0oooo001b0?ooo`800000^P3oool200;F7080oooo00@0
0]HL0?ooo`3oool0oooo1002eQ`30?ooo`@00]HL0`3oool200;F70030?ooo`02eQ`00]HL00<0oooo
0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70<0
oooo0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`0103oool00]HL00;F7002eQ`30?oo
o`<00]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool2
00;F70<0oooo0P02eQ`30?ooo`800]HL0P3oool300;F7080oooo0`02eQ`20?ooo`H00]HL00<0oooo
0000000000002P3oool00780oooo0P00002h0?ooo`800]HL0P3oool200;F7080oooo1002eQ`30?oo
o`@00]HL0`3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`00`3oool00]HL00;F70030?oo
o`800]HL00@0oooo00;F7002eQ`0oooo0`02eQ`30?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?oo
o`0300;F70050?ooo`02eQ`00]HL00;F703oool00P02eQ`40?ooo`800]HL0P3oool200;F7080oooo
0`02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL0P3oool300;F7080oooo0`02eQ`20?ooo`<0
0]HL0P3oool200;F70<0oooo0P02eQ`30?ooo`D00]HL103oool00`000000oooo0?ooo`090?ooo`00
LP3oool200000;H0oooo0P02eQ`20?ooo`800]HL0P3oool400;F70<0oooo1002eQ`30?ooo`800]HL
00<0oooo00;F7002eQ`00`3oool200;F70030?ooo`02eQ`00]HL0080oooo0`02eQ`0103oool00]HL
00;F703oool200;F70@0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F7080
oooo0P02eQ`40?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080
oooo0P02eQ`30?ooo`800]HL0P3oool300;F7080oooo0`02eQ`20?ooo`<00]HL0P3oool500;F70L0
oooo00<000000?ooo`3oool02@3oool00780oooo0P00002e0?ooo`0300;F703oool0oooo00800]HL
0P3oool400;F70<0oooo1002eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P3oool300;F70030?oo
o`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`3oool300;F70030?oo
o`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`00]HL0`3oool300;F7004
0?ooo`02eQ`00]HL00;F7080oooo0P02eQ`20?ooo`800]HL0P3oool300;F70040?ooo`02eQ`00]HL
00;F7080oooo0`02eQ`20?ooo`800]HL0`3oool200;F70<0oooo0P02eQ`30?ooo`D00]HL2@3oool0
0`000000oooo0?ooo`090?ooo`00LP3oool200000;<0oooo0P02eQ`00`3oool00]HL00;F70020?oo
o`800]HL00<0oooo00;F703oool00P3oool400;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?oo
o`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F
7080oooo0P02eQ`20?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70@0oooo0P02eQ`2
0?ooo`800]HL0P3oool300;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`20?ooo`800]HL0`3o
ool200;F7080oooo0`02eQ`20?ooo`<00]HL0P3oool300;F7080oooo1@02eQ`<0?ooo`030000003o
ool0oooo00T0oooo001b0?ooo`800000/@3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`0
0`3oool00]HL00;F70020?ooo`@00]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`2
0?ooo`800]HL0P3oool200;F7080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL00D0oooo
00;F7002eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`40?ooo`800]HL00@0
oooo00;F7002eQ`00]HL0P3oool200;F7080oooo0P02eQ`20?ooo`<00]HL00@0oooo00;F7002eQ`0
0]HL0P3oool300;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool300;F7080oooo1P02eQ`>0?ooo`03
0000003oool0oooo00T0oooo001b0?ooo`800000[`3oool200;F70030?ooo`02eQ`00]HL0080oooo
0P02eQ`00`3oool00]HL00;F70020?ooo`@00]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo
0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL
00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`0103oool00]HL00;F7002eQ`30?ooo`<0
0]HL00<0oooo00;F7002eQ`00P3oool300;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`20?oo
o`800]HL0`3oool200;F7080oooo0`02eQ`20?ooo`800]HL0`3oool200;F70<0oooo1@02eQ`A0?oo
o`030000003oool0oooo00T0oooo001b0?ooo`800000[@3oool200;F70030?ooo`02eQ`00]HL0080
oooo0P02eQ`00`3oool00]HL00;F70020?ooo`@00]HL0`3oool200;F70030?ooo`02eQ`00]HL0080
oooo0P02eQ`20?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL00@00]HL0`3oool200;F7003
0?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F7080
oooo0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0`02eQ`0103oool00]HL00;F7002eQ`20?oo
o`<00]HL0P3oool200;F7080oooo0`02eQ`20?ooo`<00]HL0P3oool500;F71@0oooo00<000000?oo
o`3oool02@3oool00780oooo0P00002[0?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7003
0?ooo`02eQ`00]HL0080oooo1002eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080
oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`30?ooo`<00]HL00@0oooo00;F
7002eQ`0oooo0`02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL103oool200;F70040?ooo`02
eQ`00]HL00;F7080oooo0P02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL0P3oool200;F70<0
oooo0P02eQ`20?ooo`<00]HL0P3oool200;F70<0oooo0P02eQ`20?ooo`H00]HL5P3oool00`000000
oooo0?ooo`090?ooo`00LP3oool200000:T0oooo0P02eQ`20?ooo`0600;F703oool0oooo0?ooo`02
eQ`0oooo0P02eQ`20?ooo`@00]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`0103o
ool00]HL00;F7002eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`30?ooo`800]HL00D0
oooo00;F7002eQ`00]HL0?ooo`0200;F7080oooo0P02eQ`20?ooo`800]HL0`3oool300;F70030?oo
o`02eQ`00]HL0080oooo0`02eQ`00`3oool00]HL00;F70020?ooo`<00]HL0P3oool200;F7080oooo
0`02eQ`20?ooo`800]HL0P3oool300;F7080oooo0`02eQ`20?ooo`D00]HL6@3oool00`000000oooo
0?ooo`090?ooo`00LP3oool200000:P0oooo00<00]HL0?ooo`3oool00P02eQ`20?ooo`@00]HL0P3o
ool400;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F7002eQ`00P3o
ool300;F70040?ooo`02eQ`00]HL0?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo
0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`00]HL0`3oool200;F7080oooo0P02eQ`20?ooo`80
0]HL0P3oool200;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool200;F7080oooo0`02eQ`20?ooo`80
0]HL0P3oool300;F7080oooo1@02eQ`L0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000
YP3oool200;F70030?ooo`02eQ`00]HL0080oooo1002eQ`20?ooo`@00]HL0`3oool200;F70030?oo
o`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F70030?oo
o`02eQ`00]HL00<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F70030?oo
o`02eQ`00]HL00@0oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL00@0oooo00;F7002
eQ`00]HL0P3oool200;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool200;F7080oooo0`02eQ`20?oo
o`800]HL0P3oool600;F71h0oooo00<000000?ooo`3oool02@3oool00780oooo0P00002T0?ooo`80
0]HL00<0oooo00;F7002eQ`00P3oool400;F7080oooo1002eQ`30?ooo`800]HL00<0oooo00;F7002
eQ`00P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002
eQ`00`3oool200;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`02
00;F70<0oooo0`02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F7080oooo0`02eQ`0
103oool00]HL00;F7002eQ`20?ooo`800]HL0P3oool300;F70040?ooo`02eQ`00]HL00;F7080oooo
0`02eQ`20?ooo`D00]HL8@3oool00`000000oooo0?ooo`090?ooo`00LP3oool300000:40oooo0P02
eQ`00`3oool00]HL00;F70020?ooo`@00]HL0P3oool400;F70<0oooo0P02eQ`00`3oool00]HL00;F
70020?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo1@02eQ`20?ooo`H00]HL00<0
oooo00;F7002eQ`00P3oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo0P02eQ`0103oool00]HL
00;F7002eQ`20?ooo`800]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F7080oooo0P02eQ`20?oo
o`<00]HL0P3oool200;F7080oooo0P02eQ`30?ooo`800]HL0P3oool500;F72@0oooo00<000000?oo
o`3oool02@3oool00780oooo0P00002P0?ooo`800]HL00<0oooo00;F7002eQ`00P3oool400;F7080
oooo1002eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL0080
oooo0P02eQ`00`3oool00]HL00;F700300;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`80
0]HL0P3oool200;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`<0
0]HL00<0oooo00;F7002eQ`00P3oool300;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`20?oo
o`<00]HL00@0oooo00;F7002eQ`00]HL0P3oool300;F7080oooo1@02eQ`V0?ooo`030000003oool0
oooo00T0oooo001b0?ooo`800000WP3oool200;F70030?ooo`02eQ`00]HL0080oooo1002eQ`20?oo
o`@00]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70020?oo
o`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P3oool2
00;F7080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool2
00;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`20?ooo`800]HL0P3oool300;F7080oooo0P02
eQ`20?ooo`800]HL0P3oool300;F7080oooo1@02eQ`Y0?ooo`030000003oool0oooo00T0oooo001b
0?ooo`800000W03oool200;F70030?ooo`02eQ`00]HL0080oooo1002eQ`20?ooo`@00]HL0`3oool2
00;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool200;F70040?ooo`02
eQ`00]HL0?ooo`800]HL0`3oool200;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002
eQ`01002eQ`30?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL
0080oooo0`02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL0P3oool300;F70040?ooo`02eQ`0
0]HL00;F7080oooo0P02eQ`20?ooo`H00]HL:`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2
000009X0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`@00]HL0P3oool400;F70<0oooo0P02eQ`0
103oool00]HL00;F703oool200;F7080oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo
0P02eQ`30?ooo`D00]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL00@0oooo
0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL
0P3oool300;F7080oooo0P02eQ`20?ooo`800]HL0P3oool300;F7080oooo1@02eQ`^0?ooo`030000
003oool0oooo00T0oooo001b0?ooo`800000V@3oool01002eQ`0oooo00;F7002eQ`20?ooo`@00]HL
0P3oool400;F70<0oooo0P02eQ`0103oool00]HL00;F703oool200;F7080oooo0P02eQ`01@3oool0
0]HL00;F7002eQ`0oooo00D00]HL0P3oool500;F7080oooo0P02eQ`20?ooo`800]HL00<0oooo00;F
7002eQ`00`3oool300;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`01@3oool00]HL00;F7002eQ`0
oooo00<00]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F7080oooo0`02eQ`0103oool00]HL00;F
7002eQ`20?ooo`800]HL0P3oool500;F7340oooo00<000000?ooo`3oool02@3oool00780oooo0P00
002G0?ooo`800]HL00@0oooo00;F703oool0oooo1002eQ`20?ooo`@00]HL0`3oool200;F70040?oo
o`02eQ`00]HL0?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo1002eQ`30?ooo`80
0]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL00@00]HL0`3oool200;F7005
0?ooo`02eQ`00]HL00;F703oool00`02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F
7080oooo0`02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL0P3oool300;F70030?ooo`02eQ`0
0]HL00@00]HL<`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000009D0oooo0P02eQ`0103o
ool00]HL00;F703oool400;F7080oooo1002eQ`30?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02
eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL0P3oool400;F70<0oooo0P02eQ`0103oool00]HL
00;F703oool300;F70040?ooo`02eQ`00]HL0?ooo`800]HL103oool200;F70030?ooo`02eQ`00]HL
0080oooo0P02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL00@0oooo00;F7002eQ`00]HL0P3o
ool200;F7080oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo1@02eQ`f0?ooo`030000003o
ool0oooo00T0oooo001b0?ooo`800000T`3oool200;F70030?ooo`02eQ`00]HL0080oooo0`02eQ`2
0?ooo`@00]HL0`3oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`00P3o
ool200;F70030?ooo`02eQ`00]HL00<00]HL0`3oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL
0P3oool200;F70030?ooo`02eQ`00]HL00<0oooo1P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`0
0P3oool300;F70030?ooo`02eQ`00]HL0080oooo0`02eQ`01@3oool00]HL00;F7002eQ`0oooo00<0
0]HL0P3oool300;F70030?ooo`02eQ`00]HL00<00]HL>@3oool00`000000oooo0?ooo`090?ooo`00
LP3oool200000940oooo0P02eQ`00`3oool00]HL00;F70020?ooo`<00]HL0P3oool400;F70<0oooo
0P02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`0103oool0
0]HL00;F703oool200;F70<0oooo1@02eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F
7002eQ`00`3oool200;F70030?ooo`02eQ`00]HL0080oooo1P02eQ`20?ooo`800]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0300;F7080oooo0P02eQ`20?ooo`800]HL0P3oool300;F70030?ooo`02eQ`0
0]HL00@00]HL>`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000008l0oooo0P02eQ`00`3o
ool00]HL00;F70020?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`30?ooo`800]HL00@0oooo00;F
7002eQ`0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02
eQ`20?ooo`D00]HL0P3oool200;F70030?ooo`02eQ`00]HL00@00]HL0`3oool200;F70030?ooo`02
eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70020?ooo`<00]HL00<0oooo00;F7002eQ`00P3o
ool200;F7080oooo0`02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL0P3oool500;F73h0oooo
00<000000?ooo`3oool02@3oool00780oooo0P00002=0?ooo`800]HL00<0oooo00;F7002eQ`00P3o
ool400;F7080oooo0`02eQ`30?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL
00;F70020?ooo`800]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0
oooo0`02eQ`0103oool00]HL00;F703oool200;F70<0oooo1P02eQ`01@3oool00]HL00;F7002eQ`0
oooo00800]HL0P3oool200;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`20?ooo`800]HL0P3o
ool200;F7080oooo0`02eQ`00`3oool00]HL00;F700300;F7440oooo00<000000?ooo`3oool02@3o
ool00780oooo0P00002<0?ooo`0400;F703oool00]HL00;F7080oooo1002eQ`20?ooo`<00]HL0`3o
ool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0`02eQ`00`3oool0
0]HL00;F700200;F70<0oooo0P02eQ`0103oool00]HL00;F703oool200;F7080oooo0P02eQ`00`3o
ool00]HL00;F70030?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70050?ooo`02eQ`00]HL
00;F703oool00`02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool300;F70040?ooo`02eQ`0
0]HL00;F7080oooo0P02eQ`20?ooo`D00]HL@`3oool00`000000oooo0?ooo`090?ooo`00I03oool3
00000080oooo0P0000070?ooo`800000RP3oool400;F7080oooo1002eQ`20?ooo`@00]HL0P3oool2
00;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`20?ooo`@00]HL
0`3oool500;F70030?ooo`02eQ`00]HL0080oooo1@02eQ`30?ooo`800]HL00<0oooo00;F7002eQ`0
0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<0
0]HL0P3oool200;F70040?ooo`02eQ`00]HL00;F7080oooo0`02eQ`00`3oool00]HL00;F700300;F
74H0oooo00<000000?ooo`3oool02@3oool006D0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`040?ooo`800000R03oool400;F7080oooo1002eQ`20?ooo`@00]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`00P3o
ool400;F70<0oooo1002eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`02eQ`30?ooo`H00]HL00<0
oooo00;F7002eQ`01002eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL0P3oool200;F7080oooo
0`02eQ`00`3oool00]HL00;F70020?ooo`<00]HL00<0oooo00;F7002eQ`01002eQa80?ooo`030000
003oool0oooo00T0oooo001P0?ooo`<000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00@0oooo0P0000260?ooo`@00]HL0P3oool400;F7080oooo1002eQ`0103oool00]HL
00;F703oool300;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo1@02eQ`2
0?ooo`D00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70030?ooo`02eQ`00]HL00<0oooo0P02
eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70050?ooo`02
eQ`00]HL00;F703oool00`02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F7080
oooo1@02eQa;0?ooo`030000003oool0oooo00T0oooo001U0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0103oool400000880oooo0P02eQ`0103oool00]HL0?ooo`3oool400;F
7080oooo1002eQ`0103oool00]HL00;F703oool200;F7080oooo0P02eQ`0103oool00]HL00;F703o
ool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL0P3oool200;F70040?ooo`02eQ`00]HL0?ooo`80
0]HL0P3oool500;F70<0oooo1@02eQ`00`3oool00]HL00;F700400;F70050?ooo`02eQ`00]HL00;F
703oool00P02eQ`20?ooo`800]HL0P3oool300;F70030?ooo`02eQ`00]HL0080oooo0`02eQ`00`3o
ool00]HL00;F700300;F74h0oooo00<000000?ooo`3oool02@3oool006D0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`040?ooo`800000PP3oool200;F70040?ooo`02eQ`00]HL
0?ooo`@00]HL0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`800]HL00D0oooo00;F7002eQ`00]HL
0?ooo`0200;F70040?ooo`02eQ`00]HL0?ooo`D00]HL0P3oool500;F70040?ooo`02eQ`00]HL0?oo
o`D00]HL0`3oool500;F7080oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0300;F7080oooo0P02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL00<0
oooo00;F7002eQ`01002eQa@0?ooo`030000003oool0oooo00T0oooo001T0?ooo`8000000P3oool0
10000000oooo0?ooo`0000060?ooo`800000P03oool200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL
0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0`02eQ`0103o
ool00]HL00;F703oool400;F70<0oooo1002eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02
eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02
eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool300;F70030?ooo`02eQ`00]HL0080oooo0`02
eQ`00`3oool00]HL00;F700300;F75<0oooo00<000000?ooo`3oool02@3oool006D0oooo00@00000
0?ooo`3oool0oooo0P0000070?ooo`800000O`3oool01@02eQ`0oooo00;F7002eQ`0oooo00@00]HL
0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`20?oo
o`800]HL00<0oooo00;F7002eQ`00P02eQ`30?ooo`@00]HL00D0oooo00;F7002eQ`00]HL0?ooo`02
00;F70030?ooo`02eQ`00]HL00<0oooo1@02eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`0
0]HL00@00]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F70050?ooo`02eQ`00]HL00;F703oool0
0`02eQ`00`3oool00]HL00;F700300;F75H0oooo00<000000?ooo`3oool02@3oool00780oooo0P00
001m0?ooo`@00]HL0P3oool300;F7080oooo1002eQ`0103oool00]HL00;F703oool200;F70040?oo
o`02eQ`00]HL0?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0400;F7080oooo1@02eQ`00`3o
ool00]HL00;F70020?ooo`D00]HL0P3oool500;F7080oooo0P02eQ`00`3oool00]HL00;F70020?oo
o`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo1P02eQ`20?ooo`800]HL00<0oooo00;F
7002eQ`01002eQaH0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000N`3oool400;F7080
oooo0`02eQ`20?ooo`@00]HL00@0oooo00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool2
00;F70040?ooo`02eQ`00]HL0?ooo`D00]HL0P3oool500;F70040?ooo`02eQ`00]HL0?ooo`D00]HL
0`3oool200;F70040?ooo`02eQ`00]HL0?ooo`H00]HL00<0oooo00;F7002eQ`01002eQ`0103oool0
0]HL00;F7002eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P3oool300;F70030?ooo`02eQ`00]HL
00<00]HLF`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000007T0oooo1002eQ`20?ooo`<0
0]HL0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`0
103oool00]HL00;F703oool500;F7080oooo1002eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo
0P02eQ`30?ooo`D00]HL00@0oooo00;F7002eQ`0oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002
eQ`00P3oool200;F7080oooo1P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`02eQaN0?ooo`03
0000003oool0oooo00T0oooo001b0?ooo`800000M`3oool400;F7080oooo0`02eQ`20?ooo`@00]HL
00@0oooo00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool200;F70040?ooo`02eQ`00]HL
0?ooo`@00]HL0`3oool400;F70050?ooo`02eQ`00]HL00;F703oool01@02eQ`20?ooo`D00]HL0P3o
ool500;F70030?ooo`02eQ`00]HL00@00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70030?oo
o`02eQ`00]HL0080oooo0`02eQ`00`3oool00]HL00;F700300;F7600oooo00<000000?ooo`3oool0
2@3oool00780oooo0P00001e0?ooo`@00]HL0P3oool300;F7080oooo1002eQ`0103oool00]HL00;F
703oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo1002eQ`20?oo
o`D00]HL00<0oooo00;F7002eQ`00P3oool400;F70<0oooo1@02eQ`00`3oool00]HL00;F700300;F
7080oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F70050?ooo`02eQ`00]HL
00;F703oool00`02eQ`00`3oool00]HL00;F700300;F76<0oooo00<000000?ooo`3oool02@3oool0
0780oooo0P00001c0?ooo`800]HL00@0oooo00;F703oool0oooo0`02eQ`20?ooo`@00]HL00@0oooo
00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool200;F70040?ooo`02eQ`00]HL0?ooo`@0
0]HL0P3oool500;F70040?ooo`02eQ`00]HL0?ooo`D00]HL0`3oool400;F7080oooo0P02eQ`0103o
ool00]HL00;F703oool600;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`00`3oool00]HL00;F
70020?ooo`800]HL00<0oooo00;F7002eQ`01002eQaU0?ooo`030000003oool0oooo00T0oooo001b
0?ooo`800000LP3oool01@02eQ`0oooo00;F7002eQ`0oooo00<00]HL0P3oool400;F70040?ooo`02
eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool400;F
7080oooo1002eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`D00]HL00<0oooo00;F
7002eQ`01002eQ`0103oool00]HL00;F703oool200;F7080oooo0P02eQ`20?ooo`800]HL00D0oooo
00;F7002eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL00<00]HLJ03oool00`000000oooo0?oo
o`090?ooo`00LP3oool200000700oooo1002eQ`0103oool00]HL00;F7002eQ`20?ooo`@00]HL00@0
oooo00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool200;F70040?ooo`02eQ`00]HL0?oo
o`@00]HL0P3oool400;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`30?ooo`D00]HL00@0oooo
00;F7002eQ`0oooo0P02eQ`20?ooo`D00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0600;F7080oooo
0P02eQ`00`3oool00]HL00;F700300;F76/0oooo00<000000?ooo`3oool02@3oool00780oooo0P00
001^0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02
eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo2P02eQ`20?ooo`@00]HL00@0oooo00;F7002
eQ`0oooo1@02eQ`30?ooo`@00]HL0P3oool500;F70030?ooo`02eQ`00]HL00<00]HL0P3oool200;F
7080oooo0P02eQ`00`3oool00]HL00;F70020?ooo`T00]HLK@3oool00`000000oooo0?ooo`090?oo
o`00LP3oool2000006`0oooo1002eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL0080
0]HL00@0oooo00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool400;F70030?ooo`02eQ`0
0]HL00800]HL0P3oool500;F70040?ooo`02eQ`00]HL0?ooo`D00]HL0P3oool500;F70030?ooo`02
eQ`00]HL00<00]HL0P3oool500;F70050?ooo`02eQ`00]HL00;F703oool01P02eQ`01@3oool00]HL
00;F7002eQ`0oooo00D00]HLL03oool00`000000oooo0?ooo`090?ooo`00LP3oool2000006X0oooo
1002eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0
oooo0P02eQ`00`3oool00]HL00;F700500;F70030?ooo`02eQ`00]HL00800]HL0P3oool500;F7004
0?ooo`02eQ`00]HL0?ooo`@00]HL0`3oool500;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F
7002eQ`00`02eQ`20?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3o
ool00]HL00;F700300;F77<0oooo00<000000?ooo`3oool02@3oool00780oooo0P00001X0?ooo`@0
0]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?oo
o`L00]HL00@0oooo00;F7002eQ`0oooo1002eQ`20?ooo`@00]HL00D0oooo00;F7002eQ`00]HL0?oo
o`0400;F7080oooo1@02eQ`00`3oool00]HL00;F700300;F7080oooo1@02eQ`01@3oool00]HL00;F
7002eQ`0oooo00H00]HL00<0oooo00;F7002eQ`01`02eQae0?ooo`030000003oool0oooo00T0oooo
001b0?ooo`<00000I@3oool400;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02
eQ`0103oool00]HL00;F703oool400;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002
eQ`00P02eQ`20?ooo`@00]HL00@0oooo00;F7002eQ`0oooo1@02eQ`20?ooo`D00]HL00@0oooo00;F
7002eQ`0oooo0P02eQ`00`3oool00]HL00;F700300;F7080oooo0P02eQ`20?ooo`800]HL00<0oooo
00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL00<00]HLN03oool00`000000oooo0?ooo`09
0?ooo`00LP3oool2000006@0oooo1002eQ`20?ooo`<00]HL00<0oooo00;F7002eQ`00P02eQ`0103o
ool00]HL00;F703oool400;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`00P02
eQ`20?ooo`@00]HL00@0oooo00;F7002eQ`0oooo1@02eQ`20?ooo`@00]HL0P3oool500;F70030?oo
o`02eQ`00]HL00<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0600;F70030?ooo`02eQ`00]HL00H0
0]HLN`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000006<0oooo0`02eQ`20?ooo`<00]HL
00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F703oool400;F70040?ooo`02eQ`00]HL0?oo
o`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700300;F70040?ooo`02eQ`00]HL
0?ooo`@00]HL0P3oool500;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`2
0?ooo`800]HL0P3oool500;F7080oooo0P02eQ`00`3oool00]HL00;F700300;F77d0oooo00<00000
0?ooo`3oool02@3oool00780oooo0P00001Q0?ooo`<00]HL0P3oool300;F70030?ooo`02eQ`00]HL
00800]HL00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool00]HL00;F700700;F7080oooo1002eQ`0
1@3oool00]HL00;F7002eQ`0oooo00@00]HL0P3oool500;F70030?ooo`02eQ`00]HL00<00]HL00<0
oooo00;F7002eQ`00`02eQ`01@3oool00]HL00;F7002eQ`0oooo00D00]HL0P3oool800;F7800oooo
00<000000?ooo`3oool02@3oool00780oooo0P00001O0?ooo`@00]HL00D0oooo00;F7002eQ`00]HL
0?ooo`0400;F70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool0
0]HL00;F700200;F7080oooo1002eQ`0103oool00]HL00;F703oool500;F7080oooo1002eQ`20?oo
o`@00]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`800]HL0P3oool500;F70030?ooo`02eQ`00]HL
00L00]HLPP3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000005d0oooo1002eQ`01@3oool0
0]HL00;F7002eQ`0oooo00@00]HL00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool00]HL00;F7002
00;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`@00]HL0P3o
ool500;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`01@3oool00]HL00;F
7002eQ`0oooo00D00]HL0P3oool200;F70030?ooo`02eQ`00]HL00<00]HLQ@3oool00`000000oooo
0?ooo`090?ooo`00LP3oool2000005/0oooo1002eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL
00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL0080
0]HL0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`@00]HL0P3oool500;F70030?ooo`02eQ`00]HL
00800]HL0P3oool400;F7080oooo0P02eQ`20?ooo`D00]HL00<0oooo00;F7002eQ`01P02eQb80?oo
o`030000003oool0oooo00T0oooo001b0?ooo`800000F@3oool400;F70050?ooo`02eQ`00]HL00;F
703oool01002eQ`0103oool00]HL00;F703oool400;F70030?ooo`02eQ`00]HL00800]HL00<0oooo
00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70050?ooo`02eQ`00]HL00;F703oool01002
eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F700300;F70050?ooo`02
eQ`00]HL00;F703oool01@02eQ`20?ooo`P00]HLRP3oool00`000000oooo0?ooo`090?ooo`00LP3o
ool2000005L0oooo1002eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00@0oooo00;F7002eQ`0
oooo1002eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002
eQ`00P02eQ`0103oool00]HL00;F703oool400;F7080oooo1@02eQ`00`3oool00]HL00;F700300;F
70030?ooo`02eQ`00]HL00<00]HL00@0oooo00;F7002eQ`0oooo1P02eQ`00`3oool00]HL00;F7006
00;F78d0oooo00<000000?ooo`3oool02@3oool00780oooo0P00001F0?ooo`<00]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0400;F70040?ooo`02eQ`00]HL0?ooo`T00]HL00@0oooo00;F7002eQ`00]HL
0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`@00]HL0P3oool500;F70030?ooo`02eQ`00]HL0080
0]HL00<0oooo00;F7002eQ`00`02eQ`01@3oool00]HL00;F7002eQ`0oooo00D00]HL00<0oooo00;F
7002eQ`01P02eQb@0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000E03oool300;F7005
0?ooo`02eQ`00]HL00;F703oool01002eQ`0103oool00]HL00;F703oool600;F70030?ooo`02eQ`0
0]HL00@00]HL0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`@00]HL0P3oool400;F70030?ooo`02
eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`0103oool00]HL00;F703oool500;F7080oooo
2002eQbB0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000DP3oool300;F70040?ooo`02
eQ`00]HL00;F7080oooo0`02eQ`0103oool00]HL00;F703oool=00;F7080oooo0`02eQ`00`3oool0
0]HL00;F700600;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool0
0]HL00;F700300;F70050?ooo`02eQ`00]HL00;F703oool01@02eQ`00`3oool00]HL00;F700600;F
79D0oooo00<000000?ooo`3oool02@3oool00780oooo0P00001@0?ooo`<00]HL00@0oooo00;F7002
eQ`00]HL0P3oool300;F70040?ooo`02eQ`00]HL0?ooo`P00]HL00<0oooo00;F7002eQ`00P02eQ`0
0`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL0P3oool400;F70030?ooo`02
eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`0103oool00]HL00;F703oool500;F7080oooo
1`02eQbH0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000CP3oool300;F7080oooo0P02
eQ`20?ooo`<00]HL00@0oooo00;F7002eQ`0oooo0`02eQ`00`3oool00]HL00;F700200;F70030?oo
o`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F703oool400;F7080
oooo1002eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00<00]HL00D0oooo00;F7002
eQ`00]HL0?ooo`0500;F70030?ooo`02eQ`00]HL00H00]HLVP3oool00`000000oooo0?ooo`090?oo
o`00LP3oool2000004`0oooo1002eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL00<0oooo00;F
7002eQ`01002eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL00;F7080oooo1002eQ`0
103oool00]HL00;F703oool400;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00P02
eQ`00`3oool00]HL00;F700300;F70040?ooo`02eQ`00]HL0?ooo`D00]HL00<0oooo00;F7002eQ`0
1P02eQbM0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000BP3oool400;F70050?ooo`02
eQ`00]HL00;F703oool00`02eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`00]HL00800]HL
00@0oooo00;F7002eQ`00]HL0P3oool;00;F7080oooo1002eQ`00`3oool00]HL00;F700300;F7003
0?ooo`02eQ`00]HL00800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0500;F70030?ooo`02eQ`00]HL
00H00]HLW`3oool00`000000oooo0?ooo`090?ooo`00LP3oool3000004P0oooo0`02eQ`01@3oool0
0]HL00;F7002eQ`0oooo00<00]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700200;F
70040?ooo`02eQ`00]HL00;F7080oooo0`02eQ`0103oool00]HL00;F703oool400;F7080oooo1002
eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00<00]HL00@0oooo00;F7002eQ`0oooo
1@02eQ`00`3oool00]HL00;F700600;F7:80oooo00<000000?ooo`3oool02@3oool00780oooo0P00
00170?ooo`<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL00@00]HL
00<0oooo00;F7002eQ`01P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?ooo`@0
0]HL00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700200;F70050?ooo`02eQ`00]HL00;F
703oool01@02eQ`00`3oool00]HL00;F700500;F7:D0oooo00<000000?ooo`3oool02@3oool000X0
oooo0P02eQaV0?ooo`800000A@3oool300;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`00`3o
ool00]HL00;F700400;F70030?ooo`02eQ`00]HL00H00]HL00<0oooo00;F7002eQ`00P02eQ`0103o
ool00]HL00;F703oool300;F7080oooo1002eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`0
0]HL00<00]HL00@0oooo00;F7002eQ`0oooo1@02eQ`00`3oool00]HL00;F700600;F7:L0oooo00<0
00000?ooo`3oool02@3oool000`0oooo0`02eQaS0?ooo`800000@`3oool300;F70050?ooo`02eQ`0
0]HL00;F703oool00`02eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`00]HL00H00]HL00<0
oooo00;F7002eQ`02@02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F
700200;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`00`3oool00]HL00;F700600;F7:X0oooo
00<000000?ooo`3oool02@3oool000h0oooo1002eQaP0?ooo`800000@@3oool300;F70050?ooo`02
eQ`00]HL00;F703oool00`02eQ`00`3oool00]HL00;F700400;F70050?ooo`02eQ`00]HL00;F703o
ool00`02eQ`20?ooo`<00]HL00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool00]HL00;F700200;F
70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00`02eQ`0103oool00]HL00;F703oool5
00;F70030?ooo`02eQ`00]HL00D00]HL[@3oool00`000000oooo0?ooo`090?ooo`00403oool500;F
75d0oooo0P00000o0?ooo`<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`0
0]HL00P00]HL00@0oooo00;F7002eQ`00]HL0P3oool300;F70040?ooo`02eQ`00]HL0?ooo`@00]HL
00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL
00D0oooo00;F7002eQ`00]HL0?ooo`0400;F70030?ooo`02eQ`00]HL00H00]HL[`3oool00`000000
oooo0?ooo`090?ooo`004P3oool500;F75/0oooo0P00000m0?ooo`<00]HL00D0oooo00;F7002eQ`0
0]HL0?ooo`0300;F70030?ooo`02eQ`00]HL00P00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0400;F
70030?ooo`02eQ`00]HL00@00]HL0P3oool>00;F70040?ooo`02eQ`00]HL0?ooo`D00]HL00<0oooo
00;F7002eQ`01@02eQbb0?ooo`030000003oool0oooo00T0oooo000D0?ooo`H00]HLF03oool20000
03`0oooo1P02eQ`01@3oool00]HL00;F7002eQ`0oooo00X00]HL00D0oooo00;F7002eQ`00]HL0?oo
o`0;00;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F
700200;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`00`3oool00]HL00;F700500;F7;D0oooo
00<000000?ooo`3oool02@3oool001H0oooo1`02eQaE0?ooo`800000>P3oool600;F70050?ooo`02
eQ`00]HL00;F703oool03P02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL00<0oooo00;F7002
eQ`00P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002
eQ`00P02eQ`0103oool00]HL00;F703oool500;F70030?ooo`02eQ`00]HL00D00]HL]`3oool00`00
0000oooo0?ooo`090?ooo`00603oool800;F7580oooo0P00000h0?ooo`H00]HL00D0oooo00;F7002
eQ`00]HL0?ooo`0>00;F70050?ooo`02eQ`00]HL00;F703oool00P02eQ`0103oool00]HL00;F7002
eQ`20?ooo`P00]HL00<0oooo00;F7002eQ`00P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL
00<0oooo00;F7002eQ`01@02eQbj0?ooo`030000003oool0oooo00T0oooo000I0?ooo`T00]HLD03o
ool2000003H0oooo0`02eQ`0103oool00]HL00;F703oool300;F70030?ooo`02eQ`00]HL00/00]HL
0P3oool300;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL
00;F700200;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool0
0]HL00;F700600;F7;`0oooo00<000000?ooo`3oool02@3oool001/0oooo2P02eQa=0?ooo`800000
=03oool300;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`00`02eQ`01@3oool0
0]HL00;F7002eQ`0oooo00<00]HL00<0oooo00;F7002eQ`02@02eQ`00`3oool00]HL00;F700600;F
70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`01P02eQ`00`3oool00]HL00;F700500;F
7;l0oooo00<000000?ooo`3oool02@3oool001d0oooo2`02eQa:0?ooo`800000<P3oool300;F7004
0?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`00`02eQ`01@3oool00]HL00;F7002eQ`0
oooo00<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70040?ooo`02eQ`00]HL00;F7080oooo
0`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0
oooo1002eQ`00`3oool00]HL00;F700500;F7<80oooo00<000000?ooo`3oool02@3oool001l0oooo
2`02eQa80?ooo`800000<03oool300;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002
eQ`00`02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`02
00;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`00`3oool00]HL00;F700600;F70030?ooo`02
eQ`00]HL00H00]HL00<0oooo00;F7002eQ`01@02eQc40?ooo`030000003oool0oooo00T0oooo000Q
0?ooo``00]HLA@3oool2000002h0oooo0`02eQ`0103oool00]HL00;F703oool300;F70030?ooo`02
eQ`00]HL00<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL00P00]HL
00<0oooo00;F7002eQ`01P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?ooo`@0
0]HL00<0oooo00;F7002eQ`01@02eQc70?ooo`030000003oool0oooo00T0oooo000S0?ooo`d00]HL
@P3oool2000002d0oooo0P02eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`00]HL00<00]HL
00<0oooo00;F7002eQ`02`02eQ`0103oool00]HL00;F7002eQ`20?ooo`<00]HL00<0oooo00;F7002
eQ`01P02eQ`00`3oool00]HL00;F700=00;F7<X0oooo00<000000?ooo`3oool02@3oool002D0oooo
3P02eQ`o0?ooo`<00000:P3oool200;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`0
2P02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0400;F
70050?ooo`02eQ`00]HL00;F703oool01002eQ`0103oool00]HL00;F703oool400;F70030?ooo`02
eQ`00]HL00D00]HLc03oool00`000000oooo0?ooo`090?ooo`009`3oool>00;F73d0oooo0P00000Y
0?oooaH00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70050?ooo`02eQ`00]HL00;F703oool0
3002eQ`00`3oool00]HL00;F700500;F70030?ooo`02eQ`00]HL00D00]HLc`3oool00`000000oooo
0?ooo`090?ooo`00:@3oool?00;F73X0oooo0P00000W0?ooo`/00]HL00<0oooo00;F7002eQ`02002
eQ`00`3oool00]HL00;F700800;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`00`3oool00]HL
00;F700200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002eQ`01002eQcB0?ooo`03
0000003oool0oooo00T0oooo000[0?oooa000]HL=`3oool2000002D0oooo2`02eQ`00`3oool00]HL
00;F700400;F70050?ooo`02eQ`00]HL00;F703oool01@02eQ`01@3oool00]HL00;F7002eQ`0oooo
00P00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0700;F70030?ooo`02eQ`00]HL00D00]HLe03oool0
0`000000oooo0?ooo`090?ooo`00;@3ooolA00;F73@0oooo0P00000S0?ooo`/00]HL00<0oooo00;F
7002eQ`01002eQ`00`3oool00]HL00;F700700;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`0
0`3oool00]HL00;F700600;F70040?ooo`02eQ`00]HL0?ooo`/00]HLe`3oool00`000000oooo0?oo
o`090?ooo`00;`3ooolA00;F7380oooo0P00000Q0?ooo`/00]HL00<0oooo00;F7002eQ`01002eQ`0
103oool00]HL00;F703oool300;F70030?ooo`02eQ`00]HL00@00]HL00D0oooo00;F7002eQ`00]HL
0?ooo`0300;F70050?ooo`02eQ`00]HL00;F703oool01`02eQ`00`3oool00]HL00;F700500;F7=T0
oooo00<000000?ooo`3oool02@3oool00340oooo4P02eQ`_0?ooo`800000803oool200;F70030?oo
o`02eQ`00]HL00D00]HL00<0oooo00;F7002eQ`01`02eQ`00`3oool00]HL00;F700700;F70030?oo
o`02eQ`00]HL00d00]HL00<0oooo00;F7002eQ`02@02eQcL0?ooo`030000003oool0oooo00T0oooo
000b0?oooa@00]HL;03oool2000001h0oooo0P02eQ`00`3oool00]HL00;F700500;F70030?ooo`02
eQ`00]HL00L00]HL00<0oooo00;F7002eQ`00`02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL
00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F
7002eQ`01002eQcO0?ooo`030000003oool0oooo00T0oooo000d0?oooaD00]HL:@3oool2000001`0
oooo0P02eQ`00`3oool00]HL00;F700500;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002
eQ`00`02eQ`01@3oool00]HL00;F7002eQ`0oooo00h00]HL00D0oooo00;F7002eQ`00]HL0?ooo`07
00;F7>40oooo00<000000?ooo`3oool02@3oool003H0oooo5@02eQ`W0?ooo`8000006P3oool200;F
70030?ooo`02eQ`00]HL00D00]HL00@0oooo00;F7002eQ`0oooo2@02eQ`00`3oool00]HL00;F7003
00;F70030?ooo`02eQ`00]HL00D00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70030?ooo`02
eQ`00]HL00T00]HLi03oool00`000000oooo0?ooo`090?ooo`00>03ooolF00;F72@0oooo0P00000H
0?ooo`800]HL00@0oooo00;F7002eQ`0oooo1002eQ`0103oool00]HL00;F703oool?00;F70050?oo
o`02eQ`00]HL00;F703oool02P02eQ`01@3oool00]HL00;F7002eQ`0oooo00H00]HLi`3oool00`00
0000oooo0?ooo`090?ooo`00>P3ooolG00;F7240oooo0P00000F0?ooo`D00]HL00<0oooo00;F7002
eQ`00P02eQ`0103oool00]HL00;F703oool200;F70040?ooo`02eQ`00]HL0?ooo`D00]HL00D0oooo
00;F7002eQ`00]HL0?ooo`0:00;F70040?ooo`02eQ`00]HL0?ooo`/00]HLj@3oool00`000000oooo
0?ooo`090?ooo`00?03ooolH00;F71h0oooo0P00000D0?ooo`D00]HL00<0oooo00;F7002eQ`00P02
eQ`00`3oool00]HL00;F700300;F70040?ooo`02eQ`00]HL0?ooo`D00]HL00<0oooo00;F7002eQ`0
1002eQ`01@3oool00]HL00;F7002eQ`0oooo00X00]HL00<0oooo00;F7002eQ`01002eQc/0?ooo`03
0000003oool0oooo00T0oooo000n0?oooaP00]HL703oool2000001<0oooo1002eQ`00`3oool00]HL
00;F700;00;F70040?ooo`02eQ`00]HL0?ooo`D00]HL00<0oooo00;F7002eQ`02002eQ`0103oool0
0]HL00;F703oool:00;F7>l0oooo00<000000?ooo`3oool02@3oool00400oooo6@02eQ`I0?ooo`80
00004@3oool400;F70030?ooo`02eQ`00]HL01@00]HL00<0oooo00;F7002eQ`01002eQ`00`3oool0
0]HL00;F700?00;F7?40oooo00<000000?ooo`3oool02@3oool00480oooo6P02eQ`F0?ooo`800000
3`3oool400;F70030?ooo`02eQ`00]HL01000]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL
00;F700400;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`01002eQc_0?ooo`05
0000003oool000000000003oool01@0000070?ooo`00A03ooolJ00;F71@0oooo0`00000<0?ooo`@0
0]HL00<0oooo00;F7002eQ`04`02eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`00]HL00l0
0]HLl@3oool200000080oooo0`0000020?ooo`030000003oool0oooo00D0oooo00160?oooa/00]HL
4@3oool2000000/0oooo4@02eQ`0103oool00]HL00;F703oool500;F70030?ooo`02eQ`00]HL00X0
0]HL00D0oooo00;F7002eQ`00]HL0?ooo`0600;F7?@0oooo00<000000?ooo`3oool00`0000000`3o
ool000000?ooo`080?ooo`00B03ooolL00;F70h0oooo0P0000090?ooo`h00]HL00@0oooo00;F7002
eQ`0oooo7`02eQch0?ooo`<0000000D0oooo0000003oool0oooo000000080?ooo`001`3oool30000
0080oooo0P00000l0?oooad00]HL2`3oool2000000L0oooo0P02eQ`00`3oool00]HL00;F700900;F
70030?ooo`02eQ`00]HL00D00]HL00@0oooo00;F7002eQ`0oooo3002eQ`01@3oool00]HL00;F7002
eQ`0oooo00H00]HL:P3oool300000080oooo0P00001P0?ooo`@000000P3oool200000600oooo0`00
00000`3oool0000000000002000000030?ooo`000000oooo00H0oooo00080?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0>`3ooolM00;F70T0oooo0P0000060?oooaP00]HL00@0
oooo00;F7002eQ`0oooo4`02eQ`^0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0G@3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`04000000030?ooo`000000000000L0oooo00030?ooo`<000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo03`0oooo7`02eQ`60?ooo`800000103ooolB
00;F70030?ooo`02eQ`00]HL00T00]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F7007
00;F7340oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1N0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1N0?ooo`D0000000<0oooo000000000000
203oool000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0n0?ooob000]HL
0`3oool200000080oooo2P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00D00]HL
00<0oooo00;F7002eQ`03@02eQ`00`3oool00]HL00;F700400;F73<0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`1O0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0GP3oool200000080oooo00@000000?ooo`3oool00000203oool000P0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`100?ooob400]HL0P00000?00;F70030?ooo`02eQ`0
0]HL00800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool500;F70030?oo
o`02eQ`00]HL00L00]HL=P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0600
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool01P3oool000L0oooo0P0000020?ooo`040000003oool0oooo000004@0
oooo7P02eQ`00`0000000]HL00;F700T00;F70030?ooo`02eQ`00]HL00<00]HL>03oool200000080
oooo00@000000?ooo`3oool00000G`3oool01P000000oooo0?ooo`000000oooo00000080oooo00<0
00000?ooo`3oool0G@3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool01P3oool000P0oooo00@000000?ooo`3oool0oooo0P0000170?oooa`00]HL00<0000000;F7002
eQ`07P02eQ`00`3oool00]HL00;F700700;F73/0oooo00@000000?ooo`3oool0oooo0P00001Q0?oo
o`8000000`3oool200000640oooo0P0000020?ooo`<000002@3oool005L0oooo6P02eQ`00`000000
0]HL00;F700600;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`04P02eQco0?oooa80
oooo00<000000?ooo`3oool02@3oool005T0oooo6002eQ`00`0000000]HL00;F700I00;F70030?oo
o`02eQ`00]HL00L00]HLo`3ooolD0?ooo`030000003oool0oooo00T0oooo001K0?oooaH00]HL00<0
000000;F7002eQ`03P02eQ`00`3oool00]HL00;F700?00;F7?l0oooo5`3oool00`000000oooo0?oo
o`090?ooo`00G@3ooolD00;F700300000002eQ`00]HL01L00]HL00<0oooo00;F7002eQ`00`02eQco
0?oooaX0oooo00<000000?ooo`3oool02@3oool005l0oooo4P02eQ`00`0000000]HL00;F700K00;F
7?l0oooo703oool00`000000oooo0?ooo`090?ooo`00H@3oool@00;F700300000002eQ`00]HL01P0
0]HLo`3ooolO0?ooo`030000003oool0oooo00T0oooo001S000000h00]HL00<0000000;F7002eQ`0
5@02eQco000002h00000000:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3o
ool<00;F700300000002eQ`00]HL01L00]HL4@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool;
00;F700300000002eQ`00]HL01H00]HL00@0oooo00;F7002eQ`00]HL3P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo05/0oooo2@02eQ`0
0`0000000]HL00;F700M00;F74T0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo00T0oooo001Z0?ooo`L00]HL00<0000000;F7002eQ`06002eQ`00`3o
ool00]HL00;F700400;F7?l0oooo603oool00`000000oooo0?ooo`090?ooo`00K03oool500;F7003
00000002eQ`00]HL01h00]HL00@0oooo00;F7002eQ`00]HLo`3ooolE0?ooo`030000003oool0oooo
00T0oooo001^0?ooo`<00]HL00<0000000;F7002eQ`05002eQ`00`3oool00]HL00;F700300;F7003
0?ooo`02eQ`00]HL00@00]HL00@0oooo00;F7002eQ`00]HLo`3ooolB0?ooo`030000003oool0oooo
00T0oooo001`0?ooo`0300;F700000000]HL02T00]HLo`3oool?0?ooo`030000003oool0oooo00T0
oooo001a0?ooo`0300000002eQ`00]HL00T00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL
00;F700200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool0
0]HL00;F700400;F70040?ooo`02eQ`00]HL00;F7?l0oooo3@3oool00`000000oooo0?ooo`090?oo
o`00L@3oool2000001l00]HL00<0oooo00;F7002eQ`01002eQ`01@3oool00]HL00;F7002eQ`0oooo
00<00]HLo`3oool:0?ooo`030000003oool0oooo00T0oooo001b0?ooo`80000000<0oooo00;F7002
eQ`08@02eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`00]HL00800]HLo`3oool70?ooo`03
0000003oool0oooo00T0oooo001b0?ooo`8000000`3ooolD00;F70030?ooo`02eQ`00]HL00<00]HL
00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F700400;F70050?ooo`02eQ`00]HL00;F703o
ool00`02eQco0?ooo`D0oooo00<000000?ooo`3oool02@3oool00780oooo0P0000050?ooo`X00]HL
00<0oooo00;F7002eQ`05`02eQ`00`3oool00]HL00;F700500;F70040?ooo`02eQ`00]HL00;F7?l0
oooo0P3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000000L0oooo4P02eQ`00`3oool00]HL
00;F700900;F70030?ooo`02eQ`00]HL00/00]HL00<0oooo00;F7002eQ`00P02eQcn0?ooo`030000
003oool0oooo00T0oooo001b0?ooo`8000002@3oool00`02eQ`0oooo00;F700H00;F70030?ooo`02
eQ`00]HL00L00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL00800]HL
n`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000000X0oooo0P02eQ`00`3oool00]HL00;F
700A00;F70040?ooo`02eQ`00]HL0?ooo`H00]HL00<0oooo00;F7002eQ`03002eQ`0103oool00]HL
00;F7002eQci0?ooo`030000003oool0oooo00T0oooo001b0?ooo`<000002`3oool>00;F70030?oo
o`02eQ`00]HL00`00]HL00<0oooo00;F7002eQ`00`02eQ`01@3oool00]HL00;F7002eQ`0oooo00<0
0]HL00D0oooo00;F7002eQ`00]HL0?ooo`0400;F7?H0oooo00<000000?ooo`3oool02@3oool00780
oooo0P00000>0?ooo`h00]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F700600;F
70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`01P02eQ`00`3oool00]HL00;F700200;F
7?<0oooo00<000000?ooo`3oool02@3oool00780oooo0P00000@0?ooo`h00]HL00@0oooo00;F7002
eQ`0oooo0P02eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`00]HL00@00]HL00@0oooo00;F
7002eQ`0oooo0`02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0oooo00;F7002eQ`00P02
eQc`0?ooo`030000003oool0oooo00T0oooo001b0?ooo`8000004P3oool400;F70030?ooo`02eQ`0
0]HL01000]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700700;F70030?ooo`02eQ`0
0]HL00H00]HL00<0oooo00;F7002eQ`00P02eQc^0?ooo`030000003oool0oooo00T0oooo001b0?oo
o`800000503oool400;F70030?ooo`02eQ`00]HL01L00]HL00D0oooo00;F7002eQ`00]HL0?ooo`02
00;F70050?ooo`02eQ`00]HL00;F703oool02002eQ`00`3oool00]HL00;F700200;F7>/0oooo00<0
00000?ooo`3oool02@3oool00780oooo0P00000F0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`0
0`3oool00]HL00;F700900;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`02`02eQ`0
0`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL00;F7080oooo1002eQcX0?ooo`030000003o
ool0oooo00T0oooo001b0?ooo`800000603oool400;F70030?ooo`02eQ`00]HL00800]HL00<0oooo
00;F7002eQ`02@02eQ`00`3oool00]HL00;F700300;F70050?ooo`02eQ`00]HL00;F703oool00`02
eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`00]HL00H00]HL00<0oooo00;F7002eQ`00P02
eQcV0?ooo`030000003oool0oooo00T0oooo001b0?ooo`8000006P3oool400;F70030?ooo`02eQ`0
0]HL00800]HL00<0oooo00;F7002eQ`00`02eQ`0103oool00]HL00;F703oool200;F70040?ooo`02
eQ`00]HL0?ooo`H00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70040?ooo`02eQ`00]HL00;F
7080oooo0`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HLh`3oool00`00
0000oooo0?ooo`090?ooo`00LP3oool2000001`0oooo2@02eQ`00`3oool00]HL00;F700300;F7004
0?ooo`02eQ`00]HL0?ooo`d00]HL00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700600;F
7080oooo1002eQcP0?ooo`030000003oool0oooo00T0oooo001b0?ooo`8000007P3oool00`02eQ`0
oooo00;F700600;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`01002eQ`00`3o
ool00]HL00;F700300;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`0103oool00]HL00;F703o
ool300;F7080oooo0`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00<00]HLg@3o
ool00`000000oooo0?ooo`090?ooo`00LP3oool2000001l0oooo0P02eQ`00`3oool00]HL00;F7005
00;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F
700700;F70030?ooo`02eQ`00]HL00T00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F
700200;F70030?ooo`02eQ`00]HL00800]HLf`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2
00000240oooo0P02eQ`00`3oool00]HL00;F700500;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0
oooo00;F7002eQ`01002eQ`0103oool00]HL00;F703oool700;F70050?ooo`02eQ`00]HL00;F703o
ool00P02eQ`0103oool00]HL00;F7002eQ`20?ooo`P00]HL0P3oool400;F7=P0oooo00<000000?oo
o`3oool02@3oool00780oooo0P00000S0?ooo`800]HL00<0oooo00;F7002eQ`01@02eQ`0103oool0
0]HL00;F703oool200;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`01002eQ`01@3o
ool00]HL00;F7002eQ`0oooo00/00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F7002
00;F70030?ooo`02eQ`00]HL00<00]HLe@3oool00`000000oooo0?ooo`090?ooo`00LP3oool20000
02D0oooo0P02eQ`00`3oool00]HL00;F700500;F70040?ooo`02eQ`00]HL0?ooo`H00]HL00D0oooo
00;F7002eQ`00]HL0?ooo`0500;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`0103oool00]HL
00;F703oool300;F7080oooo2@02eQ`00`3oool00]HL00;F700300;F7=80oooo00<000000?ooo`3o
ool02@3oool00780oooo0P00000W0?ooo`800]HL00<0oooo00;F7002eQ`01@02eQ`00`3oool00]HL
00;F700700;F70050?ooo`02eQ`00]HL00;F703oool02P02eQ`01@3oool00]HL00;F7002eQ`0oooo
00800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL
00800]HL0P3oool400;F7=00oooo00<000000?ooo`3oool02@3oool00780oooo0P00000Y0?ooo`X0
0]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700400;F70040?ooo`02eQ`00]HL0?oo
o`<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0;00;F7080oooo1002eQ`00`3oool00]HL00;F7002
00;F7080oooo1002eQc=0?ooo`030000003oool0oooo00T0oooo001b0?ooo`<00000:P3ooolA00;F
70030?ooo`02eQ`00]HL00@00]HL00@0oooo00;F7002eQ`0oooo0`02eQ`0103oool00]HL00;F7002
eQ`20?ooo`<00]HL00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool00]HL00;F700200;F70030?oo
o`02eQ`00]HL00800]HL0P3oool500;F7<X0oooo00<000000?ooo`3oool02@3oool00780oooo0P00
000]0?ooo`P00]HL00<0oooo00;F7002eQ`01P02eQ`00`3oool00]HL00;F700400;F70030?ooo`02
eQ`00]HL00T00]HL00<0oooo00;F7002eQ`02@02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P02
eQ`20?ooo`@00]HLb03oool00`000000oooo0?ooo`090?ooo`00LP3oool2000002l0oooo2002eQ`0
0`3oool00]HL00;F700600;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`00`3oool00]HL00;F
700800;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool00]HL
00;F700800;F7080oooo1002eQc50?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000<@3o
ool800;F70030?ooo`02eQ`00]HL00H00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70040?oo
o`02eQ`00]HL0?ooo`<00]HL00@0oooo00;F7002eQ`00]HL0P3oool300;F70030?ooo`02eQ`00]HL
00D00]HL0P3oool400;F70030?ooo`02eQ`00]HL00800]HL0P3oool500;F7<80oooo00<000000?oo
o`3oool02@3oool00780oooo0P00000c0?ooo`0300;F703oool00]HL00D00]HL00<0oooo00;F7002
eQ`01P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL00@0oooo00;F7002eQ`0oooo0`02eQ`0
0`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0oooo1002
eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`00]HL00800]HL0P3oool500;F7;l0oooo00<0
00000?ooo`3oool02@3oool00780oooo0P00000d0?ooo`800]HL00<0oooo00;F7002eQ`01002eQ`0
0`3oool00]HL00;F700600;F70030?ooo`02eQ`00]HL00D00]HL00<0oooo00;F7002eQ`02@02eQ`0
0`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL0P3oool400;F70030?ooo`02
eQ`00]HL00<00]HL0P3oool400;F7;d0oooo00<000000?ooo`3oool02@3oool00780oooo0P00000f
0?ooo`800]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700600;F70030?ooo`02eQ`0
0]HL00H00]HL00@0oooo00;F7002eQ`0oooo0`02eQ`0103oool00]HL00;F7002eQ`20?ooo`L00]HL
00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`00]HL00800]HL
0P3oool500;F7;X0oooo00<000000?ooo`3oool02@3oool00780oooo0P00000h0?ooo`800]HL00<0
oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700300;F70050?ooo`02eQ`00]HL00;F703oool0
1`02eQ`0103oool00]HL00;F703oool300;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002
eQ`00P02eQ`0103oool00]HL00;F703oool400;F7080oooo1002eQ`00`3oool00]HL00;F700300;F
7080oooo1@02eQbg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000>P3oool200;F7003
0?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`00`02eQ`01@3oool00]HL00;F7002eQ`0oooo
00<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70030?ooo`02eQ`00]HL00H00]HL0P3oool3
00;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00`02
eQ`20?ooo`D00]HL]03oool00`000000oooo0?ooo`090?ooo`00LP3oool2000003`0oooo0P02eQ`0
0`3oool00]HL00;F700400;F70030?ooo`02eQ`00]HL00<00]HL00D0oooo00;F7002eQ`00]HL0?oo
o`0300;F70050?ooo`02eQ`00]HL00;F703oool01`02eQ`0103oool00]HL00;F7002eQ`20?ooo`@0
0]HL00@0oooo00;F7002eQ`0oooo1002eQ`20?ooo`D00]HL00<0oooo00;F7002eQ`00P02eQ`20?oo
o`D00]HL/P3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000003h0oooo0P02eQ`0103oool0
0]HL00;F703oool300;F70030?ooo`02eQ`00]HL00<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`03
00;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL
00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700600;F7080oooo1002eQ`00`3oool00]HL
00;F700300;F7080oooo1@02eQb_0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000@03o
ool200;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`00`02eQ`01@3oool00]HL
00;F7002eQ`0oooo00<00]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F703oool300;F
70030?ooo`02eQ`00]HL00800]HL0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`@00]HL0P3oool5
00;F70030?ooo`02eQ`00]HL00800]HL0`3oool500;F7:`0oooo00<000000?ooo`3oool02@3oool0
0780oooo0P0000120?ooo`800]HL00@0oooo00;F7002eQ`0oooo0`02eQ`00`3oool00]HL00;F7003
00;F70050?ooo`02eQ`00]HL00;F703oool02002eQ`0103oool00]HL00;F703oool400;F70040?oo
o`02eQ`00]HL00;F7080oooo1002eQ`0103oool00]HL00;F703oool500;F7080oooo1002eQ`00`3o
ool00]HL00;F700300;F7080oooo1@02eQbZ0?ooo`030000003oool0oooo00T0oooo001b0?ooo`80
0000A03oool200;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`00`02eQ`01@3o
ool00]HL00;F7002eQ`0oooo00P00]HL00<0oooo00;F7002eQ`01@02eQ`00`3oool00]HL00;F7002
00;F70030?ooo`02eQ`00]HL00H00]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`D00]HL00<0oooo
00;F7002eQ`00`02eQ`20?ooo`D00]HLY`3oool00`000000oooo0?ooo`090?ooo`00LP3oool20000
04H0oooo1@02eQ`01@3oool00]HL00;F7002eQ`0oooo00D00]HL00@0oooo00;F7002eQ`00]HL0P3o
ool300;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@0
0]HL0P3oool400;F70040?ooo`02eQ`00]HL0?ooo`D00]HL0P3oool400;F70030?ooo`02eQ`00]HL
00<00]HL0`3oool500;F7:@0oooo00<000000?ooo`3oool02@3oool00780oooo0P0000180?ooo`03
00;F703oool00]HL00800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0900;F7080oooo0`02eQ`0103o
ool00]HL00;F7002eQ`20?ooo`800]HL00<0oooo00;F7002eQ`01P02eQ`20?ooo`@00]HL00D0oooo
00;F7002eQ`00]HL0?ooo`0400;F7080oooo1@02eQ`00`3oool00]HL00;F700300;F7080oooo1P02
eQbQ0?ooo`030000003oool0oooo00T0oooo001b0?ooo`<00000B03oool200;F70050?ooo`02eQ`0
0]HL00;F703oool00`02eQ`00`3oool00]HL00;F700800;F70050?ooo`02eQ`00]HL00;F703oool0
1002eQ`0103oool00]HL00;F703oool400;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F7004
0?ooo`02eQ`00]HL0?ooo`D00]HL0P3oool500;F70030?ooo`02eQ`00]HL00<00]HL0P3oool500;F
79l0oooo00<000000?ooo`3oool02@3oool00780oooo0P00001;0?ooo`800]HL00D0oooo00;F7002
eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL00P00]HL00D0oooo00;F7002eQ`00]HL0?ooo`04
00;F70030?ooo`02eQ`00]HL00D00]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL00D0oooo
00;F7002eQ`00]HL0?ooo`0400;F7080oooo1@02eQ`00`3oool00]HL00;F700300;F70<0oooo1@02
eQbL0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000C@3oool200;F70050?ooo`02eQ`0
0]HL00;F703oool00`02eQ`00`3oool00]HL00;F700800;F70030?ooo`02eQ`00]HL00H00]HL0P3o
ool200;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`20?ooo`D00]HL00@0oooo00;F7002eQ`0
oooo1@02eQ`20?ooo`D00]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`H00]HLV@3oool00`000000
oooo0?ooo`090?ooo`00LP3oool2000004l0oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<0
0]HL00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700600;F7080oooo0P02eQ`00`3oool0
0]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F70040?ooo`02eQ`00]HL0?oo
o`D00]HL0P3oool500;F70030?ooo`02eQ`00]HL00@00]HL0P3oool600;F79H0oooo00<000000?oo
o`3oool02@3oool00780oooo0P00001A0?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F
70040?ooo`02eQ`00]HL0?ooo`L00]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F7002
eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F7080oooo1002
eQ`01@3oool00]HL00;F7002eQ`0oooo00D00]HL0P3oool500;F70030?ooo`02eQ`00]HL00<00]HL
0`3oool500;F79@0oooo00<000000?ooo`3oool02@3oool00780oooo0P00001C0?ooo`800]HL00D0
oooo00;F7002eQ`00]HL0?ooo`0300;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00D0oooo00;F7002
eQ`00]HL0?ooo`0400;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0oooo1002eQ`0
0`3oool00]HL00;F700200;F7080oooo1@02eQ`0103oool00]HL00;F703oool500;F7080oooo1@02
eQ`20?ooo`D00]HL0`3oool500;F7940oooo00<000000?ooo`3oool02@3oool00780oooo0P00001E
0?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70040?ooo`02eQ`00]HL0?ooo`<00]HL
00@0oooo00;F7002eQ`00]HL0P3oool300;F70030?ooo`02eQ`00]HL00800]HL00D0oooo00;F7002
eQ`00]HL0?ooo`0400;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F70050?ooo`02eQ`00]HL
00;F703oool01@02eQ`20?ooo`D00]HL00<0oooo00;F7002eQ`00`02eQ`30?ooo`H00]HLSP3oool0
0`000000oooo0?ooo`090?ooo`00LP3oool2000005L0oooo0P02eQ`00`3oool00]HL00;F700500;F
70040?ooo`02eQ`00]HL0?ooo`<00]HL00@0oooo00;F7002eQ`00]HL0P3oool300;F70030?ooo`02
eQ`00]HL00800]HL0P3oool200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02
eQ`20?ooo`D00]HL00@0oooo00;F7002eQ`0oooo1@02eQ`20?ooo`H00]HL00<0oooo00;F7002eQ`0
0`02eQ`30?ooo`H00]HLR`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000005T0oooo0P02
eQ`00`3oool00]HL00;F700500;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00@0oooo00;F7002eQ`0
0]HL0P3oool800;F7080oooo0P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL0080
0]HL0`3oool400;F70050?ooo`02eQ`00]HL00;F703oool01@02eQ`20?ooo`D00]HL00<0oooo00;F
7002eQ`01002eQ`30?ooo`800]HL00<0oooo00;F7002eQ`0R@3oool00`000000oooo0?ooo`090?oo
o`00LP3oool2000005/0oooo0P02eQ`00`3oool00]HL00;F700500;F70040?ooo`02eQ`00]HL0?oo
o`<00]HL00@0oooo00;F7002eQ`00]HL0P3oool400;F70040?ooo`02eQ`00]HL00;F7080oooo0P02
eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00<00]HL0P3oool400;F7080oooo0P02
eQ`00`3oool00]HL00;F700300;F70<0oooo1@02eQ`00`3oool00]HL00;F700300;F70<0oooo1P02
eQb60?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000G@3oool00`02eQ`0oooo0?ooo`07
00;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F
700200;F70030?ooo`02eQ`00]HL00800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0400;F70030?oo
o`02eQ`00]HL00800]HL0P3oool500;F70030?ooo`02eQ`00]HL0080oooo1@02eQ`20?ooo`D00]HL
0P3oool500;F70<0oooo1P02eQb30?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000GP3o
ool200;F7080oooo1`02eQ`0103oool00]HL00;F703oool300;F70030?ooo`02eQ`00]HL00800]HL
00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F7080oooo0P02eQ`00`3oool00]HL
00;F700200;F70030?ooo`02eQ`00]HL00800]HL0`3oool400;F70050?ooo`02eQ`00]HL00;F703o
ool01@02eQ`30?ooo`D00]HL00<0oooo00;F7002eQ`01002eQ`30?ooo`800]HL00<0oooo00;F7002
eQ`0P@3oool00`000000oooo0?ooo`090?ooo`00LP3oool200000600oooo0P02eQ`00`3oool00]HL
00;F700600;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool0
0]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL0P3oool200;F70030?ooo`02eQ`00]HL0080
0]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`D00]HL00<0oooo00;F7002eQ`00P3oool400;F70<0
oooo1@02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`3oool600;F77h0oooo00<000000?ooo`3o
ool02@3oool00780oooo0P00001R0?ooo`800]HL00<0oooo00;F7002eQ`01P02eQ`0103oool00]HL
00;F703oool300;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool0
0]HL00;F700200;F7080oooo0P02eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`00]HL0080
0]HL0P3oool500;F70050?ooo`02eQ`00]HL00;F703oool01@02eQ`30?ooo`D00]HL00<0oooo00;F
7002eQ`01002eQ`30?ooo`H00]HLN`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000006@0
oooo0P02eQ`00`3oool00]HL00;F700600;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F
7002eQ`00P02eQ`20?ooo`P00]HL0P3oool300;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F
7002eQ`00P02eQ`30?ooo`D00]HL00@0oooo00;F7002eQ`0oooo1@02eQ`30?ooo`D00]HL0P3oool6
00;F70<0oooo0P02eQ`0103oool00]HL00;F7002eQah0?ooo`030000003oool0oooo00T0oooo001b
0?ooo`800000IP3oool200;F70030?ooo`02eQ`00]HL00H00]HL00@0oooo00;F7002eQ`0oooo0`02
eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700200;F7080oooo0P02
eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00<00]HL0P3oool500;F70050?ooo`02
eQ`00]HL00;F703oool01@02eQ`30?ooo`D00]HL0P3oool200;F70030?ooo`02eQ`00]HL00<0oooo
0`02eQ`00`3oool00]HL00;F701f0?ooo`030000003oool0oooo00T0oooo001b0?ooo`<00000I`3o
ool200;F70030?ooo`02eQ`00]HL00H00]HL00@0oooo00;F7002eQ`0oooo2002eQ`20?ooo`@00]HL
00<0oooo00;F7002eQ`00P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL
0`3oool400;F7080oooo0P02eQ`00`3oool00]HL00;F700300;F70<0oooo1P02eQ`00`3oool00]HL
00;F700400;F70<0oooo1P02eQac0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000JP3o
ool200;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`0103oool00]HL00;F703oool800;F7080
oooo1002eQ`00`3oool00]HL00;F700200;F7080oooo0P02eQ`00`3oool00]HL00;F700300;F7003
0?ooo`02eQ`00]HL00<00]HL0P3oool500;F70030?ooo`02eQ`00]HL0080oooo1@02eQ`30?ooo`80
0]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`0103oool0
0]HL00;F7002eQa`0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000K03oool200;F7005
0?ooo`02eQ`00]HL00;F703oool01002eQ`0103oool00]HL00;F703oool400;F70040?ooo`02eQ`0
0]HL00;F7080oooo1002eQ`00`3oool00]HL00;F700200;F7080oooo0`02eQ`00`3oool00]HL00;F
700200;F70030?ooo`02eQ`00]HL00<00]HL0P3oool500;F70050?ooo`02eQ`00]HL00;F703oool0
1@02eQ`30?ooo`H00]HL00<0oooo00;F7002eQ`01002eQ`30?ooo`<00]HL00@0oooo00;F7002eQ`0
0]HLK@3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000006h0oooo0P02eQ`01@3oool00]HL
00;F7002eQ`0oooo00@00]HL00@0oooo00;F7002eQ`0oooo1002eQ`0103oool00]HL00;F7002eQ`2
0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`2
0?ooo`@00]HL0`3oool500;F70030?ooo`02eQ`00]HL0080oooo1@02eQ`30?ooo`800]HL00<0oooo
00;F7002eQ`00P3oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo0`02eQ`00`3oool00]HL00;F
701[0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000L03oool200;F70050?ooo`02eQ`0
0]HL00;F703oool01002eQ`0103oool00]HL00;F703oool400;F70030?ooo`02eQ`00]HL00800]HL
00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700300;F7080oooo0P02eQ`00`3oool00]HL
00;F700300;F70030?ooo`02eQ`00]HL00<00]HL0P3oool200;F70040?ooo`02eQ`00]HL0?ooo`<0
0]HL00<0oooo00;F7002eQ`00`02eQ`30?ooo`H00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F
70@0oooo0P02eQ`0103oool00]HL00;F7002eQaX0?ooo`030000003oool0oooo00T0oooo001b0?oo
o`800000LP3oool00`02eQ`0oooo0?ooo`0300;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F
7002eQ`0oooo1002eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F7002
00;F7080oooo0P02eQ`00`3oool00]HL00;F700300;F70040?ooo`02eQ`00]HL0?ooo`800]HL0P3o
ool500;F7080oooo0P02eQ`20?ooo`D00]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo1P02
eQ`30?ooo`<00]HL00@0oooo00;F7002eQ`00]HLI@3oool00`000000oooo0?ooo`090?ooo`00LP3o
ool2000007<0oooo0P02eQ`20?ooo`<00]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F
703oool400;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F70030?ooo`02eQ`00]HL00800]HL
0P3oool300;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00`02eQ`30?ooo`D00]HL
00D0oooo00;F7002eQ`00]HL0?ooo`0200;F70030?ooo`02eQ`00]HL00<0oooo1P02eQ`20?ooo`80
0]HL00@0oooo00;F7002eQ`00]HL0`3oool300;F70030?ooo`02eQ`00]HL06<0oooo00<000000?oo
o`3oool02@3oool00780oooo0P00001e0?ooo`800]HL0P3oool300;F70030?ooo`02eQ`00]HL0080
0]HL00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3o
ool00]HL00;F700200;F70<0oooo0P02eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`00]HL
00<00]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F700400;F
70<0oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL00<0oooo00;F7002eQ`0103oool2
00;F70040?ooo`02eQ`00]HL00;F7600oooo00<000000?ooo`3oool02@3oool00780oooo0P00001g
0?ooo`800]HL0P3oool300;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0oooo1002
eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700300;F7080oooo0P02
eQ`0103oool00]HL00;F703oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL0P3oool600;F7003
0?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`<00]HL00<0oooo00;F7002
eQ`00P3oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo0`02eQ`0103oool00]HL00;F7002eQaM
0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000N@3oool200;F7080oooo0`02eQ`00`3o
ool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`2
0?ooo`@00]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`02eQ`0
0`3oool00]HL00;F700300;F70<0oooo0P02eQ`0103oool00]HL00;F703oool300;F70030?ooo`02
eQ`00]HL00@00]HL0`3oool200;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`0103oool00]HL
00;F7002eQ`30?ooo`<00]HL00@0oooo00;F7002eQ`00]HLFP3oool00`000000oooo0?ooo`090?oo
o`00LP3oool2000007/0oooo0P02eQ`20?ooo`<00]HL00<0oooo00;F7002eQ`00P02eQ`0103oool0
0]HL00;F703oool400;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F7080oooo1002eQ`20?oo
o`800]HL0P3oool400;F7080oooo1@02eQ`20?ooo`D00]HL0P3oool200;F7080oooo0P02eQ`00`3o
ool00]HL00;F70030?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool300;F70030?ooo`02eQ`00]HL
00@0oooo0`02eQ`00`3oool00]HL00;F701H0?ooo`030000003oool0oooo00T0oooo001b0?ooo`80
0000O@3oool200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`0103oool0
0]HL00;F703oool400;F70030?ooo`02eQ`00]HL00800]HL0P3oool500;F70030?ooo`02eQ`00]HL
00800]HL0P3oool300;F70030?ooo`02eQ`00]HL00<00]HL00@0oooo00;F7002eQ`0oooo0P02eQ`3
0?ooo`D00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0600;F70<0oooo1P02eQ`20?ooo`800]HL00@0
oooo00;F7002eQ`00]HL103oool200;F70040?ooo`02eQ`00]HL00;F75D0oooo00<000000?ooo`3o
ool02@3oool00780oooo0P00001o0?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL
00;F700200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`D0
0]HL00<0oooo00;F7002eQ`00P02eQ`30?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3o
ool00]HL00;F700300;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F
70030?ooo`02eQ`00]HL00@0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`<00]HL00<0oooo00;F
7002eQ`0103oool300;F70040?ooo`02eQ`00]HL00;F7580oooo00<000000?ooo`3oool02@3oool0
0780oooo0P0000210?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F
70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`30?ooo`@00]HL00<0oooo
00;F7002eQ`00`02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`D00]HL0P3oool6
00;F70050?ooo`02eQ`00]HL00;F703oool01P02eQ`30?ooo`H00]HL0P3oool200;F70040?ooo`02
eQ`00]HL00;F70@0oooo0`02eQ`0103oool00]HL00;F7002eQa?0?ooo`030000003oool0oooo00T0
oooo001T0?ooo`<000000P3oool2000000L0oooo0P0000230?ooo`800]HL00<0oooo00;F7002eQ`0
0P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002
eQ`00`02eQ`20?ooo`@00]HL00@0oooo00;F7002eQ`0oooo0P02eQ`20?ooo`800]HL0P3oool500;F
70040?ooo`02eQ`00]HL0?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`2
0?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F70050?ooo`02eQ`00]HL00;F703oool00`02
eQ`0103oool00]HL00;F7002eQ`40?ooo`800]HL0P3oool200;F74d0oooo00<000000?ooo`3oool0
2@3oool006D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`800000
Q@3oool200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL
00;F703oool400;F70030?ooo`02eQ`00]HL00<00]HL0P3oool400;F70030?ooo`02eQ`00]HL00<0
0]HL0P3oool300;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`3
0?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`0103oool00]HL00;F7002
eQ`30?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool300;F70030?ooo`02eQ`00]HL00@0oooo0`02
eQ`0103oool00]HL00;F7002eQa:0?ooo`030000003oool0oooo00T0oooo001U0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0103oool2000008L0oooo00<00]HL0?ooo`3oool0
1002eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?ooo`D00]HL00<0oooo00;F7002
eQ`00P02eQ`20?ooo`@00]HL0P3oool400;F70<0oooo0P02eQ`0103oool00]HL00;F703oool200;F
70030?ooo`02eQ`00]HL00@00]HL0P3oool600;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`0
0`3oool00]HL00;F70040?ooo`800]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F70040?ooo`02
eQ`00]HL00;F70@0oooo0`02eQ`0103oool00]HL00;F7002eQa70?ooo`030000003oool0oooo00T0
oooo001U0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool4000008H0
oooo0P02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F703oool500;F
70030?ooo`02eQ`00]HL00800]HL0P3oool500;F70030?ooo`02eQ`00]HL00800]HL0`3oool200;F
70030?ooo`02eQ`00]HL00<00]HL0P3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`00`3o
ool00]HL00;F70020?ooo`800]HL0P3oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo0`02eQ`0
0`3oool00]HL00;F70020?ooo`<00]HL00@0oooo00;F7002eQ`00]HL103oool200;F7080oooo0P02
eQa50?ooo`030000003oool0oooo00T0oooo001U0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0103oool2000008X0oooo0P02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P02
eQ`00`3oool00]HL00;F70020?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`800]HL00@0
oooo00;F7002eQ`0oooo1@02eQ`20?ooo`800]HL0P3oool500;F70040?ooo`02eQ`00]HL0?ooo`80
0]HL0`3oool600;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`00`3oool00]HL00;F70040?oo
o`800]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F7080oooo0P02eQ`40?ooo`<00]HL00@0oooo
00;F7002eQ`00]HL@P3oool00`000000oooo0?ooo`090?ooo`00I03oool200000080oooo00@00000
0?ooo`3oool000001P3oool2000008`0oooo0P02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P02
eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`800]HL
00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`<00]HL00@0oooo00;F7002
eQ`0oooo0P02eQ`00`3oool00]HL00;F700400;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?oo
o`800]HL0P3oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo0`02eQ`00`3oool00]HL00;F7002
0?ooo`<00]HL00@0oooo00;F7002eQ`00]HL103oool300;F70040?ooo`02eQ`00]HL00;F73l0oooo
00<000000?ooo`3oool02@3oool006D0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`800000
SP3oool200;F7080oooo1002eQ`00`3oool00]HL00;F700200;F7080oooo0P02eQ`00`3oool00]HL
00;F700200;F70030?ooo`02eQ`00]HL00800]HL0P3oool500;F70040?ooo`02eQ`00]HL0?ooo`80
0]HL0`3oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL
00<0oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL00D0oooo00;F7002eQ`00]HL0?oo
o`0200;F70@0oooo0P02eQ`0103oool00]HL00;F7002eQ`20?ooo`<00]HL00@0oooo00;F7002eQ`0
0]HL103oool200;F7080oooo0`02eQ`l0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000
T03oool200;F7080oooo1002eQ`0103oool00]HL00;F7002eQ`30?ooo`800]HL00<0oooo00;F7002
eQ`00P02eQ`00`3oool00]HL00;F700200;F70<0oooo1002eQ`00`3oool00]HL00;F700300;F70<0
oooo0P02eQ`00`3oool00]HL00;F700400;F70040?ooo`02eQ`00]HL0?ooo`800]HL0`3oool300;F
70030?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`00]HL0`3oool3
00;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`20?ooo`800]HL103oool300;F7080oooo0P02
eQ`j0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000TP3oool200;F7080oooo1002eQ`0
103oool00]HL00;F7002eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F
700200;F70<0oooo1002eQ`20?ooo`@00]HL0`3oool200;F7080oooo0P02eQ`0103oool00]HL00;F
703oool600;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool300;F70030?oo
o`02eQ`00]HL00@0oooo0P02eQ`20?ooo`800]HL0P3oool300;F70040?ooo`02eQ`00]HL00;F70@0
oooo0`02eQ`0103oool00]HL00;F7002eQ`g0?ooo`030000003oool0oooo00T0oooo001b0?ooo`80
0000U03oool200;F7080oooo2002eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool0
0]HL00;F700200;F70<0oooo1002eQ`20?ooo`D00]HL0P3oool300;F70040?ooo`02eQ`00]HL0?oo
o`800]HL0P3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`01@3oool00]HL00;F7002eQ`0
oooo00<00]HL0P3oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo0`02eQ`0103oool00]HL00;F
7002eQ`20?ooo`800]HL0P3oool200;F70D0oooo0P02eQ`20?ooo`<00]HL=03oool00`000000oooo
0?ooo`090?ooo`00LP3oool2000009H0oooo0P02eQ`20?ooo`<00]HL00<0oooo00;F7002eQ`00P02
eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700300;F7080oooo1@02
eQ`0103oool00]HL00;F703oool200;F70<0oooo0P02eQ`0103oool00]HL00;F703oool200;F7080
oooo0P02eQ`00`3oool00]HL00;F70030?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool200;F7080
oooo0`02eQ`00`3oool00]HL00;F70040?ooo`800]HL0P3oool200;F7080oooo0`02eQ`0103oool0
0]HL00;F7002eQ`40?ooo`<00]HL0P3oool300;F7340oooo00<000000?ooo`3oool02@3oool00780
oooo0P00002H0?ooo`800]HL0P3oool300;F70030?ooo`02eQ`00]HL00800]HL0`3oool200;F7003
0?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`20?ooo`800]HL00@0oooo00;F
7002eQ`0oooo0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL00<0oooo00;F7002eQ`01002eQ`0
103oool00]HL00;F703oool300;F70<0oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL
0P3oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo0`02eQ`0103oool00]HL00;F7002eQ`20?oo
o`<00]HL00@0oooo00;F7002eQ`00]HL103oool300;F7080oooo0P02eQ`_0?ooo`030000003oool0
oooo00T0oooo001b0?ooo`800000VP3oool200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F
7002eQ`00P02eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F703oool2
00;F7080oooo0P02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02
eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo0`02eQ`00`3oool00]HL00;F70030?ooo`<00]HL
00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`20?ooo`800]HL103oool200;F7080oooo
0P02eQ`30?ooo`800]HL0P3oool200;F70D0oooo0P02eQ`20?ooo`<00]HL;03oool00`000000oooo
0?ooo`090?ooo`00LP3oool2000009`0oooo00<00]HL0?ooo`3oool01002eQ`00`3oool00]HL00;F
700200;F70<0oooo0P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?ooo`800]HL
0P3oool500;F70030?ooo`02eQ`00]HL00<00]HL0`3oool200;F7080oooo0P02eQ`00`3oool00]HL
00;F70020?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F70030?ooo`02eQ`00]HL0080oooo
0`02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL0`3oool300;F70040?ooo`02eQ`00]HL00;F
7080oooo0`02eQ`0103oool00]HL00;F7002eQ`40?ooo`<00]HL0P3oool300;F72T0oooo00<00000
0?ooo`3oool02@3oool00780oooo0P00002M0?ooo`800]HL0P3oool400;F70030?ooo`02eQ`00]HL
00800]HL0`3oool200;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`3
0?ooo`@00]HL0P3oool500;F7080oooo0`02eQ`0103oool00]HL00;F703oool300;F70040?ooo`02
eQ`00]HL0?ooo`<00]HL0`3oool200;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`20?ooo`80
0]HL0P3oool200;F70@0oooo0`02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL0P3oool300;F
70@0oooo0`02eQ`20?ooo`800]HL9`3oool00`000000oooo0?ooo`090?ooo`00LP3oool2000009l0
oooo0P02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`30?ooo`800]HL00<0oooo00;F7002
eQ`00P02eQ`00`3oool00]HL00;F700300;F70<0oooo1002eQ`20?ooo`800]HL00<0oooo00;F7002
eQ`00`3oool200;F70050?ooo`02eQ`00]HL00;F703oool00P02eQ`01@3oool00]HL00;F7002eQ`0
oooo00800]HL0`3oool300;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`<00]HL00@0oooo
00;F7002eQ`00]HL103oool200;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool200;F70D0oooo0P02
eQ`20?ooo`<00]HL903oool00`000000oooo0?ooo`090?ooo`00LP3oool200000:40oooo0P02eQ`2
0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`2
0?ooo`@00]HL0`3oool500;F70040?ooo`02eQ`00]HL0?ooo`800]HL0`3oool200;F7080oooo0P02
eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F70050?ooo`02
eQ`00]HL00;F703oool00`02eQ`20?ooo`800]HL0P3oool200;F70@0oooo0`02eQ`0103oool00]HL
00;F7002eQ`20?ooo`800]HL0P3oool300;F70@0oooo0`02eQ`20?ooo`<00]HL8@3oool00`000000
oooo0?ooo`090?ooo`00LP3oool200000:<0oooo0P02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`0
0P02eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0`3oool200;F70040?oo
o`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F7080oooo0P02eQ`00`3oool0
0]HL00;F70020?ooo`800]HL00@0oooo00;F7002eQ`00]HL0`3oool200;F7080oooo0P02eQ`20?oo
o`800]HL0P3oool300;F70040?ooo`02eQ`00]HL00;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool3
00;F7080oooo0`02eQ`40?ooo`<00]HL0P3oool300;F71h0oooo00<000000?ooo`3oool02@3oool0
0780oooo0P00002U0?ooo`800]HL0P3oool400;F70030?ooo`02eQ`00]HL00800]HL0`3oool200;F
70030?ooo`02eQ`00]HL00800]HL0P3oool400;F70<0oooo0P02eQ`0103oool00]HL00;F703oool5
00;F70<0oooo0`02eQ`0103oool00]HL00;F703oool300;F70050?ooo`02eQ`00]HL00;F703oool0
0P02eQ`30?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool300;F7080oooo0P02eQ`20?ooo`800]HL
103oool300;F70040?ooo`02eQ`00]HL00;F7080oooo0`02eQ`20?ooo`800]HL1@3oool200;F70<0
oooo0P02eQ`L0?ooo`030000003oool0oooo00T0oooo001b0?ooo`<00000YP3oool200;F7080oooo
1002eQ`00`3oool00]HL00;F700200;F70<0oooo0P02eQ`00`3oool00]HL00;F700300;F70030?oo
o`02eQ`00]HL00800]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo1@02eQ`30?ooo`800]HL
00D0oooo00;F7002eQ`00]HL0?ooo`0200;F7080oooo0P02eQ`00`3oool00]HL00;F70040?ooo`80
0]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F7080oooo0`02eQ`0103oool00]HL00;F7002eQ`4
0?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`20?ooo`<00]HL103oool300;F7080oooo0`02eQ`I
0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000Z@3oool200;F7080oooo1002eQ`00`3o
ool00]HL00;F700200;F70<0oooo0P02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`0
0]HL00<00]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F7003
0?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`0103oool00]HL00;F7002
eQ`30?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool300;F7080oooo0P02eQ`20?ooo`800]HL103o
ool300;F70040?ooo`02eQ`00]HL00;F7080oooo0`02eQ`20?ooo`800]HL1@3oool300;F7080oooo
0`02eQ`F0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000Z`3oool200;F7080oooo1002
eQ`00`3oool00]HL00;F700200;F70<0oooo0P02eQ`0103oool00]HL00;F703oool200;F70040?oo
o`02eQ`00]HL0?ooo`800]HL0P3oool500;F7080oooo0P02eQ`00`3oool00]HL00;F70030?ooo`80
0]HL0P3oool200;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`00`3oool00]HL00;F70040?oo
o`800]HL00@0oooo00;F7002eQ`00]HL0P3oool200;F7080oooo0P02eQ`20?ooo`<00]HL103oool2
00;F7080oooo0`02eQ`20?ooo`800]HL0P3oool300;F70D0oooo0`02eQ`20?ooo`<00]HL4`3oool0
0`000000oooo0?ooo`090?ooo`00LP3oool200000:d0oooo0P02eQ`20?ooo`@00]HL00<0oooo00;F
7002eQ`00P02eQ`30?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703o
ool200;F70<0oooo1@02eQ`0103oool00]HL00;F703oool200;F70<0oooo0`02eQ`00`3oool00]HL
00;F70020?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`20?ooo`800]HL
0P3oool200;F7080oooo0`02eQ`20?ooo`800]HL103oool300;F7080oooo0P02eQ`20?ooo`<00]HL
0P3oool300;F70D0oooo0P02eQ`30?ooo`800]HL4@3oool00`000000oooo0?ooo`090?ooo`00LP3o
ool200000:l0oooo00@00]HL0?ooo`3oool0oooo1002eQ`00`3oool00]HL00;F700200;F70<0oooo
0P02eQ`0103oool00]HL00;F703oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL0`3oool200;F
70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F70050?ooo`02eQ`0
0]HL00;F703oool00P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`00]HL0`3oool300;F70050?oo
o`02eQ`00]HL00;F703oool00`02eQ`20?ooo`800]HL0P3oool200;F70D0oooo0P02eQ`20?ooo`<0
0]HL0P3oool300;F7080oooo0P02eQ`50?ooo`<00]HL0P3oool300;F70h0oooo00<000000?ooo`3o
ool02@3oool00780oooo0P00002`0?ooo`800]HL0`3oool400;F70030?ooo`02eQ`00]HL00800]HL
0`3oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`30?oo
o`800]HL00@0oooo00;F7002eQ`0oooo1P02eQ`30?ooo`800]HL0P3oool200;F70030?ooo`02eQ`0
0]HL0080oooo0P02eQ`20?ooo`800]HL103oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool3
00;F70040?ooo`02eQ`00]HL00;F70@0oooo0`02eQ`20?ooo`800]HL0`3oool200;F7080oooo0`02
eQ`50?ooo`<00]HL0P3oool300;F70/0oooo00<000000?ooo`3oool02@3oool00780oooo0P00002b
0?ooo`800]HL0`3oool01@02eQ`0oooo00;F7002eQ`0oooo00@00]HL0`3oool200;F70040?ooo`02
eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`30?ooo`800]HL00<0oooo00;F7002
eQ`00P3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL00D0oooo00;F7002
eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL00@0oooo0P02eQ`20?ooo`800]HL0P3oool300;F
7080oooo0P02eQ`20?ooo`800]HL1@3oool200;F7080oooo0`02eQ`20?ooo`<00]HL0P3oool300;F
70D0oooo0P02eQ`30?ooo`800]HL2@3oool00`000000oooo0?ooo`090?ooo`00LP3oool200000;@0
oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo1002eQ`30?ooo`800]HL00@0oooo00;F
7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool200;F70<0oooo0P02eQ`00`3oool00]HL00;F
70020?ooo`800]HL00<0oooo00;F7002eQ`00`3oool300;F70050?ooo`02eQ`00]HL00;F703oool0
0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`00]HL0`3oool300;F70040?ooo`02eQ`00]HL00;F
7080oooo0P02eQ`20?ooo`<00]HL00@0oooo00;F7002eQ`00]HL103oool300;F7080oooo0P02eQ`3
0?ooo`800]HL0`3oool200;F70D0oooo0`02eQ`20?ooo`<00]HL1P3oool00`000000oooo0?ooo`09
0?ooo`00LP3oool200000;H0oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo1002eQ`3
0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool200;F70<0oooo
0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F7080oooo
0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL
0P3oool300;F7080oooo0P02eQ`20?ooo`800]HL1@3oool200;F7080oooo0`02eQ`20?ooo`<00]HL
0P3oool300;F70D0oooo0`02eQ`20?ooo`<00]HL0`3oool00`000000oooo0?ooo`090?ooo`00LP3o
ool200000;P0oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo1002eQ`30?ooo`800]HL
00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F700300;F70<0oooo0P02eQ`01@3oool0
0]HL00;F7002eQ`0oooo00800]HL00<0oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`01@3o
ool00]HL00;F7002eQ`0oooo00<00]HL00<0oooo00;F7002eQ`0103oool300;F70040?ooo`02eQ`0
0]HL00;F7080oooo0P02eQ`20?ooo`<00]HL00@0oooo00;F7002eQ`00]HL103oool300;F7080oooo
0`02eQ`20?ooo`<00]HL0P3oool300;F70D0oooo0P02eQ`30?ooo`<00]HL00<000000?ooo`3oool0
2@3oool00780oooo0P00002j0?ooo`800]HL0P3oool200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL
0`3oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL0P3oool400;F70<0oooo0`02eQ`0103oool0
0]HL00;F703oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo0P02eQ`20?ooo`800]HL0P3oool2
00;F7080oooo0P02eQ`0103oool00]HL00;F7002eQ`40?ooo`800]HL0P3oool200;F7080oooo0P02
eQ`30?ooo`800]HL0P3oool200;F70D0oooo0P02eQ`30?ooo`800]HL0`3oool200;F70<0oooo0P02
eQ`50?ooo`<00]HL0`3oool2000000X0oooo001b0?ooo`800000_03oool200;F7080oooo0P02eQ`0
103oool00]HL00;F703oool400;F70<0oooo0P02eQ`0103oool00]HL00;F703oool200;F7080oooo
1@02eQ`30?ooo`800]HL00@0oooo00;F7002eQ`0oooo0`02eQ`00`3oool00]HL00;F70030?ooo`<0
0]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F7080oooo0P02eQ`20?ooo`800]HL103oool200;F
7080oooo0P02eQ`20?ooo`<00]HL0P3oool200;F7080oooo0`02eQ`40?ooo`<00]HL0P3oool300;F
7080oooo0`02eQ`20?ooo`<00]HL1@3oool300;F708000002P3oool00780oooo0P00002n0?ooo`80
0]HL0P3oool200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL0`3oool200;F70040?ooo`02eQ`00]HL
0?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`00`3oool00]HL00;F7002
0?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`00`3oool00]HL00;F7002
0?ooo`<00]HL00<0oooo00;F7002eQ`0103oool300;F70040?ooo`02eQ`00]HL00;F7080oooo0P02
eQ`20?ooo`<00]HL0P3oool200;F70D0oooo0`02eQ`20?ooo`800]HL0`3oool200;F70<0oooo0P02
eQ`60?ooo`8000002P3oool00780oooo0P0000300?ooo`800]HL0P3oool200;F70040?ooo`02eQ`0
oooo0?ooo`@00]HL0`3oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL0P3oool200;F70030?oo
o`02eQ`00]HL00<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F7002eQ`0
103oool200;F7080oooo0P02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL00@0oooo00;F7002
eQ`00]HL103oool200;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool200;F7080oooo0`02eQ`50?oo
o`800]HL0P3oool300;F7080oooo0`02eQ`20?ooo`<00]HL0`3oool2000000X0oooo001b0?ooo`80
0000`P3oool200;F7080oooo1002eQ`20?ooo`@00]HL0`3oool200;F70040?ooo`02eQ`00]HL0?oo
o`800]HL0P3oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`00`3oool00]HL00;F70020?oo
o`800]HL00@0oooo00;F7002eQ`00]HL0`3oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool2
00;F7080oooo0P02eQ`40?ooo`800]HL0P3oool300;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool2
00;F70D0oooo0`02eQ`20?ooo`800]HL0`3oool300;F7080oooo0`02eQ`2000000X0oooo001b0?oo
o`800000a03oool01002eQ`0oooo0?ooo`3oool400;F7080oooo1002eQ`30?ooo`800]HL00<0oooo
00;F7002eQ`00`02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F70030?ooo`02eQ`0
0]HL0080oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0`02eQ`00`3oool00]HL00;F7002
0?ooo`800]HL0P3oool200;F70@0oooo0`02eQ`20?ooo`800]HL0P3oool300;F7080oooo0P02eQ`2
0?ooo`<00]HL1@3oool200;F7080oooo0`02eQ`30?ooo`800]HL0`3oool2000000X0oooo001b0?oo
o`<00000a03oool200;F70<0oooo1002eQ`20?ooo`@00]HL0`3oool200;F7080oooo1002eQ`20?oo
o`800]HL00<0oooo00;F7002eQ`00`3oool200;F70050?ooo`02eQ`00]HL00;F703oool00P02eQ`2
0?ooo`800]HL0`3oool300;F7080oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL00@0
oooo00;F7002eQ`00]HL103oool200;F7080oooo0P02eQ`30?ooo`800]HL0P3oool300;F7080oooo
0P02eQ`50?ooo`<00]HL0P3oool300;F7080oooo0`02eQ`2000000X0oooo001b0?ooo`800000a`3o
ool200;F70<0oooo1002eQ`20?ooo`@00]HL0`3oool200;F7080oooo1@02eQ`0103oool00]HL00;F
703oool200;F70<0oooo0`02eQ`0103oool00]HL00;F703oool300;F70030?ooo`02eQ`00]HL00@0
oooo0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL103oool300;F7004
0?ooo`02eQ`00]HL00;F7080oooo0P02eQ`30?ooo`800]HL0P3oool300;F70D0oooo0P02eQ`30?oo
o`800]HL0`3oool2000000X0oooo001b0?ooo`800000b@3oool200;F70<0oooo1002eQ`20?ooo`@0
0]HL0`3oool200;F7080oooo0P02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL
00@0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F
7080oooo0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`50?ooo`800]HL0P3oool200;F
7080oooo0`02eQ`20?ooo`<00]HL0P3oool200;F70D0oooo0`02eQ`20?ooo`<00]HL00<000000?oo
o`3oool02@3oool00780oooo0P00003;0?ooo`800]HL0`3oool400;F7080oooo1002eQ`30?ooo`80
0]HL0P3oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F
70030?ooo`02eQ`00]HL0080oooo0P02eQ`0103oool00]HL00;F7002eQ`30?ooo`800]HL0P3oool3
00;F70030?ooo`02eQ`00]HL0080oooo0`02eQ`0103oool00]HL00;F7002eQ`40?ooo`800]HL0P3o
ool300;F7080oooo0P02eQ`30?ooo`800]HL0P3oool300;F70D0oooo0P02eQ`30?ooo`8000002P3o
ool00780oooo0P00003=0?ooo`800]HL0`3oool400;F7080oooo1002eQ`30?ooo`800]HL0P3oool2
00;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`00]HL0`3oool200;F70030?oo
o`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL0`3oool300;F7080oooo0P02eQ`0103oool00]HL
00;F7002eQ`20?ooo`800]HL0P3oool200;F70@0oooo0`02eQ`20?ooo`800]HL0P3oool300;F7080
oooo0`02eQ`20?ooo`800]HL1@3oool300;F708000002P3oool00780oooo0P00003?0?ooo`800]HL
0`3oool01002eQ`0oooo00;F7002eQ`20?ooo`0400;F703oool00]HL00;F70<0oooo0P02eQ`20?oo
o`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`20?ooo`800]HL0`3oool200;F70030?ooo`02eQ`0
0]HL0080oooo0P02eQ`20?ooo`800]HL103oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool2
00;F7080oooo0P02eQ`50?ooo`800]HL0P3oool300;F7080oooo0P02eQ`30?ooo`800]HL0P3oool3
00;F70D0oooo0P00000:0?ooo`00LP3oool200000=40oooo0P02eQ`20?ooo`800]HL00@0oooo00;F
7002eQ`0oooo0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL0P3oool200;F70040?ooo`02eQ`0
0]HL0?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL
00<0oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool300;F70040?oo
o`02eQ`00]HL00;F70@0oooo0P02eQ`30?ooo`800]HL0P3oool300;F7080oooo0P02eQ`30?ooo`80
0]HL0`3oool2000000X0oooo001b0?ooo`800000d`3oool200;F7080oooo0P02eQ`0103oool00]HL
00;F703oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002
eQ`0oooo0`02eQ`00`3oool00]HL00;F70030?ooo`800]HL0P3oool200;F7080oooo0P02eQ`00`3o
ool00]HL00;F70040?ooo`800]HL0P3oool300;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`2
0?ooo`800]HL103oool300;F7080oooo0P02eQ`30?ooo`800]HL0P3oool300;F7080oooo0`02eQ`2
000000X0oooo001b0?ooo`800000e@3oool200;F7080oooo0P02eQ`0103oool00]HL00;F703oool2
00;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P3oool2
00;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL0P3oool200;F70040?ooo`02eQ`0
0]HL00;F70<0oooo0`02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL1@3o
ool200;F7080oooo0`02eQ`20?ooo`800]HL0`3oool200;F70<0oooo0P00000:0?ooo`00LP3oool2
00000=L0oooo0P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F
70030?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F
70030?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`40?ooo`800]HL0P3o
ool200;F7080oooo0P02eQ`20?ooo`<00]HL00@0oooo00;F7002eQ`00]HL103oool300;F7080oooo
0P02eQ`20?ooo`<00]HL0P3oool300;F708000002P3oool00780oooo0P00003I0?ooo`0400;F703o
ool0oooo0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F70030?ooo`80
0]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70040?ooo`80
0]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`40?ooo`800]HL0P3oool200;F7080
oooo0P02eQ`30?ooo`800]HL0P3oool200;F70D0oooo0P02eQ`20?ooo`<00]HL0P3oool200;F70<0
oooo0P00000:0?ooo`00LP3oool200000=X0oooo0P02eQ`30?ooo`800]HL00@0oooo00;F7002eQ`0
oooo0P02eQ`00`3oool00]HL00;F70030?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL0080
oooo0P02eQ`00`3oool00]HL00;F70040?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080
oooo0P02eQ`40?ooo`800]HL0P3oool300;F70040?ooo`02eQ`00]HL00;F7080oooo0P02eQ`20?oo
o`800]HL1@3oool200;F70<0oooo0P02eQ`20?ooo`<00]HL0P00000:0?ooo`00LP3oool200000=`0
oooo0P02eQ`30?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F70030?oo
o`800]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70040?oo
o`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL00@0oooo0`02eQ`2
0?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`<00]HL103oool300;F7080oooo0P02eQ`3
0?ooo`8000002P3oool00780oooo0P00003N0?ooo`800]HL0`3oool200;F70040?ooo`02eQ`00]HL
0?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F7080oooo0P02eQ`00`3oool00]HL00;F7002
0?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`20?ooo`800]HL00@0oooo
00;F7002eQ`00]HL103oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool300;F7080oooo0P02
eQ`50?ooo`800]HL0P3oool300;F70030000003oool0oooo00T0oooo001b0?ooo`800000h03oool2
00;F70<0oooo0P02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02
eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70040?ooo`02eQ`00]HL00;F70<0oooo
0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`40?ooo`800]HL0P3oool200;F7080oooo
0`02eQ`20?ooo`800]HL0P3oool200;F70D0oooo0P02eQ`30?ooo`8000002P3oool00780oooo0P00
003R0?ooo`800]HL0`3oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`0
0`3oool200;F7080oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F70<0oooo
0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`40?ooo`800]HL0P3oool300;F7080oooo
0P02eQ`20?ooo`800]HL0P3oool300;F70@0oooo0`02eQ`2000000X0oooo001b0?ooo`<00000h`3o
ool200;F70<0oooo0P02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL00<0oooo
0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`30?ooo`800]HL
0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL103oool300;F7080oooo0P02eQ`20?ooo`800]HL
0P3oool300;F7080oooo0P02eQ`50?ooo`8000002P3oool00780oooo0P00003V0?ooo`800]HL0`3o
ool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`00`3oool200;F7080oooo
0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F70<0oooo0`02eQ`00`3oool00]HL
00;F70020?ooo`800]HL0P3oool200;F70D0oooo0P02eQ`20?ooo`800]HL0P3oool200;F70<0oooo
0P02eQ`20?ooo`800]HL0`3oool2000000X0oooo001b0?ooo`800000j03oool200;F70<0oooo0P02
eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL00<0oooo0P02eQ`20?ooo`800]HL
00D0oooo00;F7002eQ`00]HL0?ooo`0200;F7080oooo0P02eQ`40?ooo`800]HL00D0oooo00;F7002
eQ`00]HL0?ooo`0300;F70040?ooo`02eQ`00]HL00;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool3
00;F7080oooo0P02eQ`20?ooo`<00]HL0P00000:0?ooo`00LP3oool200000>X0oooo0P02eQ`30?oo
o`0300;F703oool0oooo00800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`30?ooo`800]HL0P3oool2
00;F7080oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL103oool200;F7080oooo0P02eQ`2
0?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`20?ooo`<00]HL0P3oool200;F7080oooo0`02eQ`2
0?ooo`8000002P3oool00780oooo0P00003/0?ooo`800]HL0P3oool200;F7080oooo00<00]HL0?oo
o`3oool00P02eQ`00`3oool00]HL00;F70030?ooo`800]HL0P3oool200;F7080oooo0P02eQ`00`3o
ool00]HL00;F70020?ooo`800]HL103oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool200;F
70@0oooo0P02eQ`30?ooo`800]HL0P3oool200;F70<0oooo0P02eQ`2000000X0oooo001b0?ooo`80
0000kP3oool01002eQ`0oooo0?ooo`3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3o
ool00]HL00;F70030?ooo`<00]HL00<0oooo00;F7002eQ`00P3oool200;F70050?ooo`02eQ`00]HL
00;F703oool00P02eQ`40?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL103oool3
00;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool2000000X0oooo001b0?ooo`800000k`3oool200;F
70<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F
70030?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F
7080oooo0P02eQ`20?ooo`800]HL0P3oool200;F70D0oooo0P02eQ`20?ooo`800]HL0`3oool200;F
70030000003oool0oooo00T0oooo001b0?ooo`800000l@3oool200;F70<0oooo0P02eQ`00`3oool0
0]HL00;F70020?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F70030?ooo`02eQ`00]HL0080
oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`20?ooo`<0
0]HL00@0oooo00;F7002eQ`00]HL103oool200;F7080oooo0`02eQ`20?ooo`8000002P3oool00780
oooo0P00003c0?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool0
0]HL00;F70040?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`0103oool0
0]HL00;F7002eQ`30?ooo`<00]HL00<0oooo00;F7002eQ`00`3oool200;F7080oooo0P02eQ`40?oo
o`800]HL0`3oool200;F708000002P3oool00780oooo0P00003e0?ooo`800]HL0`3oool200;F7003
0?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL00;F70040?ooo`800]HL00<0oooo00;F7002
eQ`00P3oool200;F7080oooo0P02eQ`20?ooo`800]HL103oool200;F70040?ooo`02eQ`00]HL00;F
7080oooo0P02eQ`20?ooo`800]HL103oool300;F7080oooo0P00000:0?ooo`00LP3oool200000?L0
oooo0P02eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL00@0
oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F7080oooo0P02eQ`40?ooo`80
0]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL1@3oool200;F708000002P3oool00780oooo
0P00003i0?ooo`800]HL0`3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL
00;F70040?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`20?ooo`800]HL
103oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool200;F70D0oooo0P00000:0?ooo`00LP3o
ool200000?/0oooo0P02eQ`30?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02
eQ`00]HL00@0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F7080oooo0P02
eQ`40?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`<00]HL0P3oool2000000X0oooo001b
0?ooo`800000o@3oool200;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo
00;F7002eQ`0103oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL0P3oool2
00;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool300;F7080oooo0P02eQ`2000000X0oooo001b0?oo
o`800000o`3oool200;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F
7002eQ`0103oool200;F70050?ooo`02eQ`00]HL00;F703oool00P02eQ`20?ooo`800]HL0P3oool2
00;F70@0oooo0P02eQ`20?ooo`800]HL0`3oool200;F7080oooo0P00000:0?ooo`00LP3oool20000
0?l0oooo0P3oool200;F70<0oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F
7002eQ`0103oool200;F7080oooo0P02eQ`00`3oool00]HL00;F70020?ooo`800]HL0P3oool200;F
70@0oooo0P02eQ`20?ooo`<00]HL0P3oool200;F708000002P3oool00780oooo0`00003o0?ooo`<0
oooo00<00]HL0?ooo`3oool00P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool0
0]HL00;F70040?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`80
0]HL103oool300;F7080oooo0P02eQ`20?ooo`8000002P3oool00780oooo0P00003o0?ooo`D0oooo
0P02eQ`40?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL00@0oooo
0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`50?ooo`800]HL
0P3oool200;F70030000003oool0oooo00T0oooo001b0?ooo`800000o`3oool70?ooo`800]HL103o
ool00`02eQ`0oooo0?ooo`0200;F7080oooo0P02eQ`00`3oool00]HL00;F70040?ooo`800]HL0P3o
ool200;F70030?ooo`02eQ`00]HL0080oooo0`02eQ`0103oool00]HL00;F7002eQ`40?ooo`800]HL
0P3oool2000000X0oooo001b0?ooo`800000o`3oool90?ooo`800]HL0`3oool200;F7080oooo0P02
eQ`20?ooo`800]HL00<0oooo00;F7002eQ`0103oool200;F7080oooo0P02eQ`0103oool00]HL00;F
7002eQ`20?ooo`800]HL0P3oool200;F70@0oooo0P02eQ`2000000X0oooo001b0?ooo`800000o`3o
ool;0?ooo`800]HL0`3oool200;F7080oooo0P02eQ`20?ooo`0300;F703oool0oooo00800]HL103o
ool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool200;F7080oooo0P02eQ`40?ooo`8000002P3o
ool00780oooo0P00003o0?ooo`d0oooo0P02eQ`30?ooo`800]HL0P3oool200;F70030?ooo`02eQ`0
0]HL0080oooo0P02eQ`40?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL0P3oool2
00;F7080oooo0P00000:0?ooo`00LP3oool200000?l0oooo3`3oool200;F70<0oooo0P02eQ`20?oo
o`800]HL00<0oooo00;F7002eQ`00P3oool200;F70@0oooo0P02eQ`20?ooo`800]HL0P3oool200;F
7080oooo0P02eQ`20?ooo`800]HL0P00000:0?ooo`00LP3oool200000?l0oooo4@3oool200;F70<0
oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70@0oooo0P02eQ`20?ooo`80
0]HL0P3oool200;F7080oooo0P02eQ`20?ooo`8000002P3oool00780oooo0P00003o0?oooa<0oooo
0P02eQ`30?ooo`800]HL0P3oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`40?ooo`800]HL
0P3oool200;F7080oooo0P02eQ`20?ooo`800]HL0P00000:0?ooo`00LP3oool200000?l0oooo5@3o
ool200;F70<0oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70@0oooo0P02
eQ`20?ooo`800]HL0P3oool200;F7080oooo0P00000:0?ooo`00LP3oool200000?l0oooo5`3oool2
00;F70<0oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F70@0oooo0P02eQ`2
0?ooo`800]HL0P3oool200;F70030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolI0?oo
o`0300;F703oool0oooo0080oooo0P02eQ`20?ooo`0300;F703oool0oooo00800]HL0P3oool200;F
70@0oooo0P02eQ`20?ooo`800]HL0P3oool2000000X0oooo001b0?ooo`800000o`3ooolJ0?ooo`80
0]HL103oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL103oool200;F7080
oooo0P02eQ`2000000X0oooo001S0?ooo`@000000P3oool2000000L0oooo0P00003o0?oooa`0oooo
0P02eQ`40?ooo`800]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`40?ooo`800]HL
0P3oool2000000X0oooo001S0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000
oooo0?ooo`040?ooo`800000o`3ooolN0?ooo`800]HL103oool200;F70030?ooo`02eQ`00]HL0080
oooo0P02eQ`20?ooo`800]HL103oool200;F708000002P3oool006@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo0P00003o0?ooob00oooo0P02eQ`40?ooo`80
0]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P02eQ`40?ooo`8000002P3oool006D0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`@00000o`3ooolP0?ooo`80
0]HL103oool200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`20?ooo`800]HL0P3oool2000000X0
oooo001V0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0103oool200000?l0oooo
903oool200;F70@0oooo00<00]HL0?ooo`3oool00P02eQ`20?ooo`800]HL0P3oool200;F70800000
2P3oool006<0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00@0
oooo0P00003o0?ooobH0oooo0P02eQ`30?ooo`800]HL0P3oool200;F7080oooo0P02eQ`20?ooo`80
00002P3oool006@0oooo0P0000030?ooo`8000001`3oool200000?l0oooo:03oool200;F70<0oooo
0P02eQ`20?ooo`800]HL0P3oool200;F708000002P3oool00780oooo0P00003o0?ooobX0oooo0P02
eQ`30?ooo`800]HL0P3oool200;F7080oooo0P00000:0?ooo`00LP3oool200000?l0oooo;03oool2
00;F70<0oooo0P02eQ`20?ooo`800]HL00<000000?ooo`3oool02@3oool00780oooo0P00003o0?oo
obh0oooo00<00]HL0?ooo`3oool00P3oool200;F7080oooo0P00000:0?ooo`00LP3oool200000?l0
oooo;`3oool200;F70@0oooo0P02eQ`2000000X0oooo001b0?ooo`800000o`3ooola0?ooo`800]HL
103oool2000000X0oooo001b0?ooo`800000o`3ooolc0?ooo`800]HL0P3oool2000000X0oooo001b
0?ooo`800000o`3ooole0?ooo`800]HL0P00000:0?ooo`00LP3oool200000?l0oooo=`3oool20000
00X0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000
o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003o
ool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?oo
o`<00000o`3ooolf0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`03
0000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo
001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg
0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo
00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000
o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003o
ool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?oo
o`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`03
0000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo
001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg
0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo
00T0oooo001b0?ooo`<00000o`3ooolf0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000
o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003o
ool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?oo
o`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`03
0000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo
001b0?ooo`800000o`3ooolg0?ooo`030000003oool0oooo00T0oooo001b0?ooo`800000o`3ooolg
0?ooo`030000003oool0oooo00T0oooo001b0?ooo`030000003oool0oooo0?l0oooo@P3oool00780
oooo00<000000?ooo`3oool0o`3ooom20?ooo`00LP3oool00`000000oooo0?ooo`3o0?oood80oooo
001b0?ooo`030000003oool0oooo0?l0oooo@P3oool00780oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`00LP3oool00`000000oooo0?ooo`3o0?oood80oooo001b0?ooo`030000003oool0oooo0?l0
oooo@P3oool00780oooo0`00003o0?oood80oooo001b0?ooo`030000003oool0oooo0?l0oooo@P3o
ool00780oooo00<000000?ooo`3oool0o`3ooom20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 437.062}, {437.062, 0}} -> {-11.0002, -28.0953, \
0.0960972, 0.124446}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Angle Dependency", "ExampleSubsection"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[
\tReadRays[tracedsystem,{ArcCos[RayTilt.{1,0,0}]/Degree,Intensity}, \
ComponentNumber->3]
];\
\>", "Input",
  CellLabel->"In[10]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.84688 0.11019 0.0147151 0.00605889 [
[.23843 .00222 -6 -9 ]
[.23843 .00222 6 0 ]
[.45881 .00222 -6 -9 ]
[.45881 .00222 6 0 ]
[.67919 .00222 -6 -9 ]
[.67919 .00222 6 0 ]
[.89957 .00222 -6 -9 ]
[.89957 .00222 6 0 ]
[.00555 .13589 -12 -4.5 ]
[.00555 .13589 0 4.5 ]
[.00555 .25707 -12 -4.5 ]
[.00555 .25707 0 4.5 ]
[.00555 .37825 -12 -4.5 ]
[.00555 .37825 0 4.5 ]
[.00555 .49943 -12 -4.5 ]
[.00555 .49943 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23843 .01472 m
.23843 .02097 L
s
[(28)] .23843 .00222 0 1 Mshowa
.45881 .01472 m
.45881 .02097 L
s
[(30)] .45881 .00222 0 1 Mshowa
.67919 .01472 m
.67919 .02097 L
s
[(32)] .67919 .00222 0 1 Mshowa
.89957 .01472 m
.89957 .02097 L
s
[(34)] .89957 .00222 0 1 Mshowa
.125 Mabswid
.07314 .01472 m
.07314 .01847 L
s
.12824 .01472 m
.12824 .01847 L
s
.18333 .01472 m
.18333 .01847 L
s
.29352 .01472 m
.29352 .01847 L
s
.34862 .01472 m
.34862 .01847 L
s
.40371 .01472 m
.40371 .01847 L
s
.5139 .01472 m
.5139 .01847 L
s
.569 .01472 m
.569 .01847 L
s
.62409 .01472 m
.62409 .01847 L
s
.73428 .01472 m
.73428 .01847 L
s
.78938 .01472 m
.78938 .01847 L
s
.84447 .01472 m
.84447 .01847 L
s
.95466 .01472 m
.95466 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.01805 .13589 m
.0243 .13589 L
s
[(20)] .00555 .13589 1 0 Mshowa
.01805 .25707 m
.0243 .25707 L
s
[(40)] .00555 .25707 1 0 Mshowa
.01805 .37825 m
.0243 .37825 L
s
[(60)] .00555 .37825 1 0 Mshowa
.01805 .49943 m
.0243 .49943 L
s
[(80)] .00555 .49943 1 0 Mshowa
.125 Mabswid
.01805 .04501 m
.0218 .04501 L
s
.01805 .0753 m
.0218 .0753 L
s
.01805 .1056 m
.0218 .1056 L
s
.01805 .16619 m
.0218 .16619 L
s
.01805 .19648 m
.0218 .19648 L
s
.01805 .22678 m
.0218 .22678 L
s
.01805 .28736 m
.0218 .28736 L
s
.01805 .31766 m
.0218 .31766 L
s
.01805 .34795 m
.0218 .34795 L
s
.01805 .40854 m
.0218 .40854 L
s
.01805 .43884 m
.0218 .43884 L
s
.01805 .46913 m
.0218 .46913 L
s
.01805 .52972 m
.0218 .52972 L
s
.01805 .56001 m
.0218 .56001 L
s
.01805 .59031 m
.0218 .59031 L
s
.25 Mabswid
.01805 0 m
.01805 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.97619 .02928 Mdot
.93751 .03921 Mdot
.89929 .0343 Mdot
.86155 .01964 Mdot
.82426 .01604 Mdot
.78742 .03735 Mdot
.75103 .0709 Mdot
.71508 .08524 Mdot
.67956 .06209 Mdot
.64446 .02322 Mdot
.60979 .02354 Mdot
.57553 .11069 Mdot
.54168 .28222 Mdot
.50823 .47586 Mdot
.47518 .60317 Mdot
.44253 .60332 Mdot
.41026 .47933 Mdot
.37837 .29304 Mdot
.34687 .12558 Mdot
.31573 .03174 Mdot
.28496 .01711 Mdot
.25455 .04753 Mdot
.22451 .0787 Mdot
.19481 .08372 Mdot
.16546 .06288 Mdot
.13646 .03434 Mdot
.1078 .01676 Mdot
.07947 .01674 Mdot
.05148 .0277 Mdot
.02381 .03771 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{556.75, 344.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008/0001F2000`400?l00000o`00003oo`3ooooo
0?ooobh0oooo00260?ooo`D000000P3oool3000006l0oooo0`0000040?ooo`800000KP3oool30000
0080oooo1@00001^0?ooo`<00000103oool3000003@0oooo00270?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`1[0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`00001/0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00001]0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0c
0?ooo`00R03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0K`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo06h0oooo00D000000?ooo`3oool0oooo
0000001c0?ooo`030000003oool0000000@00000=03oool008T0oooo00@000000?ooo`3oool0oooo
0`00001`0?ooo`8000000`3oool010000000oooo0?ooo`00001^0?ooo`8000001@3oool00`000000
oooo0?ooo`1^0?ooo`8000000P3oool010000000oooo0?ooo`00000e0?ooo`00QP3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`1_0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0KP3oool00`000000oooo000000030?ooo`030000003o
ool0oooo06l0oooo00H000000?ooo`3oool000000?ooo`00000e0?ooo`00QP3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`1[0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`00001/0?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo06/0oooo00D000000?ooo`3oool0oooo000000030?oo
o`800000=@3oool008L0oooo0`0000030?ooo`<00000K`3oool3000000@0oooo0P00001^0?ooo`<0
00000`3oool3000006l0oooo0`0000050?ooo`030000003oool0oooo03<0oooo000D0?ooo`030000
003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo
0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3o
oolG0?ooo`00503oool00`000000oooo0?ooo`3o0?oook<0oooo0P00001Q0?ooo`002`3ooooo0000
0?l000008@0000020?ooo`00503oool00`000000oooo0?ooo`0K0?ooo`030000003oool0000000<0
00002`3oool4000000T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01D0oooo100000020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0oooo100000090?ooo`03
0000003oool0oooo00D0oooo0P00000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0603oool001@0oooo00<000000?ooo`3oool06`3oool00`000000oooo00000003000000/0oooo
100000090?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0E0?ooo`@000000P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`8000002P3oool00`000000oooo
0?ooo`040?ooo`@000004`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01P0oooo
000D0?ooo`030000003oool0oooo01h0oooo0P00000=0?ooo`800000AP3oool00`000000oooo0?oo
o`0F0?ooo`800000G@3oool00`000000oooo0?ooo`1Q0?ooo`8000004@3oool00`000000oooo0?oo
o`1N0?ooo`@000004`3oool00`000000oooo0?ooo`0f0?ooo`00503oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0CP3oool200000100oooo1000000@
0?ooo`030000003oool0oooo05l0oooo0P00000D0?ooo`030000003oool0oooo03H0oooo000D0?oo
o`030000003oool0oooo0?l0oooo?P3oool4000000l0oooo100000310?ooo`00503oool00`000000
oooo0?ooo`0?0?ooo`800000o`3oool]0?ooo`@00000403oool200000<80oooo000D0?ooo`030000
003oool0oooo00h0oooo1000003o0?ooobd0oooo0P0000350?ooo`8000003P3oool001@0oooo00<0
00000?ooo`3oool03P3oool4000008`0oooo0P00003o0?ooofD0oooo1000000=0?ooo`00503oool0
0`000000oooo0?ooo`0?0?ooo`800000;03oool2000005h0oooo1000003o0?oooc/0oooo0P00000W
0?ooo`@000003@3oool001@0oooo00<000000?ooo`3oool0?03oool4000005d0oooo1000003o0?oo
ocX0oooo1000000W0?ooo`8000003P3oool001@0oooo00<000000?ooo`3oool00P00000j0?ooo`@0
0000GP3oool200000?h0oooo0P00000j0?ooo`@00000=`3oool001@0oooo00<000000?ooo`000000
0`00000j0?ooo`800000o`3ooomO0?ooo`@00000>P3oool2000001<0oooo0P00000S0?ooo`00503o
ool00`000000oooo0000000300000?l0ooooV`3oool4000004h0oooo1000000R0?ooo`00503oool0
0`000000oooo0?ooo`0200000?l0ooooW@3oool2000004l0oooo1000000R0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooo40oooo0P00000S0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo0`00001m0?ooo`800000o`3ooonG0?ooo`00503oool00`000000oooo0?oo
o`1l0?ooo`@00000o`3ooonF0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`@00000o`3ooonF
0?ooo`00503oool00`000000oooo0?ooo`1m0?ooo`800000o`3ooonG0?ooo`00503oool00`000000
oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo
000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooofD0oooo0P00002_0?ooo`00503oool00`000000oooo0?ooo`1=0?ooo`800000o`3ooolE0?oo
o`@00000[P3oool001@0oooo00<000000?ooo`3oool0C03oool400000?l0oooo503oool400000:h0
oooo000D0?ooo`030000003oool0oooo04`0oooo1000003o0?oooaD0oooo0P00002_0?ooo`00503o
ool00`000000oooo0?ooo`1=0?ooo`800000o`3oooo70?ooo`00503oool00`000000oooo0?ooo`3o
0?oooh/0oooo0P0000290?ooo`00503oool00`000000oooo0?ooo`3o0?ooohX0oooo100000280?oo
o`00503oool00`000000oooo0?ooo`3o0?ooohX0oooo100000280?ooo`00503oool00`000000oooo
0?ooo`3o0?oooh/0oooo0P0000290?ooo`00503oool3000006d0oooo0P00003o0?ooojL0oooo000D
0?ooo`030000003oool0oooo06`0oooo1000003o0?ooojH0oooo000D0?ooo`030000003oool0oooo
06`0oooo1000003o0?ooojH0oooo000D0?ooo`030000003oool0oooo05d0oooo0P00000>0?ooo`80
0000o`3ooonW0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`@00000o`3ooolH0?ooo`800000
W03oool001@0oooo00<000000?ooo`3oool0G03oool400000?l0oooo5`3oool4000009/0oooo000D
0?ooo`030000003oool0oooo05d0oooo0P00003o0?oooaP0oooo1000002K0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooogP0oooo0P00002L0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`<00000o`3ooooo0?oooaL0oooo000D0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooob`0
oooo0P00003X0?ooo`00503oool00`000000oooo0?ooo`3o0?ooob/0oooo1000003W0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooob/0oooo1000003W0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooob`0oooo0P00003X0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0[`3oool200000?l0ooooI@3oool001@0oooo00<000000?ooo`3oool0[P3oool40000
0?l0ooooI03oool001@0oooo00<000000?ooo`3oool0[P3oool400000?l0ooooI03oool001@0oooo
00<000000?ooo`3oool0[`3oool200000?l0ooooI@3oool00080oooo1@0000030?ooo`800000203o
ool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool000<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00103o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`050?ooo`D00000o`3ooooo0?oooaD0oooo00020?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00
0P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool000<0oooo0`0000040?ooo`800000203oool00`000000
oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo
000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0
oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo0`00003o
0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0
oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`<00000o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D
0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`<00000
o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D
0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000
003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo
0?l0ooooo`3ooolG0?ooo`00103oool3000000<0oooo0P0000080?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool00080oooo1@0000020?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo00020?ooo`040000
003oool0oooo000000<0oooo00@000000?ooo`3oool000001`3oool500000?l0ooooo`3ooolE0?oo
o`000`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000L0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaL0oooo00040?ooo`8000000`3oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`80
0000203oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D
0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oaX0oooo0P00003j0?ooo`00503oool00`000000oooo0?ooo`3o0?oooaT0oooo1000003i0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooaT0oooo1000003i0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooaX0oooo0P00003j0?ooo`00503oool300000?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0`03oool200000?l0
ooooE03oool001@0oooo00<000000?ooo`3oool0_`3oool400000?l0ooooD`3oool001@0oooo00<0
00000?ooo`3oool0_`3oool400000?l0ooooD`3oool001@0oooo00<000000?ooo`3oool0`03oool2
00000?l0ooooE03oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0
oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`00503oool300000?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0
oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool300000?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D
0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ool0oooo5`3oool000<0oooo0`0000040?ooo`800000203oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool00080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo00020?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000070?ooo`D00000o`3ooooo0?oooaD0oooo00020?oo
o`@000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo00030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool000@0oooo0P0000040?oo
o`800000203oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000
oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo
000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo0`00003o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000
oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo
000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0
oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo0`00003o
0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0
oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`<00000o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`P0oooo0P00003o0?ooo`d0oooo000D
0?ooo`030000003oool0oooo0?l0oooo1`3oool400000?l0oooo303oool001@0oooo00<000000?oo
o`3oool0dP3oool200000380oooo1000003o0?ooo``0oooo000D0?ooo`030000003oool0oooo0=40
oooo1000000b0?ooo`800000o`3oool=0?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`@00000
o`3ooom10?ooo`00503oool00`000000oooo0?ooo`3B0?ooo`800000o`3ooom20?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D
0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`000`3oool3000000@0oooo0P0000080?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000L0oooo1@00
003o0?ooool0oooo5@3oool000<0oooo0`0000030?ooo`040000003oool0oooo000000L0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo00020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`3o0?ooool0oooo5`3oool000<0oooo0`0000040?ooo`800000203oool00`000000oooo
0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D
0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000
003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo
0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3o
oolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo0`00003o0?oo
ool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000
003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo
0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3o
oolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00
503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo0`00003o0?ooool0oooo5`3oool001@0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3o
oolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00
503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0
oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?oo
o`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo0`00003o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0
oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?oo
o`3S0?ooo`800000403oool200000?l0oooo7`3oool001@0oooo00<000000?ooo`3oool0hP3oool4
000000h0oooo1000003o0?oooah0oooo000D0?ooo`030000003oool0oooo0>80oooo1000000>0?oo
o`@00000o`3ooolN0?ooo`00503oool00`000000oooo0?ooo`3S0?ooo`800000403oool200000?l0
oooo7`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool00001\
\>"],
  ImageRangeCache->{{{0, 555.75}, {343.125, 0}} -> {25.6507, -4.80052, \
0.0167263, 0.304193}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ListPlot[
\tReadRays[tracedsystem,{ArcCos[RayTilt.{1,0,0}]/Degree,Intensity}, \
ComponentNumber->2]
];\
\>", "Input",
  CellLabel->"In[11]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.80393 0.110816 0.0147151 0.00589897 [
[.29891 .00222 -6 -9 ]
[.29891 .00222 6 0 ]
[.52054 .00222 -6 -9 ]
[.52054 .00222 6 0 ]
[.74217 .00222 -6 -9 ]
[.74217 .00222 6 0 ]
[.96381 .00222 -6 -9 ]
[.96381 .00222 6 0 ]
[.06478 .13269 -12 -4.5 ]
[.06478 .13269 0 4.5 ]
[.06478 .25067 -12 -4.5 ]
[.06478 .25067 0 4.5 ]
[.06478 .36865 -12 -4.5 ]
[.06478 .36865 0 4.5 ]
[.06478 .48663 -12 -4.5 ]
[.06478 .48663 0 4.5 ]
[.06478 .60461 -18 -4.5 ]
[.06478 .60461 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.29891 .01472 m
.29891 .02097 L
s
[(28)] .29891 .00222 0 1 Mshowa
.52054 .01472 m
.52054 .02097 L
s
[(30)] .52054 .00222 0 1 Mshowa
.74217 .01472 m
.74217 .02097 L
s
[(32)] .74217 .00222 0 1 Mshowa
.96381 .01472 m
.96381 .02097 L
s
[(34)] .96381 .00222 0 1 Mshowa
.125 Mabswid
.13269 .01472 m
.13269 .01847 L
s
.1881 .01472 m
.1881 .01847 L
s
.2435 .01472 m
.2435 .01847 L
s
.35432 .01472 m
.35432 .01847 L
s
.40973 .01472 m
.40973 .01847 L
s
.46513 .01472 m
.46513 .01847 L
s
.57595 .01472 m
.57595 .01847 L
s
.63136 .01472 m
.63136 .01847 L
s
.68677 .01472 m
.68677 .01847 L
s
.79758 .01472 m
.79758 .01847 L
s
.85299 .01472 m
.85299 .01847 L
s
.9084 .01472 m
.9084 .01847 L
s
.02187 .01472 m
.02187 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.07728 .13269 m
.08353 .13269 L
s
[(20)] .06478 .13269 1 0 Mshowa
.07728 .25067 m
.08353 .25067 L
s
[(40)] .06478 .25067 1 0 Mshowa
.07728 .36865 m
.08353 .36865 L
s
[(60)] .06478 .36865 1 0 Mshowa
.07728 .48663 m
.08353 .48663 L
s
[(80)] .06478 .48663 1 0 Mshowa
.07728 .60461 m
.08353 .60461 L
s
[(100)] .06478 .60461 1 0 Mshowa
.125 Mabswid
.07728 .04421 m
.08103 .04421 L
s
.07728 .0737 m
.08103 .0737 L
s
.07728 .1032 m
.08103 .1032 L
s
.07728 .16219 m
.08103 .16219 L
s
.07728 .19168 m
.08103 .19168 L
s
.07728 .22118 m
.08103 .22118 L
s
.07728 .28017 m
.08103 .28017 L
s
.07728 .30966 m
.08103 .30966 L
s
.07728 .33916 m
.08103 .33916 L
s
.07728 .39815 m
.08103 .39815 L
s
.07728 .42764 m
.08103 .42764 L
s
.07728 .45714 m
.08103 .45714 L
s
.07728 .51613 m
.08103 .51613 L
s
.07728 .54562 m
.08103 .54562 L
s
.07728 .57512 m
.08103 .57512 L
s
.25 Mabswid
.07728 0 m
.07728 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .59044 Mdot
.05938 .58077 Mdot
.09475 .58555 Mdot
.12993 .59982 Mdot
.16492 .60332 Mdot
.19972 .58258 Mdot
.23432 .54991 Mdot
.26872 .53595 Mdot
.30294 .55849 Mdot
.33695 .59633 Mdot
.37077 .59602 Mdot
.4044 .51117 Mdot
.43783 .34416 Mdot
.47106 .15563 Mdot
.5041 .03169 Mdot
.53694 .03154 Mdot
.56958 .15226 Mdot
.60203 .33363 Mdot
.63429 .49667 Mdot
.66634 .58804 Mdot
.6982 .60228 Mdot
.72987 .57266 Mdot
.76134 .54232 Mdot
.79261 .53743 Mdot
.8237 .55772 Mdot
.85458 .58551 Mdot
.88527 .60263 Mdot
.91577 .60264 Mdot
.94608 .59197 Mdot
.97619 .58223 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[11]:=",
  ImageSize->{597.562, 369.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009E0001LB000`400?l00000o`00003oo`3ooooo
0?oooeL0oooo002^0?ooo`D000000P3oool3000007T0oooo0`0000040?ooo`800000N03oool30000
0080oooo1@00001g0?ooo`<00000103oool3000001P0oooo002_0?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`1e0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`00001f0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00001f0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0G
0?ooo`00/03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0N@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo07P0oooo00D000000?ooo`3oool0oooo
0000001l0?ooo`030000003oool0000000@00000603oool00;40oooo00@000000?ooo`3oool0oooo
0`00001j0?ooo`8000000`3oool010000000oooo0?ooo`00001h0?ooo`8000001@3oool00`000000
oooo0?ooo`1g0?ooo`8000000P3oool010000000oooo0?ooo`00000I0?ooo`00[P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`1i0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0N03oool00`000000oooo000000030?ooo`030000003o
ool0oooo07P0oooo00H000000?ooo`3oool000000?ooo`00000I0?ooo`00[P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`1e0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`00001f0?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo07@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`8000006@3oool00:l0oooo0`0000030?ooo`<00000N@3oool3000000@0oooo0P00001h0?ooo`<0
00000`3oool3000007P0oooo0`0000050?ooo`030000003oool0oooo01L0oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool000H0ooooo`00003o0000
04/000001P3oool001<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01X0oooo000C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0J0?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool06P3oool003<0oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`0J0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0
oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0oooo
o`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<00000
0?ooo`3oool0m@3oool200000180oooo0P00003o0?oooaD0oooo000c0?ooo`030000003oool0oooo
0?@0oooo1000000@0?ooo`@00000o`3ooolD0?ooo`00<`3oool00`000000oooo0?ooo`3d0?ooo`@0
0000403oool400000?l0oooo503oool003<0oooo00<000000?ooo`3oool0m@3oool200000180oooo
0P00003o0?oooaD0oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0oooo8@3oool003<0oooo0`00003o0?ooool0oooo8@3oool003<0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?oo
o`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`<00000o`3ooooo0?oo
ob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00
<`3oool300000?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00
<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3o
oooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`00
0000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40
oooo000P0?ooo`D000000`3oool2000000T0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo
000Q0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`3o0?ooool0oooo8@3oool00280oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000080?ooo`D00000o`3ooooo0?oooal0oooo000S0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00
803oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`3o0?ooool0oooo8@3oool00200oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000Q0?oo
o`<00000103oool2000000T0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo
8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0
oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0
oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0oooo
7@3oool200000?l0oooo0P3oool003<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`@00000o`3o
ool10?ooo`00<`3oool00`000000oooo0?ooo`3R0?ooo`800000=`3oool400000?l0oooo0@3oool0
03<0oooo00<000000?ooo`3oool0h@3oool4000003L0oooo0P00003o0?ooo`80oooo000c0?ooo`03
0000003oool0oooo0>40oooo1000003o0?oooc/0oooo000c0?ooo`030000003oool0oooo0>80oooo
0P00003o0?oooc`0oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool3
00000?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0
oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0oooo
o`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?oo
o`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo8@3oool003<0oooo0`00003o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`<00000o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00
<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool00280oooo0`0000030?ooo`8000002@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool002<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000P
0?ooo`D000000P3oool010000000oooo0?ooo`0000080?ooo`D00000o`3ooooo0?oooal0oooo000P
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`3o0?ooool0oooo8@3oool00240oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`008P3oool2000000<0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool002<0oooo00<0
00000?ooo`3oool00P3oool2000000T0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooob40oooo000c0?ooo`<00000o`3ooooo0?ooob40oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00
<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3o
oooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`00
0000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40
oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?oo
o`3o0?ooool0oooo8@3oool003<0oooo0`00003o0?ooool0oooo8@3oool003<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00
<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3o
oooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`00
0000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40
oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?oo
o`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?oo
o`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oooc00
oooo0P00003^0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooobl0oooo1000003]0?ooo`00<`3o
ool00`000000oooo0?ooo`3o0?ooobl0oooo1000003]0?ooo`00<`3oool00`000000oooo0?ooo`3o
0?oooc00oooo0P00003^0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0
oooo0`00003o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo
000c0?ooo`030000003oool0oooo0<l0oooo0P00003o0?ooodl0oooo000c0?ooo`030000003oool0
oooo0<h0oooo1000003o0?ooodh0oooo000c0?ooo`030000003oool0oooo0<h0oooo1000003o0?oo
odh0oooo000c0?ooo`030000003oool0oooo0<l0oooo0P00003o0?ooodl0oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool00240oooo0`0000040?oo
o`8000002@3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool00200oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooob40oooo000P0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00803oool4000000<0oooo00@00000
0?ooo`3oool00000203oool500000?l0ooooo`3ooolO0?ooo`00803oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000Q
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`3o0?ooool0oooo8@3oool00280oooo0P0000040?ooo`8000002@3oool00`000000oooo0?ooo`3o
0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo
8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0
oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0
oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0oooo
o`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?oo
o`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob40oooo000c0?ooo`<00000o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0
oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0
oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0oooo
o`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?oo
o`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool300000?l0ooooo`3ooolQ0?oo
o`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`<00000o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00
8@3oool3000000@0oooo0P0000090?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00803o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`3o0?ooool0oooo8@3oool00200oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000Q0?ooo`<0
00000`3oool010000000oooo0?ooo`0000080?ooo`D00000o`3ooooo0?oooal0oooo000P0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo0?l0ooooo`3ooolQ0?ooo`00803oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool00240oooo0`000004
0?ooo`8000002@3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?oo
o`3oool0o`3ooom20?ooo`800000g03oool003<0oooo00<000000?ooo`3oool0o`3ooom10?ooo`@0
0000f`3oool003<0oooo00<000000?ooo`3oool0o`3ooom10?ooo`@00000f`3oool003<0oooo00<0
00000?ooo`3oool0o`3ooom20?ooo`800000g03oool003<0oooo00<000000?ooo`3oool0o`3ooooo
0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000
oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo
000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`2k
0?ooo`800000o`3ooomS0?ooo`00<`3oool00`000000oooo0?ooo`2j0?ooo`@00000o`3ooomR0?oo
o`00<`3oool00`000000oooo0?ooo`2j0?ooo`@00000o`3ooomR0?ooo`00<`3oool00`000000oooo
0?ooo`2k0?ooo`800000o`3ooomS0?ooo`00<`3oool300000?l0ooooo`3ooolQ0?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob40oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`1/0?ooo`800000o`3o
oonb0?ooo`00<`3oool00`000000oooo0?ooo`1[0?ooo`@00000o`3oool`0?ooo`800000O`3oool0
03<0oooo00<000000?ooo`3oool0J`3oool400000?l0oooo;`3oool4000007h0oooo000c0?ooo`03
0000003oool0oooo06`0oooo0P00003o0?oooc00oooo1000001n0?ooo`00<`3oool00`000000oooo
0?ooo`3o0?oooh`0oooo0P00000A0?ooo`800000O`3oool003<0oooo00<000000?ooo`3oool0o`3o
oon;0?ooo`@00000T@3oool003<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`@00000T@3oool0
03<0oooo0`00003o0?oooh`0oooo0P00002B0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0
oooo8@3oool003<0oooo00<000000?ooo`3oool0F03oool200000?l0ooooaP3oool003<0oooo00<0
00000?ooo`3oool0E`3oool400000?l0ooooa@3oool003<0oooo00<000000?ooo`3oool0E`3oool4
00000?l0ooooa@3oool003<0oooo00<000000?ooo`3oool0F03oool200000?l0ooooaP3oool003<0
oooo00<000000?ooo`3oool0o`3ooona0?ooo`800000K@3oool003<0oooo00<000000?ooo`3oool0
P03oool200000?l0oooo;P3oool4000006`0oooo000c0?ooo`030000003oool0oooo07l0oooo1000
003o0?ooobd0oooo1000001/0?ooo`00<`3oool00`000000oooo0?ooo`1o0?ooo`@00000o`3oool^
0?ooo`800000K@3oool003<0oooo00<000000?ooo`3oool0P03oool200000?l0ooooWP3oool003<0
oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0oooo
o`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool003<0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooob40oooo000c0?ooo`030000003oool0oooo0?l0ooooNP3oool20000
0:@0oooo000c0?ooo`030000003oool0oooo0?l0ooooN@3oool400000:<0oooo000c0?ooo`<00000
o`3ooomi0?ooo`@00000X`3oool003<0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`800000Y03o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000X0?ooo`8000002@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo2`3oool2000001@0oooo000W0?ooo`@00000203oool00`000000
oooo0?ooo`140?ooo`800000o`3oooo30?ooo`@000004`3oool002L0oooo100000080?ooo`030000
003oool0oooo00L0oooo0P00000j0?ooo`@00000o`3oooml0?ooo`800000A03oool4000001<0oooo
000X0?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`@00000>@3oool400000?l0ooooN`3o
ool4000004@0oooo0P00000D0?ooo`00<`3oool00`000000oooo0?ooo`060?ooo`@00000>P3oool2
00000?l0oooo3`3oool2000006/0oooo1000001J0?ooo`004`3oool2000001h0oooo00<000000?oo
o`3oool01`3oool200000?l0ooooB`3oool4000006/0oooo0P00001K0?ooo`004P3oool4000001d0
oooo00<000000?ooo`3oool0o`3ooomD0?ooo`@00000X03oool2000002H0oooo000B0?ooo`@00000
7@3oool00`000000oooo0?ooo`3o0?oooeD0oooo0P00002P0?ooo`@000009@3oool001<0oooo0P00
000N0?ooo`030000003oool0oooo0:P0oooo0P00003o0?ooodd0oooo1000000U0?ooo`00<`3oool0
0`000000oooo0?ooo`2D0?ooo`8000004@3oool400000?l0ooooC@3oool2000002H0oooo000c0?oo
o`030000003oool0oooo09<0oooo1000000@0?ooo`@00000o`3ooome0?ooo`00<`3oool00`000000
oooo0?ooo`0K0?ooo`800000MP3oool400000140oooo0P00003o0?ooogH0oooo000K0?ooo`<00000
103oool2000000@0oooo0P0000090?ooo`030000003oool0oooo01X0oooo1000001f0?ooo`800000
d@3oool2000006/0oooo0P00000@0?ooo`800000=`3oool001`0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool06P3oool400000140oooo0P00003o0?ooocH0oooo1000001Y0?ooo`@000003P3oool4000003H0
oooo000L0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo01/0oooo0P00000A0?ooo`@00000o`3ooole0?oo
o`@00000J@3oool4000000h0oooo1000000f0?ooo`00703oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool5000002`0oooo1000003o
0?ooocH0oooo0P00001[0?ooo`800000403oool2000003L0oooo000L0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo02l0oooo0P00003o0?ooonl0oooo000K0?ooo`800000103oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo
000L0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`8000002@3oool00`000000oooo0?oo
o`3o0?ooool0oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000c0?oo
o`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0
oooo8@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 596.562}, {368.312, 0}} -> {25.2014, -4.73354, \
0.0154659, 0.290538}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingStrength Dependency", "ExampleSubsection"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[
\tReadRays[tracedsystem,{ArcCos[RayTilt.{1,0,0}]/Degree,GratingStrength/(Pi/2)\
}, {DiffractionOrderNumber->1,IntersectionNumber->3}]
];\
\>", "Input",
  CellLabel->"In[74]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.84688 0.11019 -109.418 109.432 [
[.23843 .00179 -6 -9 ]
[.23843 .00179 6 0 ]
[.45881 .00179 -6 -9 ]
[.45881 .00179 6 0 ]
[.67919 .00179 -6 -9 ]
[.67919 .00179 6 0 ]
[.89957 .00179 -6 -9 ]
[.89957 .00179 6 0 ]
[.00555 .12372 -30 -4.5 ]
[.00555 .12372 0 4.5 ]
[.00555 .23315 -30 -4.5 ]
[.00555 .23315 0 4.5 ]
[.00555 .34258 -30 -4.5 ]
[.00555 .34258 0 4.5 ]
[.00555 .45201 -30 -4.5 ]
[.00555 .45201 0 4.5 ]
[.00555 .56144 -30 -4.5 ]
[.00555 .56144 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23843 .01429 m
.23843 .02054 L
s
[(28)] .23843 .00179 0 1 Mshowa
.45881 .01429 m
.45881 .02054 L
s
[(30)] .45881 .00179 0 1 Mshowa
.67919 .01429 m
.67919 .02054 L
s
[(32)] .67919 .00179 0 1 Mshowa
.89957 .01429 m
.89957 .02054 L
s
[(34)] .89957 .00179 0 1 Mshowa
.125 Mabswid
.07314 .01429 m
.07314 .01804 L
s
.12824 .01429 m
.12824 .01804 L
s
.18333 .01429 m
.18333 .01804 L
s
.29352 .01429 m
.29352 .01804 L
s
.34862 .01429 m
.34862 .01804 L
s
.40371 .01429 m
.40371 .01804 L
s
.5139 .01429 m
.5139 .01804 L
s
.569 .01429 m
.569 .01804 L
s
.62409 .01429 m
.62409 .01804 L
s
.73428 .01429 m
.73428 .01804 L
s
.78938 .01429 m
.78938 .01804 L
s
.84447 .01429 m
.84447 .01804 L
s
.95466 .01429 m
.95466 .01804 L
s
.25 Mabswid
0 .01429 m
1 .01429 L
s
.01805 .12372 m
.0243 .12372 L
s
[(1.001)] .00555 .12372 1 0 Mshowa
.01805 .23315 m
.0243 .23315 L
s
[(1.002)] .00555 .23315 1 0 Mshowa
.01805 .34258 m
.0243 .34258 L
s
[(1.003)] .00555 .34258 1 0 Mshowa
.01805 .45201 m
.0243 .45201 L
s
[(1.004)] .00555 .45201 1 0 Mshowa
.01805 .56144 m
.0243 .56144 L
s
[(1.005)] .00555 .56144 1 0 Mshowa
.125 Mabswid
.01805 .03617 m
.0218 .03617 L
s
.01805 .05806 m
.0218 .05806 L
s
.01805 .07994 m
.0218 .07994 L
s
.01805 .10183 m
.0218 .10183 L
s
.01805 .1456 m
.0218 .1456 L
s
.01805 .16749 m
.0218 .16749 L
s
.01805 .18938 m
.0218 .18938 L
s
.01805 .21126 m
.0218 .21126 L
s
.01805 .25504 m
.0218 .25504 L
s
.01805 .27692 m
.0218 .27692 L
s
.01805 .29881 m
.0218 .29881 L
s
.01805 .32069 m
.0218 .32069 L
s
.01805 .36447 m
.0218 .36447 L
s
.01805 .38635 m
.0218 .38635 L
s
.01805 .40824 m
.0218 .40824 L
s
.01805 .43013 m
.0218 .43013 L
s
.01805 .4739 m
.0218 .4739 L
s
.01805 .49579 m
.0218 .49579 L
s
.01805 .51767 m
.0218 .51767 L
s
.01805 .53956 m
.0218 .53956 L
s
.01805 .58333 m
.0218 .58333 L
s
.01805 .60522 m
.0218 .60522 L
s
.25 Mabswid
.01805 0 m
.01805 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.97619 .60332 Mdot
.93751 .51968 Mdot
.89929 .4432 Mdot
.86155 .37369 Mdot
.82426 .31092 Mdot
.78742 .25471 Mdot
.75103 .20487 Mdot
.71508 .1612 Mdot
.67956 .12355 Mdot
.64446 .09173 Mdot
.60979 .06559 Mdot
.57553 .04496 Mdot
.54168 .02971 Mdot
.50823 .01967 Mdot
.47518 .01472 Mdot
.44253 .01472 Mdot
.41026 .01952 Mdot
.37837 .02902 Mdot
.34687 .04309 Mdot
.31573 .0616 Mdot
.28496 .08444 Mdot
.25455 .1115 Mdot
.22451 .14268 Mdot
.19481 .17786 Mdot
.16546 .21696 Mdot
.13646 .25986 Mdot
.1078 .30648 Mdot
.07947 .35672 Mdot
.05148 .41049 Mdot
.02381 .46771 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[74]:=",
  ImageSize->{559.688, 345.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008_0001FB000`400?l00000o`00003oo`3ooooo
0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo
003o0?ooool0oooo<@3oool009<0oooo1@0000020?ooo`<00000K03oool3000000@0oooo0P00001]
0?ooo`<000000P3oool5000006/0oooo0`0000040?ooo`<00000<@3oool009@0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0oooo06P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000006/0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000006X0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0300oooo002E0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`1/0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0K@3oool01@000000oooo
0?ooo`3oool000000700oooo00<000000?ooo`0000001000000a0?ooo`00UP3oool010000000oooo
0?ooo`3oool3000006d0oooo0P0000030?ooo`040000003oool0oooo000006d0oooo0P0000050?oo
o`030000003oool0oooo06/0oooo0P0000020?ooo`040000003oool0oooo00000380oooo002C0?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo06`0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0K03oool01P000000oooo0?ooo`000000oooo00000380oooo002C0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo06P0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000006/0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`3oool0J03oool01@000000oooo0?ooo`3oool0
000000<0oooo0P00000b0?ooo`00U03oool3000000<0oooo0`00001/0?ooo`<00000103oool20000
06d0oooo0`0000030?ooo`<00000K03oool3000000D0oooo00<000000?ooo`3oool0<03oool002@0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0oooo
o`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0
gP3oool200000100oooo0P00003o0?oooaL0oooo000K0?ooool00000o`00000F00000000903oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo100000060?ooo`030000003oool0
oooo00D0oooo1000000B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0F0?ooo`00903oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
008000003`3oool2000000L0oooo00<000000?ooo`3oool01P3oool2000000l0oooo0P0000020?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?oo
o`00903oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo05L0oooo1000000G0?ooo`03
0000003oool0oooo01H0oooo1000001I0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0<`3oool002@0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1G0?ooo`@00000
5`3oool00`000000oooo0?ooo`0F0?ooo`@00000F@3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo03<0oooo000T0?ooo`030000003oool0oooo0<d0oooo0P00000b0?ooo`800000o`3o
ool60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?oo
o`3oool0_03oool2000005D0oooo0P00003c0?ooo`00903oool00`000000oooo0?ooo`2k0?ooo`@0
0000D`3oool400000?80oooo000T0?ooo`030000003oool0oooo0;/0oooo1000001C0?ooo`@00000
lP3oool002@0oooo00<000000?ooo`3oool0_03oool2000005D0oooo0P00003c0?ooo`00903oool0
0`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo0`00003o0?ooool0oooo2P3oool002@0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0:/0oooo
0P00003o0?oooe`0oooo000T0?ooo`030000003oool0oooo0:X0oooo1000001g0?ooo`800000h@3o
ool002@0oooo00<000000?ooo`3oool0ZP3oool4000007H0oooo1000003P0?ooo`00903oool00`00
0000oooo0?ooo`2[0?ooo`800000M`3oool400000>00oooo000T0?ooo`030000003oool0oooo0?l0
oooo9P3oool200000>40oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000
oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo0`00002K0?ooo`800000o`3ooom/0?ooo`00903o
ool00`000000oooo0?ooo`2J0?ooo`@00000o`3ooom[0?ooo`00903oool00`000000oooo0?ooo`2J
0?ooo`@00000V@3oool200000<l0oooo000T0?ooo`030000003oool0oooo09/0oooo0P00002I0?oo
o`@00000cP3oool002@0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`@00000cP3oool002@0oooo
00<000000?ooo`3oool0o`3ooolh0?ooo`800000c`3oool002@0oooo00<000000?ooo`3oool0o`3o
oooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`00
0000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0
oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool300000?l0ooooo`3o
ool:0?ooo`00903oool00`000000oooo0?ooo`2:0?ooo`800000o`3ooomm0?ooo`00903oool00`00
0000oooo0?ooo`290?ooo`@00000o`3oooml0?ooo`00903oool00`000000oooo0?ooo`290?ooo`@0
0000o`3oooml0?ooo`00903oool00`000000oooo0?ooo`2:0?ooo`800000o`3ooomm0?ooo`00903o
ool00`000000oooo0?ooo`3o0?oood/0oooo0P00002l0?ooo`00903oool00`000000oooo0?ooo`3o
0?ooodX0oooo1000002k0?ooo`00903oool00`000000oooo0?ooo`3o0?ooodX0oooo1000002k0?oo
o`00903oool00`000000oooo0?ooo`3o0?oood/0oooo0P00002l0?ooo`00903oool00`000000oooo
0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T
0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool300000?l0ooooo`3oool:0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool0
0`000000oooo0?ooo`1j0?ooo`800000o`3ooon=0?ooo`00903oool00`000000oooo0?ooo`1i0?oo
o`@00000o`3ooon<0?ooo`00903oool00`000000oooo0?ooo`1i0?ooo`@00000o`3ooon<0?ooo`00
903oool00`000000oooo0?ooo`1j0?ooo`800000o`3ooon=0?ooo`00903oool00`000000oooo0?oo
o`3o0?ooool0oooo2P3oool000040?ooo`0000000000000000@0oooo00<000000?ooo`3oool00`3o
ool2000000@0oooo0P0000030?ooo`<00000203oool00`000000oooo0?ooo`3o0?ooool0oooo2P3o
ool00080oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooed0oooo
0P00002Z0?ooo`000P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooG03oool400000:T0oooo00020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0oooo1000003o0?oo
oe/0oooo1000002Y0?ooo`000P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooG@3oool200000:X0oooo00000`3oool000000000000:0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool2000000T0oooo00<000000?ooo`3oool0o`3o
oooo0?ooo`X0oooo00020?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`00
0000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0
oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?oo
o`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0JP3oool200000?l0ooooW@3oool0
02@0oooo00<000000?ooo`3oool0J@3oool400000?l0ooooW03oool002@0oooo00<000000?ooo`3o
ool0J@3oool400000?l0ooooW03oool002@0oooo0`00001Z0?ooo`800000o`3ooonM0?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000
oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo
000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o
0?ooog00oooo0P00002G0?ooo`00903oool00`000000oooo0?ooo`3o0?ooofl0oooo1000002F0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooofl0oooo1000002F0?ooo`00903oool00`000000oooo
0?ooo`3o0?ooog00oooo0P00002G0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3o
ool002@0oooo0`00003o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo
0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0FP3oool200000?l0oooo[@3o
ool002@0oooo00<000000?ooo`3oool0F@3oool400000?l0oooo[03oool002@0oooo00<000000?oo
o`3oool0F@3oool400000?l0oooo[03oool002@0oooo00<000000?ooo`3oool0FP3oool200000?l0
oooo[@3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003o
ool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool0
02@0oooo0`00003o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0
oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?oo
o`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?oo
o`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0
oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooon30?ooo`800000Q03oool002@0oooo00<0
00000?ooo`3oool0o`3ooon20?ooo`@00000P`3oool002@0oooo00<000000?ooo`3oool0o`3ooon2
0?ooo`@00000P`3oool002@0oooo00<000000?ooo`3oool0o`3ooon30?ooo`800000Q03oool002@0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`<00000o`3ooooo0?ooo`X0oooo
000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`1;
0?ooo`800000o`3ooonl0?ooo`00903oool00`000000oooo0?ooo`1:0?ooo`@00000o`3ooonk0?oo
o`00903oool00`000000oooo0?ooo`1:0?ooo`@00000o`3ooonk0?ooo`00903oool00`000000oooo
0?ooo`1;0?ooo`800000o`3ooonl0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3o
ool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo
0?l0ooooo`3oool:0?ooo`0000@0oooo0000000000000000103oool00`000000oooo0?ooo`030?oo
o`800000103oool200000080oooo1@0000070?ooo`030000003oool0oooo0?l0ooooo`3oool:0?oo
o`000P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooo`3o
ool:0?ooo`000P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
o`3oool:0?ooo`000P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?ooo`@00000o`3ooooo0?ooo`T0
oooo00020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000P3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o
0?ooool0oooo2P3oool000030?ooo`000000000000X0oooo00@000000?ooo`3oool000000P3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3o0?ooool0oooo2P3oool00080oooo00<000000?ooo`3oool02@3oool2000000@0oooo0P00
00030?ooo`<00000203oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool0
0`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooonG0?oo
o`800000L03oool002@0oooo0`00003o0?oooiH0oooo1000001_0?ooo`00903oool00`000000oooo
0?ooo`3o0?oooiH0oooo1000001_0?ooo`00903oool00`000000oooo0?ooo`0k0?ooo`800000o`3o
oomJ0?ooo`800000L03oool002@0oooo00<000000?ooo`3oool0>P3oool400000?l0oooob`3oool0
02@0oooo00<000000?ooo`3oool0>P3oool400000?l0oooob`3oool002@0oooo00<000000?ooo`3o
ool0>`3oool200000?l0ooooc03oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo
000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o
0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`03
0000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo
2P3oool002@0oooo0`00003o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000
oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo
000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o
0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`03
0000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo
2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0
oooo0?l0ooooo`3oool:0?ooo`00903oool300000?l0ooooo`3oool:0?ooo`00903oool00`000000
oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0;03oool200000?l0oooo
f`3oool002@0oooo00<000000?ooo`3oool0:`3oool400000?l0oooofP3oool002@0oooo00<00000
0?ooo`3oool0:`3oool400000?l0oooofP3oool002@0oooo00<000000?ooo`3oool0;03oool20000
0?l0ooooO03oool2000005d0oooo000T0?ooo`030000003oool0oooo0?l0ooooZ@3oool4000005`0
oooo000T0?ooo`030000003oool0oooo0?l0ooooZ@3oool4000005`0oooo000T0?ooo`030000003o
ool0oooo0?l0ooooZP3oool2000005d0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:
0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo0`00003o0?ooool0
oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003o
ool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool0
02@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0
ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:
0?ooo`0000@0oooo0000000000000000103oool00`000000oooo0?ooo`030?ooo`800000103oool2
000000<0oooo0`0000080?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`000P3oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo
00020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0
oooo00020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`800000203oool400000?l0ooooo`3oool90?ooo`000P3oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`0000<0oooo0000
000000002P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`000P3o
ool00`000000oooo0?ooo`090?ooo`800000103oool2000000<0oooo0`0000080?ooo`030000003o
ool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool0
02@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo01d0
oooo0P00003o0?ooonX0oooo000T0?ooo`030000003oool0oooo01`0oooo1000003o0?ooonT0oooo
000T0?ooo`030000003oool0oooo01`0oooo1000003o0?ooonT0oooo000T0?ooo`030000003oool0
oooo01d0oooo0P00003o0?ooonX0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo0`00003o0?ooool0oooo
2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0
oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?oookh0oooo0P0000190?oo
o`00903oool00`000000oooo0?ooo`3o0?oookd0oooo100000180?ooo`00903oool00`000000oooo
0?ooo`3o0?oookd0oooo100000180?ooo`00903oool00`000000oooo0?ooo`3o0?oookh0oooo0P00
00190?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00
903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo0`00003o0?ooool0oooo2P3o
ool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo
0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo
00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3o
ool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00
903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3o
oooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool30000
00h0oooo0P00003o0?ooooT0oooo000T0?ooo`030000003oool0oooo00d0oooo1000003o0?ooooP0
oooo000T0?ooo`030000003oool0oooo00d0oooo1000003o0?ooooP0oooo000T0?ooo`030000003o
ool0oooo00h0oooo0P00003o0?ooooT0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:
0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool300000?l0
ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:
0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0oooodP3oool2000003D0oooo
000T0?ooo`030000003oool0oooo0?l0ooood@3oool4000003@0oooo000T0?ooo`030000003oool0
oooo0?l0ooood@3oool4000003@0oooo000T0?ooo`030000003oool0oooo0?l0oooodP3oool20000
03D0oooo0000103oool000000000000000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`800000103oool3000000L0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo00020?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo00020?oo
o`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`00
0000oooo00D000001`3oool400000?l0ooooo`3oool90?ooo`000P3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo00020?ooo`030000
003oool0oooo00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0000000P0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo00000`3oool0
00000000000:0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool2
000000P0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo00020?ooo`030000003oool0oooo
00T0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo
00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo00800000o`3o
oooo0?ooo`P0oooo000T0?ooo`030000003oool0000000<00000o`3ooooo0?ooo`L0oooo000T0?oo
o`030000003oool0000000<00000o`3ooooo0?ooo`L0oooo000T0?ooo`030000003oool0oooo0080
0000o`3ooooo0?ooo`P0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903o
ool300000?l0ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool0
02@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0
ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:
0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo0`00003o0?ooool0oooo2P3oool0
02@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0
ooooo`3oool:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:
0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool300000?l0
ooooiP3oool200000240oooo000T0?ooo`030000003oool0oooo0?l0ooooi@3oool400000200oooo
000T0?ooo`030000003oool0oooo0?l0ooooi@3oool400000200oooo000T0?ooo`030000003oool0
oooo0?l0ooooiP3oool200000240oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool0
0`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000oooo
0?ooo`3o0?ooool0oooo2P3oool002@0oooo0`00003o0?ooool0oooo2P3oool002@0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool0
0`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`0000@0oooo000000000000
0000103oool00`000000oooo0?ooo`030?ooo`800000103oool2000000<0oooo0`0000080?ooo`03
0000003oool0oooo0?l0ooooo`3oool:0?ooo`000P3oool00`000000oooo0?ooo`080?ooo`040000
003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo00020?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo00D0oooo1000003o0?ooool0oooo2@3oool00080oooo00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool00080oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0000003oool0100000080?ooo`03
0000003oool0oooo0?l0ooooo`3oool:0?ooo`0000<0oooo0000000000002P3oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000002`3oool00`000000oooo0?ooo`3o
0?ooool0oooo2P3oool00080oooo00<000000?ooo`3oool02@3oool2000000@0oooo0P0000020?oo
o`D000001`3oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000
oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo
000T0?ooo`<00000o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:
0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool00`000000
oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooook0?ooo`800000
303oool002@0oooo00<000000?ooo`3oool0o`3ooooj0?ooo`@000002`3oool002@0oooo00<00000
0?ooo`3oool0o`3ooooj0?ooo`@000002`3oool002@0oooo0`00003o0?oooo/0oooo0P00000<0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00903oool0
0`000000oooo0?ooo`3o0?ooool0oooo2P3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`X0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`00o`3ooooo0?oooc40oooo
003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo0000\
\>"],
  ImageRangeCache->{{{0, 558.688}, {344.938, 0}} -> {25.3743, 0.999662, \
0.0170705, 1.71887*^-5}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Diffraction with TurboPlot", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
turbotracedsystem = TurboPlot[system,ThresholdIntensity -> 0, \
PlotType -> TopView, AspectRatio -> 1, Axes->True];\
\>", "Input",
  CellLabel->"In[25]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.0238095 0.5 0.0190476 [
[.02381 .4875 -9 -9 ]
[.02381 .4875 9 0 ]
[.5 .4875 -6 -9 ]
[.5 .4875 6 0 ]
[.7381 .4875 -6 -9 ]
[.7381 .4875 6 0 ]
[.97619 .4875 -6 -9 ]
[.97619 .4875 6 0 ]
[.2494 .11905 -18 -4.5 ]
[.2494 .11905 0 4.5 ]
[.2494 .30952 -18 -4.5 ]
[.2494 .30952 0 4.5 ]
[.2494 .69048 -12 -4.5 ]
[.2494 .69048 0 4.5 ]
[.2494 .88095 -12 -4.5 ]
[.2494 .88095 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-10)] .02381 .4875 0 1 Mshowa
.5 .5 m
.5 .50625 L
s
[(10)] .5 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(20)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(30)] .97619 .4875 0 1 Mshowa
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.21429 .5 m
.21429 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.40476 .5 m
.40476 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.59524 .5 m
.59524 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.78571 .5 m
.78571 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.2619 .11905 m
.26815 .11905 L
s
[(-20)] .2494 .11905 1 0 Mshowa
.2619 .30952 m
.26815 .30952 L
s
[(-10)] .2494 .30952 1 0 Mshowa
.2619 .69048 m
.26815 .69048 L
s
[(10)] .2494 .69048 1 0 Mshowa
.2619 .88095 m
.26815 .88095 L
s
[(20)] .2494 .88095 1 0 Mshowa
.125 Mabswid
.2619 .15714 m
.26565 .15714 L
s
.2619 .19524 m
.26565 .19524 L
s
.2619 .23333 m
.26565 .23333 L
s
.2619 .27143 m
.26565 .27143 L
s
.2619 .34762 m
.26565 .34762 L
s
.2619 .38571 m
.26565 .38571 L
s
.2619 .42381 m
.26565 .42381 L
s
.2619 .4619 m
.26565 .4619 L
s
.2619 .5381 m
.26565 .5381 L
s
.2619 .57619 m
.26565 .57619 L
s
.2619 .61429 m
.26565 .61429 L
s
.2619 .65238 m
.26565 .65238 L
s
.2619 .72857 m
.26565 .72857 L
s
.2619 .76667 m
.26565 .76667 L
s
.2619 .80476 m
.26565 .80476 L
s
.2619 .84286 m
.26565 .84286 L
s
.2619 .08095 m
.26565 .08095 L
s
.2619 .04286 m
.26565 .04286 L
s
.2619 .00476 m
.26565 .00476 L
s
.2619 .91905 m
.26565 .91905 L
s
.2619 .95714 m
.26565 .95714 L
s
.2619 .99524 m
.26565 .99524 L
s
.25 Mabswid
.2619 0 m
.2619 1 L
s
.5 g
.26165 .02381 m
.2619 .02381 L
.2619 .18254 L
.26165 .18254 L
.26165 .02381 L
F
.26165 .18254 m
.2619 .18254 L
.2619 .34127 L
.26165 .34127 L
.26165 .18254 L
F
.26165 .34127 m
.2619 .34127 L
.2619 .5 L
.26165 .5 L
.26165 .34127 L
F
.26165 .5 m
.2619 .5 L
.2619 .65873 L
.26165 .65873 L
.26165 .5 L
F
.26165 .65873 m
.2619 .65873 L
.2619 .81746 L
.26165 .81746 L
.26165 .65873 L
F
.26165 .81746 m
.2619 .81746 L
.2619 .97619 L
.26165 .97619 L
.26165 .81746 L
F
0 g
.5 Mabswid
.26165 .02381 m
.26165 .18254 L
.26165 .34127 L
.26165 .5 L
.26165 .65873 L
.26165 .81746 L
.26165 .97619 L
.2619 .97619 L
.2619 .81746 L
.2619 .65873 L
.2619 .5 L
.2619 .34127 L
.2619 .18254 L
.2619 .02381 L
.26165 .02381 L
s
.5 g
.26165 .5 m
.2619 .5 L
.2619 .5 L
.26165 .5 L
.26165 .5 L
F
.26165 .5 m
.2619 .5 L
.2619 .5 L
.26165 .5 L
.26165 .5 L
F
.26165 .5 m
.2619 .5 L
.2619 .5 L
.26165 .5 L
.26165 .5 L
F
.26165 .5 m
.2619 .5 L
.2619 .5 L
.26165 .5 L
.26165 .5 L
F
.26165 .5 m
.2619 .5 L
.2619 .5 L
.26165 .5 L
.26165 .5 L
F
.26165 .5 m
.2619 .5 L
.2619 .5 L
.26165 .5 L
.26165 .5 L
F
0 g
.26165 .5 m
.26165 .5 L
.26165 .5 L
.26165 .5 L
.26165 .5 L
.26165 .5 L
.26165 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.26165 .5 L
s
.5 g
.2619 .02381 m
.2619 .02381 L
.2619 .18254 L
.2619 .18254 L
.2619 .02381 L
F
.2619 .18254 m
.2619 .18254 L
.2619 .34127 L
.2619 .34127 L
.2619 .18254 L
F
.2619 .34127 m
.2619 .34127 L
.2619 .5 L
.2619 .5 L
.2619 .34127 L
F
.2619 .5 m
.2619 .5 L
.2619 .65873 L
.2619 .65873 L
.2619 .5 L
F
.2619 .65873 m
.2619 .65873 L
.2619 .81746 L
.2619 .81746 L
.2619 .65873 L
F
.2619 .81746 m
.2619 .81746 L
.2619 .97619 L
.2619 .97619 L
.2619 .81746 L
F
0 g
.2619 .02381 m
.2619 .18254 L
.2619 .34127 L
.2619 .5 L
.2619 .65873 L
.2619 .81746 L
.2619 .97619 L
.2619 .97619 L
.2619 .81746 L
.2619 .65873 L
.2619 .5 L
.2619 .34127 L
.2619 .18254 L
.2619 .02381 L
.2619 .02381 L
s
.5 g
.2619 .5 m
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
F
0 g
.2619 .5 m
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
s
.5 g
.2619 .02381 m
.26429 .02381 L
.26429 .18254 L
.2619 .18254 L
.2619 .02381 L
F
.2619 .18254 m
.26429 .18254 L
.26429 .34127 L
.2619 .34127 L
.2619 .18254 L
F
.2619 .34127 m
.26429 .34127 L
.26429 .5 L
.2619 .5 L
.2619 .34127 L
F
.2619 .5 m
.26429 .5 L
.26429 .65873 L
.2619 .65873 L
.2619 .5 L
F
.2619 .65873 m
.26429 .65873 L
.26429 .81746 L
.2619 .81746 L
.2619 .65873 L
F
.2619 .81746 m
.26429 .81746 L
.26429 .97619 L
.2619 .97619 L
.2619 .81746 L
F
0 g
.2619 .02381 m
.2619 .18254 L
.2619 .34127 L
.2619 .5 L
.2619 .65873 L
.2619 .81746 L
.2619 .97619 L
.26429 .97619 L
.26429 .81746 L
.26429 .65873 L
.26429 .5 L
.26429 .34127 L
.26429 .18254 L
.26429 .02381 L
.2619 .02381 L
s
.5 g
.2619 .5 m
.26429 .5 L
.26429 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.26429 .5 L
.26429 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.26429 .5 L
.26429 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.26429 .5 L
.26429 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.26429 .5 L
.26429 .5 L
.2619 .5 L
.2619 .5 L
F
.2619 .5 m
.26429 .5 L
.26429 .5 L
.2619 .5 L
.2619 .5 L
F
0 g
.2619 .5 m
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.2619 .5 L
.26429 .5 L
.26429 .5 L
.26429 .5 L
.26429 .5 L
.26429 .5 L
.26429 .5 L
.26429 .5 L
.2619 .5 L
s
.26165 .97619 m
.26165 .95996 L
.26165 .91239 L
.26165 .83672 L
.26165 .7381 L
.26165 .62325 L
.26165 .5 L
.26165 .37675 L
.26165 .2619 L
.26165 .16328 L
.26165 .08761 L
.26165 .04004 L
.26165 .02381 L
.26165 .04004 L
.26165 .08761 L
.26165 .16328 L
.26165 .2619 L
.26165 .37675 L
.26165 .5 L
.26165 .62325 L
.26165 .7381 L
.26165 .83672 L
.26165 .91239 L
.26165 .95996 L
.26165 .97619 L
s
.2619 .97619 m
.2619 .95996 L
.2619 .91239 L
.2619 .83672 L
.2619 .7381 L
.2619 .62325 L
.2619 .5 L
.2619 .37675 L
.2619 .2619 L
.2619 .16328 L
.2619 .08761 L
.2619 .04004 L
.2619 .02381 L
.2619 .04004 L
.2619 .08761 L
.2619 .16328 L
.2619 .2619 L
.2619 .37675 L
.2619 .5 L
.2619 .62325 L
.2619 .7381 L
.2619 .83672 L
.2619 .91239 L
.2619 .95996 L
.2619 .97619 L
s
.2619 .97619 m
.2619 .95996 L
.2619 .91239 L
.2619 .83672 L
.2619 .7381 L
.2619 .62325 L
.2619 .5 L
.2619 .37675 L
.2619 .2619 L
.2619 .16328 L
.2619 .08761 L
.2619 .04004 L
.2619 .02381 L
.2619 .04004 L
.2619 .08761 L
.2619 .16328 L
.2619 .2619 L
.2619 .37675 L
.2619 .5 L
.2619 .62325 L
.2619 .7381 L
.2619 .83672 L
.2619 .91239 L
.2619 .95996 L
.2619 .97619 L
s
.26429 .97619 m
.26429 .95996 L
.26429 .91239 L
.26429 .83672 L
.26429 .7381 L
.26429 .62325 L
.26429 .5 L
.26429 .37675 L
.26429 .2619 L
.26429 .16328 L
.26429 .08761 L
.26429 .04004 L
.26429 .02381 L
.26429 .04004 L
.26429 .08761 L
.26429 .16328 L
.26429 .2619 L
.26429 .37675 L
.26429 .5 L
.26429 .62325 L
.26429 .7381 L
.26429 .83672 L
.26429 .91239 L
.26429 .95996 L
.26429 .97619 L
s
.26165 .97619 m
.2619 .97619 L
.2619 .95996 L
.26165 .95996 L
.26165 .97619 L
s
.26165 .95996 m
.2619 .95996 L
.2619 .91239 L
.26165 .91239 L
.26165 .95996 L
s
.26165 .91239 m
.2619 .91239 L
.2619 .83672 L
.26165 .83672 L
.26165 .91239 L
s
.26165 .83672 m
.2619 .83672 L
.2619 .7381 L
.26165 .7381 L
.26165 .83672 L
s
.26165 .7381 m
.2619 .7381 L
.2619 .62325 L
.26165 .62325 L
.26165 .7381 L
s
.26165 .62325 m
.2619 .62325 L
.2619 .5 L
.26165 .5 L
.26165 .62325 L
s
.26165 .5 m
.2619 .5 L
.2619 .37675 L
.26165 .37675 L
.26165 .5 L
s
.26165 .37675 m
.2619 .37675 L
.2619 .2619 L
.26165 .2619 L
.26165 .37675 L
s
.26165 .2619 m
.2619 .2619 L
.2619 .16328 L
.26165 .16328 L
.26165 .2619 L
s
.26165 .16328 m
.2619 .16328 L
.2619 .08761 L
.26165 .08761 L
.26165 .16328 L
s
.26165 .08761 m
.2619 .08761 L
.2619 .04004 L
.26165 .04004 L
.26165 .08761 L
s
.26165 .04004 m
.2619 .04004 L
.2619 .02381 L
.26165 .02381 L
.26165 .04004 L
s
.26165 .02381 m
.2619 .02381 L
.2619 .04004 L
.26165 .04004 L
.26165 .02381 L
s
.26165 .04004 m
.2619 .04004 L
.2619 .08761 L
.26165 .08761 L
.26165 .04004 L
s
.26165 .08761 m
.2619 .08761 L
.2619 .16328 L
.26165 .16328 L
.26165 .08761 L
s
.26165 .16328 m
.2619 .16328 L
.2619 .2619 L
.26165 .2619 L
.26165 .16328 L
s
.26165 .2619 m
.2619 .2619 L
.2619 .37675 L
.26165 .37675 L
.26165 .2619 L
s
.26165 .37675 m
.2619 .37675 L
.2619 .5 L
.26165 .5 L
.26165 .37675 L
s
.26165 .5 m
.2619 .5 L
.2619 .62325 L
.26165 .62325 L
.26165 .5 L
s
.26165 .62325 m
.2619 .62325 L
.2619 .7381 L
.26165 .7381 L
.26165 .62325 L
s
.26165 .7381 m
.2619 .7381 L
.2619 .83672 L
.26165 .83672 L
.26165 .7381 L
s
.26165 .83672 m
.2619 .83672 L
.2619 .91239 L
.26165 .91239 L
.26165 .83672 L
s
.26165 .91239 m
.2619 .91239 L
.2619 .95996 L
.26165 .95996 L
.26165 .91239 L
s
.26165 .95996 m
.2619 .95996 L
.2619 .97619 L
.26165 .97619 L
.26165 .95996 L
s
.2619 .97619 m
.2619 .97619 L
.2619 .95996 L
.2619 .95996 L
.2619 .97619 L
s
.2619 .95996 m
.2619 .95996 L
.2619 .91239 L
.2619 .91239 L
.2619 .95996 L
s
.2619 .91239 m
.2619 .91239 L
.2619 .83672 L
.2619 .83672 L
.2619 .91239 L
s
.2619 .83672 m
.2619 .83672 L
.2619 .7381 L
.2619 .7381 L
.2619 .83672 L
s
.2619 .7381 m
.2619 .7381 L
.2619 .62325 L
.2619 .62325 L
.2619 .7381 L
s
.2619 .62325 m
.2619 .62325 L
.2619 .5 L
.2619 .5 L
.2619 .62325 L
s
.2619 .5 m
.2619 .5 L
.2619 .37675 L
.2619 .37675 L
.2619 .5 L
s
.2619 .37675 m
.2619 .37675 L
.2619 .2619 L
.2619 .2619 L
.2619 .37675 L
s
.2619 .2619 m
.2619 .2619 L
.2619 .16328 L
.2619 .16328 L
.2619 .2619 L
s
.2619 .16328 m
.2619 .16328 L
.2619 .08761 L
.2619 .08761 L
.2619 .16328 L
s
.2619 .08761 m
.2619 .08761 L
.2619 .04004 L
.2619 .04004 L
.2619 .08761 L
s
.2619 .04004 m
.2619 .04004 L
.2619 .02381 L
.2619 .02381 L
.2619 .04004 L
s
.2619 .02381 m
.2619 .02381 L
.2619 .04004 L
.2619 .04004 L
.2619 .02381 L
s
.2619 .04004 m
.2619 .04004 L
.2619 .08761 L
.2619 .08761 L
.2619 .04004 L
s
.2619 .08761 m
.2619 .08761 L
.2619 .16328 L
.2619 .16328 L
.2619 .08761 L
s
.2619 .16328 m
.2619 .16328 L
.2619 .2619 L
.2619 .2619 L
.2619 .16328 L
s
.2619 .2619 m
.2619 .2619 L
.2619 .37675 L
.2619 .37675 L
.2619 .2619 L
s
.2619 .37675 m
.2619 .37675 L
.2619 .5 L
.2619 .5 L
.2619 .37675 L
s
.2619 .5 m
.2619 .5 L
.2619 .62325 L
.2619 .62325 L
.2619 .5 L
s
.2619 .62325 m
.2619 .62325 L
.2619 .7381 L
.2619 .7381 L
.2619 .62325 L
s
.2619 .7381 m
.2619 .7381 L
.2619 .83672 L
.2619 .83672 L
.2619 .7381 L
s
.2619 .83672 m
.2619 .83672 L
.2619 .91239 L
.2619 .91239 L
.2619 .83672 L
s
.2619 .91239 m
.2619 .91239 L
.2619 .95996 L
.2619 .95996 L
.2619 .91239 L
s
.2619 .95996 m
.2619 .95996 L
.2619 .97619 L
.2619 .97619 L
.2619 .95996 L
s
.2619 .97619 m
.26429 .97619 L
.26429 .95996 L
.2619 .95996 L
.2619 .97619 L
s
.2619 .95996 m
.26429 .95996 L
.26429 .91239 L
.2619 .91239 L
.2619 .95996 L
s
.2619 .91239 m
.26429 .91239 L
.26429 .83672 L
.2619 .83672 L
.2619 .91239 L
s
.2619 .83672 m
.26429 .83672 L
.26429 .7381 L
.2619 .7381 L
.2619 .83672 L
s
.2619 .7381 m
.26429 .7381 L
.26429 .62325 L
.2619 .62325 L
.2619 .7381 L
s
.2619 .62325 m
.26429 .62325 L
.26429 .5 L
.2619 .5 L
.2619 .62325 L
s
.2619 .5 m
.26429 .5 L
.26429 .37675 L
.2619 .37675 L
.2619 .5 L
s
.2619 .37675 m
.26429 .37675 L
.26429 .2619 L
.2619 .2619 L
.2619 .37675 L
s
.2619 .2619 m
.26429 .2619 L
.26429 .16328 L
.2619 .16328 L
.2619 .2619 L
s
.2619 .16328 m
.26429 .16328 L
.26429 .08761 L
.2619 .08761 L
.2619 .16328 L
s
.2619 .08761 m
.26429 .08761 L
.26429 .04004 L
.2619 .04004 L
.2619 .08761 L
s
.2619 .04004 m
.26429 .04004 L
.26429 .02381 L
.2619 .02381 L
.2619 .04004 L
s
.2619 .02381 m
.26429 .02381 L
.26429 .04004 L
.2619 .04004 L
.2619 .02381 L
s
.2619 .04004 m
.26429 .04004 L
.26429 .08761 L
.2619 .08761 L
.2619 .04004 L
s
.2619 .08761 m
.26429 .08761 L
.26429 .16328 L
.2619 .16328 L
.2619 .08761 L
s
.2619 .16328 m
.26429 .16328 L
.26429 .2619 L
.2619 .2619 L
.2619 .16328 L
s
.2619 .2619 m
.26429 .2619 L
.26429 .37675 L
.2619 .37675 L
.2619 .2619 L
s
.2619 .37675 m
.26429 .37675 L
.26429 .5 L
.2619 .5 L
.2619 .37675 L
s
.2619 .5 m
.26429 .5 L
.26429 .62325 L
.2619 .62325 L
.2619 .5 L
s
.2619 .62325 m
.26429 .62325 L
.26429 .7381 L
.2619 .7381 L
.2619 .62325 L
s
.2619 .7381 m
.26429 .7381 L
.26429 .83672 L
.2619 .83672 L
.2619 .7381 L
s
.2619 .83672 m
.26429 .83672 L
.26429 .91239 L
.2619 .91239 L
.2619 .83672 L
s
.2619 .91239 m
.26429 .91239 L
.26429 .95996 L
.2619 .95996 L
.2619 .91239 L
s
.2619 .95996 m
.26429 .95996 L
.26429 .97619 L
.2619 .97619 L
.2619 .95996 L
s
.97619 .5 m
.97619 .57937 L
.97619 .65873 L
.97619 .7381 L
.97619 .81746 L
.97619 .89683 L
.97619 .97619 L
.97619 .97619 L
.97619 .89683 L
.97619 .81746 L
.97619 .7381 L
.97619 .65873 L
.97619 .57937 L
.97619 .5 L
.97619 .5 L
s
.97619 .7381 m
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
.97619 .7381 L
s
.97619 .97619 m
.97619 .96808 L
.97619 .94429 L
.97619 .90645 L
.97619 .85714 L
.97619 .79972 L
.97619 .7381 L
.97619 .67647 L
.97619 .61905 L
.97619 .56974 L
.97619 .5319 L
.97619 .50811 L
.97619 .5 L
.97619 .50811 L
.97619 .5319 L
.97619 .56974 L
.97619 .61905 L
.97619 .67647 L
.97619 .7381 L
.97619 .79972 L
.97619 .85714 L
.97619 .90645 L
.97619 .94429 L
.97619 .96808 L
.97619 .97619 L
s
.97619 .02381 m
.97619 .10317 L
.97619 .18254 L
.97619 .2619 L
.97619 .34127 L
.97619 .42063 L
.97619 .5 L
.97619 .5 L
.97619 .42063 L
.97619 .34127 L
.97619 .2619 L
.97619 .18254 L
.97619 .10317 L
.97619 .02381 L
.97619 .02381 L
s
.97619 .2619 m
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
.97619 .2619 L
s
.97619 .5 m
.97619 .49189 L
.97619 .4681 L
.97619 .43026 L
.97619 .38095 L
.97619 .32353 L
.97619 .2619 L
.97619 .20028 L
.97619 .14286 L
.97619 .09355 L
.97619 .05571 L
.97619 .03192 L
.97619 .02381 L
.97619 .03192 L
.97619 .05571 L
.97619 .09355 L
.97619 .14286 L
.97619 .20028 L
.97619 .2619 L
.97619 .32353 L
.97619 .38095 L
.97619 .43026 L
.97619 .4681 L
.97619 .49189 L
.97619 .5 L
s
.009 .837 .111 r
.02381 .39003 m
.26165 .48085 L
s
0 0 0 r
2.5 Mabswid
.26165 .48085 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .48217 L
s
0 0 0 r
2.5 Mabswid
.26165 .48217 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .48348 L
s
0 0 0 r
2.5 Mabswid
.26165 .48348 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .48479 L
s
0 0 0 r
2.5 Mabswid
.26165 .48479 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .4861 L
s
0 0 0 r
2.5 Mabswid
.26165 .4861 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .48741 L
s
0 0 0 r
2.5 Mabswid
.26165 .48741 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .48873 L
s
0 0 0 r
2.5 Mabswid
.26165 .48873 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .49004 L
s
0 0 0 r
2.5 Mabswid
.26165 .49004 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .49135 L
s
0 0 0 r
2.5 Mabswid
.26165 .49135 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .49266 L
s
0 0 0 r
2.5 Mabswid
.26165 .49266 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .49398 L
s
0 0 0 r
2.5 Mabswid
.26165 .49398 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .49529 L
s
0 0 0 r
2.5 Mabswid
.26165 .49529 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .4966 L
s
0 0 0 r
2.5 Mabswid
.26165 .4966 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .49791 L
s
0 0 0 r
2.5 Mabswid
.26165 .49791 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .49922 L
s
0 0 0 r
2.5 Mabswid
.26165 .49922 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .50054 L
s
0 0 0 r
2.5 Mabswid
.26165 .50054 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .50185 L
s
0 0 0 r
2.5 Mabswid
.26165 .50185 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .50316 L
s
0 0 0 r
2.5 Mabswid
.26165 .50316 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .50447 L
s
0 0 0 r
2.5 Mabswid
.26165 .50447 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .50579 L
s
0 0 0 r
2.5 Mabswid
.26165 .50579 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .5071 L
s
0 0 0 r
2.5 Mabswid
.26165 .5071 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .50841 L
s
0 0 0 r
2.5 Mabswid
.26165 .50841 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .50972 L
s
0 0 0 r
2.5 Mabswid
.26165 .50972 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .51103 L
s
0 0 0 r
2.5 Mabswid
.26165 .51103 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .51235 L
s
0 0 0 r
2.5 Mabswid
.26165 .51235 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .51366 L
s
0 0 0 r
2.5 Mabswid
.26165 .51366 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .51497 L
s
0 0 0 r
2.5 Mabswid
.26165 .51497 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .51628 L
s
0 0 0 r
2.5 Mabswid
.26165 .51628 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .5176 L
s
0 0 0 r
2.5 Mabswid
.26165 .5176 Mdot
.009 .837 .111 r
.5 Mabswid
.02381 .39003 m
.26165 .51891 L
s
0 0 0 r
2.5 Mabswid
.26165 .51891 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .48085 m
.2619 .48095 L
s
0 0 0 r
2.5 Mabswid
.2619 .48095 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .48217 m
.2619 .48227 L
s
0 0 0 r
2.5 Mabswid
.2619 .48227 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .48348 m
.2619 .48358 L
s
0 0 0 r
2.5 Mabswid
.2619 .48358 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .48479 m
.2619 .48489 L
s
0 0 0 r
2.5 Mabswid
.2619 .48489 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .4861 m
.2619 .48621 L
s
0 0 0 r
2.5 Mabswid
.2619 .48621 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .48741 m
.2619 .48752 L
s
0 0 0 r
2.5 Mabswid
.2619 .48752 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .48873 m
.2619 .48883 L
s
0 0 0 r
2.5 Mabswid
.2619 .48883 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .49004 m
.2619 .49015 L
s
0 0 0 r
2.5 Mabswid
.2619 .49015 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .49135 m
.2619 .49146 L
s
0 0 0 r
2.5 Mabswid
.2619 .49146 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .49266 m
.2619 .49278 L
s
0 0 0 r
2.5 Mabswid
.2619 .49278 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .49398 m
.2619 .49409 L
s
0 0 0 r
2.5 Mabswid
.2619 .49409 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .49529 m
.2619 .4954 L
s
0 0 0 r
2.5 Mabswid
.2619 .4954 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .4966 m
.2619 .49672 L
s
0 0 0 r
2.5 Mabswid
.2619 .49672 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .49791 m
.2619 .49803 L
s
0 0 0 r
2.5 Mabswid
.2619 .49803 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .49922 m
.2619 .49934 L
s
0 0 0 r
2.5 Mabswid
.2619 .49934 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50054 m
.2619 .50066 L
s
0 0 0 r
2.5 Mabswid
.2619 .50066 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50185 m
.2619 .50197 L
s
0 0 0 r
2.5 Mabswid
.2619 .50197 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50316 m
.2619 .50328 L
s
0 0 0 r
2.5 Mabswid
.2619 .50328 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50447 m
.2619 .5046 L
s
0 0 0 r
2.5 Mabswid
.2619 .5046 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50579 m
.2619 .50591 L
s
0 0 0 r
2.5 Mabswid
.2619 .50591 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5071 m
.2619 .50722 L
s
0 0 0 r
2.5 Mabswid
.2619 .50722 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50841 m
.2619 .50854 L
s
0 0 0 r
2.5 Mabswid
.2619 .50854 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .50972 m
.2619 .50985 L
s
0 0 0 r
2.5 Mabswid
.2619 .50985 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51103 m
.2619 .51117 L
s
0 0 0 r
2.5 Mabswid
.2619 .51117 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51235 m
.2619 .51248 L
s
0 0 0 r
2.5 Mabswid
.2619 .51248 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51366 m
.2619 .51379 L
s
0 0 0 r
2.5 Mabswid
.2619 .51379 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51497 m
.2619 .51511 L
s
0 0 0 r
2.5 Mabswid
.2619 .51511 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51628 m
.2619 .51642 L
s
0 0 0 r
2.5 Mabswid
.2619 .51642 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .5176 m
.2619 .51773 L
s
0 0 0 r
2.5 Mabswid
.2619 .51773 Mdot
.009 .837 .111 r
.5 Mabswid
.26165 .51891 m
.2619 .51905 L
s
0 0 0 r
2.5 Mabswid
.2619 .51905 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48095 m
.2619 .48095 L
s
0 0 0 r
2.5 Mabswid
.2619 .48095 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48095 m
.2619 .48095 L
s
0 0 0 r
2.5 Mabswid
.2619 .48095 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48227 m
.2619 .48227 L
s
0 0 0 r
2.5 Mabswid
.2619 .48227 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48227 m
.2619 .48227 L
s
0 0 0 r
2.5 Mabswid
.2619 .48227 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48358 m
.2619 .48358 L
s
0 0 0 r
2.5 Mabswid
.2619 .48358 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48358 m
.2619 .48358 L
s
0 0 0 r
2.5 Mabswid
.2619 .48358 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48489 m
.2619 .48489 L
s
0 0 0 r
2.5 Mabswid
.2619 .48489 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48489 m
.2619 .48489 L
s
0 0 0 r
2.5 Mabswid
.2619 .48489 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48621 m
.2619 .48621 L
s
0 0 0 r
2.5 Mabswid
.2619 .48621 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48621 m
.2619 .48621 L
s
0 0 0 r
2.5 Mabswid
.2619 .48621 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48752 m
.2619 .48752 L
s
0 0 0 r
2.5 Mabswid
.2619 .48752 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48752 m
.2619 .48752 L
s
0 0 0 r
2.5 Mabswid
.2619 .48752 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48883 m
.2619 .48883 L
s
0 0 0 r
2.5 Mabswid
.2619 .48883 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48883 m
.2619 .48883 L
s
0 0 0 r
2.5 Mabswid
.2619 .48883 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49015 m
.2619 .49015 L
s
0 0 0 r
2.5 Mabswid
.2619 .49015 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49015 m
.2619 .49015 L
s
0 0 0 r
2.5 Mabswid
.2619 .49015 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49146 m
.2619 .49146 L
s
0 0 0 r
2.5 Mabswid
.2619 .49146 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49146 m
.2619 .49146 L
s
0 0 0 r
2.5 Mabswid
.2619 .49146 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49278 m
.2619 .49278 L
s
0 0 0 r
2.5 Mabswid
.2619 .49278 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49278 m
.2619 .49278 L
s
0 0 0 r
2.5 Mabswid
.2619 .49278 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49409 m
.2619 .49409 L
s
0 0 0 r
2.5 Mabswid
.2619 .49409 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49409 m
.2619 .49409 L
s
0 0 0 r
2.5 Mabswid
.2619 .49409 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .4954 m
.2619 .4954 L
s
0 0 0 r
2.5 Mabswid
.2619 .4954 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .4954 m
.2619 .4954 L
s
0 0 0 r
2.5 Mabswid
.2619 .4954 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49672 m
.2619 .49672 L
s
0 0 0 r
2.5 Mabswid
.2619 .49672 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49672 m
.2619 .49672 L
s
0 0 0 r
2.5 Mabswid
.2619 .49672 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49803 m
.2619 .49803 L
s
0 0 0 r
2.5 Mabswid
.2619 .49803 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49803 m
.2619 .49803 L
s
0 0 0 r
2.5 Mabswid
.2619 .49803 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49934 m
.2619 .49934 L
s
0 0 0 r
2.5 Mabswid
.2619 .49934 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49934 m
.2619 .49934 L
s
0 0 0 r
2.5 Mabswid
.2619 .49934 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50066 m
.2619 .50066 L
s
0 0 0 r
2.5 Mabswid
.2619 .50066 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50066 m
.2619 .50066 L
s
0 0 0 r
2.5 Mabswid
.2619 .50066 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50197 m
.2619 .50197 L
s
0 0 0 r
2.5 Mabswid
.2619 .50197 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50197 m
.2619 .50197 L
s
0 0 0 r
2.5 Mabswid
.2619 .50197 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50328 m
.2619 .50328 L
s
0 0 0 r
2.5 Mabswid
.2619 .50328 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50328 m
.2619 .50328 L
s
0 0 0 r
2.5 Mabswid
.2619 .50328 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5046 m
.2619 .5046 L
s
0 0 0 r
2.5 Mabswid
.2619 .5046 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5046 m
.2619 .5046 L
s
0 0 0 r
2.5 Mabswid
.2619 .5046 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50591 m
.2619 .50591 L
s
0 0 0 r
2.5 Mabswid
.2619 .50591 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50591 m
.2619 .50591 L
s
0 0 0 r
2.5 Mabswid
.2619 .50591 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50722 m
.2619 .50722 L
s
0 0 0 r
2.5 Mabswid
.2619 .50722 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50722 m
.2619 .50722 L
s
0 0 0 r
2.5 Mabswid
.2619 .50722 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50854 m
.2619 .50854 L
s
0 0 0 r
2.5 Mabswid
.2619 .50854 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50854 m
.2619 .50854 L
s
0 0 0 r
2.5 Mabswid
.2619 .50854 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50985 m
.2619 .50985 L
s
0 0 0 r
2.5 Mabswid
.2619 .50985 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50985 m
.2619 .50985 L
s
0 0 0 r
2.5 Mabswid
.2619 .50985 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51117 m
.2619 .51117 L
s
0 0 0 r
2.5 Mabswid
.2619 .51117 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51117 m
.2619 .51117 L
s
0 0 0 r
2.5 Mabswid
.2619 .51117 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51248 m
.2619 .51248 L
s
0 0 0 r
2.5 Mabswid
.2619 .51248 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51248 m
.2619 .51248 L
s
0 0 0 r
2.5 Mabswid
.2619 .51248 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51379 m
.2619 .51379 L
s
0 0 0 r
2.5 Mabswid
.2619 .51379 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51379 m
.2619 .51379 L
s
0 0 0 r
2.5 Mabswid
.2619 .51379 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51511 m
.2619 .51511 L
s
0 0 0 r
2.5 Mabswid
.2619 .51511 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51511 m
.2619 .51511 L
s
0 0 0 r
2.5 Mabswid
.2619 .51511 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51642 m
.2619 .51642 L
s
0 0 0 r
2.5 Mabswid
.2619 .51642 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51642 m
.2619 .51642 L
s
0 0 0 r
2.5 Mabswid
.2619 .51642 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51773 m
.2619 .51773 L
s
0 0 0 r
2.5 Mabswid
.2619 .51773 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51773 m
.2619 .51773 L
s
0 0 0 r
2.5 Mabswid
.2619 .51773 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51905 m
.2619 .51905 L
s
0 0 0 r
2.5 Mabswid
.2619 .51905 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51905 m
.2619 .51905 L
s
0 0 0 r
2.5 Mabswid
.2619 .51905 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48095 m
.26429 .47963 L
s
0 0 0 r
2.5 Mabswid
.26429 .47963 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48095 m
.26429 .48186 L
s
0 0 0 r
2.5 Mabswid
.26429 .48186 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48227 m
.26429 .48096 L
s
0 0 0 r
2.5 Mabswid
.26429 .48096 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48227 m
.26429 .48319 L
s
0 0 0 r
2.5 Mabswid
.26429 .48319 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48358 m
.26429 .48229 L
s
0 0 0 r
2.5 Mabswid
.26429 .48229 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48358 m
.26429 .48452 L
s
0 0 0 r
2.5 Mabswid
.26429 .48452 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48489 m
.26429 .48363 L
s
0 0 0 r
2.5 Mabswid
.26429 .48363 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48489 m
.26429 .48584 L
s
0 0 0 r
2.5 Mabswid
.26429 .48584 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48621 m
.26429 .48495 L
s
0 0 0 r
2.5 Mabswid
.26429 .48495 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48621 m
.26429 .48717 L
s
0 0 0 r
2.5 Mabswid
.26429 .48717 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48752 m
.26429 .48628 L
s
0 0 0 r
2.5 Mabswid
.26429 .48628 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48752 m
.26429 .4885 L
s
0 0 0 r
2.5 Mabswid
.26429 .4885 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48883 m
.26429 .48761 L
s
0 0 0 r
2.5 Mabswid
.26429 .48761 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .48883 m
.26429 .48982 L
s
0 0 0 r
2.5 Mabswid
.26429 .48982 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49015 m
.26429 .48894 L
s
0 0 0 r
2.5 Mabswid
.26429 .48894 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49015 m
.26429 .49115 L
s
0 0 0 r
2.5 Mabswid
.26429 .49115 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49146 m
.26429 .49027 L
s
0 0 0 r
2.5 Mabswid
.26429 .49027 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49146 m
.26429 .49248 L
s
0 0 0 r
2.5 Mabswid
.26429 .49248 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49278 m
.26429 .4916 L
s
0 0 0 r
2.5 Mabswid
.26429 .4916 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49278 m
.26429 .4938 L
s
0 0 0 r
2.5 Mabswid
.26429 .4938 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49409 m
.26429 .49293 L
s
0 0 0 r
2.5 Mabswid
.26429 .49293 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49409 m
.26429 .49513 L
s
0 0 0 r
2.5 Mabswid
.26429 .49513 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .4954 m
.26429 .49426 L
s
0 0 0 r
2.5 Mabswid
.26429 .49426 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .4954 m
.26429 .49646 L
s
0 0 0 r
2.5 Mabswid
.26429 .49646 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49672 m
.26429 .49558 L
s
0 0 0 r
2.5 Mabswid
.26429 .49558 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49672 m
.26429 .49778 L
s
0 0 0 r
2.5 Mabswid
.26429 .49778 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49803 m
.26429 .49691 L
s
0 0 0 r
2.5 Mabswid
.26429 .49691 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49803 m
.26429 .49911 L
s
0 0 0 r
2.5 Mabswid
.26429 .49911 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49934 m
.26429 .49824 L
s
0 0 0 r
2.5 Mabswid
.26429 .49824 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .49934 m
.26429 .50044 L
s
0 0 0 r
2.5 Mabswid
.26429 .50044 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50066 m
.26429 .49956 L
s
0 0 0 r
2.5 Mabswid
.26429 .49956 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50066 m
.26429 .50176 L
s
0 0 0 r
2.5 Mabswid
.26429 .50176 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50197 m
.26429 .50089 L
s
0 0 0 r
2.5 Mabswid
.26429 .50089 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50197 m
.26429 .50309 L
s
0 0 0 r
2.5 Mabswid
.26429 .50309 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50328 m
.26429 .50222 L
s
0 0 0 r
2.5 Mabswid
.26429 .50222 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50328 m
.26429 .50442 L
s
0 0 0 r
2.5 Mabswid
.26429 .50442 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5046 m
.26429 .50354 L
s
0 0 0 r
2.5 Mabswid
.26429 .50354 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .5046 m
.26429 .50574 L
s
0 0 0 r
2.5 Mabswid
.26429 .50574 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50591 m
.26429 .50487 L
s
0 0 0 r
2.5 Mabswid
.26429 .50487 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50591 m
.26429 .50707 L
s
0 0 0 r
2.5 Mabswid
.26429 .50707 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50722 m
.26429 .50619 L
s
0 0 0 r
2.5 Mabswid
.26429 .50619 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50722 m
.26429 .5084 L
s
0 0 0 r
2.5 Mabswid
.26429 .5084 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50854 m
.26429 .50752 L
s
0 0 0 r
2.5 Mabswid
.26429 .50752 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50854 m
.26429 .50972 L
s
0 0 0 r
2.5 Mabswid
.26429 .50972 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50985 m
.26429 .50884 L
s
0 0 0 r
2.5 Mabswid
.26429 .50884 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .50985 m
.26429 .51105 L
s
0 0 0 r
2.5 Mabswid
.26429 .51105 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51117 m
.26429 .51017 L
s
0 0 0 r
2.5 Mabswid
.26429 .51017 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51117 m
.26429 .51238 L
s
0 0 0 r
2.5 Mabswid
.26429 .51238 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51248 m
.26429 .51149 L
s
0 0 0 r
2.5 Mabswid
.26429 .51149 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51248 m
.26429 .5137 L
s
0 0 0 r
2.5 Mabswid
.26429 .5137 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51379 m
.26429 .51282 L
s
0 0 0 r
2.5 Mabswid
.26429 .51282 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51379 m
.26429 .51503 L
s
0 0 0 r
2.5 Mabswid
.26429 .51503 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51511 m
.26429 .51414 L
s
0 0 0 r
2.5 Mabswid
.26429 .51414 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51511 m
.26429 .51636 L
s
0 0 0 r
2.5 Mabswid
.26429 .51636 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51642 m
.26429 .51547 L
s
0 0 0 r
2.5 Mabswid
.26429 .51547 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51642 m
.26429 .51768 L
s
0 0 0 r
2.5 Mabswid
.26429 .51768 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51773 m
.26429 .51679 L
s
0 0 0 r
2.5 Mabswid
.26429 .51679 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51773 m
.26429 .51901 L
s
0 0 0 r
2.5 Mabswid
.26429 .51901 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51905 m
.26429 .51812 L
s
0 0 0 r
2.5 Mabswid
.26429 .51812 Mdot
.009 .837 .111 r
.5 Mabswid
.2619 .51905 m
.26429 .52034 L
s
0 0 0 r
2.5 Mabswid
.26429 .52034 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48186 m
.97619 .75372 L
s
0 0 0 r
2.5 Mabswid
.97619 .75372 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48319 m
.97619 .75898 L
s
0 0 0 r
2.5 Mabswid
.97619 .75898 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48452 m
.97619 .76423 L
s
0 0 0 r
2.5 Mabswid
.97619 .76423 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48584 m
.97619 .76949 L
s
0 0 0 r
2.5 Mabswid
.97619 .76949 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48717 m
.97619 .77474 L
s
0 0 0 r
2.5 Mabswid
.97619 .77474 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .4885 m
.97619 .78 L
s
0 0 0 r
2.5 Mabswid
.97619 .78 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48982 m
.97619 .78525 L
s
0 0 0 r
2.5 Mabswid
.97619 .78525 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49115 m
.97619 .79051 L
s
0 0 0 r
2.5 Mabswid
.97619 .79051 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49248 m
.97619 .79576 L
s
0 0 0 r
2.5 Mabswid
.97619 .79576 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .4938 m
.97619 .80101 L
s
0 0 0 r
2.5 Mabswid
.97619 .80101 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49513 m
.97619 .80627 L
s
0 0 0 r
2.5 Mabswid
.97619 .80627 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49646 m
.97619 .81152 L
s
0 0 0 r
2.5 Mabswid
.97619 .81152 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49778 m
.97619 .81678 L
s
0 0 0 r
2.5 Mabswid
.97619 .81678 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49911 m
.97619 .82203 L
s
0 0 0 r
2.5 Mabswid
.97619 .82203 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50044 m
.97619 .82729 L
s
0 0 0 r
2.5 Mabswid
.97619 .82729 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50176 m
.97619 .83254 L
s
0 0 0 r
2.5 Mabswid
.97619 .83254 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50309 m
.97619 .8378 L
s
0 0 0 r
2.5 Mabswid
.97619 .8378 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50442 m
.97619 .84305 L
s
0 0 0 r
2.5 Mabswid
.97619 .84305 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50574 m
.97619 .84831 L
s
0 0 0 r
2.5 Mabswid
.97619 .84831 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50707 m
.97619 .85356 L
s
0 0 0 r
2.5 Mabswid
.97619 .85356 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .5084 m
.97619 .85881 L
s
0 0 0 r
2.5 Mabswid
.97619 .85881 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50972 m
.97619 .86407 L
s
0 0 0 r
2.5 Mabswid
.97619 .86407 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51105 m
.97619 .86932 L
s
0 0 0 r
2.5 Mabswid
.97619 .86932 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51238 m
.97619 .87458 L
s
0 0 0 r
2.5 Mabswid
.97619 .87458 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .5137 m
.97619 .87983 L
s
0 0 0 r
2.5 Mabswid
.97619 .87983 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51503 m
.97619 .88509 L
s
0 0 0 r
2.5 Mabswid
.97619 .88509 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51636 m
.97619 .89034 L
s
0 0 0 r
2.5 Mabswid
.97619 .89034 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51768 m
.97619 .8956 L
s
0 0 0 r
2.5 Mabswid
.97619 .8956 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51901 m
.97619 .90085 L
s
0 0 0 r
2.5 Mabswid
.97619 .90085 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .52034 m
.97619 .9061 L
s
0 0 0 r
2.5 Mabswid
.97619 .9061 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .47963 m
.97619 .08534 L
s
0 0 0 r
2.5 Mabswid
.97619 .08534 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48096 m
.97619 .09182 L
s
0 0 0 r
2.5 Mabswid
.97619 .09182 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48229 m
.97619 .09818 L
s
0 0 0 r
2.5 Mabswid
.97619 .09818 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48363 m
.97619 .10445 L
s
0 0 0 r
2.5 Mabswid
.97619 .10445 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48495 m
.97619 .11061 L
s
0 0 0 r
2.5 Mabswid
.97619 .11061 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48628 m
.97619 .11668 L
s
0 0 0 r
2.5 Mabswid
.97619 .11668 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48761 m
.97619 .12266 L
s
0 0 0 r
2.5 Mabswid
.97619 .12266 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .48894 m
.97619 .12855 L
s
0 0 0 r
2.5 Mabswid
.97619 .12855 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49027 m
.97619 .13435 L
s
0 0 0 r
2.5 Mabswid
.97619 .13435 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .4916 m
.97619 .14006 L
s
0 0 0 r
2.5 Mabswid
.97619 .14006 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49293 m
.97619 .1457 L
s
0 0 0 r
2.5 Mabswid
.97619 .1457 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49426 m
.97619 .15125 L
s
0 0 0 r
2.5 Mabswid
.97619 .15125 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49558 m
.97619 .15672 L
s
0 0 0 r
2.5 Mabswid
.97619 .15672 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49691 m
.97619 .16212 L
s
0 0 0 r
2.5 Mabswid
.97619 .16212 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49824 m
.97619 .16745 L
s
0 0 0 r
2.5 Mabswid
.97619 .16745 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .49956 m
.97619 .1727 L
s
0 0 0 r
2.5 Mabswid
.97619 .1727 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50089 m
.97619 .17789 L
s
0 0 0 r
2.5 Mabswid
.97619 .17789 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50222 m
.97619 .18301 L
s
0 0 0 r
2.5 Mabswid
.97619 .18301 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50354 m
.97619 .18806 L
s
0 0 0 r
2.5 Mabswid
.97619 .18806 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50487 m
.97619 .19304 L
s
0 0 0 r
2.5 Mabswid
.97619 .19304 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50619 m
.97619 .19797 L
s
0 0 0 r
2.5 Mabswid
.97619 .19797 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50752 m
.97619 .20283 L
s
0 0 0 r
2.5 Mabswid
.97619 .20283 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .50884 m
.97619 .20763 L
s
0 0 0 r
2.5 Mabswid
.97619 .20763 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51017 m
.97619 .21238 L
s
0 0 0 r
2.5 Mabswid
.97619 .21238 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51149 m
.97619 .21707 L
s
0 0 0 r
2.5 Mabswid
.97619 .21707 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51282 m
.97619 .2217 L
s
0 0 0 r
2.5 Mabswid
.97619 .2217 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51414 m
.97619 .22628 L
s
0 0 0 r
2.5 Mabswid
.97619 .22628 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51547 m
.97619 .2308 L
s
0 0 0 r
2.5 Mabswid
.97619 .2308 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51679 m
.97619 .23527 L
s
0 0 0 r
2.5 Mabswid
.97619 .23527 Mdot
.009 .837 .111 r
.5 Mabswid
.26429 .51812 m
.97619 .2397 L
s
0 0 0 r
2.5 Mabswid
.97619 .2397 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00C03oool00`000000oooo0?ooo`3A0?ooo`00C03oool200000=80oooo
001<0?ooo`030000003oool0oooo0=40oooo001<0?ooo`030000003oool0oooo0=40oooo001<0?oo
o`030000003oool0oooo0=40oooo001<0?ooo`030000003oool0oooo0=40oooo001<0?ooo`800000
bP3oool00`000000oooo0?ooo`050?ooo`00C03oool200000<X0oooo00<000000?ooo`3oool01@3o
ool004`0oooo0P00003:0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000bP3oool00`00
0000oooo0?ooo`050?ooo`00C03oool200000<X0oooo00<000000?ooo`3oool01@3oool004`0oooo
0P00003:0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000bP3oool00`000000oooo0?oo
o`050?ooo`00C03oool200000<X0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00003:0?oo
o`030000003oool0oooo00D0oooo001<0?ooo`800000bP3oool00`000000oooo0?ooo`050?ooo`00
C03oool200000<X0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00003:0?ooo`030000003o
ool0oooo00D0oooo001<0?ooo`800000bP3oool00`000000oooo0?ooo`050?ooo`00C03oool20000
0<X0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00003:0?ooo`030000003oool0oooo00D0
oooo001<0?ooo`800000bP3oool00`000000oooo0?ooo`050?ooo`00C03oool200000<X0oooo00<0
00000?ooo`3oool01@3oool004`0oooo0P00003:0?ooo`030000003oool0oooo00D0oooo001<0?oo
o`800000b@3oool2000000L0oooo001<0?ooo`800000a`3oool200;F708000001`3oool004`0oooo
0P0000350?ooo`800]HL0P3oool2000000L0oooo001<0?ooo`800000a03oool00`02eQ`0oooo0?oo
o`0200;F708000001`3oool004`0oooo0P0000320?ooo`800]HL00<0oooo00;F7002eQ`00P3oool2
000000L0oooo001<0?ooo`800000`03oool200;F7080oooo00<00]HL0?ooo`3oool00P02eQ`20000
00L0oooo001<0?ooo`800000_P3oool200;F7080oooo0P02eQ`00`3oool00]HL00;F700200;F7080
00001`3oool003d0oooo1@0000030?ooo`8000001@3oool200000;`0oooo0P02eQ`20?ooo`800]HL
00<0oooo00;F7002eQ`00P02eQ`20?ooo`8000001`3oool003h0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`800000^`3oool00`02eQ`0oooo0?ooo`0200;F7080
oooo0`02eQ`20?ooo`800]HL0P0000070?ooo`00=`3oool5000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`800000^@3oool200;F70030?ooo`02eQ`00]HL0080
oooo0`02eQ`20?ooo`800]HL0P3oool2000000L0oooo00100?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`<00000]P3oool200;F70030?ooo`02eQ`00]HL0080
oooo1002eQ`00`3oool00]HL00;F70020?ooo`800]HL0P0000070?ooo`00?@3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool00000103oool200000;D0oooo0P02eQ`20?oo
o`0300;F703oool0oooo00@00]HL00<0oooo00;F7002eQ`00P3oool200;F7080oooo0P0000070?oo
o`00?@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000103oool2
00000;<0oooo0P02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`0300;F703oool0
oooo00800]HL0P3oool200;F708000001`3oool003h0oooo0`0000040?ooo`8000001@3oool20000
0;80oooo00<00]HL0?ooo`3oool00P02eQ`00`3oool00]HL00;F700200;F7080oooo0P02eQ`00`3o
ool00]HL00;F70020?ooo`@00]HL0P0000070?ooo`00C03oool200000;00oooo0P02eQ`0103oool0
0]HL00;F703oool400;F7080oooo0P02eQ`00`3oool00]HL00;F70020?ooo`@00]HL0P3oool20000
00L0oooo001<0?ooo`800000[P3oool200;F70030?ooo`02eQ`00]HL0080oooo0`02eQ`20?ooo`80
0]HL00<0oooo00;F7002eQ`00P3oool400;F7080oooo0P02eQ`2000000L0oooo001<0?ooo`800000
[03oool200;F70030?ooo`02eQ`00]HL0080oooo0`02eQ`20?ooo`800]HL00<0oooo00;F7002eQ`0
0P3oool400;F7080oooo1002eQ`2000000L0oooo001<0?ooo`800000ZP3oool200;F7080oooo00<0
0]HL0?ooo`3oool00`02eQ`20?ooo`800]HL0P3oool00`02eQ`0oooo0?ooo`0400;F7080oooo1002
eQ`20?ooo`8000001`3oool004`0oooo0P00002X0?ooo`800]HL0P3oool200;F70030?ooo`02eQ`0
0]HL00800]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL00800]HL0P3oool4
00;F7080oooo0P02eQ`2000000L0oooo001<0?ooo`800000Y`3oool00`02eQ`0oooo0?ooo`0200;F
70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P3oool200;F70030?ooo`02eQ`00]HL
00800]HL0P3oool400;F7080oooo0P02eQ`20?ooo`8000001`3oool004`0oooo0P00002U0?ooo`80
0]HL00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool00]HL00;F70020?ooo`800]HL00<0oooo00;F
7002eQ`00P02eQ`20?ooo`@00]HL0P3oool200;F7080oooo0P02eQ`2000000L0oooo001<0?ooo`80
0000X`3oool200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002eQ`00P3oool200;F
70030?ooo`02eQ`00]HL00800]HL0P3oool400;F7080oooo0P02eQ`20?ooo`@00]HL0P0000070?oo
o`00C03oool200000:40oooo0P02eQ`20?ooo`0300;F703oool0oooo00<00]HL0P3oool00`02eQ`0
oooo0?ooo`0200;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F7080oooo0P02eQ`20?ooo`@0
0]HL0P3oool2000000L0oooo001<0?ooo`800000W`3oool200;F7080oooo0P02eQ`0103oool00]HL
00;F7002eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo1002eQ`20?ooo`@00]HL0P3oool200;F
7080oooo1002eQ`20?ooo`800]HL0P0000070?ooo`00C03oool2000009h0oooo00<00]HL0?ooo`3o
ool00P02eQ`0103oool00]HL00;F7002eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo1002eQ`2
0?ooo`@00]HL0P3oool200;F70030?ooo`02eQ`00]HL00<00]HL0P3oool400;F708000001`3oool0
04`0oooo0P00002L0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0`02eQ`20?ooo`800]HL00@0oooo
00;F7002eQ`0oooo1002eQ`20?ooo`@00]HL0P3oool200;F70030?ooo`02eQ`00]HL00<00]HL0P3o
ool400;F7080oooo0P0000070?ooo`00C03oool2000009X0oooo0P02eQ`0103oool00]HL00;F703o
ool300;F7080oooo0P02eQ`0103oool00]HL00;F703oool400;F7080oooo1002eQ`20?ooo`800]HL
00<0oooo00;F7002eQ`00P02eQ`20?ooo`D00]HL0P3oool200;F708000001`3oool004`0oooo0P00
002H0?ooo`800]HL00@0oooo00;F7002eQ`0oooo1002eQ`0103oool00]HL00;F703oool200;F7003
0?ooo`02eQ`00]HL00800]HL0P3oool400;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`20?oo
o`@00]HL0`3oool400;F708000001`3oool004`0oooo0P00002F0?ooo`800]HL0P3oool00`02eQ`0
oooo00;F700300;F70040?ooo`02eQ`00]HL0?ooo`800]HL0P3oool300;F7080oooo1002eQ`00`3o
ool00]HL00;F70020?ooo`@00]HL0P3oool400;F7080oooo1@02eQ`20?ooo`8000001`3oool004`0
oooo0P00002E0?ooo`0300;F703oool0oooo00800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F
70030?ooo`02eQ`00]HL0080oooo0`02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P3oool400;F
7080oooo1002eQ`20?ooo`@00]HL0`3oool200;F708000001`3oool004`0oooo0P00002C0?ooo`80
0]HL00@0oooo00;F7002eQ`0oooo0`02eQ`0103oool00]HL00;F703oool200;F7080oooo1002eQ`0
0`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL0080oooo1002eQ`20?ooo`@00]HL0P3oool4
00;F7080oooo1@02eQ`2000000L0oooo001<0?ooo`800000T@3oool200;F70040?ooo`02eQ`00]HL
0?ooo`<00]HL0P3oool01002eQ`0oooo00;F7002eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P02
eQ`00`3oool00]HL00;F70020?ooo`@00]HL0P3oool400;F7080oooo1002eQ`20?ooo`D00]HL0P3o
ool2000000L0oooo001<0?ooo`800000S`3oool200;F70040?ooo`02eQ`00]HL0?ooo`<00]HL0P3o
ool200;F70040?ooo`02eQ`0oooo0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL
00;F70020?ooo`@00]HL0P3oool400;F7080oooo1002eQ`20?ooo`@00]HL0`3oool200;F70800000
1`3oool004`0oooo0P00002=0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0`02eQ`20?ooo`800]HL
00@0oooo00;F7002eQ`0oooo1002eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL0080
oooo1002eQ`00`3oool00]HL00;F700200;F7080oooo1@02eQ`20?ooo`@00]HL0P3oool500;F7080
00001`3oool004`0oooo0P00002;0?ooo`800]HL0P3oool00`02eQ`0oooo00;F700200;F7080oooo
0P02eQ`0103oool00]HL00;F703oool400;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002
eQ`00P3oool400;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F7080oooo1@02eQ`20?ooo`L0
0]HL0P0000070?ooo`00C03oool2000008X0oooo00<00]HL0?ooo`3oool01P02eQ`0103oool00]HL
00;F703oool200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`0103oool0
0]HL00;F703oool500;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F7080oooo1@02eQ`20?oo
o`H00]HL0`3oool2000000L0oooo001<0?ooo`800000R03oool200;F70030?ooo`02eQ`00]HL00@0
0]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL
00800]HL00@0oooo00;F7002eQ`0oooo1@02eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`2
0?ooo`@00]HL0P3oool700;F7080oooo0`02eQ`2000000L0oooo001<0?ooo`800000QP3oool200;F
70040?ooo`02eQ`00]HL0?ooo`<00]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F
700200;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0oooo1002eQ`20?ooo`@00]HL
0P3oool400;F7080oooo1002eQ`20?ooo`L00]HL0P3oool500;F708000001`3oool004`0oooo0P00
00240?ooo`800]HL00@0oooo00;F7002eQ`0oooo0`02eQ`0103oool00]HL00;F703oool200;F7003
0?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F703oool400;F
7080oooo1002eQ`20?ooo`@00]HL0P3oool400;F7080oooo1P02eQ`30?ooo`L00]HL0P0000070?oo
o`00C03oool200000880oooo0P02eQ`0103oool00]HL00;F703oool300;F70040?ooo`02eQ`00]HL
0?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`0
0]HL0?ooo`@00]HL0P3oool400;F70030?ooo`02eQ`00]HL00800]HL0P3oool500;F70030?ooo`02
eQ`00]HL00D00]HL0P3oool700;F70<0oooo0P0000070?ooo`00C03oool200000840oooo00D00]HL
0?ooo`3oool00]HL0?ooo`0300;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`0
0P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002
eQ`00P02eQ`20?ooo`@00]HL0P3oool400;F7080oooo1`02eQ`20?ooo`L00]HL0P3oool300;F7080
00001`3oool004`0oooo0P00001o0?ooo`800]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`0500;F
703oool00]HL00;F703oool01002eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL0?oo
o`@00]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool400;F7080oooo1P02eQ`30?oo
o`L00]HL0P3oool500;F708000001`3oool004`0oooo0P00001m0?ooo`800]HL00<0oooo00;F7002
eQ`00`02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F7004
0?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool400;F
70030?ooo`02eQ`00]HL00D00]HL0P3oool700;F7080oooo2002eQ`2000000L0oooo001<0?ooo`80
0000N`3oool200;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool0
0]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0oooo1002eQ`00`3o
ool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`00]HL
00D00]HL0P3oool700;F7080oooo1`02eQ`30?ooo`8000001`3oool004`0oooo0P00001i0?ooo`80
0]HL00@0oooo00;F7002eQ`0oooo0`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL
00800]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F703oool400;F70030?ooo`02eQ`0
0]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool600;F70<0oooo1P02eQ`3
0?ooo`L00]HL0P3oool300;F708000001`3oool004`0oooo0P00001h0?ooo`0500;F703oool00]HL
00;F703oool00`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo
00;F7002eQ`00P02eQ`0103oool00]HL00;F703oool400;F70030?ooo`02eQ`00]HL00800]HL00<0
oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool600;F7080oooo1`02eQ`20?ooo`L00]HL0`3o
ool500;F708000001`3oool004`0oooo0P00001f0?ooo`800]HL00<0oooo00;F703oool00`02eQ`0
0`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`0
0`3oool00]HL00;F700500;F70040?ooo`02eQ`00]HL00;F7080oooo1002eQ`20?ooo`@00]HL00<0
oooo00;F7002eQ`01@02eQ`20?ooo`H00]HL0`3oool700;F7080oooo1@02eQ`40?ooo`030000003o
ool0oooo00D0oooo001<0?ooo`800000M03oool200;F70030?ooo`02eQ`00]HL00<00]HL00H0oooo
00;F7002eQ`0oooo00;F703oool400;F70030?ooo`02eQ`00]HL00X00]HL00@0oooo00;F7002eQ`0
0]HL0P3oool400;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`01002eQ`20?ooo`L0
0]HL0P3oool700;F70<0oooo1@02eQ`60?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000
LP3oool200;F70030?ooo`02eQ`00]HL00<00]HL00@0oooo00;F7002eQ`0oooo1P02eQ`00`3oool0
0]HL00;F700400;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@0
0]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`H00]HL0P3oool700;F7080oooo1`02eQ`20?ooo`D0
0]HL2@3oool00`000000oooo0?ooo`050?ooo`00C03oool200000700oooo0P02eQ`00`3oool00]HL
00;F700300;F70040?ooo`02eQ`00]HL0?ooo`H00]HL00<0oooo00;F7002eQ`01002eQ`00`3oool0
0]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL0P3oool300;F7080oooo1002eQ`00`3oool0
0]HL00;F700500;F7080oooo1P02eQ`20?ooo`L00]HL0`3oool400;F70`0oooo00<000000?ooo`3o
ool01@3oool004`0oooo0P00001^0?ooo`800]HL00<0oooo00;F7002eQ`00`02eQ`0103oool00]HL
00;F703oool600;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool0
0]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F70030?ooo`02eQ`00]HL00@0
0]HL0P3oool700;F7080oooo1`02eQ`20?ooo`D00]HL3P3oool00`000000oooo0?ooo`050?ooo`00
C03oool2000006d0oooo00D00]HL0?ooo`02eQ`00]HL0?ooo`0200;F7080oooo00<00]HL0?ooo`02
eQ`01@02eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002
eQ`00P02eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700400;F7080
oooo1P02eQ`20?ooo`L00]HL0P3oool500;F7140oooo00<000000?ooo`3oool01@3oool004`0oooo
0P00001[0?ooo`800]HL00<0oooo00;F703oool00`02eQ`00`3oool00]HL00;F700600;F70030?oo
o`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F7002eQ`20?ooo`@0
0]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700500;F7080oooo1P02eQ`20?ooo`L0
0]HL0P3oool500;F71<0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00001Y0?ooo`800]HL
00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F700600;F70030?ooo`02eQ`00]HL00@00]HL
00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F7002eQ`20?ooo`@00]HL00<0oooo00;F7002
eQ`00P02eQ`00`3oool00]HL00;F700400;F7080oooo1`02eQ`20?ooo`H00]HL0P3oool500;F71H0
oooo00<000000?ooo`3oool01@3oool004`0oooo0P00001W0?ooo`800]HL00<0oooo00;F7002eQ`0
0`02eQ`00`3oool00]HL00;F700600;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`0
0P02eQ`0103oool00]HL00;F7002eQ`20?ooo`<00]HL0P3oool400;F70030?ooo`02eQ`00]HL00@0
0]HL0P3oool600;F7080oooo1`02eQ`20?ooo`D00]HL603oool00`000000oooo0?ooo`050?ooo`00
C03oool2000006D0oooo0P02eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`00]HL00H00]HL
00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700600;F70030?ooo`02eQ`00]HL00800]HL
0P3oool300;F70030?ooo`02eQ`00]HL00D00]HL0P3oool600;F7080oooo1P02eQ`20?ooo`D00]HL
6`3oool00`000000oooo0?ooo`050?ooo`00C03oool2000006@0oooo00<00]HL0?ooo`02eQ`01002
eQ`00`3oool00]HL00;F700600;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`01P02
eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`01002
eQ`20?ooo`H00]HL0P3oool700;F7080oooo1002eQ`N0?ooo`030000003oool0oooo00D0oooo001<
0?ooo`800000HP3oool700;F70030?ooo`02eQ`00]HL00H00]HL00<0oooo00;F7002eQ`03@02eQ`0
0`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`01002eQ`2
0?ooo`H00]HL0P3oool600;F7080oooo1@02eQ`P0?ooo`030000003oool0oooo00D0oooo001<0?oo
o`800000H03oool200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`01P02eQ`00`3o
ool00]HL00;F700<00;F7080oooo0`02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`01002eQ`20?oo
o`D00]HL0P3oool700;F7080oooo1002eQ`S0?ooo`030000003oool0oooo00D0oooo001<0?ooo`80
0000GP3oool200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`01P02eQ`00`3oool0
0]HL00;F700800;F70040?ooo`02eQ`00]HL00;F7080oooo0`02eQ`20?ooo`<00]HL00<0oooo00;F
7002eQ`01002eQ`20?ooo`H00]HL0P3oool600;F7080oooo1@02eQ`U0?ooo`030000003oool0oooo
00D0oooo001<0?ooo`800000G03oool200;F70030?ooo`02eQ`00]HL00/00]HL00<0oooo00;F7002
eQ`02002eQ`0103oool00]HL00;F7002eQ`20?ooo`<00]HL00<0oooo00;F7002eQ`00P02eQ`00`3o
ool00]HL00;F700400;F7080oooo1P02eQ`00`3oool00]HL00;F700500;F7080oooo1002eQ`X0?oo
o`030000003oool0oooo00D0oooo000n0?ooo`<00000103oool2000000D0oooo0P00001K0?ooo`03
00;F703oool00]HL00@00]HL00<0oooo00;F7002eQ`01@02eQ`00`3oool00]HL00;F700800;F7005
0?ooo`02eQ`00]HL00;F703oool01002eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL
00@00]HL00<0oooo00;F7002eQ`01002eQ`20?ooo`H00]HL0P3oool500;F72X0oooo00<000000?oo
o`3oool01@3oool003l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`800000F@3oool700;F70030?ooo`02eQ`00]HL00D00]HL00<0oooo00;F7002eQ`03002eQ`00`3o
ool00]HL00;F700200;F70030?ooo`02eQ`00]HL00P00]HL0P3oool600;F7080oooo1P02eQ`20?oo
o`@00]HL;@3oool00`000000oooo0?ooo`050?ooo`00=`3oool5000000<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`800000E`3oool200;F70030?ooo`02eQ`00]HL
00800]HL00<0oooo00;F7002eQ`01@02eQ`00`3oool00]HL00;F700<00;F70040?ooo`02eQ`00]HL
00;F7080oooo0`02eQ`00`3oool00]HL00;F700400;F7080oooo1@02eQ`20?ooo`H00]HL0P3oool4
00;F7300oooo00<000000?ooo`3oool01@3oool003l0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`<00000E03oool200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo
00;F7002eQ`05002eQ`0103oool00]HL00;F7002eQ`20?ooo`<00]HL00<0oooo00;F7002eQ`01002
eQ`00`3oool00]HL00;F700400;F7080oooo1P02eQ`00`3oool00]HL00;F700300;F7380oooo00<0
00000?ooo`3oool01@3oool003l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`800000D`3oool200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`04`02
eQ`20?ooo`<00]HL00<0oooo00;F7002eQ`02002eQ`20?ooo`H00]HL00<0oooo00;F7002eQ`01002
eQ`20?ooo`@00]HL=@3oool00`000000oooo0?ooo`050?ooo`00?P3oool2000000@0oooo00@00000
0?ooo`3oool00000103oool200000540oooo0P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02
eQ`00]HL01<00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700800;F7080oooo1@02
eQ`20?ooo`H00]HL00<0oooo00;F7002eQ`00`02eQ`g0?ooo`030000003oool0oooo00D0oooo000o
0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`800000D03oool00`02eQ`0oooo00;F7003
00;F70030?ooo`02eQ`00]HL01<00]HL00<0oooo00;F7002eQ`00P02eQ`01@3oool00]HL00;F7002
eQ`0oooo00H00]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700400;F7080oooo1002
eQ`j0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000CP3ooolL00;F70040?ooo`02eQ`0
0]HL00;F7080oooo2@02eQ`20?ooo`D00]HL0P3oool600;F70030?ooo`02eQ`00]HL00<00]HL?03o
ool00`000000oooo0?ooo`050?ooo`00C03oool2000004`0oooo0P02eQ`00`3oool00]HL00;F700G
00;F70050?ooo`02eQ`00]HL00;F703oool02P02eQ`20?ooo`D00]HL00<0oooo00;F7002eQ`01002
eQ`20?ooo`@00]HL?`3oool00`000000oooo0?ooo`050?ooo`00C03oool2000004X0oooo0P02eQ`0
0`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL01800]HL00D0oooo00;F7002eQ`00]HL0?oo
o`0:00;F70030?ooo`02eQ`00]HL00<00]HL0P3oool600;F70030?ooo`02eQ`00]HL00800]HL@P3o
ool00`000000oooo0?ooo`050?ooo`00C03oool2000004P0oooo0P02eQ`00`3oool00]HL00;F7002
00;F70030?ooo`02eQ`00]HL01400]HL00<0oooo00;F7002eQ`00P02eQ`01@3oool00]HL00;F7002
eQ`0oooo00D00]HL0P3oool500;F7080oooo1@02eQ`20?ooo`@00]HLA03oool00`000000oooo0?oo
o`050?ooo`00C03oool2000004L0oooo00<00]HL0?ooo`02eQ`00`02eQ`00`3oool00]HL00;F700A
00;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`01`02eQ`00`3oool00]HL00;F7004
00;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`00P02eQa70?ooo`030000003oool0
oooo00D0oooo001<0?ooo`800000A@3oool600;F70030?ooo`02eQ`00]HL01400]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0:00;F70030?ooo`02eQ`00]HL00<00]HL0P3oool500;F7080oooo1002eQa9
0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000@`3oool600;F70030?ooo`02eQ`00]HL
01400]HL00D0oooo00;F7002eQ`00]HL0?ooo`0900;F7080oooo1@02eQ`00`3oool00]HL00;F7004
00;F70030?ooo`02eQ`00]HL00800]HLC03oool00`000000oooo0?ooo`050?ooo`00C03oool20000
0440oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo01<00]HL00D0oooo00;F7002eQ`00]HL0?oo
o`0900;F70030?ooo`02eQ`00]HL00<00]HL0P3oool500;F7080oooo1002eQa>0?ooo`030000003o
ool0oooo00D0oooo001<0?ooo`800000?`3oool200;F70050?ooo`02eQ`00]HL00;F703oool04`02
eQ`01@3oool00]HL00;F7002eQ`0oooo00T00]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL
00;F700400;F70030?ooo`02eQ`00]HL00800]HLD@3oool00`000000oooo0?ooo`050?ooo`00C03o
ool2000003h0oooo00<00]HL0?ooo`02eQ`05@02eQ`00`3oool00]HL00;F700200;F70030?ooo`02
eQ`00]HL00H00]HL0P3oool500;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00P02
eQaD0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000?03ooolH00;F70050?ooo`02eQ`0
0]HL00;F703oool02@02eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`00]HL00@00]HL00<0
oooo00;F7002eQ`00P02eQaF0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000>P3ooolH
00;F70050?ooo`02eQ`00]HL00;F703oool02@02eQ`00`3oool00]HL00;F700300;F70030?ooo`02
eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00P02eQaI0?ooo`030000003oool0oooo00D0oooo001<
0?ooo`800000>03oool600;F70030?ooo`02eQ`00]HL00l00]HL00D0oooo00;F7002eQ`00]HL0?oo
o`0800;F7080oooo1002eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`00]HL00800]HLF`3o
ool00`000000oooo0?ooo`050?ooo`00C03oool2000003H0oooo0P02eQ`01@3oool00]HL00;F7002
eQ`0oooo01400]HL00D0oooo00;F7002eQ`00]HL0?ooo`0800;F70030?ooo`02eQ`00]HL00<00]HL
00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F700200;F75h0oooo00<000000?ooo`3oool0
1@3oool004`0oooo0P00000d0?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0N00;F70030?oo
o`02eQ`00]HL00800]HL0P3oool400;F7080oooo1002eQaP0?ooo`030000003oool0oooo00D0oooo
001<0?ooo`800000<`3oool00`02eQ`0oooo00;F700200;F70030?ooo`02eQ`00]HL01800]HL00<0
oooo00;F7002eQ`01P02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F
700200;F76<0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00000a0?ooo`D00]HL00<0oooo
00;F7002eQ`03P02eQ`01@3oool00]HL00;F7002eQ`0oooo00P00]HL00<0oooo00;F7002eQ`00`02
eQ`00`3oool00]HL00;F700200;F7080oooo0`02eQaV0?ooo`030000003oool0oooo00D0oooo001<
0?ooo`800000;`3ooolF00;F70050?ooo`02eQ`00]HL00;F703oool02002eQ`00`3oool00]HL00;F
700200;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00P02eQaX0?ooo`030000003o
ool0oooo00D0oooo001<0?ooo`800000;@3ooolF00;F70030?ooo`02eQ`00]HL00T00]HL00<0oooo
00;F7002eQ`00`02eQ`00`3oool00]HL00;F700200;F7080oooo0`02eQa[0?ooo`030000003oool0
oooo00D0oooo00090?ooo`800]HL@@3oool2000002/0oooo0P02eQ`00`3oool00]HL00;F700A00;F
70030?ooo`02eQ`00]HL00T00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700300;F
70030?ooo`02eQ`00]HL00800]HLK@3oool00`000000oooo0?ooo`050?ooo`002`3oool300;F73h0
oooo0P00000Z0?ooo`0300;F703oool00]HL01D00]HL00<0oooo00;F7002eQ`01P02eQ`00`3oool0
0]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL0P3oool300;F7700oooo00<000000?ooo`3o
ool01@3oool000d0oooo0`02eQ`l0?ooo`800000:03ooolH00;F70030?ooo`02eQ`00]HL00D00]HL
00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700200;F7780oooo00<000000?ooo`3oool0
1@3oool000l0oooo1002eQ`i0?ooo`8000009P3oool500;F70030?ooo`02eQ`00]HL00`00]HL00D0
oooo00;F7002eQ`00]HL0?ooo`0700;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`0
0P02eQ`00`3oool00]HL00;F700200;F77D0oooo00<000000?ooo`3oool01@3oool00140oooo1@02
eQ`f0?ooo`800000903oool500;F70030?ooo`02eQ`00]HL00`00]HL00<0oooo00;F7002eQ`02@02
eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02
eQag0?ooo`030000003oool0oooo00D0oooo000B0?ooo`H00]HL=03oool200000280oooo1@02eQ`0
0`3oool00]HL00;F700<00;F70040?ooo`02eQ`00]HL0?ooo`L00]HL00<0oooo00;F7002eQ`00P02
eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HLNP3oool00`000000oooo0?oo
o`050?ooo`00503oool700;F7340oooo0P00000Q0?ooo`0300;F703oool00]HL01<00]HL00<0oooo
00;F7002eQ`01@02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00@0oooo
00;F7002eQ`00]HLO@3oool00`000000oooo0?ooo`050?ooo`005P3oool700;F72l0oooo0P00000O
0?oooaH00]HL00<0oooo00;F7002eQ`01@02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0
oooo00;F7002eQ`00P02eQao0?ooo`030000003oool0oooo00D0oooo000H0?ooo`P00]HL;03oool2
000001d0oooo7@02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00@0oooo
00;F7002eQ`00]HLPP3oool00`000000oooo0?ooo`050?ooo`006P3oool800;F72X0oooo0P00000K
0?oooa800]HL00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700600;F70030?ooo`02eQ`0
0]HL00800]HLQ03oool00`000000oooo0?ooo`050?ooo`00703oool900;F72L0oooo0P00000I0?oo
oa800]HL00@0oooo00;F7002eQ`0oooo2`02eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`0
0]HL00;F78L0oooo00<000000?ooo`3oool01@3oool001h0oooo2P02eQ`T0?ooo`8000005`3oool2
00;F70030?ooo`02eQ`00]HL00d00]HL00@0oooo00;F7002eQ`0oooo1P02eQ`00`3oool00]HL00;F
700600;F70030?ooo`02eQ`00]HL00800]HLR@3oool00`000000oooo0?ooo`050?ooo`007`3oool;
00;F7280oooo0P00000F0?ooo`0500;F703oool00]HL00;F703oool05P02eQ`01@3oool00]HL00;F
7002eQ`0oooo00@00]HL00@0oooo00;F7002eQ`00]HLS03oool00`000000oooo0?ooo`050?ooo`00
8@3oool<00;F71l0oooo0P00000D0?ooo`@00]HL00<0oooo00;F7002eQ`06002eQ`01@3oool00]HL
00;F7002eQ`0oooo00<00]HLS`3oool00`000000oooo0?ooo`050?ooo`008`3oool<00;F71d0oooo
0P00000B0?ooo`@00]HL00<0oooo00;F7002eQ`04`02eQ`00`3oool00]HL00;F700600;F70040?oo
o`02eQ`00]HL00;F7940oooo00<000000?ooo`3oool01@3oool002D0oooo3@02eQ`J0?ooo`800000
403oool@00;F70040?ooo`02eQ`00]HL0?ooo`H00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F
70040?ooo`02eQ`00]HL00;F79@0oooo00<000000?ooo`3oool01@3oool002L0oooo3P02eQ`G0?oo
o`8000003P3oool@00;F70040?ooo`02eQ`00]HL0?oooa800]HLUP3oool00`000000oooo0?ooo`05
0?ooo`00:@3oool>00;F71D0oooo0P00000=0?ooo`0300;F703oool00]HL01D00]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0300;F70040?ooo`02eQ`00]HL00;F79T0oooo00<000000?ooo`3oool01@3o
ool002/0oooo3`02eQ`B0?ooo`8000002`3ooolH00;F70030?ooo`02eQ`00]HL00T00]HLV`3oool0
0`000000oooo0?ooo`050?ooo`001`3oool3000000@0oooo0P00000L0?oooa000]HL403oool20000
00T0oooo6`02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL4@3oool3000000@0oooo0P00000j
0?ooo`D000000`3oool2000003/0oooo0`0000020?ooo`040000003oool00000000000@0oooo0008
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000007@3ooolA00;F70d0oooo0P00
00070?oooa400]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F700800;F71D0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000j0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000>@3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3o
ool00`000000oooo0?ooo`010?ooo`001@0000030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000007`3ooolA00;F70/0oooo0P0000050?oooaL00]HL00<0oooo00;F7002eQ`01002
eQ`0103oool00]HL00;F7002eQ`G0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000>`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000003d0oooo00@000000?oo
o`00000000000P3oool00`000000oooo0?ooo`010?ooo`00203oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000240oooo4P02eQ`80?ooo`800000103oool300;F70030?ooo`02eQ`0
0]HL00L00]HL00<0oooo00;F7002eQ`02@02eQ`00`3oool00]HL00;F700400;F71X0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000l0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0i0?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool0
0@3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000S0?oooa<00]HL
1@3oool200000080oooo5@02eQ`00`3oool00]HL00;F700400;F70040?ooo`02eQ`00]HL00;F71`0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000i0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`00000m0?ooo`040000003oool0000000000080oooo
00<000000?ooo`3oool00@3oool000L0oooo0P0000040?ooo`040000003oool0oooo000002D0oooo
4`02eQ`30?ooo`8000006002eQ`00`3oool00]HL00;F700400;F71h0oooo0P0000040?ooo`040000
003oool0oooo000003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000003T0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo00<000000?ooo`3oool0
0@3oool000P0oooo00<000000?ooo`3oool00`3oool2000002P0oooo5002eQ`00`0000000]HL00;F
700H00;F70040?ooo`02eQ`00]HL00;F7240oooo00<000000?ooo`3oool00`3oool2000003/0oooo
0`0000040?ooo`800000>`3oool300000080oooo00@000000?ooo`0000000000103oool003T0oooo
4`02eQ`00`0000000]HL00;F700?00;F70030?ooo`02eQ`00]HL00L00]HL/03oool00`000000oooo
0?ooo`050?ooo`00>`3ooolA00;F700300000002eQ`00]HL01<00]HL00<0oooo00;F7002eQ`0/`3o
ool00`000000oooo0?ooo`050?ooo`00?@3oool?00;F700300000002eQ`00]HL01@00]HL]@3oool0
0`000000oooo0?ooo`050?ooo`00?`3oool=00;F700300000002eQ`00]HL00P00]HL00<0oooo00;F
7002eQ`01P02eQbh0?ooo`030000003oool0oooo00D0oooo00110?ooo`/00]HL00<0000000;F7002
eQ`03`02eQbj0?ooo`030000003oool0oooo00D0oooo00020?oood4000002@02eQ`00`0000000]HL
00;F700>00;F7<<0000000090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3o
ool700;F700300000002eQ`00]HL01000]HL203oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00D0oooo00090?ooo`030000003oool0oooo03X0oooo1P02eQ`00`0000000]HL00;F700<
00;F70030?ooo`02eQ`00]HL00@00]HL;P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool01@3oool004P0oooo1002eQ`00`0000000]HL00;F700E00;F
7;@0oooo00<000000?ooo`3oool01@3oool004X0oooo0P02eQ`00`0000000]HL00;F700A00;F7003
0?ooo`02eQ`00]HL00@00]HL/@3oool00`000000oooo0?ooo`050?ooo`00B`3oool00`0000000]HL
00;F700L00;F7:h0oooo00<000000?ooo`3oool01@3oool004/0oooo0P00000?00;F70030?ooo`02
eQ`00]HL00H00]HL00<0oooo00;F7002eQ`01002eQb/0?ooo`030000003oool0oooo00D0oooo001<
0?ooo`80000000<0oooo00;F7002eQ`07P02eQbY0?ooo`030000003oool0oooo00D0oooo001<0?oo
o`8000000`3ooolQ00;F7:H0oooo00<000000?ooo`3oool01@3oool004`0oooo0P0000050?ooo`03
00;F703oool00]HL01h00]HLY03oool00`000000oooo0?ooo`050?ooo`00C03oool2000000H0oooo
8`02eQbQ0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000203ooolA00;F70030?ooo`02
eQ`00]HL00L00]HL00<0oooo00;F7002eQ`01P02eQbN0?ooo`030000003oool0oooo00D0oooo001<
0?ooo`8000002P3ooolT00;F79`0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00000<0?oo
oa`00]HL00<0oooo00;F7002eQ`01P02eQbI0?ooo`030000003oool0oooo00D0oooo001<0?ooo`80
00003P3ooolU00;F79L0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00000@0?oooa800]HL
00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700600;F79@0oooo00<000000?ooo`3oool0
1@3oool004`0oooo0P00000B0?ooo`0300;F703oool00]HL00l00]HL00<0oooo00;F7002eQ`04P02
eQbA0?ooo`030000003oool0oooo00D0oooo001<0?ooo`8000004`3ooolO00;F70030?ooo`02eQ`0
0]HL00H00]HLS`3oool00`000000oooo0?ooo`050?ooo`00C03oool2000001D0oooo:@02eQb<0?oo
o`030000003oool0oooo00D0oooo001<0?ooo`8000005`3ooolD00;F70030?ooo`02eQ`00]HL00T0
0]HL00<0oooo00;F7002eQ`01`02eQb90?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000
6@3oool:00;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`02@02eQ`00`3oool00]HL
00;F700700;F78L0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00000K0?ooo`L00]HL00@0
oooo00;F7002eQ`0oooo2@02eQ`00`3oool00]HL00;F700:00;F70030?ooo`02eQ`00]HL00L00]HL
Q03oool00`000000oooo0?ooo`050?ooo`00C03oool2000001d0oooo00<00]HL0?ooo`02eQ`01002
eQ`0103oool00]HL00;F703ooolF00;F70030?ooo`02eQ`00]HL00P00]HLP@3oool00`000000oooo
0?ooo`050?ooo`00C03oool2000001h0oooo0P02eQ`00`3oool00]HL00;F700300;F70040?ooo`02
eQ`00]HL0?oooaL00]HL00<0oooo00;F7002eQ`01`02eQao0?ooo`030000003oool0oooo00D0oooo
001<0?ooo`800000803oool800;F70040?ooo`02eQ`00]HL0?ooo`X00]HL00<0oooo00;F7002eQ`0
2P02eQ`00`3oool00]HL00;F700800;F77`0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00
000R0?ooo`P00]HL00@0oooo00;F7002eQ`0oooo2P02eQ`00`3oool00]HL00;F700;00;F70030?oo
o`02eQ`00]HL00L00]HLNP3oool00`000000oooo0?ooo`050?ooo`00C03oool2000002@0oooo2002
eQ`0103oool00]HL00;F703oool:00;F70030?ooo`02eQ`00]HL00/00]HL00<0oooo00;F7002eQ`0
2002eQag0?ooo`030000003oool0oooo00D0oooo001<0?ooo`8000009P3oool800;F70040?ooo`02
eQ`00]HL0?oooaT00]HL00<0oooo00;F7002eQ`02002eQad0?ooo`030000003oool0oooo00D0oooo
001<0?ooo`800000:03oool800;F70040?ooo`02eQ`00]HL0?ooo`/00]HL00<0oooo00;F7002eQ`0
2`02eQ`00`3oool00]HL00;F700800;F7780oooo00<000000?ooo`3oool01@3oool004`0oooo0P00
000Z0?ooo`0300;F703oool00]HL00D00]HL00@0oooo00;F7002eQ`0oooo2`02eQ`00`3oool00]HL
00;F700;00;F70030?ooo`02eQ`00]HL00T00]HLK`3oool00`000000oooo0?ooo`050?ooo`00C03o
ool2000002/0oooo0P02eQ`00`3oool00]HL00;F700400;F70040?ooo`02eQ`00]HL0?ooo`/00]HL
00<0oooo00;F7002eQ`03002eQ`00`3oool00]HL00;F700900;F76`0oooo00<000000?ooo`3oool0
1@3oool004`0oooo0P00000]0?ooo`T00]HL00@0oooo00;F7002eQ`0oooo6P02eQ`00`3oool00]HL
00;F700900;F76X0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00000_0?ooo`T00]HL00@0
oooo00;F7002eQ`0oooo3002eQ`00`3oool00]HL00;F700<00;F70030?ooo`02eQ`00]HL00T00]HL
I`3oool00`000000oooo0?ooo`050?ooo`00C03oool200000340oooo2@02eQ`0103oool00]HL00;F
703oool<00;F70030?ooo`02eQ`00]HL00`00]HL00<0oooo00;F7002eQ`02P02eQaT0?ooo`030000
003oool0oooo00D0oooo001<0?ooo`800000<`3oool900;F70040?ooo`02eQ`00]HL0?ooo``00]HL
00<0oooo00;F7002eQ`03@02eQ`00`3oool00]HL00;F700900;F7680oooo00<000000?ooo`3oool0
1@3oool004`0oooo0P00000e0?ooo`0300;F703oool00]HL00H00]HL00@0oooo00;F7002eQ`0oooo
3002eQ`00`3oool00]HL00;F700=00;F70030?ooo`02eQ`00]HL00X00]HLG`3oool00`000000oooo
0?ooo`050?ooo`00C03oool2000003H0oooo0P02eQ`00`3oool00]HL00;F700500;F70040?ooo`02
eQ`00]HL0?oooad00]HL00<0oooo00;F7002eQ`02@02eQaM0?ooo`030000003oool0oooo00D0oooo
001<0?ooo`800000>03oool200;F70030?ooo`02eQ`00]HL00D00]HL00@0oooo00;F7002eQ`0oooo
3@02eQ`00`3oool00]HL00;F700=00;F70030?ooo`02eQ`00]HL00X00]HLFP3oool00`000000oooo
0?ooo`050?ooo`00C03oool2000003X0oooo0P02eQ`00`3oool00]HL00;F700500;F70040?ooo`02
eQ`00]HL0?ooo`d00]HL00<0oooo00;F7002eQ`03P02eQ`00`3oool00]HL00;F700:00;F75L0oooo
00<000000?ooo`3oool01@3oool004`0oooo0P00000l0?ooo`X00]HL00@0oooo00;F7002eQ`0oooo
3@02eQ`00`3oool00]HL00;F700>00;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`0
E@3oool00`000000oooo0?ooo`050?ooo`00C03oool2000003h0oooo2P02eQ`0103oool00]HL00;F
703oool=00;F70030?ooo`02eQ`00]HL00h00]HL0P3oool<00;F7580oooo00<000000?ooo`3oool0
1@3oool004`0oooo0P0000100?ooo`X00]HL00@0oooo00;F7002eQ`0oooo3P02eQ`00`3oool00]HL
00;F700>00;F70030?ooo`02eQ`00]HL00L00]HL00@0oooo00;F7002eQ`00]HLC`3oool00`000000
oooo0?ooo`050?ooo`00C03oool200000480oooo00<00]HL0?ooo`02eQ`01`02eQ`0103oool00]HL
00;F703oool>00;F70030?ooo`02eQ`00]HL00X00]HL00@0oooo00;F7002eQ`00]HL0P3oool900;F
70030?ooo`02eQ`00]HL04d0oooo00<000000?ooo`3oool01@3oool004`0oooo0P0000130?ooo`80
0]HL00<0oooo00;F7002eQ`01P02eQ`0103oool00]HL00;F703oool>00;F70030?ooo`02eQ`00]HL
00l00]HL00<0oooo00;F7002eQ`02`02eQa:0?ooo`030000003oool0oooo00D0oooo001<0?ooo`80
0000A@3oool200;F70030?ooo`02eQ`00]HL00H00]HL00@0oooo00;F7002eQ`0oooo3P02eQ`00`3o
ool00]HL00;F700?00;F7080oooo2@02eQ`0103oool00]HL00;F7002eQa70?ooo`030000003oool0
oooo00D0oooo001<0?ooo`800000A`3oool200;F70030?ooo`02eQ`00]HL00H00]HL00@0oooo00;F
7002eQ`0oooo3P02eQ`20?ooo``00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F7002
00;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`0A@3oool00`000000oooo0?ooo`05
0?ooo`00C03oool2000004T0oooo2`02eQ`0103oool00]HL00;F703oool?00;F70030?ooo`02eQ`0
0]HL00l00]HL0P3oool900;F70040?ooo`02eQ`00]HL00;F7480oooo00<000000?ooo`3oool01@3o
ool004`0oooo0P00001;0?ooo`/00]HL00@0oooo00;F7002eQ`0oooo3`02eQ`01@3oool00]HL00;F
7002eQ`0oooo00T00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70030?oo
o`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`0@03oool00`000000oooo0?ooo`050?ooo`00C03o
ool2000004d0oooo00<00]HL0?ooo`02eQ`02002eQ`0103oool00]HL00;F703oool?00;F70030?oo
o`02eQ`00]HL00H00]HL00<0oooo00;F7002eQ`01`02eQ`00`3oool00]HL00;F700800;F70040?oo
o`02eQ`00]HL00;F73d0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00001>0?ooo`800]HL
00<0oooo00;F7002eQ`01`02eQ`0103oool00]HL00;F703oool?00;F70030?ooo`02eQ`00]HL0100
0]HL0P3oool400;F70030?ooo`02eQ`00]HL00<00]HL00@0oooo00;F7002eQ`00]HL>P3oool00`00
0000oooo0?ooo`050?ooo`00C03oool200000500oooo0P02eQ`00`3oool00]HL00;F700700;F7004
0?ooo`02eQ`00]HL0?ooo`l00]HL0P3oool800;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F
7002eQ`00P02eQ`00`3oool00]HL00;F700900;F70030?ooo`02eQ`00]HL03P0oooo00<000000?oo
o`3oool01@3oool004`0oooo0P00001B0?ooo`800]HL00<0oooo00;F7002eQ`01`02eQ`0103oool0
0]HL00;F703oool@00;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`00`3oool00]HL00;F7007
00;F7080oooo1002eQ`00`3oool00]HL00;F700300;F70040?ooo`02eQ`00]HL00;F73D0oooo00<0
00000?ooo`3oool01@3oool003h0oooo0`0000040?ooo`8000001@3oool2000005@0oooo0P02eQ`0
0`3oool00]HL00;F700700;F70040?ooo`02eQ`00]HL0?oooa000]HL00<0oooo00;F7002eQ`03002
eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00`02
eQ`0103oool00]HL00;F7002eQ`b0?ooo`030000003oool0oooo00D0oooo000o0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool2000005H0oooo3002eQ`01@3oool00]HL
00;F7002eQ`0oooo00/00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0900;F70030?ooo`02eQ`00]HL
00800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00`02eQ`20?oo
o`800]HL<03oool00`000000oooo0?ooo`050?ooo`00?`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo0`00001G0?ooo``00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0;
00;F70040?ooo`02eQ`00]HL00;F7080oooo0`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02
eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700300;F70030?ooo`02
eQ`00]HL00<00]HL00@0oooo00;F7002eQ`00]HL;@3oool00`000000oooo0?ooo`050?ooo`00?`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P00001J0?ooo`0300;F
703oool00]HL00d00]HL00<0oooo00;F7002eQ`03@02eQ`20?ooo`<00]HL00<0oooo00;F7002eQ`0
2002eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700300;F7080oooo
0`02eQ`Z0?ooo`030000003oool0oooo00D0oooo000o0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool2000005/0oooo0P02eQ`00`3oool00]HL00;F700700;F70030?oo
o`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`03P02eQ`00`3oool00]HL00;F700700;F70030?oo
o`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F700300;F70030?oo
o`02eQ`00]HL00<00]HL0P3oool200;F72P0oooo00<000000?ooo`3oool01@3oool003h0oooo0P00
00040?ooo`040000003oool0oooo000000@0oooo0P00001M0?ooo`800]HL00<0oooo00;F7002eQ`0
1`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00D00]HL00<0oooo00;F7002eQ`0
1P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`0
0`02eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700400;F70040?oo
o`02eQ`00]HL00;F72D0oooo00<000000?ooo`3oool01@3oool003l0oooo00<000000?ooo`3oool0
0`3oool2000000D0oooo0P00001O0?ooo`800]HL00<0oooo00;F7002eQ`01`02eQ`00`3oool00]HL
00;F700200;F70030?ooo`02eQ`00]HL00D00]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL
00;F7002eQ`20?ooo`<00]HL00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700200;F7080
oooo1@02eQ`00`3oool00]HL00;F700300;F7080oooo0P02eQ`S0?ooo`030000003oool0oooo00D0
oooo001<0?ooo`800000H@3oool200;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`0
0P02eQ`00`3oool00]HL00;F700500;F70030?ooo`02eQ`00]HL00800]HL00@0oooo00;F7002eQ`0
0]HL0P3oool300;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool0
0]HL00;F700200;F7080oooo1002eQ`20?ooo`D00]HL00@0oooo00;F7002eQ`00]HL803oool00`00
0000oooo0?ooo`050?ooo`00C03oool2000006<0oooo0P02eQ`00`3oool00]HL00;F700700;F7003
0?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`02P02eQ`0103oool00]HL00;F7002eQ`20?oo
o`@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`00]HL
00800]HL0P3oool500;F70030?ooo`02eQ`00]HL00<00]HL0P3oool300;F71d0oooo00<000000?oo
o`3oool01@3oool004`0oooo0P00001U0?ooo`0300;F703oool00]HL00T00]HL00<0oooo00;F7002
eQ`00P02eQ`00`3oool00]HL00;F700:00;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002
eQ`00P02eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700300;F7080
oooo1002eQ`20?ooo`D00]HL0P3oool200;F71/0oooo00<000000?ooo`3oool01@3oool004`0oooo
0P00001V0?ooo`800]HL00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700200;F70050?oo
o`02eQ`00]HL00;F703oool03@02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00<0
0]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F700200;F7080oooo1@02eQ`00`3oool0
0]HL00;F700300;F7080oooo0`02eQ`H0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000
J03oool200;F70030?ooo`02eQ`00]HL00P00]HL00<0oooo00;F7002eQ`00P02eQ`01@3oool00]HL
00;F7002eQ`0oooo00d00]HL0P3oool300;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002
eQ`00`02eQ`00`3oool00]HL00;F700300;F7080oooo1002eQ`20?ooo`D00]HL0P3oool300;F71D0
oooo00<000000?ooo`3oool01@3oool004`0oooo0P00001Z0?ooo`800]HL00<0oooo00;F7002eQ`0
2002eQ`00`3oool00]HL00;F700200;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`00`3oool0
0]HL00;F700200;F70040?ooo`02eQ`00]HL00;F7080oooo1002eQ`00`3oool00]HL00;F700200;F
7080oooo1002eQ`20?ooo`@00]HL0P3oool500;F70030?ooo`02eQ`00]HL00@00]HL0P3oool200;F
71<0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00001/0?ooo`800]HL00<0oooo00;F7002
eQ`02002eQ`00`3oool00]HL00;F700200;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`00`3o
ool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`00`3o
ool00]HL00;F700300;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`20?oo
o`@00]HL0P3oool500;F7080oooo0`02eQ`@0?ooo`030000003oool0oooo00D0oooo001<0?ooo`80
0000KP3oool200;F70030?ooo`02eQ`00]HL00P00]HL00<0oooo00;F7002eQ`00P02eQ`01@3oool0
0]HL00;F7002eQ`0oooo00@00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F
70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F700300;F
7080oooo1002eQ`20?ooo`D00]HL0P3oool500;F7080oooo0`02eQ`=0?ooo`030000003oool0oooo
00D0oooo001<0?ooo`800000L03oool00`02eQ`0oooo0?ooo`0200;F70030?ooo`02eQ`00]HL00D0
0]HL00<0oooo00;F7002eQ`00P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0oooo00;F
7002eQ`00P02eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700200;F
7080oooo1002eQ`20?ooo`@00]HL0`3oool400;F7080oooo1@02eQ`30?ooo`800]HL2`3oool00`00
0000oooo0?ooo`050?ooo`00C03oool200000740oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo
00L00]HL00<0oooo00;F7002eQ`00P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0oooo
00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F7003
00;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`D00]HL0P3oool5
00;F7080oooo0`02eQ`80?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000L`3oool200;F
70050?ooo`02eQ`00]HL00;F703oool00`02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00D0
oooo00;F7002eQ`00]HL0?ooo`0400;F70030?ooo`02eQ`00]HL00<00]HL00@0oooo00;F7002eQ`0
0]HL0P3oool400;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`@0
0]HL0P3oool500;F7080oooo1@02eQ`30?ooo`800]HL1P3oool00`000000oooo0?ooo`050?ooo`00
C03oool2000007D0oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL00D0oooo00;F7002
eQ`00]HL0?ooo`0400;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`00`3oool00]HL00;F7003
00;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool4
00;F7080oooo1@02eQ`20?ooo`D00]HL0P3oool500;F7080oooo0`02eQ`30?ooo`030000003oool0
oooo00D0oooo001<0?ooo`800000M`3oool200;F70030?ooo`02eQ`00]HL00D00]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0400;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`00P02eQ`0
0`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`0
0]HL00<00]HL0P3oool400;F7080oooo1@02eQ`20?ooo`H00]HL0P3oool300;F70030000003oool0
oooo00D0oooo001<0?ooo`800000N@3oool200;F70030?ooo`02eQ`00]HL00D00]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0400;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`00P02eQ`0
0`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`0
0]HL00<00]HL0P3oool500;F7080oooo1@02eQ`20?ooo`D00]HL0P3oool2000000L0oooo001<0?oo
o`800000N`3oool200;F70030?ooo`02eQ`00]HL00D00]HL00D0oooo00;F7002eQ`00]HL0?ooo`04
00;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F7002
00;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F7080oooo1002eQ`20?ooo`D00]HL00<0oooo
00;F7002eQ`00`02eQ`20?ooo`D00]HL0`3oool400;F708000001`3oool004`0oooo0P00001m0?oo
o`0300;F703oool0oooo00L00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0400;F70030?ooo`02eQ`0
0]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`0
0]HL00800]HL0P3oool400;F7080oooo1002eQ`20?ooo`D00]HL0P3oool500;F7080oooo1@02eQ`2
0?ooo`<00]HL00<000000?ooo`3oool01@3oool004`0oooo0P00001n0?ooo`800]HL00<0oooo00;F
7002eQ`01P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0oooo00;F7002eQ`00P02eQ`0
0`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F70030?ooo`02eQ`0
0]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`@00]HL0P3oool500;F7080oooo1@02eQ`2
0?ooo`8000001`3oool004`0oooo0P0000200?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`04
00;F70050?ooo`02eQ`00]HL00;F703oool01002eQ`00`3oool00]HL00;F700200;F70030?ooo`02
eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool400;F70030?ooo`02
eQ`00]HL00<00]HL0P3oool500;F7080oooo1002eQ`30?ooo`@00]HL0P0000070?ooo`00C03oool2
00000880oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00D0oooo00;F7002eQ`00]HL
0?ooo`0400;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL
00;F700300;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F7080oooo1002eQ`20?ooo`D00]HL
0P3oool500;F7080oooo0`02eQ`00`000000oooo0?ooo`050?ooo`00C03oool2000008@0oooo0P02
eQ`01@3oool00]HL00;F7002eQ`0oooo00P00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL
00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL
00;F700200;F7080oooo1002eQ`20?ooo`D00]HL0P3oool400;F70<0oooo1002eQ`20?ooo`800000
1`3oool004`0oooo0P0000260?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0800;F70030?oo
o`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F7080oooo
1002eQ`00`3oool00]HL00;F700200;F7080oooo1@02eQ`00`3oool00]HL00;F700300;F7080oooo
1@02eQ`20?ooo`@00]HL0P0000070?ooo`00C03oool2000008P0oooo00<00]HL0?ooo`3oool00`02
eQ`00`3oool00]HL00;F700600;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02
eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`20?ooo`@00]HL0P3oool400;F7080oooo1002
eQ`20?ooo`D00]HL0P3oool300;F70030000003oool0oooo00D0oooo001<0?ooo`800000R@3oool2
00;F7080oooo0`02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0oooo00;F7002eQ`00P02
eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F7080oooo1002
eQ`20?ooo`@00]HL0P3oool500;F7080oooo1002eQ`20?ooo`8000001`3oool004`0oooo0P00002;
0?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0
oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00<00]HL00<0
oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool400;F7080oooo1@02eQ`20?ooo`@00]HL0P00
00070?ooo`00C03oool2000008d0oooo0P02eQ`00`3oool00]HL00;F700600;F70030?ooo`02eQ`0
0]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`0
0]HL00<00]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool500;F7080oooo1002eQ`2
0?ooo`<00]HL00<000000?ooo`3oool01@3oool004`0oooo0P00002?0?ooo`800]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0400;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`0
0`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00]HL00;F700300;F70030?ooo`02eQ`0
0]HL00800]HL0`3oool400;F7080oooo1@02eQ`00`3oool00000000000070?ooo`00C03oool20000
0940oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0oooo00;F7002eQ`00P02eQ`0
0`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL0P3oool400;F70030?ooo`02eQ`0
0]HL00<00]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`@00]HL0P3oool400;F708000001`3oool0
04`0oooo0P00002C0?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0400;F70030?ooo`02eQ`0
0]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`<00]HL0P3oool400;F7080oooo1002eQ`2
0?ooo`@00]HL0P3oool400;F70<0oooo0P02eQ`00`000000oooo0?ooo`050?ooo`00C03oool20000
09D0oooo00<00]HL0?ooo`3oool00`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL
00800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`<00]HL0P3oool400;F7080oooo1002eQ`20?oo
o`@00]HL0P3oool500;F70030?ooo`000000000000L0oooo001<0?ooo`800000UP3oool200;F7080
oooo0`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002
eQ`00P02eQ`20?ooo`<00]HL0P3oool400;F7080oooo1002eQ`20?ooo`@00]HL0P3oool400;F7080
00001`3oool004`0oooo0P00002H0?ooo`800]HL0P3oool300;F70030?ooo`02eQ`00]HL00800]HL
00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F7080oooo0`02eQ`20?ooo`@00]HL
0P3oool400;F7080oooo1002eQ`30?ooo`800]HL00<000000?ooo`3oool01@3oool004`0oooo0P00
002J0?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02
eQ`00]HL00;F7080oooo1002eQ`20?ooo`<00]HL0P3oool400;F7080oooo1002eQ`20?ooo`D00]HL
00<0oooo0000000000001`3oool004`0oooo0P00002L0?ooo`800]HL00<0oooo00;F7002eQ`00P02
eQ`00`3oool00]HL00;F700200;F70040?ooo`02eQ`00]HL00;F7080oooo1002eQ`20?ooo`@00]HL
00<0oooo00;F7002eQ`00P02eQ`20?ooo`D00]HL0P3oool300;F708000001`3oool004`0oooo0P00
002N0?ooo`800]HL00@0oooo00;F7002eQ`00]HL0P3oool300;F7080oooo0`02eQ`20?ooo`@00]HL
0P3oool400;F70030?ooo`02eQ`00]HL00800]HL0P3oool500;F7080oooo0P02eQ`00`000000oooo
0?ooo`050?ooo`00C03oool200000:00oooo00<00]HL0?ooo`3oool00`02eQ`20?ooo`<00]HL0P3o
ool300;F7080oooo1002eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00`02eQ`20?ooo`@00]HL00<0
oooo0000000000001`3oool004`0oooo0P00002Q0?ooo`800]HL0P3oool300;F70030?ooo`02eQ`0
0]HL00800]HL0P3oool300;F7080oooo1002eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00`02eQ`2
0?ooo`<00]HL0P0000070?ooo`00C03oool200000:<0oooo0P02eQ`20?ooo`<00]HL00<0oooo00;F
7002eQ`00P02eQ`20?ooo`<00]HL0P3oool400;F7080oooo1002eQ`20?ooo`@00]HL0P3oool200;F
70030000003oool0oooo00D0oooo001<0?ooo`800000Y@3oool200;F7080oooo0`02eQ`00`3oool0
0]HL00;F700200;F7080oooo0`02eQ`20?ooo`@00]HL0P3oool400;F7080oooo1002eQ`00`3oool0
0000000000070?ooo`00C03oool200000:L0oooo0P02eQ`00`3oool00]HL00;F700200;F70030?oo
o`02eQ`00]HL00800]HL0P3oool300;F7080oooo1002eQ`20?ooo`@00]HL0P3oool300;F70800000
1`3oool004`0oooo0P00002Y0?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F
700200;F7080oooo0`02eQ`20?ooo`@00]HL0P3oool400;F7080oooo0P02eQ`00`000000oooo0?oo
o`050?ooo`00C03oool200000:/0oooo0P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`0
0]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool400;F70030?ooo`000000
000000L0oooo001<0?ooo`800000[@3oool00`02eQ`0oooo0?ooo`0400;F70030?ooo`02eQ`00]HL
00800]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`@00]HL0P3oool300;F708000001`3oool004`0
oooo0P00002^0?ooo`800]HL0P3oool300;F7080oooo1002eQ`00`3oool00]HL00;F700200;F7080
oooo1002eQ`20?ooo`800]HL00<000000?ooo`3oool01@3oool004`0oooo0P00002`0?ooo`800]HL
0P3oool300;F7080oooo1002eQ`00`3oool00]HL00;F700200;F7080oooo1002eQ`00`3oool00000
000000070?ooo`00C03oool200000;80oooo0P02eQ`20?ooo`<00]HL0P3oool400;F70030?ooo`02
eQ`00]HL00800]HL0P3oool300;F708000001`3oool004`0oooo0P00002d0?ooo`800]HL00<0oooo
00;F7002eQ`00P02eQ`20?ooo`<00]HL0P3oool400;F7080oooo0P02eQ`00`000000oooo0?ooo`05
0?ooo`00C03oool200000;H0oooo0P02eQ`00`3oool00]HL00;F700200;F7080oooo0`02eQ`20?oo
o`@00]HL00<0oooo0000000000001`3oool003d0oooo1@0000030?ooo`8000001@3oool200000;P0
oooo00<00]HL0?ooo`3oool01002eQ`00`3oool00]HL00;F700200;F7080oooo0`02eQ`2000000L0
oooo000n0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool20000
0;T0oooo0P02eQ`20?ooo`@00]HL00<0oooo00;F7002eQ`00P02eQ`20?ooo`800]HL00<000000?oo
o`3oool01@3oool003l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`<00000^P3oool200;F7080oooo1002eQ`00`3oool00]HL00;F700200;F70030?ooo`0000000000
00L0oooo00100?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`800000_@3oool200;F7080oooo0`02eQ`20?ooo`<00]HL0P0000070?ooo`00?@3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000103oool200000;l0oooo0P02eQ`2
0?ooo`<00]HL0P3oool200;F70030000003oool0oooo00D0oooo000m0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`800000`@3oool200;F70030?ooo`02
eQ`00]HL00800]HL00<0oooo0000000000001`3oool003h0oooo0`0000040?ooo`8000001@3oool2
00000<<0oooo0P02eQ`0103oool00]HL00;F7002eQ`2000000L0oooo001<0?ooo`800000a@3oool0
0`02eQ`0oooo0?ooo`0200;F70030000003oool0oooo00D0oooo001<0?ooo`800000aP3oool200;F
70030?ooo`000000000000L0oooo001<0?ooo`800000b03oool00`02eQ`00000000000070?ooo`00
C03oool200000<T0oooo0P0000070?ooo`00C03oool200000<X0oooo00<000000?ooo`3oool01@3o
ool004`0oooo0P00003:0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000bP3oool00`00
0000oooo0?ooo`050?ooo`00C03oool200000<X0oooo00<000000?ooo`3oool01@3oool004`0oooo
0P00003:0?ooo`030000003oool0oooo00D0oooo001<0?ooo`800000bP3oool00`000000oooo0?oo
o`050?ooo`00C03oool200000<X0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00003:0?oo
o`030000003oool0oooo00D0oooo001<0?ooo`800000bP3oool00`000000oooo0?ooo`050?ooo`00
C03oool200000<X0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00003:0?ooo`030000003o
ool0oooo00D0oooo001<0?ooo`800000bP3oool00`000000oooo0?ooo`050?ooo`00C03oool20000
0<X0oooo00<000000?ooo`3oool01@3oool004`0oooo0P00003:0?ooo`030000003oool0oooo00D0
oooo001<0?ooo`800000bP3oool00`000000oooo0?ooo`050?ooo`00C03oool200000<X0oooo00<0
00000?ooo`3oool01@3oool004`0oooo0P00003:0?ooo`030000003oool0oooo00D0oooo001<0?oo
o`800000bP3oool00`000000oooo0?ooo`050?ooo`00C03oool200000<X0oooo00<000000?ooo`3o
ool01@3oool004`0oooo0P00003:0?ooo`030000003oool0oooo00D0oooo001<0?ooo`030000003o
ool0oooo0=40oooo001<0?ooo`030000003oool0oooo0=40oooo001<0?ooo`030000003oool0oooo
0=40oooo001<0?ooo`030000003oool0oooo0=40oooo001<0?ooo`800000dP3oool004`0oooo00<0
00000?ooo`3oool0d@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-11.3276, -26.4549, 0.147484, \
0.184354}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ListPlot[
\tReadRays[turbotracedsystem,{ArcCos[RayTilt.{1,0,0}]/Degree,Intensity}, \
ComponentNumber->3]
];\
\>", "Input",
  CellLabel->"In[26]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.84688 0.11019 0.0147151 0.00605889 [
[.23843 .00222 -6 -9 ]
[.23843 .00222 6 0 ]
[.45881 .00222 -6 -9 ]
[.45881 .00222 6 0 ]
[.67919 .00222 -6 -9 ]
[.67919 .00222 6 0 ]
[.89957 .00222 -6 -9 ]
[.89957 .00222 6 0 ]
[.00555 .13589 -12 -4.5 ]
[.00555 .13589 0 4.5 ]
[.00555 .25707 -12 -4.5 ]
[.00555 .25707 0 4.5 ]
[.00555 .37825 -12 -4.5 ]
[.00555 .37825 0 4.5 ]
[.00555 .49943 -12 -4.5 ]
[.00555 .49943 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23843 .01472 m
.23843 .02097 L
s
[(28)] .23843 .00222 0 1 Mshowa
.45881 .01472 m
.45881 .02097 L
s
[(30)] .45881 .00222 0 1 Mshowa
.67919 .01472 m
.67919 .02097 L
s
[(32)] .67919 .00222 0 1 Mshowa
.89957 .01472 m
.89957 .02097 L
s
[(34)] .89957 .00222 0 1 Mshowa
.125 Mabswid
.07314 .01472 m
.07314 .01847 L
s
.12824 .01472 m
.12824 .01847 L
s
.18333 .01472 m
.18333 .01847 L
s
.29352 .01472 m
.29352 .01847 L
s
.34862 .01472 m
.34862 .01847 L
s
.40371 .01472 m
.40371 .01847 L
s
.5139 .01472 m
.5139 .01847 L
s
.569 .01472 m
.569 .01847 L
s
.62409 .01472 m
.62409 .01847 L
s
.73428 .01472 m
.73428 .01847 L
s
.78938 .01472 m
.78938 .01847 L
s
.84447 .01472 m
.84447 .01847 L
s
.95466 .01472 m
.95466 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.01805 .13589 m
.0243 .13589 L
s
[(20)] .00555 .13589 1 0 Mshowa
.01805 .25707 m
.0243 .25707 L
s
[(40)] .00555 .25707 1 0 Mshowa
.01805 .37825 m
.0243 .37825 L
s
[(60)] .00555 .37825 1 0 Mshowa
.01805 .49943 m
.0243 .49943 L
s
[(80)] .00555 .49943 1 0 Mshowa
.125 Mabswid
.01805 .04501 m
.0218 .04501 L
s
.01805 .0753 m
.0218 .0753 L
s
.01805 .1056 m
.0218 .1056 L
s
.01805 .16619 m
.0218 .16619 L
s
.01805 .19648 m
.0218 .19648 L
s
.01805 .22678 m
.0218 .22678 L
s
.01805 .28736 m
.0218 .28736 L
s
.01805 .31766 m
.0218 .31766 L
s
.01805 .34795 m
.0218 .34795 L
s
.01805 .40854 m
.0218 .40854 L
s
.01805 .43884 m
.0218 .43884 L
s
.01805 .46913 m
.0218 .46913 L
s
.01805 .52972 m
.0218 .52972 L
s
.01805 .56001 m
.0218 .56001 L
s
.01805 .59031 m
.0218 .59031 L
s
.25 Mabswid
.01805 0 m
.01805 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.97619 .02928 Mdot
.93751 .03921 Mdot
.89929 .0343 Mdot
.86155 .01964 Mdot
.82426 .01604 Mdot
.78742 .03735 Mdot
.75103 .0709 Mdot
.71508 .08524 Mdot
.67956 .06209 Mdot
.64446 .02322 Mdot
.60979 .02354 Mdot
.57553 .11069 Mdot
.54168 .28222 Mdot
.50823 .47586 Mdot
.47518 .60317 Mdot
.44253 .60332 Mdot
.41026 .47933 Mdot
.37837 .29304 Mdot
.34687 .12558 Mdot
.31573 .03174 Mdot
.28496 .01711 Mdot
.25455 .04753 Mdot
.22451 .0787 Mdot
.19481 .08372 Mdot
.16546 .06288 Mdot
.13646 .03434 Mdot
.1078 .01676 Mdot
.07947 .01674 Mdot
.05148 .0277 Mdot
.02381 .03771 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{556.5, 343.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008/0001Eb000`400?l00000o`00003oo`3ooooo
0?ooobh0oooo00260?ooo`D000000P3oool3000006h0oooo0`0000040?ooo`800000K`3oool30000
0080oooo1@00001]0?ooo`<00000103oool3000003D0oooo00270?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`1Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`00001]0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00001/0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0d
0?ooo`00R03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0KP3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo06l0oooo00D000000?ooo`3oool0oooo
0000001b0?ooo`030000003oool0000000@00000=@3oool008T0oooo00@000000?ooo`3oool0oooo
0`00001_0?ooo`8000000`3oool010000000oooo0?ooo`00001_0?ooo`8000001@3oool00`000000
oooo0?ooo`1]0?ooo`8000000P3oool010000000oooo0?ooo`00000f0?ooo`00QP3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`1^0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0K`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo06h0oooo00H000000?ooo`3oool000000?ooo`00000f0?ooo`00QP3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`1Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`00001]0?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo06X0oooo00D000000?ooo`3oool0oooo000000030?oo
o`800000=P3oool001@0oooo00<000000?ooo`3oool0L03oool3000000<0oooo0`00001^0?ooo`<0
0000103oool2000006l0oooo0`0000030?ooo`<00000KP3oool3000000D0oooo00<000000?ooo`3o
ool0=03oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000;0?ooool00000o`00000Q00000080oooo000D0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`0000000`00000;0?ooo`@000002@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool40000
0080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool03P3oool4000000T0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01T0oooo000D0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`0000000`00000;0?ooo`@000002@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool400000080oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool03P3oool4000000T0oooo00<000000?ooo`3oool01@3oool2000001<0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0I0?ooo`00503oool00`000000oooo0?ooo`0N0?ooo`800000
3@3oool2000004H0oooo00<000000?ooo`3oool05P3oool2000005`0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`1;0?ooo`8000004@3oool400000180oooo00<000000?ooo`3oool0
=`3oool001@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo04l0oooo0P00000@0?ooo`8000004P3oool00`000000oooo0?ooo`1N0?ooo`@000004P3o
ool00`000000oooo0?ooo`0g0?ooo`00503oool00`000000oooo0?ooo`3o0?oooch0oooo1000000>
0?ooo`@00000L`3oool2000004d0oooo000D0?ooo`030000003oool0oooo00l0oooo0P00003o0?oo
obd0oooo1000000>0?ooo`@00000`P3oool001@0oooo00<000000?ooo`3oool03P3oool400000?l0
oooo;@3oool200000100oooo0P00002b0?ooo`8000003`3oool001@0oooo00<000000?ooo`3oool0
3P3oool4000008`0oooo0P00003o0?ooof@0oooo1000000>0?ooo`00503oool00`000000oooo0?oo
o`0?0?ooo`800000S03oool400000?l0ooooH`3oool4000000h0oooo000D0?ooo`030000003oool0
oooo03d0oooo0P00001N0?ooo`@00000o`3ooolk0?ooo`8000009`3oool2000000l0oooo000D0?oo
o`030000003oool0oooo00800000>P3oool4000005h0oooo0P00003n0?ooo`800000>P3oool40000
03L0oooo000D0?ooo`030000003oool0000000<00000>@3oool400000?l0ooooGP3oool4000003T0
oooo1000000A0?ooo`800000903oool001@0oooo00<000000?ooo`0000000`00000j0?ooo`800000
o`3ooomO0?ooo`@00000>P3oool200000140oooo1000000S0?ooo`00503oool00`000000oooo0?oo
o`0200000?l0ooooW@3oool2000004h0oooo1000000S0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooo00oooo0P00000T0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo0`00001m0?ooo`800000o`3ooonG0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`@00000
o`3ooonF0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`@00000o`3ooonF0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`800000o`3ooonG0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000
003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3o
ool001@0oooo00<000000?ooo`3oool0C@3oool200000?l0oooo5@3oool200000;00oooo000D0?oo
o`030000003oool0oooo04`0oooo1000003o0?oooa<0oooo1000002_0?ooo`00503oool00`000000
oooo0?ooo`1<0?ooo`@00000o`3ooolC0?ooo`@00000[`3oool001@0oooo00<000000?ooo`3oool0
C@3oool200000?l0oooo5@3oool200000;00oooo000D0?ooo`030000003oool0oooo0?l0ooooR`3o
ool2000008T0oooo000D0?ooo`030000003oool0oooo0?l0ooooRP3oool4000008P0oooo000D0?oo
o`030000003oool0oooo0?l0ooooRP3oool4000008P0oooo000D0?ooo`030000003oool0oooo0?l0
ooooR`3oool2000008T0oooo000D0?ooo`<00000o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo06d0oooo0P00003o0?ooojL0oooo000D0?ooo`030000003oool0oooo06`0oooo1000003o
0?ooojH0oooo000D0?ooo`030000003oool0oooo05d0oooo0P00000=0?ooo`@00000o`3ooonV0?oo
o`00503oool00`000000oooo0?ooo`1L0?ooo`@000003@3oool200000?l0oooo2@3oool2000009`0
oooo000D0?ooo`030000003oool0oooo05`0oooo1000003o0?oooaL0oooo1000002K0?ooo`00503o
ool00`000000oooo0?ooo`1M0?ooo`800000o`3ooolH0?ooo`@00000V`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooomh0?ooo`800000W03oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D
0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000
003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3o
ool001@0oooo0`00003o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3oool/0?oo
o`800000j03oool001@0oooo00<000000?ooo`3oool0o`3oool[0?ooo`@00000i`3oool001@0oooo
00<000000?ooo`3oool0o`3oool[0?ooo`@00000i`3oool001@0oooo00<000000?ooo`3oool0o`3o
ool/0?ooo`800000j03oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0:l0oooo0P00003o0?ooofD0oooo000D0?ooo`030000003oool0oooo0:h0oooo1000003o
0?ooof@0oooo000D0?ooo`030000003oool0oooo0:h0oooo1000003o0?ooof@0oooo000D0?ooo`03
0000003oool0oooo0:l0oooo0P00003o0?ooofD0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`000P3oool5000000<0oooo0P0000080?ooo`030000003oool0oooo0?l0ooooo`3o
oolG0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo00040?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000001`3oool500000?l0ooooo`3ooolE0?ooo`001@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool00080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo00020?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`000`3oool3000000@0oooo0P0000080?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00
503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0
oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?oo
o`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`<00000o`3o
oooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0
oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?oo
o`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`00503oool300000?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool300000?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000
oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo
000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooool0oooo5`3oool000@0oooo0`0000030?ooo`800000203oool00`000000oooo0?ooo`3o0?oo
ool0oooo5`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo00020?ooo`D000000P3oool010000000
oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`000P3oool010000000
oooo0?ooo`0000030?ooo`040000003oool0oooo000000L0oooo1@00003o0?ooool0oooo5@3oool0
00<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo0?l0ooooo`3ooolG0?ooo`00103oool2000000<0oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool000D0oooo00<000000?ooo`3oool00P3oool20000
00P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooolJ
0?ooo`800000nP3oool001@0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`@00000n@3oool001@0
oooo00<000000?ooo`3oool0o`3ooolI0?ooo`@00000n@3oool001@0oooo00<000000?ooo`3oool0
o`3ooolJ0?ooo`800000nP3oool001@0oooo0`00003o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0<00oooo0P00003o0?oo
oe@0oooo000D0?ooo`030000003oool0oooo0;l0oooo1000003o0?oooe<0oooo000D0?ooo`030000
003oool0oooo0;l0oooo1000003o0?oooe<0oooo000D0?ooo`030000003oool0oooo0<00oooo0P00
003o0?oooe@0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0
oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?oo
o`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
01@0oooo0`00003o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0
oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?oo
o`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo0`00003o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaL0oooo00030?ooo`<00000103oool2000000P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo00020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000001`3oool500000?l0ooooo`3ooolE0?ooo`000P3oool4
000000<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`3o0?ooool0oooo5`3o
ool00080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo00040?ooo`800000103oool2
000000P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo
0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3o
oolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00
503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0
oooo000D0?ooo`<00000o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3o
oolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00
503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0
oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?oo
o`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`<00000o`3o
oooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0
oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?oo
o`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`00503oool300000?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3oool80?ooo`800000o`3oool=0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo1000003o0?ooo``0oooo000D0?ooo`030000003oool0
oooo0=40oooo0P00000c0?ooo`@00000o`3oool<0?ooo`00503oool00`000000oooo0?ooo`3@0?oo
o`@00000<`3oool200000?l0oooo3@3oool001@0oooo00<000000?ooo`3oool0d03oool400000?l0
oooo@P3oool001@0oooo00<000000?ooo`3oool0d@3oool200000?l0oooo@`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool000<0oooo0`0000040?ooo`800000203oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool00080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo0002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000070?ooo`D00000
o`3ooooo0?oooaD0oooo00030?ooo`<000000`3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo0?l0ooooo`3ooolG0?ooo`000P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool00080oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000L0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaL0oooo00030?ooo`<00000103oool2000000P0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000
oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo
000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`<00000o`3ooooo
0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000
oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo
000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0
oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`<00000o`3ooooo0?oooaL0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo
5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0
oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000D0?ooo`<00000o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0oooo
o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0
h`3oool200000100oooo0P00003o0?oooal0oooo000D0?ooo`030000003oool0oooo0>80oooo1000
000>0?ooo`@00000o`3ooolN0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`@000003P3oool4
00000?l0oooo7P3oool001@0oooo00<000000?ooo`3oool0h`3oool200000100oooo0P00003o0?oo
oal0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo000D
0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ool0oooo5`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo0000\
\>"],
  ImageRangeCache->{{{0, 555.5}, {342.938, 0}} -> {25.6501, -4.80206, \
0.0167357, 0.304364}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of a Reflection Hologram (without refraction)", 
  "ExampleSection"],

Cell[CellGroupData[{

Cell["Source", "ExampleSubsection"],

Cell["wavelength = 0.5;", "Input",
  CellLabel->"In[237]:="],

Cell["\<\
lightsource = WedgeOfRays[
\t2,
\tNumberOfRays -> 31,
\tIntrinsicMedium -> 1.52,
\tWaveLength -> wavelength,
\tPolarization -> {1,0,0},
\tBirthPoint -> {-10.,-10.*Tan[30*Degree],0}
];\
\>", "Input",
  CellLabel->"In[267]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Grating Thickness for GratingStrength of Pi/2", "ExampleSubsection"],

Cell[CellGroupData[{

Cell["\<\
Block[{gratingstrength, n1, d, wavelength, recangle, sigangle},
gratingstrength = Pi*n1*d/wavelength/Sqrt[Cos[recangle]*Cos[sigangle]];
d = d/.Solve[gratingstrength==Pi/2, d][[1]];
recangle=30*Degree;
sigangle=-40*Degree;
n1=0.02;
wavelength=0.5;
Print[\"grating thickness in microns for 84% efficiency: \",d];
Print[\"gratingstrength/Pi: \",gratingstrength/Pi];
]\
\>", "Input",
  CellLabel->"In[268]:="],

Cell[BoxData[
    InterpretationBox[\("grating thickness in microns for 84% efficiency: "\
\[InvisibleSpace]10.181278377561267`\),
      SequenceForm[ 
      "grating thickness in microns for 84% efficiency: ", 
        10.181278377561267],
      Editable->False]], "Print",
  CellLabel->"From In[268]:="],

Cell[BoxData[
    InterpretationBox[\("gratingstrength/Pi: \
"\[InvisibleSpace]0.49999999999999994`\),
      SequenceForm[ "gratingstrength/Pi: ", 0.49999999999999994],
      Editable->False]], "Print",
  CellLabel->"From In[268]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Grating Vector -1st order", "ExampleSubsection"],

Cell[CellGroupData[{

Cell["\<\
Clear[BraggGrating];
BraggGrating[type_, index_, wavelength_, anglerec_, anglesig_, \
ordernumber_]:=
Block[{orderphase,eqx,sx,sz,rx,rz,Kx,Kz,k,lamda,sigangle,recangle},
\torderphase=If[type===Transmission,1,-1];
(*grating equation*)
\teqx = sx == rx + ordernumber*Kx;
(*phase mismatch of 0*)
\teqz = 0 == sz - orderphase*rz - orderphase*ordernumber*Kz;
(*wave vector parts*)\t
\trx = k*Sin[recangle];
\trz = k*Cos[recangle];
\tsx = k*Sin[sigangle];
\tsz = k*Cos[sigangle];
(*grating vector*)
\teqx = Kx/.Solve[eqx, Kx][[1]];
\teqz = Kz/.Solve[eqz, Kz][[1]];
\tPrint[\"x part of grating vector Kx = \", eqx];
\tPrint[\"z part of grating vector Kz = \", eqz];
\t
\tk = index*2*Pi/(wavelength*10^(-6));
\tPrint[\"length of wavevectors k = \",k];
\tsigangle = anglesig*Degree;
\trecangle = anglerec*Degree;
\tPrint[\"rx = \",rx];
\tPrint[\"rz = \",rz];
\tPrint[\"sx = \",sx];
\tPrint[\"sz = \",sz];
\tPrint[\"Kx = \",eqx,\" = \",eqx/2/Pi/1000,\" line pairs per mm\"];
\tPrint[\"Kz = \",eqz,\" = \",eqz/2/Pi/1000,\" line pairs per mm\"];
\tArcSin[(rx+ordernumber*eqx)/k]/Degree;
\tsz - orderphase*rz - orderphase*ordernumber*eqz
];
BraggGrating[Reflection,1.52,0.5,30,40,-1]\
\>", "Input",
  CellLabel->"In[241]:="],

Cell[BoxData[
    InterpretationBox[\("x part of grating vector Kx = "\[InvisibleSpace]\(k\ \
Sin[recangle] - k\ Sin[sigangle]\)\),
      SequenceForm[ "x part of grating vector Kx = ", 
        Plus[ 
          Times[ k, 
            Sin[ recangle]], 
          Times[ -1, k, 
            Sin[ sigangle]]]],
      Editable->False]], "Print",
  CellLabel->"From In[241]:="],

Cell[BoxData[
    InterpretationBox[\("z part of grating vector Kz = "\[InvisibleSpace]\(k\ \
Cos[recangle] + k\ Cos[sigangle]\)\),
      SequenceForm[ "z part of grating vector Kz = ", 
        Plus[ 
          Times[ k, 
            Cos[ recangle]], 
          Times[ k, 
            Cos[ sigangle]]]],
      Editable->False]], "Print",
  CellLabel->"From In[241]:="],

Cell[BoxData[
    InterpretationBox[\("length of wavevectors k = \
"\[InvisibleSpace]1.9100883333825942`*^7\),
      SequenceForm[ "length of wavevectors k = ", 19100883.333825942],
      Editable->False]], "Print",
  CellLabel->"From In[241]:="],

Cell[BoxData[
    InterpretationBox[\("rx = "\[InvisibleSpace]9.550441666912971`*^6\),
      SequenceForm[ "rx = ", 9550441.6669129711],
      Editable->False]], "Print",
  CellLabel->"From In[241]:="],

Cell[BoxData[
    InterpretationBox[\("rz = "\[InvisibleSpace]1.6541850201816065`*^7\),
      SequenceForm[ "rz = ", 16541850.201816065],
      Editable->False]], "Print",
  CellLabel->"From In[241]:="],

Cell[BoxData[
    InterpretationBox[\("sx = "\[InvisibleSpace]1.2277811141051434`*^7\),
      SequenceForm[ "sx = ", 12277811.141051434],
      Editable->False]], "Print",
  CellLabel->"From In[241]:="],

Cell[BoxData[
    InterpretationBox[\("sz = "\[InvisibleSpace]1.4632125536541263`*^7\),
      SequenceForm[ "sz = ", 14632125.536541263],
      Editable->False]], "Print",
  CellLabel->"From In[241]:="],

Cell[BoxData[
    InterpretationBox[\("Kx = "\[InvisibleSpace]\(-2.727369474138463`*^6\)\
\[InvisibleSpace]" = "\[InvisibleSpace]\(-434.0743334470796`\)\
\[InvisibleSpace]" line pairs per mm"\),
      SequenceForm[ 
      "Kx = ", -2727369.4741384629, " = ", -434.0743334470796, 
        " line pairs per mm"],
      Editable->False]], "Print",
  CellLabel->"From In[241]:="],

Cell[BoxData[
    InterpretationBox[\("Kz = "\[InvisibleSpace]3.1173975738357328`*^7\
\[InvisibleSpace]" = "\[InvisibleSpace]4961.492334586386`\[InvisibleSpace]" \
line pairs per mm"\),
      SequenceForm[ 
      "Kz = ", 31173975.738357328, " = ", 4961.4923345863863, 
        " line pairs per mm"],
      Editable->False]], "Print",
  CellLabel->"From In[241]:="],

Cell[BoxData[
    \(0.`\)], "Output",
  CellLabel->"Out[243]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define Grating", "ExampleSubsection"],

Cell["\<\
The rays are directed in -x direction, the grating must be taken \
negative.\
\>", "ExampleText",
  FormatType->InputForm],

Cell["\<\
reflectiongrating = Grating[
\t{-4961.49, 434.074, 0},
\t50,
\t.1,
\tComponentMedium -> 1.52,
\tVacuumFrequency -> False,
\tCoupledWaveTheory->True,
\tGratingMedium -> 1.52,
\tGratingThickness -> 10.1813,
\tGratingModulation -> {{0.02,#1&,#1&,#1&}},
\tGratingRotationMatrix -> {{1,0,0},{0,1,0},{0,0,1}}
];\
\>", "Input",
  CellLabel->"In[269]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define System", "ExampleSubsection"],

Cell["\<\
system = {
\tlightsource,
\treflectiongrating,
\tMove[Screen[30],{-30,20}],
\tMove[Screen[30],{30,20}]
};\
\>", "Input",
  CellLabel->"In[274]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trace System", "ExampleSubsection"],

Cell["\<\
tracedsystem = PropagateSystem[system, \
ThresholdIntensity->0];\
\>", "Input",
  CellLabel->"In[275]:="],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[tracedsystem, PlotType -> TopView, AspectRatio -> 1, \
Axes->True];\
\>", "Input",
  CellLabel->"In[276]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.015873 0.442002 0.0152625 [
[.02381 .4295 -9 -9 ]
[.02381 .4295 9 0 ]
[.18254 .4295 -9 -9 ]
[.18254 .4295 9 0 ]
[.34127 .4295 -9 -9 ]
[.34127 .4295 9 0 ]
[.65873 .4295 -6 -9 ]
[.65873 .4295 6 0 ]
[.81746 .4295 -6 -9 ]
[.81746 .4295 6 0 ]
[.97619 .4295 -6 -9 ]
[.97619 .4295 6 0 ]
[.4875 .13675 -18 -4.5 ]
[.4875 .13675 0 4.5 ]
[.4875 .28938 -18 -4.5 ]
[.4875 .28938 0 4.5 ]
[.4875 .59463 -12 -4.5 ]
[.4875 .59463 0 4.5 ]
[.4875 .74725 -12 -4.5 ]
[.4875 .74725 0 4.5 ]
[.4875 .89988 -12 -4.5 ]
[.4875 .89988 0 4.5 ]
[.49992 .02381 -3 -4.5 ]
[.49992 .02381 3 4.5 ]
[.02381 .48168 -6 -4.5 ]
[.02381 .48168 6 4.5 ]
[.97619 .48168 -6 -4.5 ]
[.97619 .48168 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .442 m
.02381 .44825 L
s
[(-30)] .02381 .4295 0 1 Mshowa
.18254 .442 m
.18254 .44825 L
s
[(-20)] .18254 .4295 0 1 Mshowa
.34127 .442 m
.34127 .44825 L
s
[(-10)] .34127 .4295 0 1 Mshowa
.65873 .442 m
.65873 .44825 L
s
[(10)] .65873 .4295 0 1 Mshowa
.81746 .442 m
.81746 .44825 L
s
[(20)] .81746 .4295 0 1 Mshowa
.97619 .442 m
.97619 .44825 L
s
[(30)] .97619 .4295 0 1 Mshowa
.125 Mabswid
.05556 .442 m
.05556 .44575 L
s
.0873 .442 m
.0873 .44575 L
s
.11905 .442 m
.11905 .44575 L
s
.15079 .442 m
.15079 .44575 L
s
.21429 .442 m
.21429 .44575 L
s
.24603 .442 m
.24603 .44575 L
s
.27778 .442 m
.27778 .44575 L
s
.30952 .442 m
.30952 .44575 L
s
.37302 .442 m
.37302 .44575 L
s
.40476 .442 m
.40476 .44575 L
s
.43651 .442 m
.43651 .44575 L
s
.46825 .442 m
.46825 .44575 L
s
.53175 .442 m
.53175 .44575 L
s
.56349 .442 m
.56349 .44575 L
s
.59524 .442 m
.59524 .44575 L
s
.62698 .442 m
.62698 .44575 L
s
.69048 .442 m
.69048 .44575 L
s
.72222 .442 m
.72222 .44575 L
s
.75397 .442 m
.75397 .44575 L
s
.78571 .442 m
.78571 .44575 L
s
.84921 .442 m
.84921 .44575 L
s
.88095 .442 m
.88095 .44575 L
s
.9127 .442 m
.9127 .44575 L
s
.94444 .442 m
.94444 .44575 L
s
.25 Mabswid
0 .442 m
1 .442 L
s
.5 .13675 m
.50625 .13675 L
s
[(-20)] .4875 .13675 1 0 Mshowa
.5 .28938 m
.50625 .28938 L
s
[(-10)] .4875 .28938 1 0 Mshowa
.5 .59463 m
.50625 .59463 L
s
[(10)] .4875 .59463 1 0 Mshowa
.5 .74725 m
.50625 .74725 L
s
[(20)] .4875 .74725 1 0 Mshowa
.5 .89988 m
.50625 .89988 L
s
[(30)] .4875 .89988 1 0 Mshowa
.125 Mabswid
.5 .16728 m
.50375 .16728 L
s
.5 .1978 m
.50375 .1978 L
s
.5 .22833 m
.50375 .22833 L
s
.5 .25885 m
.50375 .25885 L
s
.5 .3199 m
.50375 .3199 L
s
.5 .35043 m
.50375 .35043 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .41148 m
.50375 .41148 L
s
.5 .47253 m
.50375 .47253 L
s
.5 .50305 m
.50375 .50305 L
s
.5 .53358 m
.50375 .53358 L
s
.5 .5641 m
.50375 .5641 L
s
.5 .62515 m
.50375 .62515 L
s
.5 .65568 m
.50375 .65568 L
s
.5 .6862 m
.50375 .6862 L
s
.5 .71673 m
.50375 .71673 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .8083 m
.50375 .8083 L
s
.5 .83883 m
.50375 .83883 L
s
.5 .86935 m
.50375 .86935 L
s
.5 .10623 m
.50375 .10623 L
s
.5 .0757 m
.50375 .0757 L
s
.5 .04518 m
.50375 .04518 L
s
.5 .01465 m
.50375 .01465 L
s
.5 .9304 m
.50375 .9304 L
s
.5 .96093 m
.50375 .96093 L
s
.5 .99145 m
.50375 .99145 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
.5 g
.49984 .06044 m
.5 .06044 L
.5 .18763 L
.49984 .18763 L
.49984 .06044 L
F
.49984 .18763 m
.5 .18763 L
.5 .31481 L
.49984 .31481 L
.49984 .18763 L
F
.49984 .31481 m
.5 .31481 L
.5 .442 L
.49984 .442 L
.49984 .31481 L
F
.49984 .442 m
.5 .442 L
.5 .56919 L
.49984 .56919 L
.49984 .442 L
F
.49984 .56919 m
.5 .56919 L
.5 .69638 L
.49984 .69638 L
.49984 .56919 L
F
.49984 .69638 m
.5 .69638 L
.5 .82357 L
.49984 .82357 L
.49984 .69638 L
F
0 g
.5 Mabswid
.49984 .06044 m
.49984 .18763 L
.49984 .31481 L
.49984 .442 L
.49984 .56919 L
.49984 .69638 L
.49984 .82357 L
.5 .82357 L
.5 .69638 L
.5 .56919 L
.5 .442 L
.5 .31481 L
.5 .18763 L
.5 .06044 L
.49984 .06044 L
s
.5 g
.49984 .442 m
.5 .442 L
.5 .442 L
.49984 .442 L
.49984 .442 L
F
.49984 .442 m
.5 .442 L
.5 .442 L
.49984 .442 L
.49984 .442 L
F
.49984 .442 m
.5 .442 L
.5 .442 L
.49984 .442 L
.49984 .442 L
F
.49984 .442 m
.5 .442 L
.5 .442 L
.49984 .442 L
.49984 .442 L
F
.49984 .442 m
.5 .442 L
.5 .442 L
.49984 .442 L
.49984 .442 L
F
.49984 .442 m
.5 .442 L
.5 .442 L
.49984 .442 L
.49984 .442 L
F
0 g
.49984 .442 m
.49984 .442 L
.49984 .442 L
.49984 .442 L
.49984 .442 L
.49984 .442 L
.49984 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.49984 .442 L
s
.5 g
.5 .06044 m
.5 .06044 L
.5 .18763 L
.5 .18763 L
.5 .06044 L
F
.5 .18763 m
.5 .18763 L
.5 .31481 L
.5 .31481 L
.5 .18763 L
F
.5 .31481 m
.5 .31481 L
.5 .442 L
.5 .442 L
.5 .31481 L
F
.5 .442 m
.5 .442 L
.5 .56919 L
.5 .56919 L
.5 .442 L
F
.5 .56919 m
.5 .56919 L
.5 .69638 L
.5 .69638 L
.5 .56919 L
F
.5 .69638 m
.5 .69638 L
.5 .82357 L
.5 .82357 L
.5 .69638 L
F
0 g
.5 .06044 m
.5 .18763 L
.5 .31481 L
.5 .442 L
.5 .56919 L
.5 .69638 L
.5 .82357 L
.5 .82357 L
.5 .69638 L
.5 .56919 L
.5 .442 L
.5 .31481 L
.5 .18763 L
.5 .06044 L
.5 .06044 L
s
.5 g
.5 .442 m
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
F
0 g
.5 .442 m
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
s
.5 g
.5 .06044 m
.50159 .06044 L
.50159 .18763 L
.5 .18763 L
.5 .06044 L
F
.5 .18763 m
.50159 .18763 L
.50159 .31481 L
.5 .31481 L
.5 .18763 L
F
.5 .31481 m
.50159 .31481 L
.50159 .442 L
.5 .442 L
.5 .31481 L
F
.5 .442 m
.50159 .442 L
.50159 .56919 L
.5 .56919 L
.5 .442 L
F
.5 .56919 m
.50159 .56919 L
.50159 .69638 L
.5 .69638 L
.5 .56919 L
F
.5 .69638 m
.50159 .69638 L
.50159 .82357 L
.5 .82357 L
.5 .69638 L
F
0 g
.5 .06044 m
.5 .18763 L
.5 .31481 L
.5 .442 L
.5 .56919 L
.5 .69638 L
.5 .82357 L
.50159 .82357 L
.50159 .69638 L
.50159 .56919 L
.50159 .442 L
.50159 .31481 L
.50159 .18763 L
.50159 .06044 L
.5 .06044 L
s
.5 g
.5 .442 m
.50159 .442 L
.50159 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.50159 .442 L
.50159 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.50159 .442 L
.50159 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.50159 .442 L
.50159 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.50159 .442 L
.50159 .442 L
.5 .442 L
.5 .442 L
F
.5 .442 m
.50159 .442 L
.50159 .442 L
.5 .442 L
.5 .442 L
F
0 g
.5 .442 m
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.5 .442 L
.50159 .442 L
.50159 .442 L
.50159 .442 L
.50159 .442 L
.50159 .442 L
.50159 .442 L
.50159 .442 L
.5 .442 L
s
.49984 .82357 m
.49984 .81056 L
.49984 .77245 L
.49984 .71181 L
.49984 .63278 L
.49984 .54076 L
.49984 .442 L
.49984 .34325 L
.49984 .25122 L
.49984 .1722 L
.49984 .11156 L
.49984 .07344 L
.49984 .06044 L
.49984 .07344 L
.49984 .11156 L
.49984 .1722 L
.49984 .25122 L
.49984 .34325 L
.49984 .442 L
.49984 .54076 L
.49984 .63278 L
.49984 .71181 L
.49984 .77245 L
.49984 .81056 L
.49984 .82357 L
s
.5 .82357 m
.5 .81056 L
.5 .77245 L
.5 .71181 L
.5 .63278 L
.5 .54076 L
.5 .442 L
.5 .34325 L
.5 .25122 L
.5 .1722 L
.5 .11156 L
.5 .07344 L
.5 .06044 L
.5 .07344 L
.5 .11156 L
.5 .1722 L
.5 .25122 L
.5 .34325 L
.5 .442 L
.5 .54076 L
.5 .63278 L
.5 .71181 L
.5 .77245 L
.5 .81056 L
.5 .82357 L
s
.5 .82357 m
.5 .81056 L
.5 .77245 L
.5 .71181 L
.5 .63278 L
.5 .54076 L
.5 .442 L
.5 .34325 L
.5 .25122 L
.5 .1722 L
.5 .11156 L
.5 .07344 L
.5 .06044 L
.5 .07344 L
.5 .11156 L
.5 .1722 L
.5 .25122 L
.5 .34325 L
.5 .442 L
.5 .54076 L
.5 .63278 L
.5 .71181 L
.5 .77245 L
.5 .81056 L
.5 .82357 L
s
.50159 .82357 m
.50159 .81056 L
.50159 .77245 L
.50159 .71181 L
.50159 .63278 L
.50159 .54076 L
.50159 .442 L
.50159 .34325 L
.50159 .25122 L
.50159 .1722 L
.50159 .11156 L
.50159 .07344 L
.50159 .06044 L
.50159 .07344 L
.50159 .11156 L
.50159 .1722 L
.50159 .25122 L
.50159 .34325 L
.50159 .442 L
.50159 .54076 L
.50159 .63278 L
.50159 .71181 L
.50159 .77245 L
.50159 .81056 L
.50159 .82357 L
s
.49984 .82357 m
.5 .82357 L
.5 .81056 L
.49984 .81056 L
.49984 .82357 L
s
.49984 .81056 m
.5 .81056 L
.5 .77245 L
.49984 .77245 L
.49984 .81056 L
s
.49984 .77245 m
.5 .77245 L
.5 .71181 L
.49984 .71181 L
.49984 .77245 L
s
.49984 .71181 m
.5 .71181 L
.5 .63278 L
.49984 .63278 L
.49984 .71181 L
s
.49984 .63278 m
.5 .63278 L
.5 .54076 L
.49984 .54076 L
.49984 .63278 L
s
.49984 .54076 m
.5 .54076 L
.5 .442 L
.49984 .442 L
.49984 .54076 L
s
.49984 .442 m
.5 .442 L
.5 .34325 L
.49984 .34325 L
.49984 .442 L
s
.49984 .34325 m
.5 .34325 L
.5 .25122 L
.49984 .25122 L
.49984 .34325 L
s
.49984 .25122 m
.5 .25122 L
.5 .1722 L
.49984 .1722 L
.49984 .25122 L
s
.49984 .1722 m
.5 .1722 L
.5 .11156 L
.49984 .11156 L
.49984 .1722 L
s
.49984 .11156 m
.5 .11156 L
.5 .07344 L
.49984 .07344 L
.49984 .11156 L
s
.49984 .07344 m
.5 .07344 L
.5 .06044 L
.49984 .06044 L
.49984 .07344 L
s
.49984 .06044 m
.5 .06044 L
.5 .07344 L
.49984 .07344 L
.49984 .06044 L
s
.49984 .07344 m
.5 .07344 L
.5 .11156 L
.49984 .11156 L
.49984 .07344 L
s
.49984 .11156 m
.5 .11156 L
.5 .1722 L
.49984 .1722 L
.49984 .11156 L
s
.49984 .1722 m
.5 .1722 L
.5 .25122 L
.49984 .25122 L
.49984 .1722 L
s
.49984 .25122 m
.5 .25122 L
.5 .34325 L
.49984 .34325 L
.49984 .25122 L
s
.49984 .34325 m
.5 .34325 L
.5 .442 L
.49984 .442 L
.49984 .34325 L
s
.49984 .442 m
.5 .442 L
.5 .54076 L
.49984 .54076 L
.49984 .442 L
s
.49984 .54076 m
.5 .54076 L
.5 .63278 L
.49984 .63278 L
.49984 .54076 L
s
.49984 .63278 m
.5 .63278 L
.5 .71181 L
.49984 .71181 L
.49984 .63278 L
s
.49984 .71181 m
.5 .71181 L
.5 .77245 L
.49984 .77245 L
.49984 .71181 L
s
.49984 .77245 m
.5 .77245 L
.5 .81056 L
.49984 .81056 L
.49984 .77245 L
s
.49984 .81056 m
.5 .81056 L
.5 .82357 L
.49984 .82357 L
.49984 .81056 L
s
.5 .82357 m
.5 .82357 L
.5 .81056 L
.5 .81056 L
.5 .82357 L
s
.5 .81056 m
.5 .81056 L
.5 .77245 L
.5 .77245 L
.5 .81056 L
s
.5 .77245 m
.5 .77245 L
.5 .71181 L
.5 .71181 L
.5 .77245 L
s
.5 .71181 m
.5 .71181 L
.5 .63278 L
.5 .63278 L
.5 .71181 L
s
.5 .63278 m
.5 .63278 L
.5 .54076 L
.5 .54076 L
.5 .63278 L
s
.5 .54076 m
.5 .54076 L
.5 .442 L
.5 .442 L
.5 .54076 L
s
.5 .442 m
.5 .442 L
.5 .34325 L
.5 .34325 L
.5 .442 L
s
.5 .34325 m
.5 .34325 L
.5 .25122 L
.5 .25122 L
.5 .34325 L
s
.5 .25122 m
.5 .25122 L
.5 .1722 L
.5 .1722 L
.5 .25122 L
s
.5 .1722 m
.5 .1722 L
.5 .11156 L
.5 .11156 L
.5 .1722 L
s
.5 .11156 m
.5 .11156 L
.5 .07344 L
.5 .07344 L
.5 .11156 L
s
.5 .07344 m
.5 .07344 L
.5 .06044 L
.5 .06044 L
.5 .07344 L
s
.5 .06044 m
.5 .06044 L
.5 .07344 L
.5 .07344 L
.5 .06044 L
s
.5 .07344 m
.5 .07344 L
.5 .11156 L
.5 .11156 L
.5 .07344 L
s
.5 .11156 m
.5 .11156 L
.5 .1722 L
.5 .1722 L
.5 .11156 L
s
.5 .1722 m
.5 .1722 L
.5 .25122 L
.5 .25122 L
.5 .1722 L
s
.5 .25122 m
.5 .25122 L
.5 .34325 L
.5 .34325 L
.5 .25122 L
s
.5 .34325 m
.5 .34325 L
.5 .442 L
.5 .442 L
.5 .34325 L
s
.5 .442 m
.5 .442 L
.5 .54076 L
.5 .54076 L
.5 .442 L
s
.5 .54076 m
.5 .54076 L
.5 .63278 L
.5 .63278 L
.5 .54076 L
s
.5 .63278 m
.5 .63278 L
.5 .71181 L
.5 .71181 L
.5 .63278 L
s
.5 .71181 m
.5 .71181 L
.5 .77245 L
.5 .77245 L
.5 .71181 L
s
.5 .77245 m
.5 .77245 L
.5 .81056 L
.5 .81056 L
.5 .77245 L
s
.5 .81056 m
.5 .81056 L
.5 .82357 L
.5 .82357 L
.5 .81056 L
s
.5 .82357 m
.50159 .82357 L
.50159 .81056 L
.5 .81056 L
.5 .82357 L
s
.5 .81056 m
.50159 .81056 L
.50159 .77245 L
.5 .77245 L
.5 .81056 L
s
.5 .77245 m
.50159 .77245 L
.50159 .71181 L
.5 .71181 L
.5 .77245 L
s
.5 .71181 m
.50159 .71181 L
.50159 .63278 L
.5 .63278 L
.5 .71181 L
s
.5 .63278 m
.50159 .63278 L
.50159 .54076 L
.5 .54076 L
.5 .63278 L
s
.5 .54076 m
.50159 .54076 L
.50159 .442 L
.5 .442 L
.5 .54076 L
s
.5 .442 m
.50159 .442 L
.50159 .34325 L
.5 .34325 L
.5 .442 L
s
.5 .34325 m
.50159 .34325 L
.50159 .25122 L
.5 .25122 L
.5 .34325 L
s
.5 .25122 m
.50159 .25122 L
.50159 .1722 L
.5 .1722 L
.5 .25122 L
s
.5 .1722 m
.50159 .1722 L
.50159 .11156 L
.5 .11156 L
.5 .1722 L
s
.5 .11156 m
.50159 .11156 L
.50159 .07344 L
.5 .07344 L
.5 .11156 L
s
.5 .07344 m
.50159 .07344 L
.50159 .06044 L
.5 .06044 L
.5 .07344 L
s
.5 .06044 m
.50159 .06044 L
.50159 .07344 L
.5 .07344 L
.5 .06044 L
s
.5 .07344 m
.50159 .07344 L
.50159 .11156 L
.5 .11156 L
.5 .07344 L
s
.5 .11156 m
.50159 .11156 L
.50159 .1722 L
.5 .1722 L
.5 .11156 L
s
.5 .1722 m
.50159 .1722 L
.50159 .25122 L
.5 .25122 L
.5 .1722 L
s
.5 .25122 m
.50159 .25122 L
.50159 .34325 L
.5 .34325 L
.5 .25122 L
s
.5 .34325 m
.50159 .34325 L
.50159 .442 L
.5 .442 L
.5 .34325 L
s
.5 .442 m
.50159 .442 L
.50159 .54076 L
.5 .54076 L
.5 .442 L
s
.5 .54076 m
.50159 .54076 L
.50159 .63278 L
.5 .63278 L
.5 .54076 L
s
.5 .63278 m
.50159 .63278 L
.50159 .71181 L
.5 .71181 L
.5 .63278 L
s
.5 .71181 m
.50159 .71181 L
.50159 .77245 L
.5 .77245 L
.5 .71181 L
s
.5 .77245 m
.50159 .77245 L
.50159 .81056 L
.5 .81056 L
.5 .77245 L
s
.5 .81056 m
.50159 .81056 L
.50159 .82357 L
.5 .82357 L
.5 .81056 L
s
.02381 .51832 m
.02381 .59463 L
.02381 .67094 L
.02381 .74725 L
.02381 .82357 L
.02381 .89988 L
.02381 .97619 L
.02381 .97619 L
.02381 .89988 L
.02381 .82357 L
.02381 .74725 L
.02381 .67094 L
.02381 .59463 L
.02381 .51832 L
.02381 .51832 L
s
.02381 .74725 m
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
.02381 .74725 L
s
.02381 .97619 m
.02381 .96839 L
.02381 .94552 L
.02381 .90914 L
.02381 .86172 L
.02381 .80651 L
.02381 .74725 L
.02381 .688 L
.02381 .63278 L
.02381 .58537 L
.02381 .54899 L
.02381 .52612 L
.02381 .51832 L
.02381 .52612 L
.02381 .54899 L
.02381 .58537 L
.02381 .63278 L
.02381 .688 L
.02381 .74725 L
.02381 .80651 L
.02381 .86172 L
.02381 .90914 L
.02381 .94552 L
.02381 .96839 L
.02381 .97619 L
s
.97619 .51832 m
.97619 .59463 L
.97619 .67094 L
.97619 .74725 L
.97619 .82357 L
.97619 .89988 L
.97619 .97619 L
.97619 .97619 L
.97619 .89988 L
.97619 .82357 L
.97619 .74725 L
.97619 .67094 L
.97619 .59463 L
.97619 .51832 L
.97619 .51832 L
s
.97619 .74725 m
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
.97619 .74725 L
s
.97619 .97619 m
.97619 .96839 L
.97619 .94552 L
.97619 .90914 L
.97619 .86172 L
.97619 .80651 L
.97619 .74725 L
.97619 .688 L
.97619 .63278 L
.97619 .58537 L
.97619 .54899 L
.97619 .52612 L
.97619 .51832 L
.97619 .52612 L
.97619 .54899 L
.97619 .58537 L
.97619 .63278 L
.97619 .688 L
.97619 .74725 L
.97619 .80651 L
.97619 .86172 L
.97619 .90914 L
.97619 .94552 L
.97619 .96839 L
.97619 .97619 L
s
.009 .837 .111 r
.34127 .35388 m
.49984 .42667 L
s
0 0 0 r
2 Mabswid
.49984 .42667 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .42768 L
s
0 0 0 r
2 Mabswid
.49984 .42768 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .4287 L
s
0 0 0 r
2 Mabswid
.49984 .4287 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .42972 L
s
0 0 0 r
2 Mabswid
.49984 .42972 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .43073 L
s
0 0 0 r
2 Mabswid
.49984 .43073 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .43175 L
s
0 0 0 r
2 Mabswid
.49984 .43175 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .43276 L
s
0 0 0 r
2 Mabswid
.49984 .43276 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .43378 L
s
0 0 0 r
2 Mabswid
.49984 .43378 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .4348 L
s
0 0 0 r
2 Mabswid
.49984 .4348 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .43581 L
s
0 0 0 r
2 Mabswid
.49984 .43581 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .43683 L
s
0 0 0 r
2 Mabswid
.49984 .43683 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .43785 L
s
0 0 0 r
2 Mabswid
.49984 .43785 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .43886 L
s
0 0 0 r
2 Mabswid
.49984 .43886 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .43988 L
s
0 0 0 r
2 Mabswid
.49984 .43988 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .4409 L
s
0 0 0 r
2 Mabswid
.49984 .4409 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .44191 L
s
0 0 0 r
2 Mabswid
.49984 .44191 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .44293 L
s
0 0 0 r
2 Mabswid
.49984 .44293 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .44395 L
s
0 0 0 r
2 Mabswid
.49984 .44395 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .44496 L
s
0 0 0 r
2 Mabswid
.49984 .44496 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .44598 L
s
0 0 0 r
2 Mabswid
.49984 .44598 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .447 L
s
0 0 0 r
2 Mabswid
.49984 .447 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .44801 L
s
0 0 0 r
2 Mabswid
.49984 .44801 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .44903 L
s
0 0 0 r
2 Mabswid
.49984 .44903 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .45004 L
s
0 0 0 r
2 Mabswid
.49984 .45004 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .45106 L
s
0 0 0 r
2 Mabswid
.49984 .45106 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .45208 L
s
0 0 0 r
2 Mabswid
.49984 .45208 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .45309 L
s
0 0 0 r
2 Mabswid
.49984 .45309 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .45411 L
s
0 0 0 r
2 Mabswid
.49984 .45411 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .45513 L
s
0 0 0 r
2 Mabswid
.49984 .45513 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .45614 L
s
0 0 0 r
2 Mabswid
.49984 .45614 Mdot
.009 .837 .111 r
.5 Mabswid
.34127 .35388 m
.49984 .45716 L
s
0 0 0 r
2 Mabswid
.49984 .45716 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .42667 m
.5 .42674 L
s
0 0 0 r
2 Mabswid
.5 .42674 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .42768 m
.5 .42776 L
s
0 0 0 r
2 Mabswid
.5 .42776 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .4287 m
.5 .42877 L
s
0 0 0 r
2 Mabswid
.5 .42877 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .42972 m
.5 .42979 L
s
0 0 0 r
2 Mabswid
.5 .42979 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43073 m
.5 .43081 L
s
0 0 0 r
2 Mabswid
.5 .43081 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43175 m
.5 .43183 L
s
0 0 0 r
2 Mabswid
.5 .43183 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43276 m
.5 .43284 L
s
0 0 0 r
2 Mabswid
.5 .43284 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43378 m
.5 .43386 L
s
0 0 0 r
2 Mabswid
.5 .43386 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .4348 m
.5 .43488 L
s
0 0 0 r
2 Mabswid
.5 .43488 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43581 m
.5 .4359 L
s
0 0 0 r
2 Mabswid
.5 .4359 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43683 m
.5 .43691 L
s
0 0 0 r
2 Mabswid
.5 .43691 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43785 m
.5 .43793 L
s
0 0 0 r
2 Mabswid
.5 .43793 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43886 m
.5 .43895 L
s
0 0 0 r
2 Mabswid
.5 .43895 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43988 m
.5 .43997 L
s
0 0 0 r
2 Mabswid
.5 .43997 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .4409 m
.5 .44098 L
s
0 0 0 r
2 Mabswid
.5 .44098 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44191 m
.5 .442 L
s
0 0 0 r
2 Mabswid
.5 .442 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44293 m
.5 .44302 L
s
0 0 0 r
2 Mabswid
.5 .44302 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44395 m
.5 .44404 L
s
0 0 0 r
2 Mabswid
.5 .44404 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44496 m
.5 .44505 L
s
0 0 0 r
2 Mabswid
.5 .44505 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44598 m
.5 .44607 L
s
0 0 0 r
2 Mabswid
.5 .44607 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .447 m
.5 .44709 L
s
0 0 0 r
2 Mabswid
.5 .44709 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44801 m
.5 .44811 L
s
0 0 0 r
2 Mabswid
.5 .44811 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44903 m
.5 .44912 L
s
0 0 0 r
2 Mabswid
.5 .44912 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45004 m
.5 .45014 L
s
0 0 0 r
2 Mabswid
.5 .45014 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45106 m
.5 .45116 L
s
0 0 0 r
2 Mabswid
.5 .45116 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45208 m
.5 .45218 L
s
0 0 0 r
2 Mabswid
.5 .45218 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45309 m
.5 .45319 L
s
0 0 0 r
2 Mabswid
.5 .45319 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45411 m
.5 .45421 L
s
0 0 0 r
2 Mabswid
.5 .45421 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45513 m
.5 .45523 L
s
0 0 0 r
2 Mabswid
.5 .45523 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45614 m
.5 .45625 L
s
0 0 0 r
2 Mabswid
.5 .45625 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45716 m
.5 .45726 L
s
0 0 0 r
2 Mabswid
.5 .45726 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42674 m
.5 .42674 L
s
0 0 0 r
2 Mabswid
.5 .42674 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42674 m
.5 .42674 L
s
0 0 0 r
2 Mabswid
.5 .42674 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42776 m
.5 .42776 L
s
0 0 0 r
2 Mabswid
.5 .42776 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42776 m
.5 .42776 L
s
0 0 0 r
2 Mabswid
.5 .42776 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42877 m
.5 .42877 L
s
0 0 0 r
2 Mabswid
.5 .42877 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42877 m
.5 .42877 L
s
0 0 0 r
2 Mabswid
.5 .42877 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42979 m
.5 .42979 L
s
0 0 0 r
2 Mabswid
.5 .42979 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42979 m
.5 .42979 L
s
0 0 0 r
2 Mabswid
.5 .42979 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43081 m
.5 .43081 L
s
0 0 0 r
2 Mabswid
.5 .43081 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43081 m
.5 .43081 L
s
0 0 0 r
2 Mabswid
.5 .43081 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43183 m
.5 .43183 L
s
0 0 0 r
2 Mabswid
.5 .43183 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43183 m
.5 .43183 L
s
0 0 0 r
2 Mabswid
.5 .43183 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43284 m
.5 .43284 L
s
0 0 0 r
2 Mabswid
.5 .43284 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43284 m
.5 .43284 L
s
0 0 0 r
2 Mabswid
.5 .43284 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43386 m
.5 .43386 L
s
0 0 0 r
2 Mabswid
.5 .43386 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43386 m
.5 .43386 L
s
0 0 0 r
2 Mabswid
.5 .43386 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43488 m
.5 .43488 L
s
0 0 0 r
2 Mabswid
.5 .43488 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43488 m
.5 .43488 L
s
0 0 0 r
2 Mabswid
.5 .43488 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .4359 m
.5 .4359 L
s
0 0 0 r
2 Mabswid
.5 .4359 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .4359 m
.5 .4359 L
s
0 0 0 r
2 Mabswid
.5 .4359 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43691 m
.5 .43691 L
s
0 0 0 r
2 Mabswid
.5 .43691 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43691 m
.5 .43691 L
s
0 0 0 r
2 Mabswid
.5 .43691 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43793 m
.5 .43793 L
s
0 0 0 r
2 Mabswid
.5 .43793 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43793 m
.5 .43793 L
s
0 0 0 r
2 Mabswid
.5 .43793 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43895 m
.5 .43895 L
s
0 0 0 r
2 Mabswid
.5 .43895 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43895 m
.5 .43895 L
s
0 0 0 r
2 Mabswid
.5 .43895 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43997 m
.5 .43997 L
s
0 0 0 r
2 Mabswid
.5 .43997 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43997 m
.5 .43997 L
s
0 0 0 r
2 Mabswid
.5 .43997 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44098 m
.5 .44098 L
s
0 0 0 r
2 Mabswid
.5 .44098 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44098 m
.5 .44098 L
s
0 0 0 r
2 Mabswid
.5 .44098 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .442 m
.5 .442 L
s
0 0 0 r
2 Mabswid
.5 .442 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .442 m
.5 .442 L
s
0 0 0 r
2 Mabswid
.5 .442 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44302 m
.5 .44302 L
s
0 0 0 r
2 Mabswid
.5 .44302 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44302 m
.5 .44302 L
s
0 0 0 r
2 Mabswid
.5 .44302 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44404 m
.5 .44404 L
s
0 0 0 r
2 Mabswid
.5 .44404 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44404 m
.5 .44404 L
s
0 0 0 r
2 Mabswid
.5 .44404 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44505 m
.5 .44505 L
s
0 0 0 r
2 Mabswid
.5 .44505 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44505 m
.5 .44505 L
s
0 0 0 r
2 Mabswid
.5 .44505 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44607 m
.5 .44607 L
s
0 0 0 r
2 Mabswid
.5 .44607 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44607 m
.5 .44607 L
s
0 0 0 r
2 Mabswid
.5 .44607 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44709 m
.5 .44709 L
s
0 0 0 r
2 Mabswid
.5 .44709 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44709 m
.5 .44709 L
s
0 0 0 r
2 Mabswid
.5 .44709 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44811 m
.5 .44811 L
s
0 0 0 r
2 Mabswid
.5 .44811 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44811 m
.5 .44811 L
s
0 0 0 r
2 Mabswid
.5 .44811 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44912 m
.5 .44912 L
s
0 0 0 r
2 Mabswid
.5 .44912 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44912 m
.5 .44912 L
s
0 0 0 r
2 Mabswid
.5 .44912 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45014 m
.5 .45014 L
s
0 0 0 r
2 Mabswid
.5 .45014 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45014 m
.5 .45014 L
s
0 0 0 r
2 Mabswid
.5 .45014 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45116 m
.5 .45116 L
s
0 0 0 r
2 Mabswid
.5 .45116 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45116 m
.5 .45116 L
s
0 0 0 r
2 Mabswid
.5 .45116 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45218 m
.5 .45218 L
s
0 0 0 r
2 Mabswid
.5 .45218 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45218 m
.5 .45218 L
s
0 0 0 r
2 Mabswid
.5 .45218 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45319 m
.5 .45319 L
s
0 0 0 r
2 Mabswid
.5 .45319 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45319 m
.5 .45319 L
s
0 0 0 r
2 Mabswid
.5 .45319 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45421 m
.5 .45421 L
s
0 0 0 r
2 Mabswid
.5 .45421 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45421 m
.5 .45421 L
s
0 0 0 r
2 Mabswid
.5 .45421 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45523 m
.5 .45523 L
s
0 0 0 r
2 Mabswid
.5 .45523 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45523 m
.5 .45523 L
s
0 0 0 r
2 Mabswid
.5 .45523 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45625 m
.5 .45625 L
s
0 0 0 r
2 Mabswid
.5 .45625 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45625 m
.5 .45625 L
s
0 0 0 r
2 Mabswid
.5 .45625 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45726 m
.5 .45726 L
s
0 0 0 r
2 Mabswid
.5 .45726 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45726 m
.5 .45726 L
s
0 0 0 r
2 Mabswid
.5 .45726 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42674 m
.49984 .42685 L
s
0 0 0 r
2 Mabswid
.49984 .42685 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42674 m
.50159 .42747 L
s
0 0 0 r
2 Mabswid
.50159 .42747 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42776 m
.49984 .42787 L
s
0 0 0 r
2 Mabswid
.49984 .42787 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42776 m
.50159 .4285 L
s
0 0 0 r
2 Mabswid
.50159 .4285 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42877 m
.49984 .42889 L
s
0 0 0 r
2 Mabswid
.49984 .42889 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42877 m
.50159 .42952 L
s
0 0 0 r
2 Mabswid
.50159 .42952 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42979 m
.49984 .42991 L
s
0 0 0 r
2 Mabswid
.49984 .42991 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .42979 m
.50159 .43055 L
s
0 0 0 r
2 Mabswid
.50159 .43055 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43081 m
.49984 .43092 L
s
0 0 0 r
2 Mabswid
.49984 .43092 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43081 m
.50159 .43158 L
s
0 0 0 r
2 Mabswid
.50159 .43158 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43183 m
.49984 .43194 L
s
0 0 0 r
2 Mabswid
.49984 .43194 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43183 m
.50159 .43261 L
s
0 0 0 r
2 Mabswid
.50159 .43261 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43284 m
.49984 .43296 L
s
0 0 0 r
2 Mabswid
.49984 .43296 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43284 m
.50159 .43363 L
s
0 0 0 r
2 Mabswid
.50159 .43363 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43386 m
.49984 .43398 L
s
0 0 0 r
2 Mabswid
.49984 .43398 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43386 m
.50159 .43466 L
s
0 0 0 r
2 Mabswid
.50159 .43466 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43488 m
.49984 .435 L
s
0 0 0 r
2 Mabswid
.49984 .435 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43488 m
.50159 .43569 L
s
0 0 0 r
2 Mabswid
.50159 .43569 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .4359 m
.49984 .43602 L
s
0 0 0 r
2 Mabswid
.49984 .43602 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .4359 m
.50159 .43672 L
s
0 0 0 r
2 Mabswid
.50159 .43672 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43691 m
.49984 .43704 L
s
0 0 0 r
2 Mabswid
.49984 .43704 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43691 m
.50159 .43775 L
s
0 0 0 r
2 Mabswid
.50159 .43775 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43793 m
.49984 .43806 L
s
0 0 0 r
2 Mabswid
.49984 .43806 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43793 m
.50159 .43877 L
s
0 0 0 r
2 Mabswid
.50159 .43877 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43895 m
.49984 .43908 L
s
0 0 0 r
2 Mabswid
.49984 .43908 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43895 m
.50159 .4398 L
s
0 0 0 r
2 Mabswid
.50159 .4398 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43997 m
.49984 .44009 L
s
0 0 0 r
2 Mabswid
.49984 .44009 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .43997 m
.50159 .44083 L
s
0 0 0 r
2 Mabswid
.50159 .44083 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44098 m
.49984 .44111 L
s
0 0 0 r
2 Mabswid
.49984 .44111 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44098 m
.50159 .44186 L
s
0 0 0 r
2 Mabswid
.50159 .44186 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .442 m
.49984 .44213 L
s
0 0 0 r
2 Mabswid
.49984 .44213 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .442 m
.50159 .44288 L
s
0 0 0 r
2 Mabswid
.50159 .44288 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44302 m
.49984 .44315 L
s
0 0 0 r
2 Mabswid
.49984 .44315 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44302 m
.50159 .44391 L
s
0 0 0 r
2 Mabswid
.50159 .44391 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44404 m
.49984 .44417 L
s
0 0 0 r
2 Mabswid
.49984 .44417 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44404 m
.50159 .44494 L
s
0 0 0 r
2 Mabswid
.50159 .44494 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44505 m
.49984 .44519 L
s
0 0 0 r
2 Mabswid
.49984 .44519 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44505 m
.50159 .44597 L
s
0 0 0 r
2 Mabswid
.50159 .44597 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44607 m
.49984 .44621 L
s
0 0 0 r
2 Mabswid
.49984 .44621 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44607 m
.50159 .44699 L
s
0 0 0 r
2 Mabswid
.50159 .44699 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44709 m
.49984 .44723 L
s
0 0 0 r
2 Mabswid
.49984 .44723 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44709 m
.50159 .44802 L
s
0 0 0 r
2 Mabswid
.50159 .44802 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44811 m
.49984 .44825 L
s
0 0 0 r
2 Mabswid
.49984 .44825 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44811 m
.50159 .44905 L
s
0 0 0 r
2 Mabswid
.50159 .44905 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44912 m
.49984 .44927 L
s
0 0 0 r
2 Mabswid
.49984 .44927 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .44912 m
.50159 .45008 L
s
0 0 0 r
2 Mabswid
.50159 .45008 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45014 m
.49984 .45029 L
s
0 0 0 r
2 Mabswid
.49984 .45029 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45014 m
.50159 .45111 L
s
0 0 0 r
2 Mabswid
.50159 .45111 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45116 m
.49984 .4513 L
s
0 0 0 r
2 Mabswid
.49984 .4513 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45116 m
.50159 .45213 L
s
0 0 0 r
2 Mabswid
.50159 .45213 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45218 m
.49984 .45232 L
s
0 0 0 r
2 Mabswid
.49984 .45232 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45218 m
.50159 .45316 L
s
0 0 0 r
2 Mabswid
.50159 .45316 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45319 m
.49984 .45334 L
s
0 0 0 r
2 Mabswid
.49984 .45334 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45319 m
.50159 .45419 L
s
0 0 0 r
2 Mabswid
.50159 .45419 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45421 m
.49984 .45436 L
s
0 0 0 r
2 Mabswid
.49984 .45436 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45421 m
.50159 .45522 L
s
0 0 0 r
2 Mabswid
.50159 .45522 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45523 m
.49984 .45538 L
s
0 0 0 r
2 Mabswid
.49984 .45538 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45523 m
.50159 .45624 L
s
0 0 0 r
2 Mabswid
.50159 .45624 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45625 m
.49984 .4564 L
s
0 0 0 r
2 Mabswid
.49984 .4564 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45625 m
.50159 .45727 L
s
0 0 0 r
2 Mabswid
.50159 .45727 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45726 m
.49984 .45742 L
s
0 0 0 r
2 Mabswid
.49984 .45742 Mdot
.009 .837 .111 r
.5 Mabswid
.5 .45726 m
.50159 .4583 L
s
0 0 0 r
2 Mabswid
.50159 .4583 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .42685 m
.02381 .74735 L
s
0 0 0 r
2 Mabswid
.02381 .74735 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .42747 m
.97619 .64531 L
s
0 0 0 r
2 Mabswid
.97619 .64531 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .42787 m
.02381 .75245 L
s
0 0 0 r
2 Mabswid
.02381 .75245 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .4285 m
.97619 .64938 L
s
0 0 0 r
2 Mabswid
.97619 .64938 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .42889 m
.02381 .75758 L
s
0 0 0 r
2 Mabswid
.02381 .75758 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .42952 m
.97619 .65345 L
s
0 0 0 r
2 Mabswid
.97619 .65345 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .42991 m
.02381 .76273 L
s
0 0 0 r
2 Mabswid
.02381 .76273 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .43055 m
.97619 .65752 L
s
0 0 0 r
2 Mabswid
.97619 .65752 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43092 m
.02381 .7679 L
s
0 0 0 r
2 Mabswid
.02381 .7679 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .43158 m
.97619 .66159 L
s
0 0 0 r
2 Mabswid
.97619 .66159 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43194 m
.02381 .77309 L
s
0 0 0 r
2 Mabswid
.02381 .77309 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .43261 m
.97619 .66566 L
s
0 0 0 r
2 Mabswid
.97619 .66566 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43296 m
.02381 .7783 L
s
0 0 0 r
2 Mabswid
.02381 .7783 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .43363 m
.97619 .66973 L
s
0 0 0 r
2 Mabswid
.97619 .66973 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43398 m
.02381 .78354 L
s
0 0 0 r
2 Mabswid
.02381 .78354 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .43466 m
.97619 .6738 L
s
0 0 0 r
2 Mabswid
.97619 .6738 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .435 m
.02381 .78879 L
s
0 0 0 r
2 Mabswid
.02381 .78879 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .43569 m
.97619 .67787 L
s
0 0 0 r
2 Mabswid
.97619 .67787 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43602 m
.02381 .79407 L
s
0 0 0 r
2 Mabswid
.02381 .79407 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .43672 m
.97619 .68194 L
s
0 0 0 r
2 Mabswid
.97619 .68194 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43704 m
.02381 .79936 L
s
0 0 0 r
2 Mabswid
.02381 .79936 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .43775 m
.97619 .68601 L
s
0 0 0 r
2 Mabswid
.97619 .68601 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43806 m
.02381 .80469 L
s
0 0 0 r
2 Mabswid
.02381 .80469 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .43877 m
.97619 .69008 L
s
0 0 0 r
2 Mabswid
.97619 .69008 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .43908 m
.02381 .81003 L
s
0 0 0 r
2 Mabswid
.02381 .81003 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .4398 m
.97619 .69415 L
s
0 0 0 r
2 Mabswid
.97619 .69415 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44009 m
.02381 .8154 L
s
0 0 0 r
2 Mabswid
.02381 .8154 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .44083 m
.97619 .69822 L
s
0 0 0 r
2 Mabswid
.97619 .69822 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44111 m
.02381 .82079 L
s
0 0 0 r
2 Mabswid
.02381 .82079 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .44186 m
.97619 .70229 L
s
0 0 0 r
2 Mabswid
.97619 .70229 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44213 m
.02381 .82621 L
s
0 0 0 r
2 Mabswid
.02381 .82621 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .44288 m
.97619 .70636 L
s
0 0 0 r
2 Mabswid
.97619 .70636 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44315 m
.02381 .83165 L
s
0 0 0 r
2 Mabswid
.02381 .83165 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .44391 m
.97619 .71043 L
s
0 0 0 r
2 Mabswid
.97619 .71043 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44417 m
.02381 .83711 L
s
0 0 0 r
2 Mabswid
.02381 .83711 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .44494 m
.97619 .7145 L
s
0 0 0 r
2 Mabswid
.97619 .7145 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44519 m
.02381 .8426 L
s
0 0 0 r
2 Mabswid
.02381 .8426 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .44597 m
.97619 .71857 L
s
0 0 0 r
2 Mabswid
.97619 .71857 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44621 m
.02381 .84812 L
s
0 0 0 r
2 Mabswid
.02381 .84812 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .44699 m
.97619 .72264 L
s
0 0 0 r
2 Mabswid
.97619 .72264 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44723 m
.02381 .85366 L
s
0 0 0 r
2 Mabswid
.02381 .85366 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .44802 m
.97619 .72671 L
s
0 0 0 r
2 Mabswid
.97619 .72671 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44825 m
.02381 .85923 L
s
0 0 0 r
2 Mabswid
.02381 .85923 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .44905 m
.97619 .73078 L
s
0 0 0 r
2 Mabswid
.97619 .73078 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .44927 m
.02381 .86483 L
s
0 0 0 r
2 Mabswid
.02381 .86483 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .45008 m
.97619 .73485 L
s
0 0 0 r
2 Mabswid
.97619 .73485 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45029 m
.02381 .87045 L
s
0 0 0 r
2 Mabswid
.02381 .87045 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .45111 m
.97619 .73892 L
s
0 0 0 r
2 Mabswid
.97619 .73892 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .4513 m
.02381 .8761 L
s
0 0 0 r
2 Mabswid
.02381 .8761 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .45213 m
.97619 .74299 L
s
0 0 0 r
2 Mabswid
.97619 .74299 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45232 m
.02381 .88178 L
s
0 0 0 r
2 Mabswid
.02381 .88178 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .45316 m
.97619 .74706 L
s
0 0 0 r
2 Mabswid
.97619 .74706 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45334 m
.02381 .88749 L
s
0 0 0 r
2 Mabswid
.02381 .88749 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .45419 m
.97619 .75113 L
s
0 0 0 r
2 Mabswid
.97619 .75113 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45436 m
.02381 .89323 L
s
0 0 0 r
2 Mabswid
.02381 .89323 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .45522 m
.97619 .7552 L
s
0 0 0 r
2 Mabswid
.97619 .7552 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45538 m
.02381 .899 L
s
0 0 0 r
2 Mabswid
.02381 .899 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .45624 m
.97619 .75927 L
s
0 0 0 r
2 Mabswid
.97619 .75927 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .4564 m
.02381 .9048 L
s
0 0 0 r
2 Mabswid
.02381 .9048 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .45727 m
.97619 .76334 L
s
0 0 0 r
2 Mabswid
.97619 .76334 Mdot
.009 .837 .111 r
.5 Mabswid
.49984 .45742 m
.02381 .91063 L
s
0 0 0 r
2 Mabswid
.02381 .91063 Mdot
.009 .837 .111 r
.5 Mabswid
.50159 .4583 m
.97619 .76741 L
s
0 0 0 r
2 Mabswid
.97619 .76741 Mdot
[(G)] .49992 .02381 0 0 Mshowa
[(S1)] .02381 .48168 0 0 Mshowa
[(S2)] .97619 .48168 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[276]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00S`3oool3000008h0oooo002>0?ooo`050000003oool000000?ooo`000000S@3oool008d0
oooo00H000000?ooo`3oool000000?ooo`00002=0?ooo`00S@3oool00`000000oooo0?ooo`030000
08d0oooo002=0?ooo`040000003oool0oooo000008l0oooo002>0?ooo`050000003oool000000?oo
o`000000S@3oool008l0oooo1000002=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03o
ool2000008h0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo
002@0?ooo`800000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`80
0000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3oool0
0900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3oool00900oooo0P00
002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3oool00900oooo0P00002>0?ooo`00
T03oool2000008h0oooo002@0?ooo`800000SP3oool00900oooo0P00002>0?ooo`00T03oool20000
08h0oooo002@0?ooo`800000SP3oool008<0oooo100000020?ooo`8000001@3oool2000008h0oooo
00230?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`020?ooo`80
0000SP3oool00800oooo0`0000000`3oool000000?ooo`020?ooo`040000003oool0oooo000000@0
oooo0P00002>0?ooo`00Q@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo0`00002=0?ooo`00QP3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo
0P00002>0?ooo`00P`3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool00P3oool2000008h0oooo00240?ooo`8000000`3oool2000000D0oooo0P00002>0?ooo`00T03o
ool2000008h0oooo002@0?ooo`800000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0
oooo002@0?ooo`800000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?oo
o`800000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3o
ool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3oool00900oooo
0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3oool00900oooo0P00002>0?oo
o`00T03oool2000008h0oooo002@0?ooo`800000SP3oool00900oooo0P00002>0?ooo`00T03oool2
000008h0oooo002@0?ooo`800000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo
002@0?ooo`800000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`80
0000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3oool0
0900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3oool00900oooo0P00
002>0?ooo`00T03oool2000008h0oooo00240?ooo`<000000P3oool2000000D0oooo0P00002>0?oo
o`00Q@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0P00002>0?oo
o`00P03oool300000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`<00000S@3oool008D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`800000SP3oool008D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`800000SP3oool008@0oooo0P0000020?ooo`040000003oool0oooo000000@0oooo0P00002>0?oo
o`00Q@3oool010000000oooo0?ooo`3oool2000000D0oooo0P00002>0?ooo`00T03oool2000008h0
oooo002@0?ooo`800000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?oo
o`800000SP3oool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3o
ool00900oooo0P00002>0?ooo`00T03oool2000008h0oooo002@0?ooo`800000SP3oool00900oooo
0P00002>0?ooo`00T03oool2000008h0oooo001S0?ooo`800]HL:`3oool2000008h0oooo001U0?oo
o`800]HL:@3oool2000008h0oooo001V0?ooo`<00]HL9`3oool2000008h0oooo001X0?ooo`@00]HL
903oool2000008h0oooo001Y0?ooo`D00]HL8P3oool2000008h0oooo001[0?ooo`D00]HL803oool2
000008h0oooo001/0?ooo`H00]HL7P3oool2000008h0oooo001^0?ooo`H00]HL703oool2000008h0
oooo001_0?ooo`L00]HL6P3oool2000008h0oooo001a0?ooo`L00]HL603oool2000008h0oooo001b
0?ooo`T00]HL5@3oool2000008h0oooo001d0?ooo`T00]HL4`3oool2000008h0oooo001e0?ooo`X0
0]HL4@3oool2000008h0oooo001g0?ooo`X00]HL3`3oool2000008h0oooo00060?ooo`8000000`3o
ool2000002D0oooo100000020?ooo`8000009P3oool300000080oooo0P00000A0?ooo`/00]HL3@3o
ool2000002L0oooo0`0000020?ooo`8000009P3oool400000080oooo0P00000V0?ooo`8000000`3o
ool2000000D0oooo00050?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo
0?ooo`0R0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0T0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool;00;F70/0oooo0P00000X
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool08`3oool01P000000oooo0?oo
o`000000oooo00000080oooo00<000000?ooo`3oool08P3oool01P000000oooo0?ooo`000000oooo
00000080oooo00<000000?ooo`3oool00P3oool00080oooo0`0000030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool07`3oool3000000030?ooo`000000oooo0080oooo00@000000?oo
o`3oool000008@3oool300000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0A0?ooo``00]HL2@3oool2000002P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0T0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool00P3oool000H0oooo0P0000020?ooo`040000
003oool0oooo000002H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0T0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool04`3oool=00;F70H0oooo0P00000X
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo02<0oooo0P0000020?ooo`040000003oool0oooo000000@0
oooo00080?ooo`030000003oool000000080oooo00<000000?ooo`3oool09@3oool00`000000oooo
000000020?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0D0?ooo`h00]HL103oool2000002P0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool000000080oooo00<000000?ooo`3oool09@3oool00`00
0000oooo000000020?ooo`030000003oool0oooo0080oooo00050?ooo`060000003oool0oooo0000
003oool000000P3oool00`000000oooo0?ooo`0R0?ooo`060000003oool0oooo0000003oool00000
0P3oool00`000000oooo0?ooo`0S0?ooo`8000000P3oool010000000oooo0?ooo`00000H0?ooo`h0
0]HL0P3oool2000002L0oooo0P0000020?ooo`040000003oool0oooo000002D0oooo00H000000?oo
o`3oool000000?ooo`0000020?ooo`030000003oool0oooo0280oooo00H000000?ooo`3oool00000
0?ooo`0000020?ooo`030000003oool0oooo0080oooo00060?ooo`8000000`3oool2000002H0oooo
0P0000030?ooo`8000009`3oool010000000oooo0?ooo`3oool2000001X0oooo3`02eQ`2000002P0
oooo00@000000?ooo`3oool0oooo0P00000W0?ooo`8000000`3oool2000002H0oooo0P0000030?oo
o`8000001@3oool008<0oooo4002eQb=0?ooo`00Q03ooolA00;F78/0oooo00260?oooa400]HLR@3o
ool008L0oooo4`02eQb60?ooo`000P3ooon7000001<00]HLQ000000000T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`0300000002eQ`00]HL01@00]HL103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3ooolJ00;F7080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`00Q@3ooolM00;F77h0oooo00230?ooob800]HLN`3oool00880oooo0`02eQ`00`3o
ool00]HL00;F700L00;F70030?ooo`02eQ`00]HL07T0oooo00200?ooo`l00]HL00@0oooo00000000
0000oooo4`02eQ`00`3oool00]HL00;F701g0?ooo`00O`3oool?00;F7080oooo0P0000020?oooaL0
0]HLM@3oool007d0oooo4002eQ`30?ooo`800000103ooolG00;F77<0oooo00030?ooo`040000003o
ool00000000000<0oooo0`00001_0?ooo``00]HL00@0oooo00;F7002eQ`00]HL103oool2000000D0
oooo6002eQaS0?ooo`040000003oool0000000000080oooo100000040?ooo`000`3oool200000080
oooo00D000000?ooo`3oool0oooo0000001^0?ooo`@00]HL00<0oooo00;F7002eQ`02P02eQ`50?oo
o`8000001`3ooolI00;F7600oooo0P0000020?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00P3oool000<0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo06/0
oooo4@02eQ`60?ooo`800000203oool@00;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002
eQ`0GP3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0103oool000@0oooo
0`0000040?ooo`030000003oool0oooo06X0oooo4@02eQ`70?ooo`8000002P3oool@00;F70030?oo
o`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`0G@3oool3000000@0oooo00<000000?ooo`3oool0
0`3oool000<0oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000JP3oool:00;F70030?oo
o`02eQ`00]HL00D00]HL203oool2000000`0oooo4002eQ`00`3oool00]HL00;F700400;F70030?oo
o`02eQ`00]HL05X0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool000<0oooo00<000000?ooo`3oool00P0000020?ooo`800000J@3ooolB00;F70T0oooo0P00
000=0?oooa400]HL00<0oooo00;F7002eQ`01`02eQaH0?ooo`030000003oool0oooo0080000000D0
oooo0000003oool0oooo000000040?ooo`00103oool2000000030?ooo`000000oooo0080oooo00<0
00000?ooo`3oool0I@3oool400;F70030?ooo`02eQ`00]HL00`00]HL2P3oool2000000l0oooo4@02
eQ`00`3oool00]HL00;F700700;F75L0oooo0P000000103oool000000?ooo`3oool2000000D0oooo
001b0?ooo`h00]HL00<0oooo00;F7002eQ`00P02eQ`;0?ooo`800000403ooolB00;F70030?ooo`02
eQ`00]HL00P00]HLH@3oool00700oooo1`02eQ`01@3oool00]HL00;F7002eQ`0oooo00P00]HL303o
ool200000180oooo4P02eQ`00`3oool00]HL00;F700500;F70030?ooo`02eQ`00]HL05l0oooo001_
0?oooa@00]HL3@3oool2000001<0oooo4`02eQ`00`3oool00]HL00;F700500;F70030?ooo`02eQ`0
0]HL05d0oooo001]0?oooaD00]HL3P3oool2000001D0oooo4`02eQ`00`3oool00]HL00;F700500;F
70030?ooo`02eQ`00]HL05/0oooo001/0?ooo`@00]HL00@0oooo00;F7002eQ`0oooo3@02eQ`?0?oo
o`8000005P3ooolD00;F70030?ooo`02eQ`00]HL00D00]HL00<0oooo00;F7002eQ`0F@3oool006X0
oooo3002eQ`00`3oool00]HL00;F700700;F7100oooo0P00000H0?oooa@00]HL00<0oooo00;F7002
eQ`02@02eQaF0?ooo`002@3oool00`000000oooo0?ooo`1M0?oooa000]HL00<0oooo00;F7002eQ`0
0`02eQ`A0?ooo`8000006@3ooolE00;F70030?ooo`02eQ`00]HL00H00]HL00<0oooo00;F7002eQ`0
C03oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`1K0?ooo`D00]HL00@0
oooo00;F7002eQ`0oooo2002eQ`00`3oool00]HL00;F700300;F7180oooo0P00000K0?oooaD00]HL
00<0oooo00;F7002eQ`01P02eQ`00`3oool00]HL00;F701:0?ooo`030000003oool0oooo00D0oooo
00090?ooo`030000003oool0oooo05X0oooo5`02eQ`C0?ooo`800000703ooolF00;F70030?ooo`02
eQ`00]HL00H00]HL00<0oooo00;F7002eQ`0B03oool00`000000oooo0?ooo`050?ooo`002@3oool0
0`000000oooo0?ooo`1H0?ooo`D00]HL00<0oooo00;F7002eQ`01@02eQ`00`3oool00]HL00;F7008
00;F71@0oooo0P00000N0?oooaH00]HL00<0oooo00;F7002eQ`01P02eQ`00`3oool00]HL00;F7016
0?ooo`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo05L0oooo2002eQ`00`3o
ool00]HL00;F700=00;F71D0oooo0P00000O0?oooaL00]HL00<0oooo00;F7002eQ`01P02eQ`00`3o
ool00]HL00;F70140?ooo`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo05D0
oooo6002eQ`G0?ooo`8000008@3ooolG00;F70030?ooo`02eQ`00]HL00H00]HL00@0oooo00;F7002
eQ`00]HL@@3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`1D0?ooo`D0
0]HL00<0oooo00;F7002eQ`04002eQ`H0?ooo`8000008`3ooolG00;F70030?ooo`02eQ`00]HL00L0
0]HL00<0oooo00;F7002eQ`0?`3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo
0?ooo`1B0?ooo`T00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700200;F70030?oo
o`02eQ`00]HL00<00]HL6@3oool2000002@0oooo6002eQ`00`3oool00]HL00;F700700;F70030?oo
o`02eQ`00]HL03d0oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0D@3o
ool500;F70030?ooo`02eQ`00]HL00/00]HL00<0oooo00;F7002eQ`00`02eQ`J0?ooo`8000009P3o
oolH00;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`0>`3oool00`000000oooo0?oo
o`050?ooo`002@3oool00`000000oooo0?ooo`1?0?oooaX00]HL6`3oool2000002L0oooo6@02eQ`0
0`3oool00]HL00;F700700;F70030?ooo`02eQ`00]HL03T0oooo00<000000?ooo`3oool01@3oool0
00T0oooo00<000000?ooo`3oool0CP3oool500;F70050?ooo`02eQ`00]HL00;F703oool04002eQ`L
0?ooo`800000:@3ooolI00;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`0=`3oool0
0`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`1<0?ooo`H00]HL00<0oooo00;F
7002eQ`01P02eQ`00`3oool00]HL00;F700900;F71d0oooo0P00000Z0?ooob@00]HL00@0oooo00;F
7002eQ`00]HL=03oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`1;0?oo
o`l00]HL00<0oooo00;F7002eQ`02@02eQ`N0?ooo`800000;03ooolI00;F70030?ooo`02eQ`00]HL
00P00]HL0P3oool200;F7380oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3o
ool0B@3oool600;F70050?ooo`02eQ`00]HL00;F703oool02P02eQ`00`3oool00]HL00;F700400;F
71l0oooo0P00000]0?oooaX00]HL00<0oooo00;F7002eQ`02@02eQ`00`3oool00]HL00;F700`0?oo
o`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo04P0oooo5@02eQ`00`3oool0
0]HL00;F700400;F7200oooo0P00000_0?oooaX00]HL00<0oooo00;F7002eQ`02@02eQ`00`3oool0
0]HL00;F700^0?ooo`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo04H0oooo
1P02eQ`00`3oool00]HL00;F700700;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`0
1002eQ`Q0?ooo`800000<03ooolK00;F70030?ooo`02eQ`00]HL00T00]HL00<0oooo00;F7002eQ`0
;03oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`150?ooo`H00]HL00D0
oooo00;F7002eQ`00]HL0?ooo`0500;F70030?ooo`02eQ`00]HL00X00]HL8P3oool200000380oooo
6`02eQ`00`3oool00]HL00;F700900;F70040?ooo`02eQ`00]HL00;F72T0oooo00<000000?ooo`3o
ool01@3oool000T0oooo00<000000?ooo`3oool0@`3ooolN00;F72<0oooo0P00000c0?oooa`00]HL
00<0oooo00;F7002eQ`02@02eQ`20?ooo`800]HL9`3oool00`000000oooo0?ooo`050?ooo`002@3o
ool00`000000oooo0?ooo`120?ooo`H00]HL00<0oooo00;F7002eQ`05@02eQ`T0?ooo`800000=@3o
oolL00;F70030?ooo`02eQ`00]HL00T00]HL0P3oool200;F72D0oooo00<000000?ooo`3oool01@3o
ool000T0oooo00<000000?ooo`3oool0@03oool;00;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo
00;F7002eQ`02`02eQ`I0?ooo`<000000P3oool2000000D0oooo0P00000f0?oooad00]HL00<0oooo
00;F7002eQ`02@02eQ`20?ooo`800]HL8`3oool00`000000oooo0?ooo`050?ooo`002@3oool00`00
0000oooo0?ooo`0o0?ooo`H00]HL00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700300;F
70030?ooo`02eQ`00]HL00D00]HL6`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo0P00000h0?oooad00]HL00<0oooo00;F7002eQ`02P02eQ`00`3oool00]HL00;F700Q
0?ooo`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo03h0oooo1P02eQ`00`3o
ool00]HL00;F700>00;F70030?ooo`02eQ`00]HL00D00]HL703oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo0P00000j0?oooa@00]HL00<0oooo00;F7002eQ`01P02eQ`0
0`3oool00]HL00;F700:00;F70030?ooo`02eQ`00]HL01l0oooo00<000000?ooo`3oool01@3oool0
00T0oooo00<000000?ooo`3oool0?03oool;00;F70030?ooo`02eQ`00]HL00X00]HL00<0oooo00;F
7002eQ`01@02eQ`M0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool3
000003X0oooo7P02eQ`00`3oool00]HL00;F700:00;F70040?ooo`02eQ`00]HL00;F71`0oooo00<0
00000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0>`3oool600;F70030?ooo`02eQ`0
0]HL00P00]HL00<0oooo00;F7002eQ`03002eQ`N0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool2000003d0oooo3002eQ`00`3oool00]HL00;F700?00;F70030?ooo`02
eQ`00]HL00X00]HL0P3oool200;F71X0oooo00<000000?ooo`3oool01@3oool000T0oooo00<00000
0?ooo`3oool0>@3ooolB00;F70030?ooo`02eQ`00]HL00`00]HL7P3oool200000080oooo00@00000
0?ooo`3oool00000103oool2000003h0oooo7`02eQ`00`3oool00]HL00;F700:00;F7080oooo0P02
eQ`H0?ooo`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo03P0oooo1P02eQ`0
0`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL01<00]HL803oool010000000oooo0?ooo`3o
ool2000000D0oooo0P0000100?oooal00]HL00<0oooo00;F7002eQ`02P02eQ`20?ooo`800]HL5P3o
ool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`0f0?ooo`L00]HL00<0oooo
00;F7002eQ`03`02eQ`00`3oool00]HL00;F700600;F72`0oooo0P0000110?ooo`d00]HL00<0oooo
00;F7002eQ`01P02eQ`00`3oool00]HL00;F700700;F70030?ooo`02eQ`00]HL00X00]HL0P3oool2
00;F71@0oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0=@3oool;00;F
70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700500;F
72h0oooo0P0000130?oooaH00]HL00<0oooo00;F7002eQ`01`02eQ`00`3oool00]HL00;F700;00;F
70030?ooo`02eQ`00]HL0180oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3o
ool0<`3oool700;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`01002eQ`00`3oool0
0]HL00;F700400;F70030?ooo`02eQ`00]HL00D00]HL;`3oool2000004@0oooo5`02eQ`00`3oool0
0]HL00;F700700;F70030?ooo`02eQ`00]HL00/00]HL00@0oooo00;F7002eQ`00]HL3`3oool00`00
0000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`0b0?ooo`@00]HL00@0oooo00;F7002
eQ`0oooo1002eQ`00`3oool00]HL00;F700;00;F70030?ooo`02eQ`00]HL00D00]HL<03oool20000
04H0oooo1@02eQ`00`3oool00]HL00;F700I00;F70030?ooo`02eQ`00]HL00/00]HL0P3oool200;F
70d0oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0<03oool700;F7003
0?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`05002eQ`a0?ooo`800000A`3oool>00;F7003
0?ooo`02eQ`00]HL01400]HL00<0oooo00;F7002eQ`02`02eQ`20?ooo`800]HL2`3oool00`000000
oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`0_0?ooo`0500;F703oool00]HL00;F703o
ool00P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00@00]HL00<0oooo00;F7002
eQ`03@02eQ`b0?ooo`800000B@3ooolG00;F70030?ooo`02eQ`00]HL00P00]HL00<0oooo00;F7002
eQ`02`02eQ`20?ooo`800]HL2@3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo
0?ooo`0]0?ooo`d00]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700=00;F73<0oooo
0P00001:0?ooo`H00]HL00<0oooo00;F7002eQ`03`02eQ`00`3oool00]HL00;F700800;F70030?oo
o`02eQ`00]HL00/00]HL0P3oool200;F70L0oooo00<000000?ooo`3oool01@3oool000T0oooo00<0
00000?ooo`3oool0;03oool00`02eQ`0oooo00;F700400;F70030?ooo`02eQ`00]HL00800]HL00<0
oooo00;F7002eQ`03002eQ`00`3oool00]HL00;F700600;F73@0oooo0P00001<0?ooo`h00]HL00<0
oooo00;F7002eQ`01`02eQ`00`3oool00]HL00;F700800;F70030?ooo`02eQ`00]HL00/00]HL0P3o
ool300;F70@0oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0:P3oool8
00;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`03002eQ`00`3oool00]HL00;F7006
00;F73D0oooo0P00001=0?ooo`H00]HL00<0oooo00;F7002eQ`01P02eQ`00`3oool00]HL00;F7007
00;F70030?ooo`02eQ`00]HL00P00]HL00<0oooo00;F7002eQ`03002eQ`20?ooo`800]HL0P3oool0
0`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`0Y0?ooo`0300;F703oool00]HL
00@00]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F700400;F70030?ooo`02eQ`0
0]HL00D00]HL00<0oooo00;F7002eQ`01P02eQ`f0?ooo`800000C`3ooolS00;F7080oooo3P02eQ`2
0?ooo`800]HL00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool09`3oool500;F
70040?ooo`02eQ`00]HL0?ooo`@00]HL00<0oooo00;F7002eQ`01@02eQ`00`3oool00]HL00;F7005
00;F70030?ooo`02eQ`00]HL00H00]HL=`3oool200000540oooo3P02eQ`00`3oool00]HL00;F7007
00;F70030?ooo`02eQ`00]HL00P00]HL0P3oool>00;F70030?ooo`000000000000L0oooo00090?oo
o`030000003oool0oooo02H0oooo00<00]HL0?ooo`02eQ`02P02eQ`00`3oool00]HL00;F700500;F
70030?ooo`02eQ`00]HL00h00]HL>03oool200000580oooo1P02eQ`00`3oool00]HL00;F700600;F
70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`02002eQ`20?ooo`d00]HL0P0000070?oo
o`002@3oool00`000000oooo0?ooo`0T0?ooo`D00]HL00@0oooo00;F7002eQ`0oooo0P02eQ`0103o
ool00]HL00;F703oool400;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`02`02eQ`i
0?ooo`800000E03oool?00;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`02002eQ`2
0?ooo`/00]HL0P0000070?ooo`002@3oool00`000000oooo0?ooo`0S0?ooo`0300;F703oool00]HL
00D00]HL00<0oooo00;F7002eQ`00P02eQ`0103oool00]HL00;F703oool400;F70030?ooo`02eQ`0
0]HL00D00]HL00<0oooo00;F7002eQ`01`02eQ`j0?ooo`800000E@3oool600;F70030?ooo`02eQ`0
0]HL00H00]HL00<0oooo00;F7002eQ`02002eQ`00`3oool00]HL00;F700800;F7080oooo2@02eQ`2
000000L0oooo00090?ooo`030000003oool0oooo0240oooo1@02eQ`0103oool00]HL00;F703oool5
00;F70030?ooo`02eQ`00]HL00D00]HL00<0oooo00;F7002eQ`01@02eQ`00`3oool00]HL00;F7007
00;F73/0oooo0P00001G0?ooo`H00]HL00<0oooo00;F7002eQ`01P02eQ`00`3oool00]HL00;F7008
00;F70030?ooo`02eQ`00]HL00P00]HL0P3oool800;F70030000003oool0oooo00D0oooo00090?oo
o`030000003oool0oooo0200oooo00<00]HL0?ooo`02eQ`01@02eQ`0103oool00]HL00;F703oool2
00;F70030?ooo`02eQ`00]HL00D00]HL00<0oooo00;F7002eQ`01@02eQ`00`3oool00]HL00;F7007
00;F73`0oooo0P00001H0?oooa000]HL00<0oooo00;F7002eQ`01`02eQ`20?ooo`X00]HL0P3oool6
00;F70030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo01h0oooo0P02eQ`0103o
ool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL00<00]HL00@0oooo00;F7002eQ`0oooo0P02
eQ`00`3oool00]HL00;F700800;F70030?ooo`02eQ`00]HL00L00]HL?@3oool2000005X0oooo1P02
eQ`00`3oool00]HL00;F700600;F70030?ooo`02eQ`00]HL00P00]HL00<0oooo00;F7002eQ`02@02
eQ`20?ooo`@00]HL00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool07@3oool0
0`02eQ`0oooo00;F700200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo
1`02eQ`01@3oool00]HL00;F7002eQ`0oooo00h00]HL?P3oool2000005/0oooo4002eQ`00`3oool0
0]HL00;F700800;F70030?ooo`02eQ`00]HL00T00]HL0P3oool200;F70030000003oool0oooo00D0
oooo00090?ooo`030000003oool0oooo01/0oooo0P02eQ`00`3oool00]HL00;F700400;F70040?oo
o`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`01@02eQ`00`3oool00]HL00;F700@00;F73l0
oooo0P00001M0?ooo`H00]HL00<0oooo00;F7002eQ`01`02eQ`00`3oool00]HL00;F700800;F7003
0?ooo`02eQ`00]HL00T00]HL00<0oooo0000000000001`3oool000T0oooo00<000000?ooo`3oool0
6P3oool00`02eQ`0oooo00;F700200;F70040?ooo`02eQ`00]HL0?ooo`D00]HL00<0oooo00;F7002
eQ`00`02eQ`0103oool00]HL00;F703ooolB00;F7400oooo0P00001N0?ooo`L00]HL00<0oooo00;F
7002eQ`01`02eQ`00`3oool00]HL00;F700800;F70030?ooo`02eQ`00]HL00P00]HL0P0000070?oo
o`002@3oool00`000000oooo0?ooo`0H0?ooo`800]HL00<0oooo00;F7002eQ`01002eQ`0103oool0
0]HL00;F703oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`00P02eQ`0
1`3oool00]HL00;F7002eQ`0oooo00;F703oool02P02eQa10?ooo`800000H03oool600;F70030?oo
o`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`02002eQ`20?ooo`P00]HL0P0000070?ooo`002@3o
ool00`000000oooo0?ooo`0G0?ooo`0300;F703oool00]HL00800]HL00@0oooo00;F7002eQ`0oooo
1P02eQ`00`3oool00]HL00;F700500;F70030?ooo`02eQ`00]HL00H00]HL00<0oooo00;F7002eQ`0
2002eQa20?ooo`800000H@3oool700;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`0
2002eQ`20?ooo`H00]HL0P0000070?ooo`002@3oool00`000000oooo0?ooo`0E0?ooo`800]HL00D0
oooo00;F7002eQ`00]HL0?ooo`0200;F70030?ooo`02eQ`00]HL00<00]HL00<0oooo00;F7002eQ`0
1P02eQ`01@3oool00]HL00;F7002eQ`0oooo00@00]HL00<0oooo00;F7002eQ`01`02eQa40?ooo`80
0000H`3oool700;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo00;F7002eQ`02002eQ`20?ooo`D0
0]HL00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0503oool00`02eQ`0oooo
00;F700200;F70050?ooo`02eQ`00]HL00;F703oool00P02eQ`0103oool00]HL00;F703oool200;F
70040?ooo`02eQ`00]HL0?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0400;F70030?ooo`02
eQ`0oooo00L00]HLA@3oool2000006@0oooo1`02eQ`00`3oool00]HL00;F700700;F7080oooo2P02
eQ`00`3oool00]HL00;F700200;F70030000003oool0oooo00D0oooo00090?ooo`030000003oool0
oooo01<0oooo00<00]HL0?ooo`02eQ`00P02eQ`0103oool00]HL00;F703oool600;F70030?ooo`02
eQ`00]HL00<00]HL00<0oooo00;F7002eQ`00P02eQ`00`3oool00]HL00;F700>00;F74H0oooo0P00
001V0?ooo`L00]HL00<0oooo00;F7002eQ`01`02eQ`00`3oool00]HL00;F700900;F70040?ooo`02
eQ`00]HL000000L0oooo00090?ooo`030000003oool0oooo0140oooo1@02eQ`01@3oool00]HL00;F
7002eQ`0oooo00800]HL00@0oooo00;F7002eQ`0oooo2002eQ`0103oool00]HL00;F703oool900;F
70030?ooo`02eQ`00]HL00@00]HLA`3oool2000006P0oooo1P02eQ`00`3oool00]HL00;F700800;F
70030?ooo`02eQ`00]HL00P00]HL00<0oooo0000000000001`3oool000T0oooo00<000000?ooo`3o
ool0403oool00`02eQ`0oooo00;F700200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`0103oool0
0]HL00;F703oool200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`01002eQ`0
0`3oool00]HL0?ooo`0300;F70030?ooo`02eQ`00]HL00@00]HLB03oool2000006T0oooo1`02eQ`0
0`3oool00]HL00;F700700;F7080oooo2@02eQ`2000000L0oooo00090?ooo`030000003oool0oooo
00h0oooo0P02eQ`0103oool00]HL00;F703oool300;F70030?ooo`02eQ`00]HL00@00]HL00@0oooo
00;F7002eQ`0oooo0P02eQ`0103oool00]HL00;F703oool300;F70030?ooo`02eQ`00]HL00800]HL
00<0oooo00;F7002eQ`02002eQa90?ooo`800000J`3oool700;F70030?ooo`02eQ`00]HL00L00]HL
00<0oooo00;F7002eQ`01P02eQ`2000000L0oooo00090?ooo`030000003oool0oooo00d0oooo00<0
0]HL0?ooo`02eQ`00P02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL00@0oooo00;F7002eQ`0
oooo3@02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00P00]HLBP3oool2000006`0
oooo1`02eQ`00`3oool00]HL00;F700800;F70030?ooo`02eQ`00]HL00@00]HL0P0000070?ooo`00
2@3oool00`000000oooo0?ooo`0;0?ooo`800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F7005
0?ooo`02eQ`00]HL00;F703oool00P02eQ`0103oool00]HL00;F703oool500;F70040?ooo`02eQ`0
0]HL0?ooo`H00]HL00<0oooo00;F7002eQ`00`02eQ`00`3oool00]HL00;F700200;F74/0oooo0P00
001^0?ooo`L00]HL00<0oooo00;F7002eQ`01`02eQ`20?ooo`D00]HL00<000000?ooo`3oool01@3o
ool000T0oooo00<000000?ooo`3oool02P3oool00`02eQ`0oooo00;F700200;F70050?ooo`02eQ`0
0]HL00;F703oool00P02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL00@0oooo00;F7002eQ`0
oooo0P02eQ`0103oool00]HL00;F703oool600;F70030?ooo`02eQ`0oooo00<00]HL00<0oooo00;F
7002eQ`00P02eQa<0?ooo`800000K`3oool700;F7080oooo2@02eQ`20?ooo`<00]HL00<000000?oo
o`3oool01@3oool000T0oooo00<000000?ooo`3oool0203oool200;F70050?ooo`02eQ`00]HL00;F
703oool00P02eQ`20?ooo`800]HL00@0oooo00;F7002eQ`0oooo1P02eQ`0103oool00]HL00;F703o
ool600;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`01P02eQa=0?ooo`800000L@3o
ool700;F70030?ooo`02eQ`00]HL00P00]HL00@0oooo00;F7002eQ`000001`3oool000T0oooo00<0
00000?ooo`3oool01`3oool00`02eQ`0oooo00;F700200;F70050?ooo`02eQ`00]HL00;F703oool0
0`02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL00@00]HL00D0oooo00;F7002
eQ`00]HL0?ooo`0200;F70030?ooo`02eQ`00]HL00800]HL00<0oooo00;F7002eQ`00P02eQ`0103o
ool00]HL00;F7002eQa>0?ooo`800000LP3oool800;F70030?ooo`02eQ`00]HL00L00]HL00<0oooo
0000000000001`3oool000T0oooo00<000000?ooo`3oool01@3oool200;F70050?ooo`02eQ`00]HL
00;F703oool00`02eQ`0103oool00]HL00;F703oool300;F70040?ooo`02eQ`00]HL0?ooo`800]HL
00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL0?ooo`0400;F70030?ooo`02eQ`00]HL00D0
0]HL00@0oooo00;F7002eQ`00]HLC`3oool2000007@0oooo1`02eQ`00`3oool00]HL00;F700700;F
708000001`3oool000T0oooo00<000000?ooo`3oool0103oool00`02eQ`0oooo00;F700200;F7005
0?ooo`02eQ`00]HL00;F703oool00`02eQ`0103oool00]HL00;F703oool300;F70040?ooo`02eQ`0
0]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo1P02eQ`01@3oool00]HL00;F7002eQ`0oooo00<0
0]HL00@0oooo00;F7002eQ`00]HLD03oool2000007D0oooo2002eQ`00`3oool00]HL00;F700500;F
708000001`3oool000T0oooo00<000000?ooo`3oool00P3oool200;F70050?ooo`02eQ`00]HL00;F
703oool00`02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL00<0oooo00;F7002eQ`01002eQ`0
103oool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL00@00]HL00D0oooo00;F7002eQ`00]HL
0?ooo`0700;F7540oooo0P00001g0?ooo`L00]HL0P3oool500;F708000001`3oool000T0oooo00D0
00000?ooo`3oool0oooo00;F70020?ooo`800]HL0P3oool200;F7080oooo0P02eQ`01@3oool00]HL
00;F7002eQ`0oooo00800]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL00;F700400;F7004
0?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`01@02eQaB0?ooo`800000N03oool800;F
70030?ooo`02eQ`00]HL00<00]HL00<000000?ooo`3oool01@3oool000T0oooo00D000000?ooo`02
eQ`00]HL0?ooo`0300;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`00`3oool00]HL00;F7002
0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`00`3oool00]HL00;F700200;F70040?ooo`02
eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`01`02eQ`00`3oool00]HL0?ooo`150?ooo`@00000
0P3oool2000000D0oooo0P00001j0?ooo`L00]HL0P3oool300;F70030000003oool0oooo00D0oooo
00090?ooo`0400000002eQ`0oooo0?ooo`<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F7080
oooo0P02eQ`00`3oool00]HL00;F700400;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F
703oool00P02eQ`00`3oool00]HL00;F700200;F70030?ooo`02eQ`00]HL00D00]HL00<0oooo00;F
703oool0AP3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3o
ool2000007/0oooo2002eQ`20?ooo`0300;F70000000oooo00H0oooo00080?ooo`80000000D0oooo
00;F7002eQ`00]HL0?ooo`0300;F70050?ooo`02eQ`00]HL00;F703oool00`02eQ`0103oool00]HL
00;F703oool300;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F703oool01002eQ`0103o
ool00]HL00;F703oool300;F70060?ooo`02eQ`00]HL00;F703oool00]HLB@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000007`0oooo2002eQ`2000000L0
oooo00080?ooo`8000000`02eQ`01@3oool00]HL00;F7002eQ`0oooo00<00]HL00<0oooo00;F7002
eQ`00P3oool200;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00@0oooo00;F7002eQ`0oooo1P02eQ`0
103oool00]HL00;F703oool300;F70060?ooo`02eQ`00]HL00;F703oool00]HLB`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0P00001o0?ooo`H00]HL0P0000070?oo
o`00203oool20000000300;F703oool0oooo00800]HL0P3oool200;F70050?ooo`02eQ`00]HL00;F
703oool00`02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`00]HL00P00]HL00<0oooo
00;F7002eQ`01002eQ`01P3oool00]HL00;F7002eQ`0oooo00;F74d0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`800000P03oool500;F708000001`3oool000P0oooo0P00
00001@3oool00]HL00;F7002eQ`0oooo00<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`0200;F7005
0?ooo`02eQ`00]HL00;F703oool00P02eQ`01P3oool00]HL00;F703oool00]HL0?ooo`800]HL00@0
oooo00;F7002eQ`0oooo0`02eQ`0103oool00]HL00;F703oool300;F70030?ooo`02eQ`0oooo04X0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo0P000022
0?ooo`<00]HL0P0000070?ooo`00203oool2000000<00]HL00D0oooo00;F7002eQ`00]HL0?ooo`02
00;F7080oooo0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL00H0oooo00;F7002eQ`0oooo
00;F703oool200;F70040?ooo`02eQ`00]HL0?ooo`<00]HL00<0oooo00;F7002eQ`01P02eQa=0?oo
o`8000000`3oool2000000D0oooo0P0000230?ooo`800]HL0P0000070?ooo`00203oool200000003
00;F703oool00]HL00800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F70040?ooo`02eQ`00]HL
0?ooo`<00]HL00H0oooo00;F7002eQ`0oooo00;F703oool200;F70040?ooo`02eQ`00]HL0?ooo`<0
0]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F75/0oooo0P0000250?ooo`0300;F70000000oooo
00H0oooo00080?ooo`80000000D0oooo00;F7002eQ`00]HL0?ooo`0300;F70040?ooo`02eQ`00]HL
0?ooo`<00]HL00@0oooo00;F7002eQ`0oooo0`02eQ`00`3oool00]HL00;F700200;F70030?ooo`02
eQ`00]HL00800]HL00<0oooo00;F703oool00`02eQ`0103oool00]HL00;F7002eQaL0?ooo`800000
Q@3oool2000000L0oooo00080?ooo`8000000P02eQ`20?ooo`800]HL0P3oool200;F70050?ooo`02
eQ`00]HL00;F703oool00P02eQ`0103oool00]HL00;F703oool700;F70060?ooo`02eQ`00]HL0?oo
o`02eQ`0oooo0`02eQ`0103oool00]HL00;F7002eQaM0?ooo`800000Q@3oool2000000L0oooo0008
0?ooo`80000000<00]HL0?ooo`02eQ`00P02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL0P3o
ool200;F70060?ooo`02eQ`00]HL0?ooo`02eQ`0oooo0P02eQ`0103oool00]HL00;F703oool200;F
70030?ooo`02eQ`00]HL00<00]HL00@0oooo00;F7002eQ`00]HLGP3oool2000008H0oooo00<00000
0?ooo`3oool01@3oool000P0oooo0P0000001@3oool00]HL00;F7002eQ`0oooo00<00]HL00@0oooo
00;F7002eQ`0oooo0`02eQ`01P3oool00]HL00;F703oool00]HL0?ooo`800]HL00@0oooo00;F7002
eQ`0oooo0P02eQ`00`3oool00]HL00;F700300;F70040?ooo`02eQ`00]HL00;F75l0oooo0P000026
0?ooo`030000003oool0oooo00D0oooo00080?ooo`8000000P02eQ`20?ooo`800]HL00D0oooo00;F
7002eQ`00]HL0?ooo`0200;F70070?ooo`02eQ`00]HL00;F703oool00]HL0?ooo`0200;F70040?oo
o`02eQ`00]HL0?ooo`800]HL00L0oooo00;F7002eQ`00]HL0?ooo`02eQ`0oooo00<00]HLH03oool2
000008H0oooo00<000000?ooo`3oool01@3oool000P0oooo0P0000000`02eQ`0oooo00;F700200;F
70050?ooo`02eQ`00]HL00;F703oool00P02eQ`00`3oool00]HL00;F700300;F70040?ooo`02eQ`0
0]HL0?ooo`800]HL00<0oooo00;F7002eQ`01002eQ`00`3oool00]HL0?ooo`0300;F7640oooo0P00
00260?ooo`030000003oool0oooo00D0oooo00080?ooo`80000000D0oooo00;F7002eQ`00]HL0?oo
o`0200;F70050?ooo`02eQ`00]HL00;F703oool00P02eQ`00`3oool00]HL0?ooo`0300;F70040?oo
o`02eQ`00]HL0?ooo`<00]HL00@0oooo00;F7002eQ`0oooo1@02eQaR0?ooo`800000QP3oool00`00
0000oooo0?ooo`050?ooo`00203oool2000000800]HL00D0oooo00;F7002eQ`00]HL0?ooo`0300;F
70060?ooo`02eQ`00]HL0?ooo`02eQ`0oooo1@02eQ`00`3oool00]HL00;F700200;F70040?ooo`02
eQ`00]HL0?ooo`D00]HLH`3oool2000008H0oooo00<000000?ooo`3oool01@3oool000P0oooo0P00
00000`02eQ`0oooo00;F700200;F70030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool00]HL0?oo
o`0200;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F703oool00P02eQ`01P3oool00]HL
00;F7002eQ`0oooo00;F76@0oooo0P0000260?ooo`030000003oool0oooo00D0oooo00080?ooo`80
000000<0oooo00;F7002eQ`00P3oool200;F70070?ooo`02eQ`00]HL00;F703oool00]HL0?ooo`02
00;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F703oool00P02eQ`01P3oool00]HL00;F
7002eQ`0oooo00;F76D0oooo0P0000260?ooo`030000003oool0oooo00D0oooo00080?ooo`800000
0P02eQ`01@3oool00]HL00;F7002eQ`0oooo00800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`0103o
ool00]HL00;F703oool200;F70030?ooo`02eQ`0oooo00800]HL00H0oooo00;F7002eQ`00]HL0?oo
o`02eQaV0?ooo`800000QP3oool00`000000oooo0?ooo`050?ooo`00203oool20000000300;F703o
ool00]HL00800]HL00H0oooo00;F7002eQ`0oooo00;F703oool300;F70040?ooo`02eQ`00]HL0?oo
o`800]HL00<0oooo00;F703oool01P02eQ`00`3oool00]HL0?ooo`1V0?ooo`800000QP3oool00`00
0000oooo0?ooo`050?ooo`00203oool2000000030?ooo`02eQ`00]HL0080oooo0P02eQ`00`3oool0
0]HL0?ooo`0300;F70040?ooo`02eQ`00]HL0?ooo`800]HL00<0oooo00;F7002eQ`00`02eQ`01@3o
ool00]HL00;F703oool00]HL06P0oooo0P0000260?ooo`030000003oool0oooo00D0oooo00080?oo
o`8000000P02eQ`01`3oool00]HL00;F7002eQ`0oooo00;F703oool00P02eQ`01@3oool00]HL00;F
7002eQ`0oooo00800]HL00<0oooo00;F7002eQ`00`02eQ`01@3oool00]HL00;F703oool00]HL06T0
oooo0P0000260?ooo`030000003oool0oooo00D0oooo00080?ooo`80000000<00]HL0?ooo`02eQ`0
0P02eQ`00`3oool00]HL0?ooo`0200;F70040?ooo`02eQ`00]HL0?ooo`L00]HL00<0oooo00;F703o
ool00P02eQ`00`3oool00]HL0?ooo`1Y0?ooo`800000QP3oool00`000000oooo0?ooo`050?ooo`00
203oool2000000040?ooo`02eQ`00]HL0?ooo`800]HL00@0oooo00;F7002eQ`0oooo0P02eQ`01P3o
ool00]HL00;F703oool00]HL0?ooo`800]HL00<0oooo00;F703oool00P02eQ`00`3oool00]HL0?oo
o`1Z0?ooo`800000QP3oool00`000000oooo0?ooo`050?ooo`00203oool2000000800]HL00@0oooo
00;F703oool0oooo0P02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`0oooo00800]HL
00<0oooo00;F703oool00P02eQ`00`3oool00]HL0?ooo`1[0?ooo`800000QP3oool00`000000oooo
0?ooo`050?ooo`00203oool20000000400;F703oool00]HL0?ooo`<00]HL00@0oooo00;F7002eQ`0
oooo0P02eQ`00`3oool00]HL0?ooo`0200;F70030?ooo`02eQ`0oooo00800]HL00<0oooo00;F703o
ool0K03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00080?ooo`800000
00<0oooo00;F703oool00`02eQ`0103oool00]HL00;F703oool200;F70030?ooo`02eQ`0oooo0080
0]HL00<0oooo00;F703oool00P02eQ`00`3oool00]HL0?ooo`1]0?ooo`030000003oool0oooo08D0
oooo00<000000?ooo`3oool01@3oool000P0oooo0P0000001@02eQ`0oooo00;F7002eQ`0oooo00<0
0]HL00H0oooo00;F7002eQ`0oooo00;F703oool200;F70030?ooo`02eQ`0oooo00@00]HLK`3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00080?ooo`80000000@0oooo00;F
7002eQ`0oooo0P02eQ`20?ooo`800]HL00<0oooo00;F703oool00P02eQ`00`3oool00]HL0?ooo`03
00;F7740oooo0P0000260?ooo`030000003oool0oooo00D0oooo00080?ooo`8000000P02eQ`0103o
ool00]HL00;F703oool300;F70030?ooo`02eQ`0oooo00800]HL00<0oooo00;F703oool00`02eQab
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000P0oooo0P0000001@02
eQ`0oooo00;F7002eQ`0oooo00D00]HL00@0oooo00;F7002eQ`0oooo1@02eQac0?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool01@3oool000P0oooo0P000000103oool00]HL00;F703o
ool200;F70030?ooo`02eQ`0oooo00T00]HLM03oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo00D0oooo00080?ooo`8000000P02eQ`01P3oool00]HL00;F703oool00]HL0?ooo`@00]HL
00D0oooo00;F7002eQ`0oooo00;F701e0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool01@3oool000P0oooo0P0000001`02eQ`0oooo00;F7002eQ`0oooo00;F703oool00P02eQ`00`3o
ool00]HL0?ooo`0200;F70030?ooo`02eQ`0oooo07D0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`050?ooo`00203oool2000000060?ooo`02eQ`00]HL0?ooo`02eQ`0oooo0P02eQ`0
0`3oool00]HL0?ooo`0200;F70030?ooo`02eQ`0oooo07H0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`050?ooo`00203oool2000000800]HL00<0oooo00;F703oool00P02eQ`00`3o
ool00]HL0?ooo`0200;F70030?ooo`02eQ`0oooo07L0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`050?ooo`00203oool20000000400;F703oool00]HL0?ooo`800]HL00<0oooo00;F
703oool00P02eQ`00`3oool00]HL0?ooo`1h0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000P0oooo0P0000000`3oool00]HL0?ooo`0200;F70030?ooo`02eQ`0oooo0080
0]HL00<0oooo00;F703oool0N@3oool2000008H0oooo00<000000?ooo`3oool01@3oool000P0oooo
0P0000001`02eQ`0oooo00;F7002eQ`0oooo00;F703oool00P02eQ`00`3oool00]HL0?ooo`1j0?oo
o`030000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000P0oooo0P0000001P3oool0
0]HL00;F703oool00]HL0?ooo`800]HL00<0oooo00;F703oool0N`3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo00D0oooo00080?ooo`8000000P02eQ`00`3oool00]HL0?ooo`0200;F
70030?ooo`02eQ`0oooo07`0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?oo
o`00203oool20000000400;F703oool00]HL0?ooo`800]HL00<0oooo00;F703oool0O@3oool00`00
0000oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00080?ooo`80000000<0oooo00;F703o
ool00P02eQ`00`3oool00]HL0?ooo`1n0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool01@3oool000P0oooo0P0000001P02eQ`0oooo00;F7002eQ`0oooo00;F77@0oooo0P0000030?oo
o`8000001@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00080?ooo`80
000000D0oooo00;F7002eQ`0oooo00;F701d0?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool01@3o
ool000P0oooo0P00000200;F70030?ooo`02eQ`0oooo07L0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool0
00P0oooo0P0000000`02eQ`0oooo00;F701g0?ooo`8000000P3oool010000000oooo0?ooo`000004
0?ooo`<00000Q@3oool00`000000oooo0?ooo`050?ooo`00203oool2000000030?ooo`02eQ`0oooo
07T0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool01@3oool000P0oooo0P0000000`02eQ`0oooo0?ooo`1f0?ooo`06
0000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool01@3oool000P0oooo0P00001j0?ooo`8000000`3oool20000
00D0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000T0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo
00090?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`050?ooo`002@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo08@0oooo0P0000260?ooo`03
0000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo
08@0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000T0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo
00090?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`050?ooo`002@3oool00`000000oooo0?ooo`240?ooo`800000QP3oool00`000000oooo0?ooo`05
0?ooo`002@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000T0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo
002@0?ooo`800000SP3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?oo
o`3oool0S@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-31.9913, -29.2156, 0.221225, \
0.230074}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Print[\"Bragg angle and diffracted intensity: \",
\tReadRays[tracedsystem,{ArcCos[RayTilt.{1,0,0}]/Degree,Intensity}, \
DiffractionOrderNumber->1][[13]]
]\
\>", "Input",
  CellLabel->"In[281]:="],

Cell[BoxData[
    InterpretationBox[\("Bragg angle and diffracted intensity: "\
\[InvisibleSpace]{29.133121499123092`, 100.`}\),
      SequenceForm[ 
      "Bragg angle and diffracted intensity: ", {29.133121499123092, 100.0}],
      Editable->False]], "Print",
  CellLabel->"From In[281]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Angle Dependency", "ExampleSubsection"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[
\tReadRays[tracedsystem,{ArcCos[RayTilt.{1,0,0}]/Degree,Intensity}, \
ComponentNumber->2]
];\
\>", "Input",
  CellLabel->"In[277]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-13.2364 0.0980176 0.0147151 0.00699745 [
[.29005 .00222 -9 -9 ]
[.29005 .00222 9 0 ]
[.48609 .00222 -9 -9 ]
[.48609 .00222 9 0 ]
[.68212 .00222 -9 -9 ]
[.68212 .00222 9 0 ]
[.87816 .00222 -9 -9 ]
[.87816 .00222 9 0 ]
[.08152 .15466 -12 -4.5 ]
[.08152 .15466 0 4.5 ]
[.08152 .29461 -12 -4.5 ]
[.08152 .29461 0 4.5 ]
[.08152 .43456 -12 -4.5 ]
[.08152 .43456 0 4.5 ]
[.08152 .57451 -12 -4.5 ]
[.08152 .57451 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.29005 .01472 m
.29005 .02097 L
s
[(138)] .29005 .00222 0 1 Mshowa
.48609 .01472 m
.48609 .02097 L
s
[(140)] .48609 .00222 0 1 Mshowa
.68212 .01472 m
.68212 .02097 L
s
[(142)] .68212 .00222 0 1 Mshowa
.87816 .01472 m
.87816 .02097 L
s
[(144)] .87816 .00222 0 1 Mshowa
.125 Mabswid
.14302 .01472 m
.14302 .01847 L
s
.19203 .01472 m
.19203 .01847 L
s
.24104 .01472 m
.24104 .01847 L
s
.33906 .01472 m
.33906 .01847 L
s
.38807 .01472 m
.38807 .01847 L
s
.43708 .01472 m
.43708 .01847 L
s
.5351 .01472 m
.5351 .01847 L
s
.5841 .01472 m
.5841 .01847 L
s
.63311 .01472 m
.63311 .01847 L
s
.73113 .01472 m
.73113 .01847 L
s
.78014 .01472 m
.78014 .01847 L
s
.82915 .01472 m
.82915 .01847 L
s
.04501 .01472 m
.04501 .01847 L
s
.92717 .01472 m
.92717 .01847 L
s
.97617 .01472 m
.97617 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.09402 .15466 m
.10027 .15466 L
s
[(20)] .08152 .15466 1 0 Mshowa
.09402 .29461 m
.10027 .29461 L
s
[(40)] .08152 .29461 1 0 Mshowa
.09402 .43456 m
.10027 .43456 L
s
[(60)] .08152 .43456 1 0 Mshowa
.09402 .57451 m
.10027 .57451 L
s
[(80)] .08152 .57451 1 0 Mshowa
.125 Mabswid
.09402 .0497 m
.09777 .0497 L
s
.09402 .08469 m
.09777 .08469 L
s
.09402 .11968 m
.09777 .11968 L
s
.09402 .18965 m
.09777 .18965 L
s
.09402 .22464 m
.09777 .22464 L
s
.09402 .25963 m
.09777 .25963 L
s
.09402 .3296 m
.09777 .3296 L
s
.09402 .36459 m
.09777 .36459 L
s
.09402 .39957 m
.09777 .39957 L
s
.09402 .46955 m
.09777 .46955 L
s
.09402 .50454 m
.09777 .50454 L
s
.09402 .53952 m
.09777 .53952 L
s
.09402 .6095 m
.09777 .6095 L
s
.25 Mabswid
.09402 0 m
.09402 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.97619 .02633 Mdot
.94266 .03772 Mdot
.90925 .03756 Mdot
.87596 .02421 Mdot
.84279 .01474 Mdot
.80974 .03105 Mdot
.77682 .06607 Mdot
.74402 .08382 Mdot
.71135 .0574 Mdot
.67879 .01517 Mdot
.64637 .09208 Mdot
.61406 .30392 Mdot
.58188 .46974 Mdot
.54983 .55445 Mdot
.51789 .59199 Mdot
.48609 .60332 Mdot
.4544 .59457 Mdot
.42285 .56043 Mdot
.39141 .4802 Mdot
.3601 .31596 Mdot
.32892 .09417 Mdot
.29785 .01599 Mdot
.26691 .0664 Mdot
.2361 .09176 Mdot
.20541 .06594 Mdot
.17484 .02601 Mdot
.14439 .01582 Mdot
.11406 .03317 Mdot
.08386 .04488 Mdot
.05377 .03638 Mdot
.02381 .01997 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[277]:=",
  ImageSize->{700, 432.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:l0001/2000`400?l00000o`00003oo`3ooooo
0?oookh0oooo00350?ooo`<000000`3oool3000000<0oooo0`00001g0?ooo`<00000103oool30000
00<0oooo0P00001h0?ooo`<00000103oool3000000030?ooo`000000000000<00000MP3oool30000
00@0oooo0`0000030?ooo`<00000E03oool00<H0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo07D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05<0oooo0036
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1e
0?ooo`040000003oool0oooo0?ooo`D000000P3oool010000000oooo0?ooo`00001h0?ooo`040000
003oool0oooo0?ooo`D000000`3oool00`000000oooo0?ooo`1g0?ooo`040000003oool0oooo0?oo
o`D0000000<0oooo0000000000000`00001D0?ooo`00aP3oool00`000000oooo0?ooo`030?ooo`80
00000`3oool3000007P0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`1f0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0D`3oool00<H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo000000030?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`040000003oool0oooo000007P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000020?ooo`050000003oool0oooo0?oo
o`000000M`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000E@3oool00<D0oooo0P0000030?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0oooo07@0oooo0P0000050?ooo`8000000`3oool010000000oooo0?ooo`00
001g0?ooo`8000001@3oool200000080oooo00D000000?ooo`3oool0oooo0000001f0?ooo`800000
1@3oool2000000@0oooo0P00001E0?ooo`00aP3oool00`000000oooo0?ooo`020?ooo`<000000`3o
ool3000007P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`800000N@3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<00000N03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D`3oool004L0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd
0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?ooohd0oooo0`00001^0?ooo`<00000LP3oool004L0oooo00<000000?ooo`3oool0
7P3oool3000006H0oooo0`00003o0?ooo`80oooo1@00001/0?ooo`D00000L@3oool000H0ooooo`00
003o00000;4000001`3oool001D0oooo0`00000=0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool07@3oool5000001h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00D000006P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`H000008@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0103oool5
000001D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01D0oooo000D0?ooo`D00000303oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01d0oooo1@00000N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`05000001X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool06`3oool3000000030?ooo`000000oooo
0200oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
00D0oooo0`00000F0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0E0?ooo`00503oool5000002h0oooo00<000000?ooo`3oool07P3oool300000680
oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool0P`3oool00`000000oooo0?ooo`1I0?ooo`00503oool5000002h0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0P@3oool3000005/0oooo000E0?ooo`<00000;`3oool00`000000oooo0?ooo`3o0?ooool0oooo
5@3oool5000005X0oooo00170?ooo`030000003oool0oooo03<0oooo0`00003o0?ooomh0oooo1@00
00100?ooo`<000005`3oool004L0oooo00<000000?ooo`3oool0<P3oool500000?l0oooog@3oool5
000003l0oooo1@00000F0?ooo`00A`3oool00`000000oooo0?ooo`0b0?ooo`D00000o`3ooooN0?oo
o`<00000@03oool5000001H0oooo00170?ooo`030000003oool0oooo0380oooo1@00003o0?oook00
oooo0`00001^0?ooo`D000005P3oool004L0oooo00<000000?ooo`3oool02@3oool3000002L0oooo
0`00003o0?oook00oooo1@00001^0?ooo`<000005`3oool004L0oooo00<000000?ooo`3oool0203o
ool500000?l0oooof@3oool5000008P0oooo00170?ooo`030000003oool0oooo00P0oooo1@00003o
0?ooomT0oooo1@0000280?ooo`00:P3oool3000001X0oooo00<000000?ooo`3oool0203oool50000
0?l0oooofP3oool300000480oooo0`0000140?ooo`00:@3oool5000001T0oooo00<000000?ooo`3o
ool02@3oool300000?l0ooooo`3ooolP0?ooo`D000004P3oool3000002h0oooo000Y0?ooo`D00000
6@3oool00`000000oooo0?ooo`3o0?ooool0oooo;03oool500000140oooo1@00000]0?ooo`00:@3o
ool5000001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooob`0oooo1@00000A0?ooo`D00000;@3o
ool002X0oooo0`00000J0?ooo`030000003oool0oooo0?l0ooooo`3oool]0?ooo`<000004P3oool5
000002d0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooom30?ooo`<00000;P3oool003h0
oooo0`0000060?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00?@3oool5000000D0oooo
00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo000m0?ooo`D000001@3oool00`000000oooo0?oo
o`3o0?ooool0ooooM03oool003d0oooo1@0000050?ooo`030000003oool0oooo0?l0ooooo`3ooomd
0?ooo`00?P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`<0
0000o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooonT
0?ooo`<00000c03oool004L0oooo00<000000?ooo`3oool0o`3ooonS0?ooo`D00000b`3oool004L0
oooo00<000000?ooo`3oool0o`3ooonS0?ooo`D00000b`3oool004L0oooo00<000000?ooo`3oool0
o`3ooonS0?ooo`D00000b`3oool004L0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`<00000c03o
ool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo
04P0oooo0`00000W0?ooo`<00000o`3ooomL0?ooo`<00000W`3oool004L0oooo00<000000?ooo`3o
ool0A`3oool5000002D0oooo1@00003o0?oooeX0oooo1@00002N0?ooo`00A`3oool00`000000oooo
0?ooo`170?ooo`D000009@3oool500000?l0ooooFP3oool5000009h0oooo00170?ooo`030000003o
ool0oooo04L0oooo1@00000U0?ooo`D00000o`3ooomJ0?ooo`D00000WP3oool004L0oooo00<00000
0?ooo`3oool0B03oool3000002L0oooo0`00003o0?oooe`0oooo0`00002O0?ooo`00A`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0
oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?oo
o`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?oo
o`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0
ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooonj0?ooo`<00000]P3oool004L0oooo00<0
00000?ooo`3oool0o`3oooni0?ooo`D00000]@3oool004L0oooo00<000000?ooo`3oool0o`3oooni
0?ooo`D00000]@3oool004L0oooo0`00003o0?oookT0oooo1@00002e0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?oookX0oooo0`00002f0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0oooo
M03oool004L0oooo00<000000?ooo`3oool0G@3oool300000?l0oooo5`3oool300000?T0oooo0017
0?ooo`030000003oool0oooo05`0oooo1@00000k0?ooo`<00000eP3oool500000?P0oooo00170?oo
o`030000003oool0oooo05`0oooo1@00000j0?ooo`D00000e@3oool500000?P0oooo00170?ooo`03
0000003oool0oooo05`0oooo1@00000j0?ooo`D00000e@3oool500000?P0oooo00170?ooo`030000
003oool0oooo05d0oooo0`00000k0?ooo`D00000eP3oool300000?T0oooo00170?ooo`030000003o
ool0oooo09`0oooo0`00003o0?ooom@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd
0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo
00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o
0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`03
0000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0oooo
M03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`<00000o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo
00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o
0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`03
0000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0oooo
M03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0
oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0oooo
o`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?oo
o`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0
o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooM03oool00380oooo1@0000030?ooo`8000002`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooM03oool003<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00=03oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo000e0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`D00000o`3ooooo0?ooog80oooo000b0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00<P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`3o0?ooool0ooooM03oool003<0oooo0`0000040?ooo`8000002`3oool00`000000oooo0?oo
o`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?oo
o`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0
ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003o
ool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool0
04L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0
ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd
0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo
00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool300000?l0ooooo`3ooomd
0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo
00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o
0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`03
0000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0oooo
M03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0
oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0oooo
o`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?oo
o`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0
o`3ooooo0?ooog@0oooo00170?ooo`<00000o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0
oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0oooo
o`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?oo
o`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0
o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
og@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo
0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo0017
0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000
003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03o
ool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo
0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo
0`00003o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo0017
0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000
003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03o
ool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo
0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo
00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3o
oomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?oo
o`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00
A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3o
oooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0
oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00=03oool3000000<0oooo0P00
000;0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00=@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0ooooM03o
ool00380oooo1@0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3o
oooo0?ooog@0oooo000b0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
2P3oool500000?l0ooooo`3ooomb0?ooo`00<`3oool00`000000oooo000000030?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo000d0?ooo`8000000`3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00=@3o
ool00`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03o
ool004L0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`<00000o`3oool@0?ooo`00A`3oool00`00
0000oooo0?ooo`3o0?ooof00oooo1@00003o0?ooo`l0oooo00170?ooo`030000003oool0oooo0?l0
ooooH03oool500000?l0oooo3`3oool004L0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`D00000
o`3oool?0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooof40oooo0`00003o0?oooa00oooo0017
0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000
003oool0oooo0;80oooo0`00003o0?oookh0oooo00170?ooo`030000003oool0oooo0;40oooo1@00
003o0?oookd0oooo00170?ooo`030000003oool0oooo0;40oooo1@00003o0?oookd0oooo00170?oo
o`030000003oool0oooo0;40oooo1@00003o0?oookd0oooo00170?ooo`030000003oool0oooo0;80
oooo0`00003o0?oookh0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo
00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool300000?l0ooooo`3ooomd
0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo
00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o
0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`03
0000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0oooo
M03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0
oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0oooo
o`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?oo
o`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0
o`3ooooo0?ooog@0oooo00170?ooo`<00000o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0
oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0oooo
o`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?oo
o`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0
o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
og@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo
0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo0017
0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000
003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03o
ool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo
0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo
0`00003o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo0017
0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000
003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03o
ool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo
0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo
00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3o
oomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?oo
o`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00
A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3o
oooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0
oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00<`3oool3000000@0oooo0P00
000;0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00<P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o0?ooool0oooo
M03oool00380oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo000b0?ooo`@000000`3oool010000000oooo
0?ooo`00000:0?ooo`D00000o`3ooooo0?ooog80oooo000b0?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool003<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0
ooooo`3ooomd0?ooo`00=03oool2000000@0oooo0P00000;0?ooo`030000003oool0oooo0?l0oooo
o`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?oo
o`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0
o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
og@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo
0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo0017
0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000
003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03o
ool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo
0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?oood/0oooo0`00003o0?ooobH0
oooo00170?ooo`030000003oool0oooo0?l0ooooBP3oool500000?l0oooo9@3oool004L0oooo0`00
003o0?ooodX0oooo1@00003o0?ooobD0oooo00170?ooo`030000003oool0oooo0?l0ooooBP3oool5
00000?l0oooo9@3oool004L0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`<00000o`3ooolV0?oo
o`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0
o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0<L0oooo0`00003o0?ooojT0oooo0017
0?ooo`030000003oool0oooo0<H0oooo1@00003o0?ooojP0oooo00170?ooo`030000003oool0oooo
0<H0oooo1@00003o0?ooojP0oooo00170?ooo`030000003oool0oooo0<H0oooo1@00003o0?ooojP0
oooo00170?ooo`030000003oool0oooo0<L0oooo0`00003o0?ooojT0oooo00170?ooo`030000003o
ool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool0
04L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0
ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd
0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo0`00003o0?ooool0ooooM03oool004L0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd
0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000
oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo
00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o
0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`03
0000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0oooo
M03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0
oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0oooo
o`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?oo
o`00A`3oool300000?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0oooo
M03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0
oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0oooo
o`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<00000
0?ooo`3oool0o`3ooole0?ooo`<00000o`3oooll0?ooo`00A`3oool00`000000oooo0?ooo`3o0?oo
oc@0oooo1@00003o0?oooc/0oooo00170?ooo`030000003oool0oooo0?l0oooo=03oool500000?l0
oooo>`3oool004L0oooo00<000000?ooo`3oool0o`3ooold0?ooo`D00000o`3ooolk0?ooo`00A`3o
ool00`000000oooo0?ooo`3M0?ooo`<00000E03oool300000?l0oooo?03oool004L0oooo00<00000
0?ooo`3oool0g03oool500000?l0ooooTP3oool004L0oooo00<000000?ooo`3oool0g03oool50000
0?l0ooooTP3oool004L0oooo00<000000?ooo`3oool0g03oool500000?l0ooooTP3oool004L0oooo
00<000000?ooo`3oool0g@3oool300000?l0ooooT`3oool004L0oooo00<000000?ooo`3oool0o`3o
oooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0
oooo000c0?ooo`<00000103oool2000000/0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo
000b0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomd0?ooo`00<P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool003<0
oooo0`0000030?ooo`040000003oool0oooo000000X0oooo1@00003o0?ooool0ooooLP3oool00380
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooog@0oooo000b0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00<`3oool3
000000@0oooo0P00000;0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0
oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?oo
o`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?oo
o`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3oool00`000000oooo0?ooo`3o0?oooal0
oooo0`00003o0?oooe80oooo00170?ooo`030000003oool0oooo0?l0oooo7P3oool500000?l0oooo
D@3oool004L0oooo00<000000?ooo`3oool0l`3oool3000002L0oooo1@00003o0?oooe40oooo0017
0?ooo`030000003oool0oooo0?80oooo1@00000V0?ooo`D00000o`3ooomA0?ooo`00A`3oool00`00
0000oooo0?ooo`3b0?ooo`D000009`3oool300000?l0ooooDP3oool004L0oooo00<000000?ooo`3o
ool0lP3oool500000?l0ooooO03oool004L0oooo00<000000?ooo`3oool0l`3oool300000?l0oooo
O@3oool004L0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0
oooo0?l0oooo2@3oool300000?l0ooooJ03oool004L0oooo00<000000?ooo`3oool0o`3oool80?oo
o`D00000o`3ooomW0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo1@00003o0?ooofL0
oooo00170?ooo`030000003oool0oooo0?l0oooo203oool500000?l0ooooI`3oool004L0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`<00000o`3ooomX0?ooo`00A`3oool00`000000oooo0?ooo`3o
0?ooool0ooooM03oool004L0oooo0`00003o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00A`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooM03oool004L0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00170?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 699}, {431.438, 0}} -> {134.944, -3.66106, \
0.0148725, 0.208329}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ListPlot[
\tReadRays[tracedsystem,{ArcCos[RayTilt.{1,0,0}]/Degree,Intensity}, \
ComponentNumber->3]
];\
\>", "Input",
  CellLabel->"In[278]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.80393 0.110816 0.0147151 0.00588623 [
[.29891 .00222 -6 -9 ]
[.29891 .00222 6 0 ]
[.52054 .00222 -6 -9 ]
[.52054 .00222 6 0 ]
[.74217 .00222 -6 -9 ]
[.74217 .00222 6 0 ]
[.96381 .00222 -6 -9 ]
[.96381 .00222 6 0 ]
[.06478 .13244 -12 -4.5 ]
[.06478 .13244 0 4.5 ]
[.06478 .25016 -12 -4.5 ]
[.06478 .25016 0 4.5 ]
[.06478 .36789 -12 -4.5 ]
[.06478 .36789 0 4.5 ]
[.06478 .48561 -12 -4.5 ]
[.06478 .48561 0 4.5 ]
[.06478 .60334 -18 -4.5 ]
[.06478 .60334 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.29891 .01472 m
.29891 .02097 L
s
[(28)] .29891 .00222 0 1 Mshowa
.52054 .01472 m
.52054 .02097 L
s
[(30)] .52054 .00222 0 1 Mshowa
.74217 .01472 m
.74217 .02097 L
s
[(32)] .74217 .00222 0 1 Mshowa
.96381 .01472 m
.96381 .02097 L
s
[(34)] .96381 .00222 0 1 Mshowa
.125 Mabswid
.13269 .01472 m
.13269 .01847 L
s
.1881 .01472 m
.1881 .01847 L
s
.2435 .01472 m
.2435 .01847 L
s
.35432 .01472 m
.35432 .01847 L
s
.40973 .01472 m
.40973 .01847 L
s
.46513 .01472 m
.46513 .01847 L
s
.57595 .01472 m
.57595 .01847 L
s
.63136 .01472 m
.63136 .01847 L
s
.68677 .01472 m
.68677 .01847 L
s
.79758 .01472 m
.79758 .01847 L
s
.85299 .01472 m
.85299 .01847 L
s
.9084 .01472 m
.9084 .01847 L
s
.02187 .01472 m
.02187 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.07728 .13244 m
.08353 .13244 L
s
[(20)] .06478 .13244 1 0 Mshowa
.07728 .25016 m
.08353 .25016 L
s
[(40)] .06478 .25016 1 0 Mshowa
.07728 .36789 m
.08353 .36789 L
s
[(60)] .06478 .36789 1 0 Mshowa
.07728 .48561 m
.08353 .48561 L
s
[(80)] .06478 .48561 1 0 Mshowa
.07728 .60334 m
.08353 .60334 L
s
[(100)] .06478 .60334 1 0 Mshowa
.125 Mabswid
.07728 .04415 m
.08103 .04415 L
s
.07728 .07358 m
.08103 .07358 L
s
.07728 .10301 m
.08103 .10301 L
s
.07728 .16187 m
.08103 .16187 L
s
.07728 .1913 m
.08103 .1913 L
s
.07728 .22073 m
.08103 .22073 L
s
.07728 .2796 m
.08103 .2796 L
s
.07728 .30903 m
.08103 .30903 L
s
.07728 .33846 m
.08103 .33846 L
s
.07728 .39732 m
.08103 .39732 L
s
.07728 .42675 m
.08103 .42675 L
s
.07728 .45618 m
.08103 .45618 L
s
.07728 .51504 m
.08103 .51504 L
s
.07728 .54448 m
.08103 .54448 L
s
.07728 .57391 m
.08103 .57391 L
s
.25 Mabswid
.07728 0 m
.07728 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .59357 Mdot
.05819 .58399 Mdot
.0924 .58412 Mdot
.12642 .59535 Mdot
.16027 .60332 Mdot
.19393 .5896 Mdot
.22741 .56014 Mdot
.26071 .54521 Mdot
.29383 .56743 Mdot
.32677 .60295 Mdot
.35952 .53826 Mdot
.39209 .36006 Mdot
.42448 .22058 Mdot
.45668 .14932 Mdot
.4887 .11774 Mdot
.52054 .10821 Mdot
.5522 .11556 Mdot
.58367 .14429 Mdot
.61496 .21177 Mdot
.64606 .34993 Mdot
.67698 .5365 Mdot
.70772 .60226 Mdot
.73828 .55986 Mdot
.76865 .53853 Mdot
.79885 .56025 Mdot
.82886 .59384 Mdot
.85869 .60241 Mdot
.88833 .58781 Mdot
.9178 .57797 Mdot
.94708 .58511 Mdot
.97619 .59891 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[278]:=",
  ImageSize->{652, 402.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:<0001TR000`400?l00000o`00003oo`3ooooo
0?ooohh0oooo002o0?ooo`D000000P3oool3000008@0oooo0`0000040?ooo`800000Q03oool30000
0080oooo1@0000240?ooo`<00000103oool3000001X0oooo00300?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`200?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000220?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000230?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0I
0?ooo`00`@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0Q03oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo08@0oooo00D000000?ooo`3oool0oooo
000000290?ooo`030000003oool0000000@000006P3oool00<80oooo00@000000?ooo`3oool0oooo
0`0000250?ooo`8000000`3oool010000000oooo0?ooo`0000240?ooo`8000001@3oool00`000000
oooo0?ooo`240?ooo`8000000P3oool010000000oooo0?ooo`00000K0?ooo`00_`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`240?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0Q03oool00`000000oooo000000030?ooo`030000003o
ool0oooo08D0oooo00H000000?ooo`3oool000000?ooo`00000K0?ooo`00_`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`200?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000220?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo0840oooo00D000000?ooo`3oool0oooo000000030?oo
o`8000006`3oool003L0oooo00<000000?ooo`3oool0QP3oool3000000<0oooo0`0000240?ooo`<0
0000103oool2000008@0oooo0`0000030?ooo`<00000Q@3oool3000000D0oooo00<000000?ooo`3o
ool06@3oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool0
03L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0
ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD
0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool000H0ooooo`00003o00000840
00001`3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01`0oooo000D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0L0?ooo`00=`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo01`0oooo000g0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0703oool003L0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0oooo
o`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo
0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g
0?ooo`@00000o`3ooooo0?oooe<0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo
0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g
0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000
003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03o
ool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo
0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`@00000o`3ooooo0?oooe<0oooo000g
0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000
003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03o
ool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo
0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3o
oomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?oo
o`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00
=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0
oooo000g0?ooo`@00000o`3ooooo0?oooe<0oooo000g0?ooo`030000003oool0oooo0?l0oooo603o
ool300000?l0oooo>@3oool003L0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`D00000o`3ooolh
0?ooo`00=`3oool00`000000oooo0?ooo`3o0?oooaL0oooo1@00003o0?ooocP0oooo000g0?ooo`03
0000003oool0oooo0?l0oooo5`3oool500000?l0oooo>03oool003L0oooo00<000000?ooo`3oool0
o`3ooolH0?ooo`<00000o`3oooli0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooob`0oooo0`00
003o0?ooobD0oooo000g0?ooo`030000003oool0oooo0?l0oooo103oool3000002@0oooo1@00003o
0?ooob@0oooo000g0?ooo`030000003oool0oooo0?l0oooo0`3oool5000002<0oooo1@00003o0?oo
ob@0oooo000g0?ooo`030000003oool0oooo0?l0oooo0`3oool5000002<0oooo1@00003o0?ooob@0
oooo000g0?ooo`030000003oool0oooo0?l0oooo0`3oool5000002@0oooo0`00003o0?ooobD0oooo
000g0?ooo`030000003oool0oooo0?l0oooo103oool300000?l0ooooC@3oool003L0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000S0?ooo`D000000`3oool2000000X0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe@0oooo000T0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool002D0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`009P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool500000?l0oooo
o`3ooomB0?ooo`008`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool002<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000T0?ooo`<00000103oool2000000X0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0
oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?oo
o`3o0?oood00oooo0`00003o0?oooa40oooo000g0?ooo`030000003oool0oooo0?l0oooo?`3oool5
00000?l0oooo403oool003L0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`D00000o`3oool@0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooocl0oooo1@00003o0?oooa00oooo000g0?ooo`030000
003oool0oooo0>h0oooo0`00001>0?ooo`<00000o`3ooolA0?ooo`00=`3oool00`000000oooo0?oo
o`3]0?ooo`D00000o`3ooomQ0?ooo`00=`3oool00`000000oooo0?ooo`3]0?ooo`D00000o`3ooomQ
0?ooo`00=`3oool00`000000oooo0?ooo`3]0?ooo`D00000o`3ooomQ0?ooo`00=`3oool00`000000
oooo0?ooo`3^0?ooo`<00000o`3ooomR0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0oooo
E03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0
oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`@00000o`3ooooo0?oooe<0oooo
000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o
0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0oooo
E03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0
oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0oooo
o`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo1000003o0?ooool0ooooD`3oool003L0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0oooo
o`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooE03oool300000?`0oooo000g0?ooo`030000
003oool0oooo0?l0ooooD`3oool500000?/0oooo000g0?ooo`030000003oool0oooo0?l0ooooD`3o
ool500000?/0oooo000g0?ooo`030000003oool0oooo0?l0ooooD`3oool500000?/0oooo000g0?oo
o`030000003oool0oooo0?l0ooooE03oool300000?`0oooo000g0?ooo`030000003oool0oooo0?l0
ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3J0?ooo`<00000o`3ooomf0?ooo`00=`3o
ool00`000000oooo0?ooo`3I0?ooo`D00000o`3ooome0?ooo`00=`3oool400000=P0oooo1@00003o
0?ooogD0oooo000g0?ooo`030000003oool0oooo0=T0oooo1@00003o0?ooogD0oooo000g0?ooo`03
0000003oool0oooo0=X0oooo0`00003o0?ooogH0oooo000g0?ooo`030000003oool0oooo0?l0oooo
o`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo
0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g
0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`009@3oool3000000<0oooo0P00000:0?oo
o`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`009P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool002<0
oooo1@0000020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000S0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000002@3oool5
00000?l0ooooo`3ooomB0?ooo`00903oool00`000000oooo000000030?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000U0?ooo`8000000`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`009P3oool00`00
0000oooo0?ooo`020?ooo`8000002P3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0oooo
o`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo
0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g
0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooE03oool003L0oooo1000003o0?ooool0ooooD`3oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo
0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g
0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000
003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03o
ool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo
0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3o
oomD0?ooo`00=`3oool400000?l0ooooo`3ooomC0?ooo`00=`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000
003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03o
ool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo
0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3o
oomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?oo
o`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00
=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0
oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool400000?l0ooooo`3o
oomC0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?oo
o`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00
=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooJ03oool300000>P0oooo000g0?oo
o`030000003oool0oooo0?l0ooooI`3oool500000>L0oooo000g0?ooo`030000003oool0oooo0?l0
ooooI`3oool500000>L0oooo000g0?ooo`030000003oool0oooo0?l0ooooI`3oool500000>L0oooo
000g0?ooo`030000003oool0oooo0?l0ooooJ03oool300000>P0oooo000g0?ooo`030000003oool0
oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`350?ooo`<00000o`3ooon;0?oo
o`00=`3oool00`000000oooo0?ooo`340?ooo`D00000o`3ooon:0?ooo`00=`3oool00`000000oooo
0?ooo`340?ooo`D00000o`3ooon:0?ooo`00=`3oool00`000000oooo0?ooo`340?ooo`D00000o`3o
oon:0?ooo`00903oool3000000@0oooo0P00000:0?ooo`030000003oool0oooo0<D0oooo0`00003o
0?oooh/0oooo000S0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`008`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`3o0?ooool0oooo
E03oool002<0oooo100000030?ooo`040000003oool0oooo000000T0oooo1@00003o0?ooool0oooo
DP3oool002<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo0?l0ooooo`3ooomD0?ooo`00903oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000U0?ooo`800000103o
ool2000000X0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0
oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0oooo
o`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo
0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g
0?ooo`@00000o`3ooooo0?oooe<0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo
0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g
0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000
003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03o
ool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo
0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`@00000o`3ooooo0?oooe<0oooo000g
0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000
003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03o
ool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo
0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3o
oomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?oo
o`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00
=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo1000003o0?ooool0ooooD`3oool003L0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3o
oomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?oo
o`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00
=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0
oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?oo
o`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?oo
o`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0
ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000T0?ooo`<00000103o
ool2000000X0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000S0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0oooo
o`3ooomD0?ooo`008`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00002@3oool500000?l0ooooo`3ooomB0?ooo`00903oool3000000<0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool002<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe@0oooo000S0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00903oool3000000@0oooo0P00000:0?oo
o`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0
ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool0
03L0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0
ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD
0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo
0?oooe@0oooo000g0?ooo`@00000o`3ooooo0?oooe<0oooo000g0?ooo`030000003oool0oooo0?l0
ooooo`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD
0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3ooooo
0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`000000
oooo0?ooo`3o0?ooog`0oooo0`00003D0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooog/0oooo
1@00003C0?ooo`00=`3oool00`000000oooo0?ooo`2`0?ooo`<00000a`3oool5000003H0oooo0`00
002J0?ooo`00=`3oool00`000000oooo0?ooo`2_0?ooo`D00000aP3oool5000003D0oooo1@00002I
0?ooo`00=`3oool00`000000oooo0?ooo`2_0?ooo`D00000a`3oool3000003H0oooo1@00002I0?oo
o`00=`3oool00`000000oooo0?ooo`2_0?ooo`D00000o`3oool10?ooo`D00000V@3oool003L0oooo
00<000000?ooo`3oool0L@3oool3000003`0oooo0`00003o0?ooo`<0oooo0`00002J0?ooo`00=`3o
ool00`000000oooo0?ooo`1`0?ooo`D00000o`3ooooN0?ooo`00=`3oool4000006l0oooo1@00003o
0?ooomh0oooo000g0?ooo`030000003oool0oooo0700oooo1@00003o0?ooomh0oooo000g0?ooo`03
0000003oool0oooo0740oooo0`00003o0?oooml0oooo000g0?ooo`030000003oool0oooo0?l0oooo
o`3ooomD0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?oo
o`00=`3oool00`000000oooo0?ooo`3o0?oooj<0oooo0`00002]0?ooo`00=`3oool00`000000oooo
0?ooo`1L0?ooo`<00000o`3ooom30?ooo`D000008`3oool3000008H0oooo000g0?ooo`030000003o
ool0oooo05/0oooo1@00003o0?oood80oooo1@00000R0?ooo`D00000Q@3oool003L0oooo00<00000
0?ooo`3oool0F`3oool500000?l0oooo@P3oool500000280oooo1@0000250?ooo`00=`3oool00`00
0000oooo0?ooo`1K0?ooo`D00000o`3ooom30?ooo`<000008`3oool5000008D0oooo000g0?ooo`03
0000003oool0oooo05`0oooo0`00000X0?ooo`<00000o`3ooom00?ooo`<00000QP3oool003L0oooo
00<000000?ooo`3oool0QP3oool500000?l0oooob03oool003L0oooo00<000000?ooo`3oool0QP3o
ool500000?l0oooob03oool003L0oooo00<000000?ooo`3oool0QP3oool500000?l0oooob03oool0
03L0oooo00<000000?ooo`3oool0Q`3oool300000?l0oooob@3oool003L0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooe@0oooo000g0?ooo`@00000o`3ooooo0?oooe<0oooo000g0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolF0?ooo`<00000>`3oool003L0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaD0oooo1@00000j0?ooo`00=`3oool00`000000oooo0?ooo`3o0?ooool0oooo5@3oool50000
03X0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooolE0?ooo`D00000>P3oool002X0oooo
0`00000:0?ooo`030000003oool0oooo00H0oooo0`00003o0?ooool0oooo3@3oool3000003/0oooo
000Y0?ooo`D000002@3oool00`000000oooo0?ooo`050?ooo`D00000o`3ooooo0?oooal0oooo0`00
000X0?ooo`00:@3oool5000000T0oooo00<000000?ooo`3oool01@3oool500000?l0oooon@3oool3
00000240oooo1@00000W0?ooo`00:@3oool5000000T0oooo00<000000?ooo`3oool01@3oool50000
03d0oooo0`00003o0?oookP0oooo1@00000P0?ooo`D000009`3oool002X0oooo0`00000:0?ooo`03
0000003oool0oooo00H0oooo0`00000m0?ooo`D00000o`3ooong0?ooo`D00000803oool5000002L0
oooo000g0?ooo`030000003oool0oooo04H0oooo1@00003o0?oookL0oooo1@00000Q0?ooo`<00000
:03oool001@0oooo0`00000P0?ooo`030000003oool0oooo04H0oooo1@00003o0?oooi80oooo0`00
000S0?ooo`<00000C@3oool001<0oooo1@00000O0?ooo`030000003oool0oooo01`0oooo0`00000X
0?ooo`<00000o`3ooonB0?ooo`D00000LP3oool001<0oooo1@00000O0?ooo`030000003oool0oooo
01/0oooo1@00003o0?oook`0oooo1@00001b0?ooo`004`3oool5000001l0oooo00<000000?ooo`3o
ool06`3oool500000?l0oooo_03oool5000005X0oooo0`00000E0?ooo`00503oool300000200oooo
00<000000?ooo`3oool06`3oool500000?l0oooo_@3oool3000005X0oooo1@00000D0?ooo`00=`3o
ool00`000000oooo0?ooo`0L0?ooo`<00000o`3ooom`0?ooo`<00000Z03oool5000001@0oooo000N
0?ooo`<00000103oool2000000@0oooo0P00000:0?ooo`030000003oool0oooo0340oooo0`00001X
0?ooo`<00000kP3oool5000005d0oooo0`0000170?ooo`D00000503oool001l0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool0<03oool5000006H0oooo1@00003]0?ooo`D00000G03oool5000004L0oooo0`00
000E0?ooo`007`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000002@3oool5000002h0oooo1@00001V0?ooo`D00000k@3oool5000005`0oooo
1@00001O0?ooo`007`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0`0?ooo`D00000IP3oool500000>h0
oooo0`00001M0?ooo`D00000G`3oool001l0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0<@3oool30000
06P0oooo0`00003o0?oooe40oooo0`00001P0?ooo`007P3oool2000000@0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooo`3ooomD
0?ooo`007`3oool00`000000oooo0?ooo`030?ooo`800000103oool2000000X0oooo00<000000?oo
o`3oool0o`3ooooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00
=`3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool003L0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe@0oooo000g0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`00=`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooE03oool00001\
\>"],
  ImageRangeCache->{{{0, 651}, {401.75, 0}} -> {25.209, -4.52069, 0.0141492, \
0.266378}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PhaseMismatch Dependency", "ExampleSubsection"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[
\tReadRays[tracedsystem,{PhaseMismatch,Intensity},
\t\tFunction[DiffractionOrderNumber,DiffractionOrderNumber===-1]]
];\
\>", "Input",
  CellLabel->"In[231]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.509027 0.0305408 0.0147151 0.00699745 [
[.05091 .00222 -9 -9 ]
[.05091 .00222 9 0 ]
[.20362 .00222 -9 -9 ]
[.20362 .00222 9 0 ]
[.35632 .00222 -6 -9 ]
[.35632 .00222 6 0 ]
[.66173 .00222 -3 -9 ]
[.66173 .00222 3 0 ]
[.81444 .00222 -6 -9 ]
[.81444 .00222 6 0 ]
[.96714 .00222 -6 -9 ]
[.96714 .00222 6 0 ]
[.49653 .15466 -12 -4.5 ]
[.49653 .15466 0 4.5 ]
[.49653 .29461 -12 -4.5 ]
[.49653 .29461 0 4.5 ]
[.49653 .43456 -12 -4.5 ]
[.49653 .43456 0 4.5 ]
[.49653 .57451 -12 -4.5 ]
[.49653 .57451 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05091 .01472 m
.05091 .02097 L
s
[(-15)] .05091 .00222 0 1 Mshowa
.20362 .01472 m
.20362 .02097 L
s
[(-10)] .20362 .00222 0 1 Mshowa
.35632 .01472 m
.35632 .02097 L
s
[(-5)] .35632 .00222 0 1 Mshowa
.66173 .01472 m
.66173 .02097 L
s
[(5)] .66173 .00222 0 1 Mshowa
.81444 .01472 m
.81444 .02097 L
s
[(10)] .81444 .00222 0 1 Mshowa
.96714 .01472 m
.96714 .02097 L
s
[(15)] .96714 .00222 0 1 Mshowa
.125 Mabswid
.08146 .01472 m
.08146 .01847 L
s
.112 .01472 m
.112 .01847 L
s
.14254 .01472 m
.14254 .01847 L
s
.17308 .01472 m
.17308 .01847 L
s
.23416 .01472 m
.23416 .01847 L
s
.2647 .01472 m
.2647 .01847 L
s
.29524 .01472 m
.29524 .01847 L
s
.32578 .01472 m
.32578 .01847 L
s
.38686 .01472 m
.38686 .01847 L
s
.4174 .01472 m
.4174 .01847 L
s
.44795 .01472 m
.44795 .01847 L
s
.47849 .01472 m
.47849 .01847 L
s
.53957 .01472 m
.53957 .01847 L
s
.57011 .01472 m
.57011 .01847 L
s
.60065 .01472 m
.60065 .01847 L
s
.63119 .01472 m
.63119 .01847 L
s
.69227 .01472 m
.69227 .01847 L
s
.72281 .01472 m
.72281 .01847 L
s
.75335 .01472 m
.75335 .01847 L
s
.78389 .01472 m
.78389 .01847 L
s
.84498 .01472 m
.84498 .01847 L
s
.87552 .01472 m
.87552 .01847 L
s
.90606 .01472 m
.90606 .01847 L
s
.9366 .01472 m
.9366 .01847 L
s
.02037 .01472 m
.02037 .01847 L
s
.99768 .01472 m
.99768 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.50903 .15466 m
.51528 .15466 L
s
[(20)] .49653 .15466 1 0 Mshowa
.50903 .29461 m
.51528 .29461 L
s
[(40)] .49653 .29461 1 0 Mshowa
.50903 .43456 m
.51528 .43456 L
s
[(60)] .49653 .43456 1 0 Mshowa
.50903 .57451 m
.51528 .57451 L
s
[(80)] .49653 .57451 1 0 Mshowa
.125 Mabswid
.50903 .0497 m
.51278 .0497 L
s
.50903 .08469 m
.51278 .08469 L
s
.50903 .11968 m
.51278 .11968 L
s
.50903 .18965 m
.51278 .18965 L
s
.50903 .22464 m
.51278 .22464 L
s
.50903 .25963 m
.51278 .25963 L
s
.50903 .3296 m
.51278 .3296 L
s
.50903 .36459 m
.51278 .36459 L
s
.50903 .39957 m
.51278 .39957 L
s
.50903 .46955 m
.51278 .46955 L
s
.50903 .50454 m
.51278 .50454 L
s
.50903 .53952 m
.51278 .53952 L
s
.50903 .6095 m
.51278 .6095 L
s
.25 Mabswid
.50903 0 m
.50903 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .04488 Mdot
.05651 .0377 Mdot
.15436 .03934 Mdot
.18689 .07575 Mdot
.21937 .09173 Mdot
.2518 .06635 Mdot
.3165 .05435 Mdot
.34875 .23135 Mdot
.38095 .41082 Mdot
.41308 .51791 Mdot
.44514 .57214 Mdot
.47712 .59683 Mdot
.50903 .60332 Mdot
.54086 .5946 Mdot
.57261 .56713 Mdot
.60427 .50919 Mdot
.63584 .39857 Mdot
.66732 .22179 Mdot
.69871 .05463 Mdot
.76117 .05736 Mdot
.79224 .08313 Mdot
.8232 .07366 Mdot
.85404 .0437 Mdot
.94584 .02813 Mdot
.97619 .03843 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[231]:=",
  ImageSize->{560, 345.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008`0001F@P10`40000100000?ooodA4A6EUIEEE
EC0`<7EeMB0P88T0002908V90000RHT0R@29RJFUYDa<C?l0003o0?oo0000ool0o`3ookjn_UeMGL;2
`W5aLH61P@00PF72PBPXoaPHoeUIogUiocPhomkNonk^olk>ojj^okJfomKFoc0`oe1@ofUYodQ8okjn
oifMooKfog5aoiFEohf=om;BdVUYJ@1U002108400840PA0@4>:Q2021PH610=[JfP3^0>k^003^k^h0
0000kY400;Xd1;;2gP00HH6=^P00XOoof_[BXN;RPL;20>k>465Q03`d93PH6000<000>0P82000VCPP
7000cP00nP3>002I0=jI46D`09U44;YU801m08G>jR2bZ_X@@?nQ06EUooo>c]8PT@1<0?;b0=K2085m
OIVIVF5QHD10@761TCSj=51@nYW>c/[oofFIVBPTKB@TB2PPREU@EGUaJG5mbYf5HC0L/VeeXE1@SA0@
om:fSH5iJBa<C?ook/h00025RHTP831UIEEEohDL:?H`B:ZZoeE4OJieD7U]cTAI_R@TQGemofE4D=jZ
TO[jn]H`A51@m_Y0FI6AodQ8f_KfmP@@210H=5UEi/[>ofe]oifEkR`D?5eMoni0FBPTJHF5ogEeokJj
ol[6nV5UmSPX8:6QnXV9nXV9oh61n_ojcZ5@;?nU0?mm0<K6aP00E@00ZP1E001EE@1EZP1Eo`2Z002Z
E@2ZZP2Zo`3oE@3oZUD005D0EED0ZUD0oeEE05EEZUFZ05FZEEFZZUFZoeGo05GoEEGoZUGoojX00:X0
EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZ[o0:[oEJ[oZZ[oool0EOl0Z_mE0?mEEOmEZ_mEoonZ
0?nZEOnZZ_nZooooEOooZYfMWFe]KJ4PlZj^[WUiNGem_Wfn07fn?7fnOGfn_Wfnoggo07go?7goOGgo
_Wgookh00;h0?;h0OKh0_[h0okhl0;hl?;hlOKhl_[hlool1o`4b0@00o`7o0C81003o0Ol1<P400201
10020@<0BP4400<10P1>0@<0X04304h110030@80BP4400810`0F0@008P400`010@040@03004104T1
00D00@4100020@03004104h100<00@40X0400`010@1=0@0500410@000P400`010@190@03004100@1
00<00@404`40028100<00@4010400`010@190@0500410@000P400`010@1>0@0300410:0100<00@40
C@401@010@40008100<00@40B@400`010@040@03004101<1000J0@@0104010010@4304@110040@05
00410@000P400`010@150@@00P430:010`1@0@0500410@000P400`010@190@0400410@<05P400281
00D00@41001>0@0500410@000P400`010@1;0@03004104l100<00@40CP400`010@1@0@0500410@00
0P400`010@190@0500410@00604002010`030@03004104X10`030@04004104d100<00@40C`400`01
0@1>0@03004104h10`030@04004104T10`030@03004101H1000R0@0400410@@0B`400`010@020@80
CP4404h100<00@40CP4404l100<00@400P4204`100@00@41100E0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
00060Ol0o`0U00L1000A0@03004100h100<00@403P400`010@0=0@03004100h100<00@403P400`01
0@0=0@03004100h100<00@403P400`010@0=0@03004100h100<00@403P400`010@0=0@03004100h1
00<00@403P400`010@0=0@03004100h100<00@403P400`010@0=0@03004100h100<00@403P400`01
0@0=0@03004100h100<00@403P400`010@0=0@03004100h100<00@403P400`010@0=0@03004100h1
00<00@403P400`010@0=0@03004100h100<00@403@400`010@070@004@400`010@0>0@03004100h1
00<00@403@400`010@0>0@03004100h100<00@403@400`010@0>0@03004100h100<00@403@400`01
0@0>0@03004100h100<00@403@400`010@0>0@03004100h100<00@403@400`010@0>0@03004100h1
00<00@403@400`010@0>0@03004100h100<00@403@400`010@0>0@03004100h100<00@403@400`01
0@0>0@03004100h100<00@403@400`010@0>0@03004100h100<00@403@400`010@0>0@03004100d1
00<00@401`40028100<00@40D0400`010@1A0@030041050100<00@40D0400`010@1A0@0300410501
00<00@405`40028100<00@40D0400`010@1A0@030041050100<00@40D0400`010@1A0@0300410501
00<00@405`400?l17@400`010@3o0A81003o0Ad100<00@40j`4302<1003o0Ad100<00@40jP4402<1
003o0Ad100<00@40j`4302<1003o0Ad100<00@40k0400`010@0R0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81000T0@<0<`430;l100<00@40n`4301<1000S0@@0<P440;l100<00@40nP4401<1
000T0@<0<`430;l100<00@40n`4301<1000C0@<03`400`010@0c0@0300410;h100<00@40^@430401
00<00@404P400181103o0@L100<00@40^04405D1000C0@<0o`470@0300410;T10`1E0@0050400`01
0@3o0@H100<00@40^P400`010@1D0@00o`4M0@<0o`4B0@00o`4M0@0300410?l14P400;810`1W0@03
004106@10`2Z0@00/@4406L100<00@40H`4401l10`280@00/P4306L100<00@40I04301h110280@00
/`400`010@1V0@03004106D100<00@407P4308P1003o0Ad100<00@40Q`400`010@270@00o`4M0@03
00410?l14P4008l10`2:0@0300410?l14P4008h1102:0@0300410?l14P4008l10`2:0@0300410?l1
4P40090100<00@40R@400`010@3o0A81003o0Ad100<00@40Z04306H1001/0@<0[@400`010@2W0@@0
IP4006/1102]0@0300410:P10`1V0@00K0430:d100<00@40Z@400`010@1U0@00K@400`010@2/0@03
00410?l14P400?l17@400`010@2G0@<0M`400?l17@400`010@2F0@@0M`400?l17@400`010@2G0@<0
M`400?l17@4309P100<00@40MP400?l17@400`010@3o0A81001m0@<0W0400`010@3o0A81001l0@@0
W0400`010@3o0A81001m0@<0W0400`010@3o0A81001n0@03004109/100<00@40o`4B0@00o`4M0@03
00410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@430?l14P400?l17@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03
00410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0@/110030@80
2@400`010@3o0A81003o0@/100<00@400`4010010@080@0300410?l14P400?l130400`010@020@04
004100P1103o0A41003o0@d100D00@4100020@03004100H100<00@40o`4B0@00o`4>0@0400410081
00<00@401P400`010@3o0A81003o0@/100@00@400P4010010@080@0300410?l14P400?l1304200@1
0P090@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l1
4P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`01
0@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad1
00<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00
o`4M0@<0o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00
o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l1
4P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`01
0@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad1
00<00@40o`4B0@00o`4M0@03004105<10`2k0@00o`4M0@0300410581102k0@00o`4M0@03004105<1
0`2k0@00o`4M0@<0E0400`010@2j0@00o`4M0@0300410?l14P400<@10`1E0@0300410?l14P400<<1
101E0@0300410?l14P400<@10`1E0@0300410?l14P400<D100<00@40E0400`010@3o0A81003o0Ad1
00<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00
o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l1
4P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`01
0@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@<0o`4B0@00o`4M0@0300410?l14P400?l17@400`01
0@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad1
00<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00
o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l1
4P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`01
0@3o0A81003o0@d100<00@400P4200T100<00@40o`4B0@00o`4=0@0500410@000P400`010@060@@0
o`4A0@00o`4:0@D00P4010010@080@0300410?l14P400?l12P4010010@030@04004100P100<00@40
o`4B0@00o`4;0@03004000<100@00@4020400`010@3o0A81003o0@`10P030@04004100P100<00@40
o`4B0@00o`4=0@03004100810P090@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03
00410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad10`3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03
00410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad10`3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03
00410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03004104410`3=0@00o`4M0@0300410401
103=0@00o`4M0@<0@@430<d1003o0Ad100<00@40@P400`010@3<0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad100<00@40o`4B0@00e@4304@100<00@40o`4B0@00e04404@100<00@40
o`4B0@00e@4304@100<00@40o`4B0@00eP400`010@130@0300410?l14P400?l17@400`010@3o0A81
003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03
00410?l14P400?l1304200@10P090@0300410?l14P400?l12`4010010@020@04004100P1103o0A41
003o0@/100@00@400P4010010@080@0300410?l14P400?l12`4300<100@00@4020400`010@3o0A81
003o0@/100<00@400`4010010@080@0300410?l14P400?l12`400`010@030@04004100P100<00@40
o`4B0@00o`4<0@<00`4200T100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03
00410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l1
7@430?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03
00410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad10`3o0A81003o0Ad100<00@40<0430=h1003o0Ad100<00@40;`440=h1
003o0Ad100<00@40<0430=h1003o0Ad100<00@40<@400`010@3M0@00o`4M0@0300410?l14P400>L1
0`0b0@0300410?l14P400>H1100b0@0300410?l14P400>L10`0b0@0300410?l14P400>P100<00@40
<@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad10`3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03
00410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l1
7@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81
003o0Ad100<00@407`430>l1003o0Ad100<00@407P440>l1003o0Ad100<00@407`430>l1003h0@<0
8@400`010@0P0@0300410>h1003g0@@0404200@10P090@0300410?l14P400?P10`0?0@0400410081
00@00@4020400`010@3o0A81003i0@03004100h100@00@400P4010010@080@@0o`4A0@00o`4<0@80
0`4010010@080@0300410?l14P400?l12`4010010@020@04004100P100<00@40o`4B0@00o`4;0@04
0041008100@00@4020400`010@3o0A81003o0@`10P040@802@400`010@3o0A81003o0Ad100<00@40
o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00o`4M0@03
004100h10`3o0@41003o0Ad100<00@403@440?l10@400?l12`4300l100<00@403P430?l10@400?l1
2P4400l100<00@403`400`010@3o0@00o`4;0@<03`400`010@3o0A81003o0@`100<00@403@430?l1
4`400?l16`440?l14`400?l170430?l14`400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00
o`4M0@<0o`4B0@00o`4M0@0300410?l14P400?l17@400`010@3o0A81003o0Ad100<00@40o`4B0@00
o`4M0@0300410?l14P400001\
\>"],
  ImageRangeCache->{{{0, 559}, {344.938, 0}} -> {-17.0718, -4.14384, 
  0.0600222, 0.261971}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{947, 590},
WindowMargins->{{24, Automatic}, {62, Automatic}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3255628639-2770075"->{
    Cell[3779, 133, 1189, 17, 200, "Print",
      CellTags->"Info3255628639-2770075"]},
  "Info3255628694-9596816"->{
    Cell[5563, 180, 1056, 15, 170, "Print",
      CellTags->"Info3255628694-9596816"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3255628639-2770075", 519593, 16222},
  {"Info3255628694-9596816", 519711, 16225}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 104, 3, 22, "ExampleSection"],

Cell[CellGroupData[{
Cell[1905, 60, 35, 0, 29, "ExampleSubsection"],
Cell[1943, 62, 297, 6, 46, "ExampleText"],
Cell[2243, 70, 58, 1, 28, "Input"],
Cell[2304, 73, 232, 10, 147, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2573, 88, 55, 0, 29, "ExampleSubsection"],

Cell[CellGroupData[{
Cell[2653, 92, 413, 12, 181, "Input"],
Cell[3069, 106, 305, 7, 20, "Print"],
Cell[3377, 115, 197, 4, 20, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3623, 125, 43, 0, 29, "ExampleSubsection"],

Cell[CellGroupData[{
Cell[3691, 129, 85, 2, 28, "Input"],
Cell[3779, 133, 1189, 17, 200, "Print",
  CellTags->"Info3255628639-2770075"]
}, Open  ]],
Cell[4983, 153, 107, 3, 32, "ExampleText"],
Cell[5093, 158, 357, 14, 215, "Input"],

Cell[CellGroupData[{
Cell[5475, 176, 85, 2, 28, "Input"],
Cell[5563, 180, 1056, 15, 170, "Print",
  CellTags->"Info3255628694-9596816"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6656, 200, 83, 2, 28, "Input"],
Cell[6742, 204, 1758, 31, 187, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8549, 241, 42, 0, 29, "ExampleSubsection"],
Cell[8594, 243, 160, 8, 113, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8791, 256, 41, 0, 29, "ExampleSubsection"],
Cell[8835, 258, 116, 4, 28, "Input"],

Cell[CellGroupData[{
Cell[8976, 266, 127, 4, 28, "Input"],
Cell[9106, 272, 154400, 4541, 445, 39621, 3119, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[163555, 4819, 45, 0, 29, "ExampleSubsection"],

Cell[CellGroupData[{
Cell[163625, 4823, 152, 6, 62, "Input"],
Cell[163780, 4831, 25101, 488, 351, 3126, 212, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[188918, 5324, 152, 6, 62, "Input"],
Cell[189073, 5332, 27418, 521, 376, 3263, 218, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[216540, 5859, 55, 0, 29, "ExampleSubsection"],

Cell[CellGroupData[{
Cell[216620, 5863, 196, 6, 79, "Input"],
Cell[216819, 5871, 27162, 536, 352, 3482, 239, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[244042, 6414, 51, 0, 34, "Subsubsection"],

Cell[CellGroupData[{
Cell[244118, 6418, 165, 4, 45, "Input"],
Cell[244286, 6424, 89145, 3732, 294, 38944, 3107, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[333468, 10161, 157, 6, 62, "Input"],
Cell[333628, 10169, 25095, 488, 350, 3126, 212, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[358760, 10662, 85, 1, 37, "ExampleSection"],

Cell[CellGroupData[{
Cell[358870, 10667, 35, 0, 29, "ExampleSubsection"],
Cell[358908, 10669, 60, 1, 28, "Input"],
Cell[358971, 10672, 234, 10, 147, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[359242, 10687, 74, 0, 29, "ExampleSubsection"],

Cell[CellGroupData[{
Cell[359341, 10691, 415, 12, 181, "Input"],
Cell[359759, 10705, 305, 7, 20, "Print"],
Cell[360067, 10714, 233, 5, 20, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[360349, 10725, 54, 0, 29, "ExampleSubsection"],

Cell[CellGroupData[{
Cell[360428, 10729, 1221, 36, 572, "Input"],
Cell[361652, 10767, 373, 10, 20, "Print"],
Cell[362028, 10779, 369, 10, 20, "Print"],
Cell[362400, 10791, 246, 5, 22, "Print"],
Cell[362649, 10798, 201, 4, 22, "Print"],
Cell[362853, 10804, 202, 4, 22, "Print"],
Cell[363058, 10810, 202, 4, 22, "Print"],
Cell[363263, 10816, 202, 4, 22, "Print"],
Cell[363468, 10822, 375, 8, 22, "Print"],
Cell[363846, 10832, 365, 8, 22, "Print"],
Cell[364214, 10842, 63, 2, 20, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[364326, 10850, 43, 0, 29, "ExampleSubsection"],
Cell[364372, 10852, 132, 4, 32, "ExampleText"],
Cell[364507, 10858, 356, 14, 215, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[364900, 10877, 42, 0, 29, "ExampleSubsection"],
Cell[364945, 10879, 156, 8, 113, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[365138, 10892, 41, 0, 29, "ExampleSubsection"],
Cell[365182, 10894, 115, 4, 28, "Input"],

Cell[CellGroupData[{
Cell[365322, 10902, 129, 4, 28, "Input"],
Cell[365454, 10908, 77405, 3725, 294, 38308, 3237, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[442896, 14638, 205, 6, 62, "Input"],
Cell[443104, 14646, 292, 6, 20, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[443445, 14658, 45, 0, 29, "ExampleSubsection"],

Cell[CellGroupData[{
Cell[443515, 14662, 153, 6, 62, "Input"],
Cell[443671, 14670, 30719, 558, 439, 3169, 213, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474427, 15233, 153, 6, 62, "Input"],
Cell[474583, 15241, 29183, 544, 409, 3280, 219, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[503815, 15791, 53, 0, 29, "ExampleSubsection"],

Cell[CellGroupData[{
Cell[503893, 15795, 180, 6, 79, "Input"],
Cell[504076, 15803, 14629, 393, 352, 3640, 252, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

