(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1729620,      69642]*)
(*NotebookOutlinePosition[   1730454,      69668]*)
(*  CellTagsIndexPosition[   1730410,      69664]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Pressure Sensitive Lens", "Section"],

Cell["\<\
This notebook demonstrates the flexibility of Optica. A lens made \
of a polymer membrane is modeled. The membrane seals a chamber with a \
pressure higher than the environment and is therefore deformed.
A ray traversing the flexible lens passes a window, the pressure fluid and \
the membrane.
The theory applied for calculation of the deformation is the plate theory \
that assumes a two dimensional stress. Normally, the limits of this theory \
are reached, if the membrane is no longer thin in thickness compared to its \
other dimensions. We use here the term plate rather than membrane.
Short names for symbols are used to reduce the overall size of the \
formulas.\
\>", "Text"],

Cell["\<\
(*this avoids a lot of warning messages for similar names*)
Off[General::\"spell\"];\
\>", "Input"],

Cell["\<\
(*these symbols are used only symbolically*)
Clear[x, y, F0];\
\>", "Input"],

Cell[CellGroupData[{

Cell["Plate theory (shear elastic, cylinder symmetric)", "Subsection"],

Cell[CellGroupData[{

Cell["Plate values (all units SI)", "Subsubsection"],

Cell["\<\
The values are typical values also usable in experiments. Usually \
t0 is smaller in practice.\
\>", "Text"],

Cell["\<\
Clear[t0,EM,ny,K,R0];
R0 = 10*10^(-3); (*plate radius*)
t0 = 0.5*1.5 10^(-3); (*half plate thickness*)
EM = 5.1*10^9; (*Pa, Youngs modulus, measured value for PET*)
ny = 0.5; (*Poisson number, incompressible*)
K = EM*t0^3 / (12*(1-ny^2)); (*plate stiffness*)\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Translation (plate center plane, 0 for r>=R0)", "Subsubsection"],

Cell["\<\
The plate is assumed to be fixed at its boundary, the translation \
and its first derivative is zero at the boundary. The force on the plate is \
the pressure in the chamber.\
\>", "Text"],

Cell["\<\
Clear[w];
w[F0_,r_] := 
If[r<R0,
\t1/64 * F0/(Pi*K) * R0^2 * 
\t\t( (1-(r/R0)^2)^2 + 16/5*1/(1-ny)*(t0/R0)^2*(1-(r/R0)^2)^2 )
,0];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["half thickness change (0 for r>=R0)", "Subsubsection"],

Cell["\<\
Deformation of the plate also causes a change in the plate \
thickness.\
\>", "Text"],

Cell["\<\
Clear[Deltat];
Deltat[F0_,r_] := 
If[r<R0,
\tt0/2 * t0^2/10/(1-ny) * F0/Pi/K * r/R0^2
,0];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plate surfaces (translation of plate center plane included)", \
"Subsubsection"],

Cell["\<\
These are the boundary surfaces forming the optical meniscus lens \
made of the polymer plate.\
\>", "Text"],

Cell["\<\
Clear[S1,S2];
S1[Deltax_,Deltay_,F0_,x_,y_] :=
\t{w[F0,Sqrt[(x-Deltax)^2+(y-Deltay)^2]] -
\tDeltat[F0,Sqrt[(x-Deltax)^2+(y-Deltay)^2]],x,y};
S2[Deltax_,Deltay_,F0_,x_,y_] := 
\t{w[F0,Sqrt[(x-Deltax)^2+(y-Deltay)^2]] +
\tDeltat[F0,Sqrt[(x-Deltax)^2+(y-Deltay)^2]]+t0,x,y};\
\>", "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Optical components definition", "Subsection"],

Cell[CellGroupData[{

Cell["Window", "Subsubsection"],

Cell["\<\
The Window forms the one side of the flexible plano convex lens. It \
is bigger than the plate to place the deformed plate off-axis.\
\>", "Text"],

Cell["\<\
Clear[LensWindow];
LensWindow = Window[R0 * 4, t0 * 10];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plate material", "Subsubsection"],

Cell["\<\
For simplicity, constant refractive indices are assumed for the \
plate and the pressure fluid.\
\>", "Text"],

Cell["\<\
Clear[PlateMaterial,FluidMaterial];
Unprotect[ModelRefractiveIndex];
ModelRefractiveIndex[PlateMaterial] = IndexFunction[1.6^2, 0, 0, 0, 0, 0];
ModelRefractiveIndex[FluidMaterial] = IndexFunction[1.61^2, 0, 0, 0, 0, 0];
Protect[ModelRefractiveIndex];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lens parameters", "Subsubsection"],

Cell["These translations place the plate in an off-axis position.", "Text"],

Cell["\<\
Clear[Deltax,Deltay];
Deltax = 0.5 * R0; (*m, Translation of plate center in x direction*)
Deltay = 1.0 * R0; (*m, Translation of plate center in y direction*)\
\>", \
"Input"],

Cell["\<\
The surfaces O1 and O2 are in the coordinate system that already \
include the translation.\
\>", "Text"],

Cell["\<\
Clear[O1,O2,PlateThickness];
O1 = Map[Function[{x,y},#]&,S1[Deltax,Deltay,F0,x,y]];
O2 = Map[Function[{x,y},#]&,S2[Deltax,Deltay,F0,x,y]];
PlateThickness = t0;\
\>", "Input"],

Cell["Now, Optica is informed about the new shapes.", "Text"],

Cell["\<\
Clear[PlateFrontSurface,PlateBackSurface];
Unprotect[ModelSurfaceShape];
ModelSurfaceShape[PlateFrontSurface,{F0_}] = {SurfaceFunction->O1};
ModelSurfaceShape[PlateBackSurface,{F0_}] = {SurfaceFunction->O2};
Protect[ModelSurfaceShape];\
\>", "Input"],

Cell["\<\
The force on the plate is the pressure times the area of the plate. \
It is perpendicular to the plate and measured in Newton. Its value is choosen \
to yield graphics that show clearly the function of the lens. The lens \
thickness is arbitrarily choosen to be 80% of the plate radius.\
\>", "Text"],

Cell["\<\
Clear[Force,LensThickness];
Force = -1200;
LensThickness = 0.8 * R0;\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lens surfaces", "Subsubsection"],

Cell["\<\
We now form the Optica objects representing the flexible lens in \
terms of surfaces. The whole lens is wrapped by Resonate to allow any path \
through the flexible lens.\
\>", "Text"],

Cell["\<\
Clear[
\tOuterPlateSurface, InnerPlateSurface,
\tInnerWindowSurface, OuterWindowSurface,
\tLensSurfaces];
OuterPlateSurface = CustomLensSurface[
\t{Force}, R0 4,
\tSurfaceLabel -> PlateFrontSurface,
\tComponentMedium -> PlateMaterial,
\tGraphicDesign -> Wire, CrossRendering -> Mesh,
\tSurfaceRayIntersections -> Numeric];
InnerPlateSurface = CustomLensSurface[
\t{Force}, R0 4,
\tSurfaceLabel -> PlateBackSurface,
\tComponentMedium -> {PlateMaterial, FluidMaterial},
\tGraphicDesign -> Wire, CrossRendering -> Mesh,
\tSurfaceRayIntersections -> Numeric];
InnerWindowSurface = LensSurface[
\tR0 4,
\tComponentMedium -> {FluidMaterial, BK7},
\tGraphicDesign -> Wire, CrossRendering -> Mesh];
OuterWindowSurface = LensSurface[
\tR0 4,
\tComponentMedium -> BK7,
\tGraphicDesign -> Wire, CrossRendering -> Mesh];
LensSurfaces = Resonate[{
\tOuterPlateSurface,
\tInnerPlateSurface,
\tMove[InnerWindowSurface, LensThickness],
\tMove[OuterWindowSurface, LensThickness+t0 10]
}];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lenses", "Subsubsection"],

Cell["\<\
We now form the Optica objects representing the flexible lens in \
terms of bulk lenses to test an alternative way of definig the same object. \
The whole lens is wrapped by Resonate to allow any path through the flexible \
lens.\
\>", "Text"],

Cell["\<\
Clear[Plate];
Plate = CustomLens[{Force}, {Force}, R0 4, PlateThickness,
\tSurfaceLabel -> {PlateFrontSurface, PlateBackSurface},
\tComponentMedium -> PlateMaterial,
\tGraphicDesign -> Wire,
\tSurfaceRayIntersections -> Numeric];
Clear[Fluid];
Fluid=CustomLens[{Force}, {Force}, R0 4, LensThickness,
\tSurfaceLabel -> {PlateBackSurface, PlanarShape},
\tComponentMedium -> FluidMaterial,
\tGraphicDesign -> Wire,
\tCrossRendering -> Mesh,
\tSurfaceRayIntersections -> Numeric];
Clear[FlexibleLens];
FlexibleLens = Resonate[{
\tPlate,
\tMove[Fluid, t0],
\tMove[LensWindow, LensThickness+t0]
}];\
\>", "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphics of the flexible lens", "Subsection"],

Cell[CellGroupData[{

Cell["Plate", "Subsubsection"],

Cell[CellGroupData[{

Cell["ShowSystem[Plate, Axes->True, BoxRatios -> {1/4, 1, 1}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.815 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.386592 1.87247 -1.92121e-16 1.87247 [
[.11001 .08829 -30.6531 -10.9375 ]
[.11001 .08829 2.78436 0 ]
[.17924 .05908 -30.2712 -10.9375 ]
[.17924 .05908 3.1663 0 ]
[.24948 .02945 -8.04496 -10.9375 ]
[.24948 .02945 .95504 0 ]
[.32074 -0.0006 -23.3852 -10.9375 ]
[.32074 -0.0006 3.11477 0 ]
[-0.00126 1.24293 -28.4375 -3.79291 ]
[-0.00126 1.24293 0 7.14459 ]
[.19654 1.40856 -28.4375 -3.92045 ]
[.19654 1.40856 0 7.01705 ]
[.37306 1.55637 -9 -4.02996 ]
[.37306 1.55637 0 6.90754 ]
[.53155 1.68907 -21.5 -4.125 ]
[.53155 1.68907 0 6.8125 ]
[.67464 1.80889 -21.5 -4.20826 ]
[.67464 1.80889 0 6.72924 ]
[.07283 .14905 -28.4375 -3.18123 ]
[.07283 .14905 0 7.75627 ]
[.05275 .37598 -28.4375 -3.30628 ]
[.05275 .37598 0 7.63122 ]
[.03084 .62365 -9 -3.44336 ]
[.03084 .62365 0 7.49414 ]
[.00683 .89504 -21.5 -3.5943 ]
[.00683 .89504 0 7.3432 ]
[-0.01958 1.19373 -21.5 -3.7613 ]
[-0.01958 1.19373 0 7.1762 ]
[ 0 0 0 0 ]
[ 1 1.815 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09632 .11832 m
.37773 0 L
s
.125 .10627 m
.13249 .11526 L
s
gsave
.11001 .08829 -91.6531 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.002) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.19398 .07726 m
.20135 .08635 L
s
gsave
.17924 .05908 -91.2712 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.26396 .04784 m
.2712 .05703 L
s
gsave
.24948 .02945 -69.045 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.33496 .01799 m
.34207 .02728 L
s
gsave
.32074 -0.0006 -84.3852 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.13872 .1005 m
.1432 .1059 L
s
.15247 .09471 m
.15694 .10013 L
s
.16627 .08891 m
.17072 .09434 L
s
.18011 .0831 m
.18454 .08854 L
s
.2079 .07141 m
.2123 .07688 L
s
.22185 .06554 m
.22624 .07102 L
s
.23585 .05966 m
.24022 .06515 L
s
.24988 .05376 m
.25424 .05926 L
s
.27808 .0419 m
.28241 .04743 L
s
.29223 .03595 m
.29655 .04149 L
s
.30643 .02998 m
.31073 .03553 L
s
.32067 .02399 m
.32496 .02956 L
s
.11132 .11202 m
.11583 .1174 L
s
.09768 .11775 m
.1022 .12312 L
s
.34928 .01196 m
.35353 .01755 L
s
.36364 .00592 m
.36788 .01153 L
s
.25 Mabswid
0 1.21835 m
.711 1.815 L
s
.02112 1.23608 m
.03231 1.23265 L
s
gsave
-0.00126 1.24293 -89.4375 -7.79291 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.21907 1.40219 m
.23033 1.399 L
s
gsave
.19654 1.40856 -89.4375 -7.92045 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.3957 1.55041 m
.40701 1.54743 L
s
gsave
.37306 1.55637 -70 -8.02996 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.55428 1.68349 m
.56564 1.6807 L
s
gsave
.53155 1.68907 -82.5 -8.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69744 1.80363 m
.70885 1.801 L
s
gsave
.67464 1.80889 -82.5 -8.20826 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06259 1.27088 m
.06932 1.26886 L
s
.1031 1.30487 m
.10983 1.30287 L
s
.14265 1.33806 m
.14939 1.3361 L
s
.1813 1.3705 m
.18805 1.36856 L
s
.25598 1.43317 m
.26275 1.43128 L
s
.29208 1.46346 m
.29885 1.4616 L
s
.32738 1.49308 m
.33415 1.49125 L
s
.36191 1.52206 m
.36869 1.52025 L
s
.42876 1.57816 m
.43556 1.5764 L
s
.46114 1.60533 m
.46794 1.60359 L
s
.49283 1.63192 m
.49964 1.63021 L
s
.52387 1.65797 m
.53069 1.65628 L
s
.58407 1.70849 m
.59089 1.70684 L
s
.61326 1.73299 m
.62009 1.73135 L
s
.64188 1.757 m
.64871 1.75539 L
s
.66993 1.78055 m
.67677 1.77895 L
s
.25 Mabswid
.09632 .11832 m
0 1.21835 L
s
.09442 .14002 m
.10522 .1355 L
s
gsave
.07283 .14905 -89.4375 -7.18123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.07452 .36737 m
.0854 .36307 L
s
gsave
.05275 .37598 -89.4375 -7.30628 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.05279 .61552 m
.06376 .61145 L
s
gsave
.03084 .62365 -70 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02898 .88745 m
.04005 .88365 L
s
gsave
.00683 .89504 -82.5 -7.5943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.00277 1.18676 m
.01394 1.18327 L
s
gsave
-0.01958 1.19373 -82.5 -7.7613 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.09058 .18395 m
.09706 .18126 L
s
.08666 .22863 m
.09316 .22597 L
s
.08268 .27408 m
.08919 .27145 L
s
.07864 .32032 m
.08515 .31771 L
s
.07032 .41525 m
.07686 .41269 L
s
.06606 .46398 m
.07261 .46145 L
s
.06171 .51358 m
.06827 .51108 L
s
.05729 .56409 m
.06386 .56162 L
s
.0482 .6679 m
.0548 .66549 L
s
.04353 .72125 m
.05014 .71887 L
s
.03877 .77561 m
.04539 .77326 L
s
.03392 .831 m
.04055 .82869 L
s
.02394 .94499 m
.03059 .94275 L
s
.0188 1.00366 m
.02547 1.00146 L
s
.01356 1.06349 m
.02024 1.06132 L
s
.00822 1.12451 m
.01491 1.12238 L
s
0 0 m
1 0 L
1 1.815 L
0 1.815 L
closepath
clip
newpath
.5 Mabswid
.8023 .95359 m
.76046 .81657 L
s
.76046 .81657 m
.85799 .78485 L
s
.76046 .81657 m
.70737 .6855 L
s
.70479 .8504 m
.76046 .81657 L
s
.83097 1.09039 m
.8023 .95359 L
s
.8023 .95359 m
.90035 .92314 L
s
.73374 .94537 m
.8023 .95359 L
s
.70737 .6855 m
.80505 .65231 L
s
.70737 .6855 m
.64526 .56653 L
s
.66781 .75988 m
.70737 .6855 L
s
.85799 .78485 m
.90035 .92314 L
s
.80505 .65231 m
.85799 .78485 L
s
.8057 .81773 m
.85799 .78485 L
s
.83097 1.09039 m
.93019 1.06097 L
s
.75312 1.03986 m
.83097 1.09039 L
s
.90035 .92314 m
.93019 1.06097 L
s
.83502 .91362 m
.90035 .92314 L
s
.74375 .53171 m
.80505 .65231 L
s
.76882 .72616 m
.80505 .65231 L
s
.85523 1.00884 m
.93019 1.06097 L
s
.64526 .56653 m
.74375 .53171 L
s
.76172 1.12879 m .94577 1.19193 L .84476 1.22058 L .656 .751 .92 r
F
0 g
.84227 1.33737 m
.84476 1.22058 L
s
.83097 1.09039 m
.8378 1.15489 L
s
.72622 .64381 m
.74375 .53171 L
s
.76172 1.12879 m .86509 1.09831 L .94577 1.19193 L .656 .751 .92 r
F
0 g
.94563 1.30922 m
.94577 1.19193 L
s
.93019 1.06097 m
.94577 1.19193 L
s
.84476 1.22058 m
.94577 1.19193 L
s
.73374 .94537 m
.70479 .8504 L
s
.64451 .88703 m
.70479 .8504 L
s
.70479 .8504 m
.66781 .75988 L
s
.75312 1.03986 m
.73374 .94537 L
s
.65956 .93648 m
.73374 .94537 L
s
.57676 .46596 m .68006 .57543 L .57747 .61149 L .544 .324 .532 r
F
0 g
.62464 .67867 m
.64111 .58912 L
s
.57676 .46596 m .67668 .42939 L .68006 .57543 L .544 .324 .532 r
F
0 g
.67668 .42939 m
.74375 .53171 L
s
.57676 .46596 m
.67668 .42939 L
s
.50503 .39022 m
.57676 .46596 L
s
.66781 .75988 m
.62464 .67867 L
s
.83502 .91362 m
.8057 .81773 L
s
.8057 .81773 m
.76882 .72616 L
s
.74902 .85337 m
.8057 .81773 L
s
.82247 1.43355 m
.84227 1.33737 L
s
.84227 1.33737 m
.94563 1.30922 L
s
.7587 1.20705 m
.84227 1.33737 L
s
.85523 1.00884 m
.83502 .91362 L
s
.76427 .90332 m
.83502 .91362 L
s
.60698 .35188 m
.67668 .42939 L
s
.76882 .72616 m
.72622 .64381 L
s
.72972 .80586 m
.76882 .72616 L
s
.67332 1.03107 m .86509 1.09831 L .76172 1.12879 L .656 .751 .92 r
F
0 g
.7587 1.20705 m
.76172 1.12879 L
s
.75312 1.03986 m
.75504 1.05973 L
s
.76172 1.12879 m
.84476 1.22058 L
s
.94563 1.30922 m
.92864 1.40557 L
s
.86369 1.17689 m
.94563 1.30922 L
s
.70748 .76367 m
.72622 .64381 L
s
.67332 1.03107 m .77914 .99859 L .86509 1.09831 L .656 .751 .92 r
F
0 g
.86369 1.17689 m
.86509 1.09831 L
s
.86509 1.09831 m
.94577 1.19193 L
s
.66937 .98549 m
.71831 1.01726 L
s
.85523 1.00884 m
.86509 1.09831 L
s
.57747 .61149 m .68363 .72945 L .57822 .76489 L .544 .324 .532 r
F
0 g
.60261 .7985 m
.61081 .75394 L
s
.62515 .84008 m
.66781 .75988 L
s
.57747 .61149 m .68006 .57543 L .68363 .72945 L .544 .324 .532 r
F
0 g
.57676 .46596 m
.57747 .61149 L
s
.68006 .57543 m
.72622 .64381 L
s
.67668 .42939 m
.68006 .57543 L
s
.52883 .5628 m
.57747 .61149 L
s
.50503 .39022 m
.60698 .35188 L
s
.50503 .39022 m
.43394 .34573 L
s
.52883 .5628 m
.50503 .39022 L
s
.70553 1.2803 m
.7587 1.20705 L
s
.65568 1.07502 m
.7587 1.20705 L
s
.78504 1.50162 m
.82247 1.43355 L
s
.82247 1.43355 m
.92864 1.40557 L
s
.70553 1.2803 m
.82247 1.43355 L
s
.63283 .52556 m
.68006 .57543 L
s
.53841 .30568 m
.60698 .35188 L
s
.63283 .52556 m
.60698 .35188 L
s
.65956 .93648 m
.64451 .88703 L
s
.64451 .88703 m
.62515 .84008 L
s
.66937 .98549 m
.65956 .93648 L
s
.62515 .84008 m
.60261 .7985 L
s
.81093 1.25063 m
.86369 1.17689 L
s
.76121 1.04303 m
.86369 1.17689 L
s
.52883 .5628 m
.48159 .5366 L
s
.55347 .74156 m
.52883 .5628 L
s
.92864 1.40557 m
.89433 1.47344 L
s
.81093 1.25063 m
.92864 1.40557 L
s
.59929 1.34424 m
.70553 1.2803 L
s
.60771 1.1172 m
.70553 1.2803 L
s
.57902 .92683 m .77914 .99859 L .67332 1.03107 L .656 .751 .92 r
F
0 g
.65568 1.07502 m
.67332 1.03107 L
s
.77453 .95272 m
.85523 1.00884 L
s
.67332 1.03107 m
.76172 1.12879 L
s
.76427 .90332 m
.74902 .85337 L
s
.74902 .85337 m
.72972 .80586 L
s
.76427 .90332 m
.77453 .95272 L
s
.72972 .80586 m
.70748 .76367 L
s
.57822 .76489 m .68739 .89213 L .57902 .92683 L .544 .324 .532 r
F
.57822 .76489 m .68363 .72945 L .68739 .89213 L F
0 g
.57747 .61149 m
.57822 .76489 L
s
.68006 .57543 m
.68363 .72945 L
s
.55347 .74156 m
.57822 .76489 L
s
.60771 1.1172 m
.65568 1.07502 L
s
.63283 .52556 m
.58734 .49829 L
s
.63283 .52556 m
.65962 .70553 L
s
.68363 .72945 m
.70748 .76367 L
s
.70534 1.31473 m
.81093 1.25063 L
s
.71354 1.08541 m
.81093 1.25063 L
s
.57902 .92683 m .68739 .89213 L .77914 .99859 L .656 .751 .92 r
F
0 g
.76121 1.04303 m
.77914 .99859 L
s
.77453 .95272 m
.77914 .99859 L
s
.77914 .99859 m
.86509 1.09831 L
s
.43394 .34573 m
.53841 .30568 L
s
.43394 .34573 m
.36807 .33831 L
s
.48159 .5366 m
.43394 .34573 L
s
.55332 1.1483 m
.60771 1.1172 L
s
.51185 1.37526 m
.59929 1.34424 L
s
.59929 1.34424 m
.78504 1.50162 L
s
.55332 1.1483 m
.59929 1.34424 L
s
.55347 .74156 m
.52995 .73028 L
s
.65962 .70553 m
.68363 .72945 L
s
.71354 1.08541 m
.76121 1.04303 L
s
.48159 .5366 m
.43895 .53604 L
s
.52995 .73028 m
.48159 .5366 L
s
.51251 1.16107 m
.55332 1.1483 L
s
.72233 1.53644 m
.78504 1.50162 L
s
.78504 1.50162 m
.89433 1.47344 L
s
.47546 .29679 m
.53841 .30568 L
s
.58734 .49829 m
.53841 .30568 L
s
.65946 1.11657 m
.71354 1.08541 L
s
.6191 1.3455 m
.70534 1.31473 L
s
.70534 1.31473 m
.89433 1.47344 L
s
.65946 1.11657 m
.70534 1.31473 L
s
.65962 .70553 m
.637 .69375 L
s
.52995 .73028 m
.50926 .73221 L
s
.58734 .49829 m
.54667 .49683 L
s
.637 .69375 m
.58734 .49829 L
s
.49616 1.15182 m
.51251 1.16107 L
s
.51251 1.16107 m
.51185 1.37526 L
s
.61928 1.12915 m
.65946 1.11657 L
s
.4816 1.36076 m
.51185 1.37526 L
s
.51185 1.37526 m
.72233 1.53644 L
s
.89433 1.47344 m
.83377 1.50791 L
s
.57902 .92683 m .61233 1.08818 L .50311 1.12129 L .544 .324 .532 r
F
0 g
.49616 1.15182 m
.50794 1.11983 L
s
.51251 1.16107 m
.52575 1.11443 L
s
.55332 1.1483 m
.5584 1.10453 L
s
.60373 1.09079 m
.60771 1.1172 L
s
.57902 .92683 m .68739 .89213 L .61233 1.08818 L .544 .324 .532 r
F
0 g
.63366 1.03247 m
.65568 1.07502 L
s
.64583 1.00068 m
.67332 1.03107 L
s
.4782 .81539 m .68739 .89213 L .57902 .92683 L .656 .751 .92 r
F
0 g
.5203 1.07486 m
.57902 .92683 L
s
.52634 1.02176 m
.57902 .92683 L
s
.5076 .97023 m
.57902 .92683 L
s
.49128 .91631 m
.57902 .92683 L
s
.50926 .73221 m
.54829 .8411 L
s
.57902 .92683 m
.57902 .92683 L
s
.52995 .73028 m
.55856 .84487 L
s
.55347 .74156 m
.5682 .84841 L
s
.57822 .76489 m
.57865 .85224 L
s
.637 .69375 m
.61731 .69527 L
s
.50926 .73221 m
.49292 .74764 L
s
.43895 .53604 m
.50926 .73221 L
s
.60399 1.11943 m
.61928 1.12915 L
s
.61928 1.12915 m
.6191 1.3455 L
s
.49616 1.15182 m
.4816 1.36076 L
s
.43895 .53604 m
.40417 .5629 L
s
.36807 .33831 m
.43895 .53604 L
s
.59102 1.33014 m
.6191 1.3455 L
s
.6191 1.3455 m
.83377 1.50791 L
s
.4782 .81539 m .58924 .77824 L .68739 .89213 L .656 .751 .92 r
F
0 g
.60399 1.11943 m
.68739 .89213 L
s
.63091 1.04088 m
.68739 .89213 L
s
.6378 .98695 m
.68739 .89213 L
s
.62013 .93443 m
.68739 .89213 L
s
.60357 .87993 m
.68739 .89213 L
s
.59302 .82651 m
.68739 .89213 L
s
.59238 .73866 m
.68739 .89213 L
s
.60203 .71045 m
.68739 .89213 L
s
.61731 .69527 m
.68739 .89213 L
s
.68739 .89213 m
.68739 .89213 L
s
.61928 1.12915 m
.68739 .89213 L
s
.637 .69375 m
.68739 .89213 L
s
.49292 .74764 m
.51893 .80177 L
s
.48225 .77593 m
.50238 .80731 L
s
.48125 .86336 m
.57902 .92683 L
s
.65946 1.11657 m
.68739 .89213 L
s
.65962 .70553 m
.68739 .89213 L
s
.68739 .89213 m
.71354 1.08541 L
s
.68739 .89213 m
.76121 1.04303 L
s
.68363 .72945 m
.68739 .89213 L
s
.68739 .89213 m
.74902 .85337 L
s
.68739 .89213 m
.76427 .90332 L
s
.68739 .89213 m
.72972 .80586 L
s
.68739 .89213 m
.77453 .95272 L
s
.68739 .89213 m
.70748 .76367 L
s
.68739 .89213 m
.77914 .99859 L
s
.36807 .33831 m
.31263 .37237 L
s
.47546 .29679 m
.36807 .33831 L
s
.61731 .69527 m
.60203 .71045 L
s
.54667 .49683 m
.61731 .69527 L
s
.49292 .74764 m
.40417 .5629 L
s
.49292 .74764 m
.48225 .77593 L
s
.54667 .49683 m
.514 .52309 L
s
.47546 .29679 m
.54667 .49683 L
s
.50311 1.12129 m .61418 1.26977 L .50175 1.30183 L .544 .324 .532 r
F
0 g
.59102 1.33014 m
.59439 1.27542 L
s
.50311 1.12129 m .61233 1.08818 L .61418 1.26977 L .544 .324 .532 r
F
0 g
.50311 1.12129 m
.57902 .92683 L
s
.49616 1.15182 m
.50311 1.12129 L
s
.61233 1.08818 m
.68739 .89213 L
s
.50311 1.12129 m
.5203 1.07486 L
s
.65864 1.52625 m
.72233 1.53644 L
s
.72233 1.53644 m
.83377 1.50791 L
s
.42317 .32978 m
.47546 .29679 L
s
.60203 .71045 m
.59238 .73866 L
s
.40417 .5629 m
.31263 .37237 L
s
.40417 .5629 m
.38039 .61707 L
s
.61233 1.08818 m
.63091 1.04088 L
s
.83377 1.50791 m
.77325 1.49661 L
s
.52634 1.02176 m
.5203 1.07486 L
s
.51873 1.21517 m
.5203 1.07486 L
s
.37018 .69599 m .58924 .77824 L .4782 .81539 L .656 .751 .92 r
F
0 g
.4782 .81539 m
.48125 .86336 L
s
.514 .52309 m
.60203 .71045 L
s
.4782 .81539 m
.57902 .92683 L
s
.3751 .79445 m
.48125 .86336 L
s
.48125 .86336 m
.49128 .91631 L
s
.5076 .97023 m
.52634 1.02176 L
s
.47446 1.12342 m
.52634 1.02176 L
s
.514 .52309 m
.42317 .32978 L
s
.514 .52309 m
.4923 .57702 L
s
.49128 .91631 m
.39532 .90481 L
s
.49128 .91631 m
.5076 .97023 L
s
.6378 .98695 m
.63091 1.04088 L
s
.63091 1.04088 m
.63376 1.18143 L
s
.5076 .97023 m
.42942 1.01774 L
s
.37018 .69599 m .48399 .65612 L .58924 .77824 L .656 .751 .92 r
F
0 g
.58924 .77824 m
.59302 .82651 L
s
.4923 .57702 m
.59238 .73866 L
s
.58924 .77824 m
.59238 .73866 L
s
.58924 .77824 m
.68739 .89213 L
s
.38039 .61707 m
.41984 .67859 L
s
.31263 .37237 m
.42317 .32978 L
s
.31263 .37237 m
.27302 .44961 L
s
.50175 1.30183 m .70008 1.44009 L .58169 1.47159 L .544 .324 .532 r
F
0 g
.4816 1.36076 m
.56717 1.44075 L
s
.59607 1.46776 m
.65864 1.52625 L
s
.50175 1.30183 m .61418 1.26977 L .70008 1.44009 L .544 .324 .532 r
F
0 g
.50175 1.30183 m
.50311 1.12129 L
s
.4816 1.36076 m
.50175 1.30183 L
s
.69042 1.42095 m
.77325 1.49661 L
s
.50175 1.30183 m
.58169 1.47159 L
s
.50175 1.30183 m
.51873 1.21517 L
s
.61233 1.08818 m
.61418 1.26977 L
s
.49048 .7552 m
.59302 .82651 L
s
.59302 .82651 m
.60357 .87993 L
s
.62013 .93443 m
.6378 .98695 L
s
.6378 .98695 m
.59134 1.08791 L
s
.60357 .87993 m
.62013 .93443 L
s
.5118 .86657 m
.60357 .87993 L
s
.62013 .93443 m
.54641 .98079 L
s
.58169 1.47159 m
.65864 1.52625 L
s
.65864 1.52625 m
.77325 1.49661 L
s
.38673 .40652 m
.42317 .32978 L
s
.61418 1.26977 m
.70008 1.44009 L
s
.61418 1.26977 m
.63376 1.18143 L
s
.70008 1.44009 m
.77325 1.49661 L
s
.25415 .56773 m .48399 .65612 L .37018 .69599 L .656 .751 .92 r
F
0 g
.37018 .69599 m
.3751 .79445 L
s
.27302 .44961 m
.37972 .61602 L
s
.37018 .69599 m
.4782 .81539 L
s
.47446 1.12342 m
.51873 1.21517 L
s
.49698 1.373 m
.51873 1.21517 L
s
.38673 .40652 m
.27302 .44961 L
s
.25415 .56773 m .37084 .52483 L .48399 .65612 L .656 .751 .92 r
F
0 g
.48399 .65612 m
.49048 .7552 L
s
.37084 .52483 m
.48399 .65612 L
s
.25415 .56773 m
.27302 .44961 L
s
.48399 .65612 m
.58924 .77824 L
s
.48399 .65612 m
.4923 .57702 L
s
.38673 .40652 m
.4923 .57702 L
s
.25415 .56773 m
.37018 .69599 L
s
.3751 .79445 m
.25947 .71938 L
s
.3751 .79445 m
.39532 .90481 L
s
.59134 1.08791 m
.63376 1.18143 L
s
.61744 1.3395 m
.63376 1.18143 L
s
.42942 1.01774 m
.47446 1.12342 L
s
.47446 1.12342 m
.41489 1.23541 L
s
.58169 1.47159 m
.70008 1.44009 L
s
.49698 1.373 m
.58169 1.47159 L
s
.39532 .90481 m
.28994 .89218 L
s
.39532 .90481 m
.42942 1.01774 L
s
.37084 .52483 m
.38673 .40652 L
s
.42942 1.01774 m
.34346 1.06997 L
s
.37866 .67744 m
.49048 .7552 L
s
.49048 .7552 m
.5118 .86657 L
s
.54641 .98079 m
.59134 1.08791 L
s
.59134 1.08791 m
.53654 1.1996 L
s
.61744 1.3395 m
.70008 1.44009 L
s
.5118 .86657 m
.41091 .85188 L
s
.5118 .86657 m
.54641 .98079 L
s
.54641 .98079 m
.46528 1.0318 L
s
.25415 .56773 m
.37084 .52483 L
s
.25415 .56773 m
.25947 .71938 L
s
.41489 1.23541 m
.49698 1.373 L
s
.49698 1.373 m
.61744 1.3395 L
s
.37084 .52483 m
.37866 .67744 L
s
.61744 1.3395 m
.53654 1.1996 L
s
.25947 .71938 m
.37866 .67744 L
s
.25947 .71938 m
.28994 .89218 L
s
.34346 1.06997 m
.41489 1.23541 L
s
.41489 1.23541 m
.53654 1.1996 L
s
.28994 .89218 m
.34346 1.06997 L
s
.41091 .85188 m
.28994 .89218 L
s
.41091 .85188 m
.37866 .67744 L
s
.34346 1.06997 m
.46528 1.0318 L
s
.53654 1.1996 m
.46528 1.0318 L
s
.46528 1.0318 m
.41091 .85188 L
s
.25 Mabswid
.09632 .11832 m
.37773 0 L
s
.125 .10627 m
.13249 .11526 L
s
gsave
.11001 .08829 -91.6531 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.002) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.19398 .07726 m
.20135 .08635 L
s
gsave
.17924 .05908 -91.2712 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.26396 .04784 m
.2712 .05703 L
s
gsave
.24948 .02945 -69.045 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.33496 .01799 m
.34207 .02728 L
s
gsave
.32074 -0.0006 -84.3852 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.13872 .1005 m
.1432 .1059 L
s
.15247 .09471 m
.15694 .10013 L
s
.16627 .08891 m
.17072 .09434 L
s
.18011 .0831 m
.18454 .08854 L
s
.2079 .07141 m
.2123 .07688 L
s
.22185 .06554 m
.22624 .07102 L
s
.23585 .05966 m
.24022 .06515 L
s
.24988 .05376 m
.25424 .05926 L
s
.27808 .0419 m
.28241 .04743 L
s
.29223 .03595 m
.29655 .04149 L
s
.30643 .02998 m
.31073 .03553 L
s
.32067 .02399 m
.32496 .02956 L
s
.11132 .11202 m
.11583 .1174 L
s
.09768 .11775 m
.1022 .12312 L
s
.34928 .01196 m
.35353 .01755 L
s
.36364 .00592 m
.36788 .01153 L
s
.25 Mabswid
0 1.21835 m
.711 1.815 L
s
.02112 1.23608 m
.03231 1.23265 L
s
gsave
-0.00126 1.24293 -89.4375 -7.79291 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.21907 1.40219 m
.23033 1.399 L
s
gsave
.19654 1.40856 -89.4375 -7.92045 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.3957 1.55041 m
.40701 1.54743 L
s
gsave
.37306 1.55637 -70 -8.02996 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.55428 1.68349 m
.56564 1.6807 L
s
gsave
.53155 1.68907 -82.5 -8.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69744 1.80363 m
.70885 1.801 L
s
gsave
.67464 1.80889 -82.5 -8.20826 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06259 1.27088 m
.06932 1.26886 L
s
.1031 1.30487 m
.10983 1.30287 L
s
.14265 1.33806 m
.14939 1.3361 L
s
.1813 1.3705 m
.18805 1.36856 L
s
.25598 1.43317 m
.26275 1.43128 L
s
.29208 1.46346 m
.29885 1.4616 L
s
.32738 1.49308 m
.33415 1.49125 L
s
.36191 1.52206 m
.36869 1.52025 L
s
.42876 1.57816 m
.43556 1.5764 L
s
.46114 1.60533 m
.46794 1.60359 L
s
.49283 1.63192 m
.49964 1.63021 L
s
.52387 1.65797 m
.53069 1.65628 L
s
.58407 1.70849 m
.59089 1.70684 L
s
.61326 1.73299 m
.62009 1.73135 L
s
.64188 1.757 m
.64871 1.75539 L
s
.66993 1.78055 m
.67677 1.77895 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144.562, 262.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@00011PP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000091d002@M000T7@0091d002@M000T7@0091d
002@M000T7@0091d002@M000T7@0091d002@M000T7@0091d002@M000T7@0091d002@M000T7@0091d
002@M000;G@24@=d00<AM7@00Q43M08A0g@34Did000/M0044GAd4@Ad00HAM7@AM142M0054GAdM140
Cg@002ad00@AM7@A17@01Q5dM15d4@9d00DAM7Ad4@1?M000;7@0115dM144M0064GAd4G@A0W@01A5d
M7@A04md000/M0044GAd4@Ad0Q4017@AM142M0054GAdM140Cg@002ad00@AM7@A0g@24@05M14AM140
0W@00a5dM0024Dmd000]M08A17@0115d4A43M08A17@00a5dM004M08AAg@001ad0Q43M0034GAd008A
0g@24@=d0a42M0044GAd4@ed0a59M0006g@0115dM144M0064GAd4G@A0W@01A5dM7@A00=d00@AM7@A
37@34DYd000EM0@A0W@0115dM144M0064GAd4G@A0W@01A5dM7@A00=d00@AM7@A27@54Dad000DM08A
0g@00a5d4@034@9d0a400g@A4@024@9d00DAM7Ad4@04M08A27@34Dmd000CM0044GAd4@Ad00HAM7@A
M142M0064GAd4G@A0W@01A5dM7@A00Yd00<AM1400Q5AM0003G@44@9d00@AM7@A17@01Q5dM15d4@9d
00<AM7@00a42M0034GAd008A2G@34EAd000CM0044GAd4@Ad114017@AM7@34@03M15d008A17@00a5d
M004M0@A00=d4G@0Dg@001=d00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM009M0<AFG@001=d
00@AM7@A17@01Q5dM15d4@9d00<AM1400W@00a5dM007M0<AFg@001Ad0Q46M08A0g@24@=d0Q47M0<A
00=d4G@0Fg@002ed115OM000:W@44F9d000WM0034G@A008AI7@002Md0Q5WM0009g@00a5dM01VM000
9g@24FMd000WM0034GAd06Id000WM0034GAd06Id000BM08A0g@00a5dM0024@9d1145M0034GAd06Id
000AM0044GAd4@Ad00@AM7@A0W@00a5dM004M0034GAd06Md000;M0@A0W@0115dM144M0044GAd4@=d
00<AM7@00g@24FQd000AM0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd06Md000AM0044GAd4@Ad
00@AM7@A17@00a5dM002M0034GAd06Md000AM0044GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@0
Ig@0019d0Q46M08A0g@24@Ed00<AM7@0Ig@002Id0Q5XM0009W@00a5dM01WM0009W@00a5dM01WM000
9W@00a5dM01WM0009W@00a5dM01WM0009W@00a5dM01WM0009G@00a5dM01XM0009G@00a5dM01XM000
9G@00a5dM00ZM0DA>G@002Ed00<AM7@0:7@44@=d114eM0009G@24BId1143M0034GAd008A00Ad4A4A
<g@002Ed00<AM7@08W@34@03M14A00Ad0a44M0034G@A039d000UM0034GAd021d0Q42M08A17@34@Id
00<AM7@00Q4`M0009G@00a5dM00NM0HA00Ad4GAd0Q43M0034GAd00=d00<AM7@00W@24Bid000UM003
4GAd01ad3145M0034GAd00=d00<AM7@00g@24Bed000UM0034GAd01]d1A44M0034G@A008A17@00a5d
M004M0034GAd008A00=d4A40;7@002Ed0Q4JM0<A0g@01A5dM7@A009d0Q400g@AM003M0034GAd00=d
0a43M0034G@A02]d000TM0034GAd01Ud0Q46M0044GAd4@=d00<AM7@00Q42M0044GAdM0<A1G@0115d
M14ZM00097@00a5dM00HM08A1g@00a5d4@04M08A0g@34@03M14A009d00<AM7@017@0115dM14YM000
47@24@=d00<AM7@00Q43M0<A17@00a5dM00HM0034G@A00Id00<AM14017@24@Ed0Q45M0034GAd00=d
00@AM7@A:G@000md00@AM7@A17@0115dM143M0034GAd00=d00<AM7@05g@0115dM147M0034GAd00=d
00<AM14017@24@Ed00<AM7@00g@01A5dM7@A02Qd0009M0@A0W@0115dM144M0044GAd4@=d00<AM7@0
0g@24AQd00DAM7Ad4@05M08A1W@24@Ad00<AM14017@00a5dM003M0034GAd009d00<AM7@09G@000md
00@AM7@A17@0115dM143M0034GAd00=d00<AM7@05W@00a5dM002M0034GAd00<A00=d4A401G@00a5d
4@03M0044G@A4@Ad00<AM7@00W@00a5dM003M0034GAd02Ad000?M0044GAd4@Ad00@AM7@A0g@00a5d
M003M0034GAd01Id00<AM7@00W@34@Ad0Q45M0034G@A00Ad0Q400g@AM002M0034GAd009d00<AM7@0
0g@24BEd000?M0044GAd4@Ad00@AM7@A0W@24@Ed00<AM7@05G@0115dM7@24@03M15d00Ad0a44M003
4G@A00Ad00@AM14A0g@00a5dM002M0044GAdM08A00<n4A4097@0011d0Q46M08A17@00a5dM003M003
4GAd01Ed1144M0054GAdM1400W@24@=d00@AM7@A0g@01A5d4G@A009d00<AM7@00g@34@03?cho008A
97@002Ad00<AM7@057@24@Md00DAM7Ad4@02M08A17@00a5d4@03M0034G@A009d00@AM7@A0W@34@08
?ULnEchAM14SM00097@00a5dM00DM08A27@0115dM142M0034G@A00=d00@AM7@A0W@0115dM142M003
4G@A008A00Tn?a4o?Sln?a400W@00a5dM00PM00097@00a5dM00DM08A27@0115dM143M08A0g@0115d
M142M0044GAd4@=d0Q402eLnEchA?ULnEchA009d00<AM7@087@002=d00<AM7@05G@00a5d4@08M003
4G@A00=d00<AM1400W@01a5dM7@AM1400W@0115dM7@24@0;?Sln?a4o?Sln?a400g@00a5dM00OM000
8g@00a5dM00DM0054GAdM1401g@00a5d4@04M0034G@A009d00@AM7@A0W@0115dM142M00=4ChA?ULn
4CiG?ULn4@04M0034GAd01id000SM0034GAd01Ad00DAM7Ad4@08M0034GAd00=d00<AM1400W@01a5d
M7@AM1400W@64@0:?cho?Q4n?cho4@Ad00<AM7@07W@002=d00<AM7@057@00a5dM002M0034GAd00Ed
00<AM7@00g@01Q5dM15d4@=d00<AM1400a42M0034ChA008A00PnEa5G?ULn4@Ed00<AM7@07G@002=d
0Q4EM0034GAd00=d00<AM7@017@24@Ed00<AM7@00Q44M08A0g@01a5d4ClA?ch00a401Cho?SlA00Id
00<AM7@077@002=d00<AM7@057@00a5dM003M0034GAd00=d0a45M0064GAd4G@A0g@24@=d00lAM14n
Ea5G?ULAEciG?Q401W@00a5dM00LM0008g@00a5dM00DM0034GAd00Ad00<AM1400Q4014LA4A45M003
4GAd008A0g@24@=d00TAM14o?Q4n?ch00Q4013ln?a46M08A7G@002=d00<AM7@04g@00a5dM004M0<A
15`00a5L4@05M0DA0W@0115d4A43M08A00`nEa5G?ULAEa5G?Q43M0<A00=d4G@077@002=d00<AM7@0
4g@00a5dM002M08A00]7G4MLAea74DML4@02M0<A0g@44@03M14A00=d0Q402cln4Cho?Q4n4Cho00@A
17@24Aad000SM0034GAd01=d00<AM1400Q49G0064EaL4G@A0g@01Q5dM7@AM08A00=d4G@00W@24@0<
?ULn4CiG?Q4n4ChA1g@24Aad000SM0034GAd01=d0Q404Ea7G4MLAea7G4MLAa57G4LA00Ad00@AM7Ad
0Q42M08A17@02a4o?SlA?cho4Cln008A1W@0115dM14KM0008W@00a5dM00DM08A35`00a5LG002G005
4GAdM1400g@24@=d0Q43M00=4CiG?Q4nEchA?ULn4@06M0044GAd4A]d000RM0034GAd01Ad01DAM157
G4MLAea7G4MLAa57G4MLAa400g@00a5dM0034@9d0a42M00<4Cln?a4o?SlA?cho0Q45M0054GAdM140
6W@0029d00<AM7@057@0115dM14:G0034EaL00AL00@AM7@A0g@24@9d00DAM14AM0024@0:EchA?ULn
4CiG?P8A1G@01A5dM7@A01Yd000RM0034GAd01Ad01LAM7Ad4DMLAea7G4MLAa57G4MLAea74@02M006
4GAd4G@A0W@24@0AM14A4Cho?Q4n?a4o?SlAM14017@00a5dM002M0034GAd01Md000RM08A5G@00a5d
M002M0034EaL00ML00<AG5`01E`00a5d4@02M0034G@A009d014AM15d4ChA?ULAEchA?ULn4@02M005
4GAdM14017@00a5dM00GM0008W@00a5dM00DM0034GAd00=d018AAea7G4MLAe`AG4MLAea7G4L24@03
M14A009d01<AM15d4G@A?a4o?Q4n?chA?SlA00=d00<AM1401W@00a5dM00FM0008W@00a5dM00DM003
4GAd00Ad00<AG5`01E`00a5LG006G00J4G@A4G@AM15d4G@AM14n4CiG4ELnEa5G?Q43M0034G@A00Id
00<AM7@05W@001Yd0Q46M0034GAd01Ad00<AM7@017@04Q5LAea7G4ML4Ea7G4MLAea7G0<A00Ad4GAd
0Q42M08A00`o?Q4n4Cho?Q4n?a44M08A1g@00a5dM00EM0006G@0115dM145M0034GAd01Ad00<AM7@0
1G@00a5LG004G0034EaL00QL0Q400g@AM002M0034GAd008A00`nEa5G?Q4nEa5G?Q45M0034GAd00Ed
00<AM7@05G@001Ud00@AM7@A1G@00a5dM00EM0034GAd00Ed01<AG4MLAe`AG4MLAea7G4MLAe`A009d
00@AM7@A0g@0314o?Q4n?a4o?Q4n?`8A17@00a5dM005M08A5W@001Ud00@AM7@A1G@00a5dM00EM003
4GAd00Id00<AG5`00U`00a5LG009G08A00=d4G@00W@04A5dM14nEchA?Q4nEa5G?ULA00Ad0Q43M0DA
5W@001Ud00@AM7@A1G@00a5dM00EM0034GAd00Md018AG4ML4Ea7G4MLAea7G4ML4E`24@=d00<AM7@0
0Q402cho4ClA?chA?Sln008A0W@00a5d4@034@=d00<AM1405G@001Ud00@AM7@A17@00a5dM00FM003
4GAd00Qd00@AG14A2e`0115LG143M08A00id4A5G?Q4nEa5G?Q4nE`8A0W@44@Ad00@AM7@A5G@001Yd
0Q45M0034GAd01Id00<AM7@01g@34@0@G14AAea7G4MLAea7G15LA`8A0W@04Q5d4A4o4Cln4ChA?SlA
?chAM0<A0W@00a5dM002M0054GAdM14057@0025d00<AM7@05W@00a5dM004M0<A0g@24@03G14A00QL
00DAG5aL4@02M0044G@AM08A00<nEa400a402ChA?ULAM15d4@03M0044GAd4@Ad00<AM7@04W@0025d
00<AM7@05W@00a5dM002M08A1W@24@0CG4ML4Ea7G4MLAe`AG4MLAa5d4@02M08A00Ln4A4A?Q4n008A
00Do?Q4AM0024@=d00<AM1401G@00a5dM00BM0008G@00a5dM00FM0034G@A008A27@00a5d4@03G003
4EaL00AL00<AG5`00e`0115d4G@24@08Ea5G?Q4n4Ch24@05Ea4AM1401G@24@Id00<AM7@04G@0025d
0Q4GM08A2g@01a5d4A5LAe`00Q402dMLAe`AG4MLAea7008A0W@02a4n4Cho4ClA?a4o008A0W@24@Ad
00<AM7@01G@00a5dM00AM0008G@00a5dM00FM0<A2W@0115d4A45G0054EaLG1401e`00a5dM0024@0;
?Q4n4ChA?Q4nEa400W@24@Ad00<AM7@01W@00a5dM00@M0008G@00a5dM00FM0034GAd008A27@0615d
4G@AAea7G4LAAe`AG4MLAea7G4LAM08A00@o4Cln0Q401Cln4ChA009d00<AM1400W@00a5d4@07M003
4GAd011d000QM0034GAd01Id00<AM7@00W@00a5dM005M0034G@A009d00<AG5`00e`34@QL00<AM140
0Q402ELAEa5G4ELAE`034@9d00HAM7@AM147M0034GAd011d000QM0034GAd01Md00<AM7@00W@24@Ed
00<AM1400g@04A57G4MLAe`AG4MLAea7G4ML00@A00Tn4ChA?Q4n4Ch00a43M08A0g@00a5dM005M003
4GAd00md000QM0034GAd01Md00<AM7@017@00a5dM002M0034G@A00Ad00<AG5`00e`34@QL0Q401ChA
?Q4n008A00IG4ELAM143M08A0g@00a5dM005M0034GAd00md000PM08A6G@00a5dM005M08A0W@0115d
M144M00G4DMLAe`AG4LAAea7G4MLAe`A?a4o4Cl00Q401ChA?Q5d008A0g@00a5dM002M0034GAd00Ed
00<AM7@03W@0021d00<AM7@067@00a5dM007M0<A0W@00a5dM003M0034EaL009L00<AG5`00Q46G08A
00=G4EL00Q401ShA4ELAM08A0W@24@Ad00<AM7@017@24A1d000PM0034GAd01Qd00<AM7@02G@0115d
M145M00D4Ea7G4LAAea7G15LAea7G15L4Cl24@0>?Q4A4ChAM15d4G@AM144M0034GAd00DA47@0021d
00<AM7@067@00a5dM009M0@A1W@01A5LG5`A00EL0Q43G0064E`A?Q4n11400eLA4@02M08A0W@00a5d
M002M0<A00=d4G@00W@00a5dM00=M00087@00a5dM00HM0034GAd00Ud00@AM7@A1g@00a5LA`024@0>
G4MLAea74DML4Ea74Ch24@03?a4o00<A0g@01Q5dM7@AM0HA17@00a5dM00=M00087@00a5dM00IM003
4GAd00Ud00<AM1400Q46M0044EaL4@ML0a43G08A00=G4A401143M0044GAdM08A0g@00a5dM004M003
4GAd00ed000PM08A6W@00a5dM009M0064GAd4G@A1G@24@0@G15LAea7G4MLAe`AG4MLA`PA0W@00a5d
4@034@9d0a47M0034GAd00ad000PM0034GAd01Ud00<AM7@02G@0115dM142M08A0g@0115d4A49G0<A
0U`00a5G4@054@9d0a42M0<A0g@00a5dM004M0034GAd00ad000PM0034GAd01Ud00<AM7@02G@0115d
M144M0044GAd4@9d010AG4MLAea7G4ML4Ea74DML2Q42M0@A17@00a5dM004M0034GAd00ad000PM003
4GAd01Ud00<AM7@02W@54@=d0a43M0034EaL00=L00@AG5`A0e`00a5LG0084@=d00@AM7@A17@00a5d
M004M0034GAd00ad000PM0034GAd01Ud00<AM7@027@34@04M15dM0HA0g@24@0<G4MLAea7G4LAAea7
0Q400e`A4@044@9d0a42M0034GAd009d00<AM7@01G@00a5dM00;M0007g@00a5dM00KM0034GAd00Ad
0a42M0044GAd4@Id2A45G0034EaL00=L00<AG1400Q4017@A4A43M0034G@A00Ed00<AM7@017@00a5d
M00;M0007g@00a5dM00KM0034GAd009d0Q45M0044GAd4@Md00PAM14AM157G0PA00A7G4ML1A400g@A
M003M0044GAd4@Ad00<AM7@017@00a5dM00;M0007g@34A]d00<AM1400Q48M0034G@A00Md00<AM7@0
0Q400g@AG005G0034EaL00/A17@0115dM144M0034GAd00Ed00<AM7@02W@001md00<AM7@06g@74@Id
00@AM7@A1W@0115dM7@24@0?M157G4MLAe`AG4MLAea700LA17@00a5d4@04M0034GAd00Ed00<AM7@0
2W@000Yd0Q43M0034GAd008A0g@34@Ed00<AM7@06g@00a5dM004M0`A1G@01A5dM15d00<A1E`00a5L
G003G0HA00=d4A401a44M0034GAd00Ad00<AM7@02W@000Ud00@AM7@A17@0115dM143M0034GAd00Ad
00<AM7@077@00a5dM009M0044GAd4@9d214017@AM7@24@08Aea7G15LAcl24@03?SlA00DA17@00a5d
M0094@Ad00<AM7@02G@000Ud00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@077@00a5dM009M005
4GAdM1401W@00a5dM0084@9L00MG4A4AEciG00<A00=L4A400Q43M0044GAd4@Ad00@AM7Ad1A4;M000
2G@0115dM144M0044GAd4@=d00<AM7@017@00a5dM00LM0034GAd00Yd00@AM7@A1W@01A5dM7@A00=d
0a402Cho?Q4n?cho?P054@03Aa5d008A0W@00a5d4@04M0044GAdM0<A00=d4G@02W@000Ud00@AM7@A
17@0115dM143M0034GAd00Ad0Q4NM0034GAd00Ud00@AM7@A1W@01A5dM7@A00=d0a4025LA4A5G?ULn
0a401U`AG15L4@9d0a400g@AM004M0<A17@00a5dM009M0002G@0115dM144M0044GAd4@9d0Q46M003
4GAd01ed00<AM7@02G@01A5dM7@A00Id00@AM7Ad0a4037@A?a4o?SlA?chA?P8A00EL4E`AG0044@06
M15dM15d1147M0034GAd00Qd000:M08A1W@24@Ad00<AM7@017@00a5dM00MM0034GAd00Ud00DAM7Ad
4@06M0034GAd008A0W@34@07EciG?Q4nE`044@07G15LG15L4@02M0HA0g@00a5dM005M0034GAd00Qd
000OM0034GAd01id00<AM7@02G@0115dM146M0<A00Ad4GAd0Q402Cln?cho4ClA?`034@08G15LAa57
G142M0044G@A4@Ad00<AM7@01G@00a5dM008M0007W@00a5dM00OM0034GAd00Ud00DAM7Ad4@05M003
4GAd009d0a401eLnEciG?UL0114015`AG143G0064EaL4G@A0g@01A5dM7@A00Md00<AM7@027@001id
00<AM7@07g@00a5dM009M0054GAdM1400g@24@03M15d009d00`AM14n?cho?Sln4Ch24@0>G15L4Ea7
G15LAe`AM142M08A0W@00a5dM005M0034GAd00Qd000NM0034GAd021d00<AM7@027@01Q5dM7@AM08A
0g@00a5d4@034@0:?ULnEciG?ULAE`8A00AL4E`A15`0115LG5`24@9d00HAM14AM146M0034GAd00Qd
000NM08A8G@00a5dM009M0034GAd008A1W@0315d4G@A?cho?Sln?`@A00m7G15LAa57G4LAAea7G140
0W@0115dM7@24@Md00<AM7@01g@001id00<AM7@08G@00a5dM008M0<A00=d4G@00g@34@0;M14A4CiG
?ULnEch011400e`AG002G0034EaL009L00@AG5aL0Q42M0054GAdM1401g@00a5dM007M0007W@00a5d
M00QM0034GAd00Qd00DAM7Ad4@03M00@4GAdM15d4ChA?Sln?chA?PDA0157G4LAAea7G15LAa57G15d
4@03M0<A1G@00a5dM007M0007W@00a5dM00QM0034GAd00Id0a44M0<A17@34@09Ea5G?ULnEa5G00<A
00=d4E`00U`00a5LG003G0034E`A00=L0Q43M0044GAd4@Ad00<AM7@01g@001id00<AM7@08W@00a5d
M004M0054GAdM1400W@24@Ed0a4023ln4Cho?Sln1142M08A00QLAa57G4MLA`8A00ILAea7G144M003
4GAd008A0W@00a5dM007M0007W@00a5dM00RM0034GAd009d0Q43M0@A00=d4G@017@34@09?ULn4CiG
?Q4n00<A0W@01A5d4E`A00IL00<AG5`015`01A5dM7@A00Ad00@AM7@A27@001id00<AM7@08W@01A5d
M7@A009d0a42M0054GAdM1400g@34@0:?Sln?a4o?SlA?`<A0W@00a5dM0024@0>Aea7G4LAAa57G4ML
Aa43M0034GAd00=d0a48M0007W@00a5dM00SM0HA1G@01A5dM7@A00=d0a402ELnEciG4ELAE`044@03
M14A00=d0Q42G0<A00=L4E`01E`0115dM146M08A27@001ed00<AM7@097@24@Yd01<AM7Ad4G@AM14o
?Sln?chA?Q4n00<A00Ad4A4A17@04Q5L4Ea7G4ML4Ea7G4MLAa5d4@9d11400g@AM007M0007G@00a5d
M00TM0034GAd00Ud018AM7Ad4G@AM14nEciG?ULn4Ch44@03M14A00Ed0Q47G0034EaL00AL1145M003
4GAd00Id000MM0034GAd02Ed00<AM7@02G@01A5dM7@A009d00XA?cho?Sln?a4o1A400g@AM003M0<A
00m7G4MLAea7G15LAea7G4L00Q46M0034GAd00Id000MM0034GAd02Ed00<AM7@02G@01Q5dM7@AM08A
00TnEciG?ULn4Ch01142M08A00=d4A400W@24@ML00<AG5`01E`00a5dM005M0034GAd00Ed000MM003
4GAd02Id00<AM7@02G@01A5d4A5d008A00Po?Sln?chA?PDA0W@34@Ad014AM157G4MLAea74DMLAea7
G0024@Id00<AM7@01G@001ed00<AM7@09W@00a5dM009M00?4G@AM14n4CiG?ULnEa5G008A00Ad4A5d
0Q400g@AM004M0034G@A00ML00<AG5`00e`00a5L4@05M0034GAd00Ed000MM08A:7@00a5dM009M00?
4GAd4ClA?cho?SlA?cho008A00Ed4A5d4@02M0034GAd009d01<AM7@AAea7G4MLAa57G4ML4E`A00Ed
00<AM7@01G@001ed00<AM7@09g@00a5dM008M08A0W@34@09?ULnEchA?ULn00@A0W@01A5dM7@A00Ad
00@AM7@A1U`00a5LG002G0044EaL4@Ad00<AM7@01G@001ed00<AM7@09g@00a5dM008M0034G@A00@A
00To?Sln4Cho?Sl01143M0054GAdM1400g@00a5dM0024@0?Aea7G4ML4Ea74DMLAe`A00=d00<AM7@0
1G@001ed00<AM7@0:7@00a5dM006M0034GAd00DA00TnEciG4ELnEch01143M0054GAdM14017@01A5d
4G@A00IL00<AG1401E`0115dM147M0007G@00a5dM00XM0034GAd00Id00@AM7Ad0Q402clA?cho4Cln
?cho00@A0g@00a5dM002M0034GAd009d0Q42M0074DMLAe`AG0024@09Aea7G4ML4G@A00Md000MM003
4GAd02Ud00<AM7@017@00a5dM002M08A00/n4CiG?Q4nEciG?P044@=d00<AM7@00g@0115dM7@24@=d
00<AG5`00e`24@ML00<AM1401W@001ad00<AM7@0:W@00a5dM004M0034GAd009d0Q402clA4ChA?Sln
?cho008A00=d4A400g@00a5dM003M0034GAd008A0g@04Q5LAea7G4LAAea7G4MLAa5d4@Id000LM0<A
:W@00a5dM003M0034GAd00=d0Q404ChA4ELAEciG?ULnEa5d4G@A009d00<AM7@017@0115d4A44M003
4EaL009L00<AG1401e`24@Id000LM0034GAd02]d00<AM7@00W@00a5dM003M0@A00lo4Cln?cho?Sln
4G@AM1400W@00a5dM004M0054G@AM14017@03A5LAe`AG15LAea7G4L00a46M00077@00a5dM00[M005
4GAdM1401W@64@0;?ULnEciG?ULAM1400W@00a5d4@07M08A0W@00a5dM002M0034E`A00=L00<AG140
0a42M0034GAd00Ad0007M08A0g@00a5dM0024@9d1145M0034GAd02ad00@AM7@A1G@54@0:?chA?Sln
?cho?P<A0W@00a5d4@08M0044GAd4@Ed00<AG4L01146M0034GAd00Ad0006M0044GAd4@Ad00@AM7@A
0W@00a5dM005M0034GAd02ad00<AM14017@34@0>M14n4CiG4ELnEciG?UL34@=d00<AM1401W@00a5d
4@02M0034GAd009d0a43M0034GAd00Ad00<AM7@017@000Id00@AM7@A17@0115dM143M0034GAd00Ed
00<AM7@0;7@64@9d00lAM14o4Cln?a4o?Sln?ch00Q45M08A1W@00a5d4@02M0074GAdM15d4@05M003
4GAd00=d00<AM7@017@000Id00@AM7@A17@0115dM143M0034GAd00Id0a4[M08A1W@03a5d4ChA?ULn
4CiG?ULnE`024@Ed0Q45M0054GAdM1400W@00a5d4@02M0034GAd00Ad00<AM7@00W@00a5dM004M000
1W@0115dM144M0044GAd4@Ad00<AM7@01W@24Bad00<AM7@017@00a5d4@024@0:?cho?Q4n?cho?P8A
1W@00a5dM002M0034GAd00=d00DAM15d4@02M0034GAd00Ad00<AM7@00W@00a5dM004M0001W@00a5d
M0024@=d00<AM7@00a400g@A4@024@Qd00<AM7@0:G@00a5dM004M00?4G@A4ELnEciG4ELnEciG008A
1W@01A5dM7@A00Id00@AM7@A0g@00a5dM005M0054GAdM1401W@000Md0Q42M0044GAdM08A0W@44@]d
00<AM7@0:G@00a5dM003M00?4G@A4Cho?Sln?a4o?Sln008A1g@0115dM147M08A00Ed4GAd4@08M004
4GAd4@Id0003M0@A00Ed4GAd4@04M0044GAd4@=d00<AM7@02G@24BUd00<AM7@00g@03a5d4A5G?ULn
EchA?ULnE`024@Md00<AM1401W@24@07M15dM15d4@08M0044GAd4@Id0008M0044GAd4@Ad00@AM7@A
0g@00a5dM00:M0034GAd02Qd00<AM7@00W@03a5d4A4n?cho?Sln4Cho?P024@Md0Q45M08A0g@01Q5d
M15d4@Ud00<AM1401W@000Qd00@AM7@A17@0115dM144M0034GAd00Yd0Q4XM0034GAd009d014AM14A
EciG?ULnEchA?ULn4@06M08A00=d4G@00W@00a5dM004M0034GAd008A2W@24@Id0008M0044GAd4@Ad
00HAM7@AM142M0034GAd00ad00<AM7@09W@01Q5dM7@AM08A00dn?cho?Sln?a4o?SlA00Ed00DAM7@A
M0034@Qd00@AM7@A2W@24@Id0009M08A1W@24@=d0Q4@M08A9W@05Q5dM7@AM14nEciG?ULnEciG4ELA
Ea42M08A0g@34@Yd00<AM7@00Q49M08A1W@002Ud00<AM7@09G@00a5d4@02M00B4Cln?cho?Sln?chA
?Q4n4G@A17@24@9d00<AM7@027@0115d4A46M0<A00=d4G@01G@002Yd00<AM7@09G@24@0>M14A4ELn
EciG?ULnEch24@03EchA00=d0Q42M0044GAd4@Yd0Q4017@AM7@34@Ad00<AM7@017@002]d0Q4UM08A
00id4A4A?Sln?cho?Sln?`8A00<n?a400a45M08A00=d4G@027@24@04M14A4@Md00<AM7@017@002ad
0Q4UM08A00ed4A4A?ULnEciG?ULn008A00AG?ULA2G@24@Yd0Q42M0034GAd00Ad00<AM7@01G@002id
00<AM7@08W@24@09M14A4Cln?cho00@A00Hn?a4o?Q4:M08A2G@00a5dM002M0034GAd00=d00<AM7@0
1G@002md00<AM7@08G@34@05M15d4EL00a402eLnEciG?ULAEchA00Yd0Q48M0034GAd009d00<AM7@0
0g@00a5dM005M000<7@00a5d4@0QM08A00=d4A400Q403Sln?cho?Sln?chA?SlA2g@24@Id00<AM7@0
17@00a5dM002M0034GAd00Ed000aM0034GAd025d11404G@A?ULnEciG?ULnEchA?ULA00]d0Q45M003
4GAd00Ed00DAM7Ad4@07M000<W@24B9d01@AM15d4Cln?cho?Sln?cho?Q4n4@ad0Q44M0034GAd00Id
00@AM7@A1g@003Ad00<AM7@087@00a5d4@024@0?EciG?ULnEciG?ULn4ChA00ad0Q43M0034GAd00Id
00<AM14027@003Ed0a4PM00A4GAd4Cho?Sln?cho?Sln?ch0114;M08A0W@00a5dM007M08A27@003Id
00<AM7@087@04A5dM14nEciG?ULnEciG?ULn008A00=d4G@02W@44@Qd0a48M00087@24@=d00<AM7@0
0Q43M0<A1g@00a5dM00PM00@4G@A?cho?Sln?cho?Sln?`8A0W@00a5dM008M0044G@A4@Ad11400g@A
M008M0007g@0115dM144M0044GAd4@=d00<AM7@01g@24B1d0Q403g@AEciG?ULnEciG?ULnE`024@9d
0Q49M08A00=d4A400Q45M0034GAd00Md000IM0@A0W@0115dM144M0044GAd4@=d00<AM7@02G@00a5d
M00NM0<A00hn?cho?Sln?cho?Sln?`8A0g@00a5dM007M08A00=d4G@01G@00a5dM008M0007g@0115d
M144M0044GAd4@=d00<AM7@02W@00a5dM00NM0<A00`nEciG?ULnEciG?UL44@=d00<AM7@01G@00a5d
M002M0034GAd00=d00<AM7@027@001md00@AM7@A17@0115dM143M0034GAd00]d00<AM7@07W@24@07
?cho?Sln?`054@=d0Q43M08A1G@00a5dM003M08A0W@00a5dM009M0007g@0115dM144M0044GAd4@9d
0Q4>M08A7g@24@03EchA00<A2G@34@=d00DAM7Ad4@08M0034G@A00]d000PM08A1W@24@Ad00<AM7@0
3G@24Amd0a43M0034GAd00Ud0Q43M08A00=d4G@01g@24@ad0010M0034GAd01ed0a43M0034GAd00Ud
0Q44M0034GAd00Ad114=M000@G@00a5d4@0NM08A0g@24@Yd0Q42M0044G@AM0HA3g@0049d00<AM7@0
7W@34@=d00<AM7@01g@94@03M14A015d0013M0034GAd01md0Q43M0034GAd009d1143M08A00=d4A40
0Q4CM000A7@00a5dM00OM08A0g@44@Ed0Q42M0<A5G@004Ed0Q4QM0<A00=d4A4017@64AQd0017M003
4GAd021d1A400g@A4@024Aad0018M0034GAd02=d0a4OM000BG@34DAd001:M0034GAd04=d0011M08A
27@24D=d0010M0044GAd4@Ud0Q51M000@7@0115dM14:M0034GAd03md0010M0044GAd4@]d00<AM7@0
?W@0041d00@AM7@A37@00a5d4@0mM000@7@0115dM14=M08A?G@0045d0Q4@M0034GAd03Yd001DM003
4G@A03Ud001EM0034GAd03Qd001FM0034GAd03Md001GM0<A=W@005Qd0Q4fM000FW@00a5dM00cM000
Fg@00a5d4@0bM000G7@00a5dM00aM000Ag@24@=d00<AM7@00Q43M0<A1W@00a5dM00`M000AW@0115d
M144M0044GAd4@=d00<AM7@01W@34Bmd0016M0044GAd4@Ad00@AM7@A0g@00a5dM008M0034GAd02ed
0016M0044GAd4@Ad00@AM7@A0g@00a5dM009M0034GAd02ad0016M0044GAd4@Ad00@AM7@A0g@00a5d
M00:M08A;7@004Id00@AM7@A17@0115dM142M08A3G@00a5dM00ZM000Ag@24@Id0Q44M0034GAd00ad
0Q4ZM000IW@24BQd001WM0034GAd02Id001XM0034G@A02Ed001YM0034GAd02Ad001ZM08A97@006ad
0a4QM000KG@00a5dM00PM000Eg@24@=d00<AM7@00Q42M0@A1g@00a5dM00OM000EW@0115dM144M004
4GAd4@9d00<AM7@0:G@005Id00@AM7@A17@0115dM143M0034GAd02Qd001FM0044GAd4@Ad00@AM7@A
0g@00a5dM00XM000EW@0115dM144M0044GAd4@Ad00<AM7@09g@005Id00@AM7@A17@01Q5dM15d4@9d
00<AM7@09g@005Md0Q46M08A0g@24BYd002@M000T7@0091d002@M000T7@0091d002@M000T7@0091d
002@M000T7@0091d002@M000T7@0091d002@M000T7@00001\
\>"],
  ImageRangeCache->{{{0, 143.562}, {261.375, 0}} -> {0.073699, -0.133928, \
0.0046448, 0.0046448}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Curvature of the flexible lens", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
ComparasionLens=PlanoConvexLens[
\t5*R0,2*R0,Abs[S2[Deltax,Deltay,Force,Deltax,Deltay][[1]]],
\tComponentMedium->BK7,GraphicDesign->Wire,CrossRendering->Mesh];
ShowSystem[{
\tFluid,
\tMove3D[ComparasionLens,
\t\t{t0-Abs[S2[Deltax,Deltay,Force,Deltax,Deltay][[1]]],0,-Deltay},
\t\t{1,0,0},0]
}, 
Frame->True, PlotType->SideView, AspectRatio -> 1/2,
ShowLabels -> False, PlotRange -> {{-0.01, 0.01}, {-0.02, 0.02}}];\
\>", \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.5 50 0.25 12.5 [
[.125 -0.0125 -19.2188 -11 ]
[.125 -0.0125 19.2188 0 ]
[.25 -0.0125 -16.7188 -11 ]
[.25 -0.0125 16.7188 0 ]
[.375 -0.0125 -19.2188 -11 ]
[.375 -0.0125 19.2188 0 ]
[.5 -0.0125 -4.5 -10.9375 ]
[.5 -0.0125 4.5 0 ]
[.625 -0.0125 -15.75 -11 ]
[.625 -0.0125 15.75 0 ]
[.75 -0.0125 -13.25 -11 ]
[.75 -0.0125 13.25 0 ]
[.875 -0.0125 -15.75 -11 ]
[.875 -0.0125 15.75 0 ]
[1 -0.0125 -10.75 -10.9375 ]
[1 -0.0125 10.75 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0625 -33.4375 -5.5 ]
[-0.0125 .0625 0 5.5 ]
[-0.0125 .125 -28.4375 -5.46875 ]
[-0.0125 .125 0 5.46875 ]
[-0.0125 .1875 -33.4375 -5.5 ]
[-0.0125 .1875 0 5.5 ]
[-0.0125 .25 -9 -5.46875 ]
[-0.0125 .25 0 5.46875 ]
[-0.0125 .3125 -26.5 -5.5 ]
[-0.0125 .3125 0 5.5 ]
[-0.0125 .375 -21.5 -5.46875 ]
[-0.0125 .375 0 5.46875 ]
[-0.0125 .4375 -26.5 -5.5 ]
[-0.0125 .4375 0 5.5 ]
[-0.0125 .5 -21.5 -5.46875 ]
[-0.0125 .5 0 5.46875 ]
[ 0 0 -0.125 0 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -80.2188 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0075) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -77.7188 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -80.2188 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0025) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.5 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -76.75 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0025) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -74.25 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -76.75 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0075) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -71.75 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0625 m
.00625 .0625 L
s
gsave
-0.0125 .0625 -94.4375 -9.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .125 m
.00625 .125 L
s
gsave
-0.0125 .125 -89.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .1875 m
.00625 .1875 L
s
gsave
-0.0125 .1875 -94.4375 -9.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25 m
.00625 .25 L
s
gsave
-0.0125 .25 -70 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .3125 m
.00625 .3125 L
s
gsave
-0.0125 .3125 -87.5 -9.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .375 m
.00625 .375 L
s
gsave
-0.0125 .375 -82.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .4375 m
.00625 .4375 L
s
gsave
-0.0125 .4375 -87.5 -9.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -82.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .0125 m
.00375 .0125 L
s
0 .025 m
.00375 .025 L
s
0 .0375 m
.00375 .0375 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .0875 m
.00375 .0875 L
s
0 .1 m
.00375 .1 L
s
0 .1125 m
.00375 .1125 L
s
0 .1375 m
.00375 .1375 L
s
0 .15 m
.00375 .15 L
s
0 .1625 m
.00375 .1625 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .2125 m
.00375 .2125 L
s
0 .225 m
.00375 .225 L
s
0 .2375 m
.00375 .2375 L
s
0 .2625 m
.00375 .2625 L
s
0 .275 m
.00375 .275 L
s
0 .2875 m
.00375 .2875 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .3375 m
.00375 .3375 L
s
0 .35 m
.00375 .35 L
s
0 .3625 m
.00375 .3625 L
s
0 .3875 m
.00375 .3875 L
s
0 .4 m
.00375 .4 L
s
0 .4125 m
.00375 .4125 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .4625 m
.00375 .4625 L
s
0 .475 m
.00375 .475 L
s
0 .4875 m
.00375 .4875 L
s
.25 Mabswid
0 0 m
0 .5 L
s
0 .49375 m
0 .5 L
s
.125 .49375 m
.125 .5 L
s
.25 .49375 m
.25 .5 L
s
.375 .49375 m
.375 .5 L
s
.5 .49375 m
.5 .5 L
s
.625 .49375 m
.625 .5 L
s
.75 .49375 m
.75 .5 L
s
.875 .49375 m
.875 .5 L
s
.125 Mabswid
.025 .49625 m
.025 .5 L
s
.05 .49625 m
.05 .5 L
s
.075 .49625 m
.075 .5 L
s
.1 .49625 m
.1 .5 L
s
.15 .49625 m
.15 .5 L
s
.175 .49625 m
.175 .5 L
s
.2 .49625 m
.2 .5 L
s
.225 .49625 m
.225 .5 L
s
.275 .49625 m
.275 .5 L
s
.3 .49625 m
.3 .5 L
s
.325 .49625 m
.325 .5 L
s
.35 .49625 m
.35 .5 L
s
.4 .49625 m
.4 .5 L
s
.425 .49625 m
.425 .5 L
s
.45 .49625 m
.45 .5 L
s
.475 .49625 m
.475 .5 L
s
.525 .49625 m
.525 .5 L
s
.55 .49625 m
.55 .5 L
s
.575 .49625 m
.575 .5 L
s
.6 .49625 m
.6 .5 L
s
.65 .49625 m
.65 .5 L
s
.675 .49625 m
.675 .5 L
s
.7 .49625 m
.7 .5 L
s
.725 .49625 m
.725 .5 L
s
.775 .49625 m
.775 .5 L
s
.8 .49625 m
.8 .5 L
s
.825 .49625 m
.825 .5 L
s
.85 .49625 m
.85 .5 L
s
.9 .49625 m
.9 .5 L
s
.925 .49625 m
.925 .5 L
s
.95 .49625 m
.95 .5 L
s
.975 .49625 m
.975 .5 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.99375 0 m
1 0 L
s
.99375 .0625 m
1 .0625 L
s
.99375 .125 m
1 .125 L
s
.99375 .1875 m
1 .1875 L
s
.99375 .25 m
1 .25 L
s
.99375 .3125 m
1 .3125 L
s
.99375 .375 m
1 .375 L
s
.99375 .4375 m
1 .4375 L
s
.125 Mabswid
.99625 .0125 m
1 .0125 L
s
.99625 .025 m
1 .025 L
s
.99625 .0375 m
1 .0375 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .0875 m
1 .0875 L
s
.99625 .1 m
1 .1 L
s
.99625 .1125 m
1 .1125 L
s
.99625 .1375 m
1 .1375 L
s
.99625 .15 m
1 .15 L
s
.99625 .1625 m
1 .1625 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .2125 m
1 .2125 L
s
.99625 .225 m
1 .225 L
s
.99625 .2375 m
1 .2375 L
s
.99625 .2625 m
1 .2625 L
s
.99625 .275 m
1 .275 L
s
.99625 .2875 m
1 .2875 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35 m
1 .35 L
s
.99625 .3625 m
1 .3625 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .4 m
1 .4 L
s
.99625 .4125 m
1 .4125 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .4625 m
1 .4625 L
s
.99625 .475 m
1 .475 L
s
.99625 .4875 m
1 .4875 L
s
.25 Mabswid
1 0 m
1 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.9 .25 L
.9 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 0 m
.9 0 L
.9 .08333 L
.5375 .08333 L
.5375 0 L
s
.5375 .08333 m
.9 .08333 L
.9 .16667 L
.5375 .16667 L
.5375 .08333 L
s
.5375 .16667 m
.9 .16667 L
.9 .25 L
.5375 .25 L
.5375 .16667 L
s
.5375 .25 m
.9 .25 L
.9 .33333 L
.48451 .33333 L
.5375 .25 L
s
.48451 .33333 m
.9 .33333 L
.9 .41667 L
.48451 .41667 L
.48451 .33333 L
s
.48451 .41667 m
.9 .41667 L
.9 .5 L
.5375 .5 L
.48451 .41667 L
s
.5375 .25 m
.5375 .25 L
.52599 .27157 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.52599 .27157 L
.49821 .29167 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.49821 .29167 L
.47032 .30893 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.47032 .30893 L
.4559 .32217 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.4559 .32217 L
.46146 .33049 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.46146 .33049 L
.48451 .33333 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.48451 .33333 L
.51433 .33049 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.51433 .33049 L
.5351 .32217 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5351 .32217 L
.5375 .30893 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .30893 L
.5375 .29167 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .29167 L
.5375 .27157 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .27157 L
.5375 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .25 L
.5375 .22843 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .22843 L
.5375 .20833 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .20833 L
.5375 .19107 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .19107 L
.5375 .17783 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .17783 L
.5375 .16951 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .16951 L
.5375 .16667 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .16667 L
.5375 .16951 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .16951 L
.5375 .17783 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .17783 L
.5375 .19107 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .19107 L
.5375 .20833 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .20833 L
.5375 .22843 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .22843 L
.5375 .25 L
.5375 .25 L
.5375 .25 L
s
.5375 .25 m
.5375 .25 L
.5375 .29314 L
.52599 .27157 L
.5375 .25 L
s
.52599 .27157 m
.5375 .29314 L
.50986 .33333 L
.49821 .29167 L
.52599 .27157 L
s
.49821 .29167 m
.50986 .33333 L
.45445 .36785 L
.47032 .30893 L
.49821 .29167 L
s
.47032 .30893 m
.45445 .36785 L
.42113 .39434 L
.4559 .32217 L
.47032 .30893 L
s
.4559 .32217 m
.42113 .39434 L
.43424 .41099 L
.46146 .33049 L
.4559 .32217 L
s
.46146 .33049 m
.43424 .41099 L
.48451 .41667 L
.48451 .33333 L
.46146 .33049 L
s
.48451 .33333 m
.48451 .41667 L
.53187 .41099 L
.51433 .33049 L
.48451 .33333 L
s
.51433 .33049 m
.53187 .41099 L
.5375 .39434 L
.5351 .32217 L
.51433 .33049 L
s
.5351 .32217 m
.5375 .39434 L
.5375 .36785 L
.5375 .30893 L
.5351 .32217 L
s
.5375 .30893 m
.5375 .36785 L
.5375 .33333 L
.5375 .29167 L
.5375 .30893 L
s
.5375 .29167 m
.5375 .33333 L
.5375 .29314 L
.5375 .27157 L
.5375 .29167 L
s
.5375 .27157 m
.5375 .29314 L
.5375 .25 L
.5375 .25 L
.5375 .27157 L
s
.5375 .25 m
.5375 .25 L
.5375 .20686 L
.5375 .22843 L
.5375 .25 L
s
.5375 .22843 m
.5375 .20686 L
.5375 .16667 L
.5375 .20833 L
.5375 .22843 L
s
.5375 .20833 m
.5375 .16667 L
.5375 .13215 L
.5375 .19107 L
.5375 .20833 L
s
.5375 .19107 m
.5375 .13215 L
.5375 .10566 L
.5375 .17783 L
.5375 .19107 L
s
.5375 .17783 m
.5375 .10566 L
.5375 .08901 L
.5375 .16951 L
.5375 .17783 L
s
.5375 .16951 m
.5375 .08901 L
.5375 .08333 L
.5375 .16667 L
.5375 .16951 L
s
.5375 .16667 m
.5375 .08333 L
.5375 .08901 L
.5375 .16951 L
.5375 .16667 L
s
.5375 .16951 m
.5375 .08901 L
.5375 .10566 L
.5375 .17783 L
.5375 .16951 L
s
.5375 .17783 m
.5375 .10566 L
.5375 .13215 L
.5375 .19107 L
.5375 .17783 L
s
.5375 .19107 m
.5375 .13215 L
.5375 .16667 L
.5375 .20833 L
.5375 .19107 L
s
.5375 .20833 m
.5375 .16667 L
.5375 .20686 L
.5375 .22843 L
.5375 .20833 L
s
.5375 .22843 m
.5375 .20686 L
.5375 .25 L
.5375 .25 L
.5375 .22843 L
s
.5375 .25 m
.5375 .25 L
.5375 .3147 L
.5375 .29314 L
.5375 .25 L
s
.5375 .29314 m
.5375 .3147 L
.5375 .375 L
.50986 .33333 L
.5375 .29314 L
s
.50986 .33333 m
.5375 .375 L
.5375 .42678 L
.45445 .36785 L
.50986 .33333 L
s
.45445 .36785 m
.5375 .42678 L
.53127 .46651 L
.42113 .39434 L
.45445 .36785 L
s
.42113 .39434 m
.53127 .46651 L
.53496 .49148 L
.43424 .41099 L
.42113 .39434 L
s
.43424 .41099 m
.53496 .49148 L
.5375 .5 L
.48451 .41667 L
.43424 .41099 L
s
.48451 .41667 m
.5375 .5 L
.5375 .49148 L
.53187 .41099 L
.48451 .41667 L
s
.53187 .41099 m
.5375 .49148 L
.5375 .46651 L
.5375 .39434 L
.53187 .41099 L
s
.5375 .39434 m
.5375 .46651 L
.5375 .42678 L
.5375 .36785 L
.5375 .39434 L
s
.5375 .36785 m
.5375 .42678 L
.5375 .375 L
.5375 .33333 L
.5375 .36785 L
s
.5375 .33333 m
.5375 .375 L
.5375 .3147 L
.5375 .29314 L
.5375 .33333 L
s
.5375 .29314 m
.5375 .3147 L
.5375 .25 L
.5375 .25 L
.5375 .29314 L
s
.5375 .25 m
.5375 .25 L
.5375 .1853 L
.5375 .20686 L
.5375 .25 L
s
.5375 .20686 m
.5375 .1853 L
.5375 .125 L
.5375 .16667 L
.5375 .20686 L
s
.5375 .16667 m
.5375 .125 L
.5375 .07322 L
.5375 .13215 L
.5375 .16667 L
s
.5375 .13215 m
.5375 .07322 L
.5375 .03349 L
.5375 .10566 L
.5375 .13215 L
s
.5375 .10566 m
.5375 .03349 L
.5375 .00852 L
.5375 .08901 L
.5375 .10566 L
s
.5375 .08901 m
.5375 .00852 L
.5375 0 L
.5375 .08333 L
.5375 .08901 L
s
.5375 .08333 m
.5375 0 L
.5375 .00852 L
.5375 .08901 L
.5375 .08333 L
s
.5375 .08901 m
.5375 .00852 L
.5375 .03349 L
.5375 .10566 L
.5375 .08901 L
s
.5375 .10566 m
.5375 .03349 L
.5375 .07322 L
.5375 .13215 L
.5375 .10566 L
s
.5375 .13215 m
.5375 .07322 L
.5375 .125 L
.5375 .16667 L
.5375 .13215 L
s
.5375 .16667 m
.5375 .125 L
.5375 .1853 L
.5375 .20686 L
.5375 .16667 L
s
.5375 .20686 m
.5375 .1853 L
.5375 .25 L
.5375 .25 L
.5375 .20686 L
s
.9 .25 m
.9 .25 L
.9 .27157 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .27157 L
.9 .29167 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .29167 L
.9 .30893 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .30893 L
.9 .32217 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .32217 L
.9 .33049 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .33049 L
.9 .33333 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .33333 L
.9 .33049 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .33049 L
.9 .32217 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .32217 L
.9 .30893 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .30893 L
.9 .29167 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .29167 L
.9 .27157 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .27157 L
.9 .25 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .25 L
.9 .22843 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .22843 L
.9 .20833 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .20833 L
.9 .19107 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .19107 L
.9 .17783 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .17783 L
.9 .16951 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .16951 L
.9 .16667 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .16667 L
.9 .16951 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .16951 L
.9 .17783 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .17783 L
.9 .19107 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .19107 L
.9 .20833 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .20833 L
.9 .22843 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .22843 L
.9 .25 L
.9 .25 L
.9 .25 L
s
.9 .25 m
.9 .25 L
.9 .29314 L
.9 .27157 L
.9 .25 L
s
.9 .27157 m
.9 .29314 L
.9 .33333 L
.9 .29167 L
.9 .27157 L
s
.9 .29167 m
.9 .33333 L
.9 .36785 L
.9 .30893 L
.9 .29167 L
s
.9 .30893 m
.9 .36785 L
.9 .39434 L
.9 .32217 L
.9 .30893 L
s
.9 .32217 m
.9 .39434 L
.9 .41099 L
.9 .33049 L
.9 .32217 L
s
.9 .33049 m
.9 .41099 L
.9 .41667 L
.9 .33333 L
.9 .33049 L
s
.9 .33333 m
.9 .41667 L
.9 .41099 L
.9 .33049 L
.9 .33333 L
s
.9 .33049 m
.9 .41099 L
.9 .39434 L
.9 .32217 L
.9 .33049 L
s
.9 .32217 m
.9 .39434 L
.9 .36785 L
.9 .30893 L
.9 .32217 L
s
.9 .30893 m
.9 .36785 L
.9 .33333 L
.9 .29167 L
.9 .30893 L
s
.9 .29167 m
.9 .33333 L
.9 .29314 L
.9 .27157 L
.9 .29167 L
s
.9 .27157 m
.9 .29314 L
.9 .25 L
.9 .25 L
.9 .27157 L
s
.9 .25 m
.9 .25 L
.9 .20686 L
.9 .22843 L
.9 .25 L
s
.9 .22843 m
.9 .20686 L
.9 .16667 L
.9 .20833 L
.9 .22843 L
s
.9 .20833 m
.9 .16667 L
.9 .13215 L
.9 .19107 L
.9 .20833 L
s
.9 .19107 m
.9 .13215 L
.9 .10566 L
.9 .17783 L
.9 .19107 L
s
.9 .17783 m
.9 .10566 L
.9 .08901 L
.9 .16951 L
.9 .17783 L
s
.9 .16951 m
.9 .08901 L
.9 .08333 L
.9 .16667 L
.9 .16951 L
s
.9 .16667 m
.9 .08333 L
.9 .08901 L
.9 .16951 L
.9 .16667 L
s
.9 .16951 m
.9 .08901 L
.9 .10566 L
.9 .17783 L
.9 .16951 L
s
.9 .17783 m
.9 .10566 L
.9 .13215 L
.9 .19107 L
.9 .17783 L
s
.9 .19107 m
.9 .13215 L
.9 .16667 L
.9 .20833 L
.9 .19107 L
s
.9 .20833 m
.9 .16667 L
.9 .20686 L
.9 .22843 L
.9 .20833 L
s
.9 .22843 m
.9 .20686 L
.9 .25 L
.9 .25 L
.9 .22843 L
s
.9 .25 m
.9 .25 L
.9 .3147 L
.9 .29314 L
.9 .25 L
s
.9 .29314 m
.9 .3147 L
.9 .375 L
.9 .33333 L
.9 .29314 L
s
.9 .33333 m
.9 .375 L
.9 .42678 L
.9 .36785 L
.9 .33333 L
s
.9 .36785 m
.9 .42678 L
.9 .46651 L
.9 .39434 L
.9 .36785 L
s
.9 .39434 m
.9 .46651 L
.9 .49148 L
.9 .41099 L
.9 .39434 L
s
.9 .41099 m
.9 .49148 L
.9 .5 L
.9 .41667 L
.9 .41099 L
s
.9 .41667 m
.9 .5 L
.9 .49148 L
.9 .41099 L
.9 .41667 L
s
.9 .41099 m
.9 .49148 L
.9 .46651 L
.9 .39434 L
.9 .41099 L
s
.9 .39434 m
.9 .46651 L
.9 .42678 L
.9 .36785 L
.9 .39434 L
s
.9 .36785 m
.9 .42678 L
.9 .375 L
.9 .33333 L
.9 .36785 L
s
.9 .33333 m
.9 .375 L
.9 .3147 L
.9 .29314 L
.9 .33333 L
s
.9 .29314 m
.9 .3147 L
.9 .25 L
.9 .25 L
.9 .29314 L
s
.9 .25 m
.9 .25 L
.9 .1853 L
.9 .20686 L
.9 .25 L
s
.9 .20686 m
.9 .1853 L
.9 .125 L
.9 .16667 L
.9 .20686 L
s
.9 .16667 m
.9 .125 L
.9 .07322 L
.9 .13215 L
.9 .16667 L
s
.9 .13215 m
.9 .07322 L
.9 .03349 L
.9 .10566 L
.9 .13215 L
s
.9 .10566 m
.9 .03349 L
.9 .00852 L
.9 .08901 L
.9 .10566 L
s
.9 .08901 m
.9 .00852 L
.9 0 L
.9 .08333 L
.9 .08901 L
s
.9 .08333 m
.9 0 L
.9 .00852 L
.9 .08901 L
.9 .08333 L
s
.9 .08901 m
.9 .00852 L
.9 .03349 L
.9 .10566 L
.9 .08901 L
s
.9 .10566 m
.9 .03349 L
.9 .07322 L
.9 .13215 L
.9 .10566 L
s
.9 .13215 m
.9 .07322 L
.9 .125 L
.9 .16667 L
.9 .13215 L
s
.9 .16667 m
.9 .125 L
.9 .1853 L
.9 .20686 L
.9 .16667 L
s
.9 .20686 m
.9 .1853 L
.9 .25 L
.9 .25 L
.9 .20686 L
s
.5375 .25 m
.9 .25 L
.9 .3147 L
.5375 .3147 L
.5375 .25 L
s
.5375 .3147 m
.9 .3147 L
.9 .375 L
.5375 .375 L
.5375 .3147 L
s
.5375 .375 m
.9 .375 L
.9 .42678 L
.5375 .42678 L
.5375 .375 L
s
.5375 .42678 m
.9 .42678 L
.9 .46651 L
.53127 .46651 L
.5375 .42678 L
s
.53127 .46651 m
.9 .46651 L
.9 .49148 L
.53496 .49148 L
.53127 .46651 L
s
.53496 .49148 m
.9 .49148 L
.9 .5 L
.5375 .5 L
.53496 .49148 L
s
.5375 .5 m
.9 .5 L
.9 .49148 L
.5375 .49148 L
.5375 .5 L
s
.5375 .49148 m
.9 .49148 L
.9 .46651 L
.5375 .46651 L
.5375 .49148 L
s
.5375 .46651 m
.9 .46651 L
.9 .42678 L
.5375 .42678 L
.5375 .46651 L
s
.5375 .42678 m
.9 .42678 L
.9 .375 L
.5375 .375 L
.5375 .42678 L
s
.5375 .375 m
.9 .375 L
.9 .3147 L
.5375 .3147 L
.5375 .375 L
s
.5375 .3147 m
.9 .3147 L
.9 .25 L
.5375 .25 L
.5375 .3147 L
s
.5375 .25 m
.9 .25 L
.9 .1853 L
.5375 .1853 L
.5375 .25 L
s
.5375 .1853 m
.9 .1853 L
.9 .125 L
.5375 .125 L
.5375 .1853 L
s
.5375 .125 m
.9 .125 L
.9 .07322 L
.5375 .07322 L
.5375 .125 L
s
.5375 .07322 m
.9 .07322 L
.9 .03349 L
.5375 .03349 L
.5375 .07322 L
s
.5375 .03349 m
.9 .03349 L
.9 .00852 L
.5375 .00852 L
.5375 .03349 L
s
.5375 .00852 m
.9 .00852 L
.9 0 L
.5375 0 L
.5375 .00852 L
s
.5375 0 m
.9 0 L
.9 .00852 L
.5375 .00852 L
.5375 0 L
s
.5375 .00852 m
.9 .00852 L
.9 .03349 L
.5375 .03349 L
.5375 .00852 L
s
.5375 .03349 m
.9 .03349 L
.9 .07322 L
.5375 .07322 L
.5375 .03349 L
s
.5375 .07322 m
.9 .07322 L
.9 .125 L
.5375 .125 L
.5375 .07322 L
s
.5375 .125 m
.9 .125 L
.9 .1853 L
.5375 .1853 L
.5375 .125 L
s
.5375 .1853 m
.9 .1853 L
.9 .25 L
.5375 .25 L
.5375 .1853 L
s
.54595 .125 m
.5375 .125 L
.5375 .125 L
.48925 .125 L
.54595 .125 L
s
.48925 .125 m
.5375 .125 L
.5375 .125 L
.45643 .125 L
.48925 .125 L
s
.45643 .125 m
.5375 .125 L
.5375 .125 L
.44568 .125 L
.45643 .125 L
s
.44568 .125 m
.5375 .125 L
.5375 .125 L
.45643 .125 L
.44568 .125 L
s
.45643 .125 m
.5375 .125 L
.5375 .125 L
.48925 .125 L
.45643 .125 L
s
.48925 .125 m
.5375 .125 L
.5375 .125 L
.54595 .125 L
.48925 .125 L
s
.54595 0 m
.5375 0 L
.5375 .04167 L
.48925 .04167 L
.54595 0 L
s
.48925 .04167 m
.5375 .04167 L
.5375 .08333 L
.45643 .08333 L
.48925 .04167 L
s
.45643 .08333 m
.5375 .08333 L
.5375 .125 L
.44568 .125 L
.45643 .08333 L
s
.44568 .125 m
.5375 .125 L
.5375 .16667 L
.45643 .16667 L
.44568 .125 L
s
.45643 .16667 m
.5375 .16667 L
.5375 .20833 L
.48925 .20833 L
.45643 .16667 L
s
.48925 .20833 m
.5375 .20833 L
.5375 .25 L
.54595 .25 L
.48925 .20833 L
s
.44568 .125 m
.45643 .125 L
.45643 .13578 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .13578 L
.45643 .14583 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .14583 L
.45643 .15446 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .15446 L
.45643 .16108 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16108 L
.45643 .16525 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16525 L
.45643 .16667 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16667 L
.45643 .16525 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16525 L
.45643 .16108 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .16108 L
.45643 .15446 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .15446 L
.45643 .14583 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .14583 L
.45643 .13578 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .13578 L
.45643 .125 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .125 L
.45643 .11422 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .11422 L
.45643 .10417 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .10417 L
.45643 .09554 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .09554 L
.45643 .08892 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08892 L
.45643 .08475 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08475 L
.45643 .08333 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08333 L
.45643 .08475 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08475 L
.45643 .08892 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .08892 L
.45643 .09554 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .09554 L
.45643 .10417 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .10417 L
.45643 .11422 L
.44568 .125 L
.44568 .125 L
s
.44568 .125 m
.45643 .11422 L
.45643 .125 L
.44568 .125 L
.44568 .125 L
s
.45643 .125 m
.48925 .125 L
.48925 .14657 L
.45643 .13578 L
.45643 .125 L
s
.45643 .13578 m
.48925 .14657 L
.48925 .16667 L
.45643 .14583 L
.45643 .13578 L
s
.45643 .14583 m
.48925 .16667 L
.48925 .18393 L
.45643 .15446 L
.45643 .14583 L
s
.45643 .15446 m
.48925 .18393 L
.48925 .19717 L
.45643 .16108 L
.45643 .15446 L
s
.45643 .16108 m
.48925 .19717 L
.48925 .20549 L
.45643 .16525 L
.45643 .16108 L
s
.45643 .16525 m
.48925 .20549 L
.48925 .20833 L
.45643 .16667 L
.45643 .16525 L
s
.45643 .16667 m
.48925 .20833 L
.48925 .20549 L
.45643 .16525 L
.45643 .16667 L
s
.45643 .16525 m
.48925 .20549 L
.48925 .19717 L
.45643 .16108 L
.45643 .16525 L
s
.45643 .16108 m
.48925 .19717 L
.48925 .18393 L
.45643 .15446 L
.45643 .16108 L
s
.45643 .15446 m
.48925 .18393 L
.48925 .16667 L
.45643 .14583 L
.45643 .15446 L
s
.45643 .14583 m
.48925 .16667 L
.48925 .14657 L
.45643 .13578 L
.45643 .14583 L
s
.45643 .13578 m
.48925 .14657 L
.48925 .125 L
.45643 .125 L
.45643 .13578 L
s
.45643 .125 m
.48925 .125 L
.48925 .10343 L
.45643 .11422 L
.45643 .125 L
s
.45643 .11422 m
.48925 .10343 L
.48925 .08333 L
.45643 .10417 L
.45643 .11422 L
s
.45643 .10417 m
.48925 .08333 L
.48925 .06607 L
.45643 .09554 L
.45643 .10417 L
s
.45643 .09554 m
.48925 .06607 L
.48925 .05283 L
.45643 .08892 L
.45643 .09554 L
s
.45643 .08892 m
.48925 .05283 L
.48925 .04451 L
.45643 .08475 L
.45643 .08892 L
s
.45643 .08475 m
.48925 .04451 L
.48925 .04167 L
.45643 .08333 L
.45643 .08475 L
s
.45643 .08333 m
.48925 .04167 L
.48925 .04451 L
.45643 .08475 L
.45643 .08333 L
s
.45643 .08475 m
.48925 .04451 L
.48925 .05283 L
.45643 .08892 L
.45643 .08475 L
s
.45643 .08892 m
.48925 .05283 L
.48925 .06607 L
.45643 .09554 L
.45643 .08892 L
s
.45643 .09554 m
.48925 .06607 L
.48925 .08333 L
.45643 .10417 L
.45643 .09554 L
s
.45643 .10417 m
.48925 .08333 L
.48925 .10343 L
.45643 .11422 L
.45643 .10417 L
s
.45643 .11422 m
.48925 .10343 L
.48925 .125 L
.45643 .125 L
.45643 .11422 L
s
.48925 .125 m
.54595 .125 L
.54595 .15735 L
.48925 .14657 L
.48925 .125 L
s
.48925 .14657 m
.54595 .15735 L
.54595 .1875 L
.48925 .16667 L
.48925 .14657 L
s
.48925 .16667 m
.54595 .1875 L
.54595 .21339 L
.48925 .18393 L
.48925 .16667 L
s
.48925 .18393 m
.54595 .21339 L
.54595 .23325 L
.48925 .19717 L
.48925 .18393 L
s
.48925 .19717 m
.54595 .23325 L
.54595 .24574 L
.48925 .20549 L
.48925 .19717 L
s
.48925 .20549 m
.54595 .24574 L
.54595 .25 L
.48925 .20833 L
.48925 .20549 L
s
.48925 .20833 m
.54595 .25 L
.54595 .24574 L
.48925 .20549 L
.48925 .20833 L
s
.48925 .20549 m
.54595 .24574 L
.54595 .23325 L
.48925 .19717 L
.48925 .20549 L
s
.48925 .19717 m
.54595 .23325 L
.54595 .21339 L
.48925 .18393 L
.48925 .19717 L
s
.48925 .18393 m
.54595 .21339 L
.54595 .1875 L
.48925 .16667 L
.48925 .18393 L
s
.48925 .16667 m
.54595 .1875 L
.54595 .15735 L
.48925 .14657 L
.48925 .16667 L
s
.48925 .14657 m
.54595 .15735 L
.54595 .125 L
.48925 .125 L
.48925 .14657 L
s
.48925 .125 m
.54595 .125 L
.54595 .09265 L
.48925 .10343 L
.48925 .125 L
s
.48925 .10343 m
.54595 .09265 L
.54595 .0625 L
.48925 .08333 L
.48925 .10343 L
s
.48925 .08333 m
.54595 .0625 L
.54595 .03661 L
.48925 .06607 L
.48925 .08333 L
s
.48925 .06607 m
.54595 .03661 L
.54595 .01675 L
.48925 .05283 L
.48925 .06607 L
s
.48925 .05283 m
.54595 .01675 L
.54595 .00426 L
.48925 .04451 L
.48925 .05283 L
s
.48925 .04451 m
.54595 .00426 L
.54595 0 L
.48925 .04167 L
.48925 .04451 L
s
.48925 .04167 m
.54595 0 L
.54595 .00426 L
.48925 .04451 L
.48925 .04167 L
s
.48925 .04451 m
.54595 .00426 L
.54595 .01675 L
.48925 .05283 L
.48925 .04451 L
s
.48925 .05283 m
.54595 .01675 L
.54595 .03661 L
.48925 .06607 L
.48925 .05283 L
s
.48925 .06607 m
.54595 .03661 L
.54595 .0625 L
.48925 .08333 L
.48925 .06607 L
s
.48925 .08333 m
.54595 .0625 L
.54595 .09265 L
.48925 .10343 L
.48925 .08333 L
s
.48925 .10343 m
.54595 .09265 L
.54595 .125 L
.48925 .125 L
.48925 .10343 L
s
.5375 .125 m
.5375 .125 L
.5375 .13578 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .13578 L
.5375 .14583 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .14583 L
.5375 .15446 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .15446 L
.5375 .16108 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16108 L
.5375 .16525 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16525 L
.5375 .16667 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16667 L
.5375 .16525 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16525 L
.5375 .16108 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .16108 L
.5375 .15446 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .15446 L
.5375 .14583 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .14583 L
.5375 .13578 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .13578 L
.5375 .125 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .125 L
.5375 .11422 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .11422 L
.5375 .10417 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .10417 L
.5375 .09554 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .09554 L
.5375 .08892 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08892 L
.5375 .08475 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08475 L
.5375 .08333 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08333 L
.5375 .08475 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08475 L
.5375 .08892 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .08892 L
.5375 .09554 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .09554 L
.5375 .10417 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .10417 L
.5375 .11422 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .11422 L
.5375 .125 L
.5375 .125 L
.5375 .125 L
s
.5375 .125 m
.5375 .125 L
.5375 .14657 L
.5375 .13578 L
.5375 .125 L
s
.5375 .13578 m
.5375 .14657 L
.5375 .16667 L
.5375 .14583 L
.5375 .13578 L
s
.5375 .14583 m
.5375 .16667 L
.5375 .18393 L
.5375 .15446 L
.5375 .14583 L
s
.5375 .15446 m
.5375 .18393 L
.5375 .19717 L
.5375 .16108 L
.5375 .15446 L
s
.5375 .16108 m
.5375 .19717 L
.5375 .20549 L
.5375 .16525 L
.5375 .16108 L
s
.5375 .16525 m
.5375 .20549 L
.5375 .20833 L
.5375 .16667 L
.5375 .16525 L
s
.5375 .16667 m
.5375 .20833 L
.5375 .20549 L
.5375 .16525 L
.5375 .16667 L
s
.5375 .16525 m
.5375 .20549 L
.5375 .19717 L
.5375 .16108 L
.5375 .16525 L
s
.5375 .16108 m
.5375 .19717 L
.5375 .18393 L
.5375 .15446 L
.5375 .16108 L
s
.5375 .15446 m
.5375 .18393 L
.5375 .16667 L
.5375 .14583 L
.5375 .15446 L
s
.5375 .14583 m
.5375 .16667 L
.5375 .14657 L
.5375 .13578 L
.5375 .14583 L
s
.5375 .13578 m
.5375 .14657 L
.5375 .125 L
.5375 .125 L
.5375 .13578 L
s
.5375 .125 m
.5375 .125 L
.5375 .10343 L
.5375 .11422 L
.5375 .125 L
s
.5375 .11422 m
.5375 .10343 L
.5375 .08333 L
.5375 .10417 L
.5375 .11422 L
s
.5375 .10417 m
.5375 .08333 L
.5375 .06607 L
.5375 .09554 L
.5375 .10417 L
s
.5375 .09554 m
.5375 .06607 L
.5375 .05283 L
.5375 .08892 L
.5375 .09554 L
s
.5375 .08892 m
.5375 .05283 L
.5375 .04451 L
.5375 .08475 L
.5375 .08892 L
s
.5375 .08475 m
.5375 .04451 L
.5375 .04167 L
.5375 .08333 L
.5375 .08475 L
s
.5375 .08333 m
.5375 .04167 L
.5375 .04451 L
.5375 .08475 L
.5375 .08333 L
s
.5375 .08475 m
.5375 .04451 L
.5375 .05283 L
.5375 .08892 L
.5375 .08475 L
s
.5375 .08892 m
.5375 .05283 L
.5375 .06607 L
.5375 .09554 L
.5375 .08892 L
s
.5375 .09554 m
.5375 .06607 L
.5375 .08333 L
.5375 .10417 L
.5375 .09554 L
s
.5375 .10417 m
.5375 .08333 L
.5375 .10343 L
.5375 .11422 L
.5375 .10417 L
s
.5375 .11422 m
.5375 .10343 L
.5375 .125 L
.5375 .125 L
.5375 .11422 L
s
.5375 .125 m
.5375 .125 L
.5375 .15735 L
.5375 .14657 L
.5375 .125 L
s
.5375 .14657 m
.5375 .15735 L
.5375 .1875 L
.5375 .16667 L
.5375 .14657 L
s
.5375 .16667 m
.5375 .1875 L
.5375 .21339 L
.5375 .18393 L
.5375 .16667 L
s
.5375 .18393 m
.5375 .21339 L
.5375 .23325 L
.5375 .19717 L
.5375 .18393 L
s
.5375 .19717 m
.5375 .23325 L
.5375 .24574 L
.5375 .20549 L
.5375 .19717 L
s
.5375 .20549 m
.5375 .24574 L
.5375 .25 L
.5375 .20833 L
.5375 .20549 L
s
.5375 .20833 m
.5375 .25 L
.5375 .24574 L
.5375 .20549 L
.5375 .20833 L
s
.5375 .20549 m
.5375 .24574 L
.5375 .23325 L
.5375 .19717 L
.5375 .20549 L
s
.5375 .19717 m
.5375 .23325 L
.5375 .21339 L
.5375 .18393 L
.5375 .19717 L
s
.5375 .18393 m
.5375 .21339 L
.5375 .1875 L
.5375 .16667 L
.5375 .18393 L
s
.5375 .16667 m
.5375 .1875 L
.5375 .15735 L
.5375 .14657 L
.5375 .16667 L
s
.5375 .14657 m
.5375 .15735 L
.5375 .125 L
.5375 .125 L
.5375 .14657 L
s
.5375 .125 m
.5375 .125 L
.5375 .09265 L
.5375 .10343 L
.5375 .125 L
s
.5375 .10343 m
.5375 .09265 L
.5375 .0625 L
.5375 .08333 L
.5375 .10343 L
s
.5375 .08333 m
.5375 .0625 L
.5375 .03661 L
.5375 .06607 L
.5375 .08333 L
s
.5375 .06607 m
.5375 .03661 L
.5375 .01675 L
.5375 .05283 L
.5375 .06607 L
s
.5375 .05283 m
.5375 .01675 L
.5375 .00426 L
.5375 .04451 L
.5375 .05283 L
s
.5375 .04451 m
.5375 .00426 L
.5375 0 L
.5375 .04167 L
.5375 .04451 L
s
.5375 .04167 m
.5375 0 L
.5375 .00426 L
.5375 .04451 L
.5375 .04167 L
s
.5375 .04451 m
.5375 .00426 L
.5375 .01675 L
.5375 .05283 L
.5375 .04451 L
s
.5375 .05283 m
.5375 .01675 L
.5375 .03661 L
.5375 .06607 L
.5375 .05283 L
s
.5375 .06607 m
.5375 .03661 L
.5375 .0625 L
.5375 .08333 L
.5375 .06607 L
s
.5375 .08333 m
.5375 .0625 L
.5375 .09265 L
.5375 .10343 L
.5375 .08333 L
s
.5375 .10343 m
.5375 .09265 L
.5375 .125 L
.5375 .125 L
.5375 .10343 L
s
.54595 .125 m
.5375 .125 L
.5375 .15735 L
.54595 .15735 L
.54595 .125 L
s
.54595 .15735 m
.5375 .15735 L
.5375 .1875 L
.54595 .1875 L
.54595 .15735 L
s
.54595 .1875 m
.5375 .1875 L
.5375 .21339 L
.54595 .21339 L
.54595 .1875 L
s
.54595 .21339 m
.5375 .21339 L
.5375 .23325 L
.54595 .23325 L
.54595 .21339 L
s
.54595 .23325 m
.5375 .23325 L
.5375 .24574 L
.54595 .24574 L
.54595 .23325 L
s
.54595 .24574 m
.5375 .24574 L
.5375 .25 L
.54595 .25 L
.54595 .24574 L
s
.54595 .25 m
.5375 .25 L
.5375 .24574 L
.54595 .24574 L
.54595 .25 L
s
.54595 .24574 m
.5375 .24574 L
.5375 .23325 L
.54595 .23325 L
.54595 .24574 L
s
.54595 .23325 m
.5375 .23325 L
.5375 .21339 L
.54595 .21339 L
.54595 .23325 L
s
.54595 .21339 m
.5375 .21339 L
.5375 .1875 L
.54595 .1875 L
.54595 .21339 L
s
.54595 .1875 m
.5375 .1875 L
.5375 .15735 L
.54595 .15735 L
.54595 .1875 L
s
.54595 .15735 m
.5375 .15735 L
.5375 .125 L
.54595 .125 L
.54595 .15735 L
s
.54595 .125 m
.5375 .125 L
.5375 .09265 L
.54595 .09265 L
.54595 .125 L
s
.54595 .09265 m
.5375 .09265 L
.5375 .0625 L
.54595 .0625 L
.54595 .09265 L
s
.54595 .0625 m
.5375 .0625 L
.5375 .03661 L
.54595 .03661 L
.54595 .0625 L
s
.54595 .03661 m
.5375 .03661 L
.5375 .01675 L
.54595 .01675 L
.54595 .03661 L
s
.54595 .01675 m
.5375 .01675 L
.5375 .00426 L
.54595 .00426 L
.54595 .01675 L
s
.54595 .00426 m
.5375 .00426 L
.5375 0 L
.54595 0 L
.54595 .00426 L
s
.54595 0 m
.5375 0 L
.5375 .00426 L
.54595 .00426 L
.54595 0 L
s
.54595 .00426 m
.5375 .00426 L
.5375 .01675 L
.54595 .01675 L
.54595 .00426 L
s
.54595 .01675 m
.5375 .01675 L
.5375 .03661 L
.54595 .03661 L
.54595 .01675 L
s
.54595 .03661 m
.5375 .03661 L
.5375 .0625 L
.54595 .0625 L
.54595 .03661 L
s
.54595 .0625 m
.5375 .0625 L
.5375 .09265 L
.54595 .09265 L
.54595 .0625 L
s
.54595 .09265 m
.5375 .09265 L
.5375 .125 L
.54595 .125 L
.54595 .09265 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@003Ud0Q43M0034GAd008A0g@24@=d00@AM7Ad0a47M08A0g@00a5dM0024@=d
0Q42M0<A27@24@=d00<AM7@00Q43M08A0W@44@04M14A4Amd0Q43M0034GAd008A0g@24@9d114017@A
4A48M08A0g@00a5dM0024@=d0Q42M0<A1g@24@=d00<AM7@00Q43M08A0g@0115dM7@34Aid000hM004
4GAd4@Ad00HAM7@AM142M0044GAd4@=d00@AM7@A1G@0115dM144M0064GAd4G@A0W@00a5d4@02M003
4GAd00Ad00@AM7@A17@01Q5dM15d4@9d00@AM7@A0g@0115dM14;M08A47@0115dM144M0064GAd4G@A
0W@0115dM143M0044GAd4@Id00@AM7@A17@01Q5dM15d4@9d00<AM1400W@00a5dM003M0044GAd4@Ad
00HAM7@AM142M0044GAd4@=d00@AM7@A2G@24@=d00<AM7@00Q43M0<A17@0039d1142M0044GAd4@Ad
00HAM7@AM142M0044GAd4@Id1142M0044GAd4@Ad00HAM7@AM142M0034GAd009d1A42M0044GAd4@Ad
00HAM7@AM142M0054GAdM1401G@00a5dM008M0044GAd4@md00@AM7@A17@01Q5dM15d4@9d00DAM7Ad
4@05M0034GAd00Ad00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM003M0044GAd4@Ad00HAM7@A
M142M0044GAd4@Id00<AM7@01W@0115dM144M0044GAd4@=d00<AM7@00g@003Qd00@AM7@A17@01Q5d
M15d4@9d00DAM7Ad4@05M0034GAd00=d00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM004M004
4GAd4@Ad00HAM7@AM142M0054GAdM1401G@00a5dM008M0044GAd4@md00@AM7@A17@01Q5dM15d4@9d
00DAM7Ad4@05M0034GAd00Ad00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM003M0044GAd4@Ad
00HAM7@AM142M0054GAdM1401G@00a5dM006M0044GAd4@Ad00@AM7@A0g@00a5dM003M000>7@0115d
M144M0064GAd4G@A0W@01A5dM7@A009d0a46M0044GAd4@Ad00HAM7@AM142M0034G@A008A1g@0115d
M144M0064GAd4G@A0W@00a5dM002M0034G@A008A2g@0115dM14?M0044GAd4@Ad00HAM7@AM142M003
4GAd009d00<AM1400Q47M0044GAd4@Ad00HAM7@AM142M0034G@A008A1W@0115dM144M0064GAd4G@A
0W@01A5dM7@A009d0a49M0044GAd4@Ad00@AM7@A0g@00a5dM003M000>7@0115dM144M0064GAd4G@A
0W@00a5d4@02M0044GAd4@Md00@AM7@A17@01Q5dM15d4@9d00@AM7@A27@0115dM144M0064GAd4G@A
0W@00a5d4@02M0044GAd4@ad00@AM7@A3g@0115dM144M0064GAd4G@A0W@00a5d4@02M0044GAd4@Qd
00@AM7@A17@01Q5dM15d4@9d00@AM7@A1g@0115dM144M0064GAd4G@A0W@00a5d4@02M0044GAd4@Yd
00@AM7@A17@0115dM143M0034GAd00=d000iM08A1W@24@=d0Q42M0@A0W@34@Id0Q46M08A0g@24@=d
0a47M08A1W@24@=d0Q43M08A0g@34@Yd00@AM7@A47@24@Id0Q43M08A0g@24@=d0a47M08A1W@24@=d
0Q43M0<A1W@24@Id0Q43M08A0W@44@9d0a48M0044GAd4@Ad00@AM7@A0W@24@Ed002JM08AL7@24@Id
0Q44M0034GAd00=d003oM25d000TM?4A2g@002Ad00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0
0g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M003
4GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0
0g@00a5dM003M0034GAd00=d00<AM7@01145M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d
00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5d
M003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM009M00097@00a5d
M00KM0034GAd01]d00<AM7@06g@00a5dM00KM0034GAd00EdFA4GM0034GAd00Ud000TM08AOG@34@03
M15d05=d00<AM7@057@24@]d000TM0034GAd07Yd0a4017@A4A5DM0034GAd01Ed00<AM7@02G@002Ad
00<AM7@0NG@34@9d0a5DM0034GAd01Ed00<AM7@02G@002Ad0Q5hM0<A0g@24@03M15d05=d00<AM7@0
57@24@]d000TM0034GAd07Id0a42M08A00Ad4G@AE7@00a5dM00EM0034GAd00Ud000TM0034GAd07Ed
0Q42M08A0gAH4AMd00<AM7@02G@002Ad0Q5dM0<A0W@00a5dM003M0<AE7@00a5dM00DM08A2g@002Ad
00<AM7@0LW@=4@03M15d05=d00<AM7@05G@00a5dM009M00097@00a5dM01aM08A0W@00a5dM003M08A
00Ad4G@AE7@00a5dM00EM0034GAd00Ud000TM08ALG@54@Ad0Q43M0034G@A05Ad00<AM7@057@24@]d
000TM0034GAd071d00<AM14017@24@Ed00<AM140E7@00a5dM00EM0034GAd00Ud000TM0034GAd06md
1142M08A1g@00a5d4@1DM0034GAd01Ed00<AM7@02G@000Ud0Q43M0034GAd008A0g@34@04M14A4@Md
0Q5_M0<A00Ad4A4A2G@34EAd00<AM7@04g@34@]d0008M0044GAd4@Ad00@AM7@A0g@0115dM142M003
4GAd00Ad00<AM7@0KG@34@9d00<AM7@01g@34@03M15d05=d00<AM7@05G@00a5dM009M0000g@44@05
M15dM14017@0115dM143M0034GAd00=d00<AM7@017@00a5dM01/M0<A0W@24@Id0a42M0034G@A05Ad
00<AM7@05G@00a5dM009M00027@0115dM144M0044GAd4@=d00<AM7@00g@00a5dM004M08AKG@01a5d
4G@AM14017@24@EdF14FM08A2g@000Qd00@AM7@A17@0115dM143M0034GAd00<A1g@00a5dM01[M0DA
0W@00a5d4@024@Md00<AM140E7@00a5dM00EM0034GAd00Ud0008M0044GAd4@Ad00@AM7@A0W@24@=d
00<AM7@01W@00a5dM01ZM6`A5g@00a5dM009M0002G@24@Id0Q44M0044GAdM0<A1W@24F]d0a43M0<A
2g@00a5d4@1DM0034GAd01Ad0Q4;M00097@00a5dM01ZM08A0W@24@9d00<AM7@02G@00a5d4@1DM003
4GAd01Ed00<AM7@02G@002Ad00<AM7@0JG@24@9d00<AM7@00W@00a5dM008M0@AE7@00a5dM00EM003
4GAd00Ud000TM08AJW@44@Ed00@AM7Ad1a4017@AM15DM0034GAd01Ad0Q4;M00097@00a5dM01YM08A
1W@54@Qd00<AM140E7@00a5dM00EM0034GAd00Ud000TM0034GAd06Ud0Q43M0<A00=d4G@02W@00a5d
4@1DM0034GAd01Ed00<AM7@02G@002Ad0Q5ZM08A00=d4A4017@00a5dM009M0034G@A05Ad00<AM7@0
57@24@]d000TM0034GAd06Qd1146M0034GAd00Ud00<AM140E7@00a5dM00EM0034GAd00Ud000TM003
4GAd06Qd0a47M0034GAd00Ud00<AM140E7@00a5dM00EM0034GAd00Ud000>M08A0g@00a5dM0024@=d
0a46M08AJGA^4AEd0a4;M0003G@0115dM144M0044GAd4@=d00<AM7@01G@00a5dM01XM0<A1g@00a5d
M009M0034G@A05Ad00<AM7@05G@00a5dM009M00027@44@05M15dM14017@0115dM143M0034GAd00Ed
00<AM7@0J7@34@Md00<AM7@02G@00a5d4@1DM0034GAd01Ed00<AM7@02G@000ed00@AM7@A17@0115d
M143M0034GAd00Ed0Q5ZM0<A1W@00a5dM009M0034G@A05Ad00<AM7@057@24@]d000=M0044GAd4@Ad
00@AM7@A0g@00a5dM005M0034GAd06Ud0Q400g@A4@024@9d00<AM7@02G@00a5d4@1DM0034GAd01Ed
00<AM7@02G@000ed00@AM7@A17@0115dM142M08A1g@00a5dM01YM08A1G@54@Ud00<AM140E7@00a5d
M00EM0034GAd00Ud000>M08A1W@24@Ad00<AM7@01G@24FYd1145M0034GAd00@A1G@00a5d4@1DM003
4GAd01Ad0Q4;M00097@00a5dM01YM08A0W@00a5dM002M0034GAd00Ad1Q400g@AM01CM0034GAd01Ed
00<AM7@02G@002Ad00<AM7@0JW@24@9d0Q42M0034GAd00Ud0a5DM0034GAd01Ed00<AM7@02G@002Ad
0Q5[M0034G@A00=d0a4;M0034G@A05Ad00<AM7@057@24@]d000TM0034GAd06YdK14GM0034GAd00Ud
000TM0034GAd06]d0Q400g@A4@02M0034G@A008A1g@00a5d4@1DM0034GAd01Ed00<AM7@02G@002Ad
0Q5]M08A0W@00a5d4@04M08A1G@00a5d4@1DM0034GAd01Ad0Q4;M00097@00a5dM01/M0034G@A009d
0Q46M0<A0W@00a5d4@1DM0034GAd01Ed00<AM7@02G@002Ad00<AM7@0KG@24@=d00<AM7@01g@34@03
M15d05=d00<AM7@05G@00a5dM009M0002G@24@=d00<AM7@00Q43M08A0W@34@Md0Q5_M08A0W@34@Ud
F14EM0<A2g@000Qd00@AM7@A17@01Q5dM15d4@9d00<AM1400W@00a5dM004M0034GAd06md0Q4017@A
M7@24@Md00<AM140E7@00a5dM00EM0034GAd00Ud0003M0@A00Ed4GAd4@04M0064GAd4G@A0W@00a5d
M002M0034GAd00Ad00<AM7@0L7@34@Ad0Q45M0034G@A05Ad00<AM7@05G@00a5dM009M00027@0115d
M144M0064GAd4G@A0W@00a5dM002M0034GAd00Ad0Q5aM0034G@A00Id0Q43M0034G@A05Ad00<AM7@0
57@24@]d0008M0044GAd4@Ad00HAM7@AM142M0034G@A008A1g@00a5dM01aM0@A1W@24@04M15d4EAd
00<AM7@05G@00a5dM009M00027@0115dM144M0064GAd4G@A0W@0115dM148M0034GAd079d3A400g@A
M01CM0034GAd01Ed00<AM7@02G@000Ud0Q46M08A0g@24@=d0a46M08AM7@24@9d0Q45M0<AE7@00a5d
M00DM08A2g@002Ad00<AM7@0MG@01A5dM7@A00Ad00<AM140E7@00a5dM00EM0034GAd00Ud000TM003
4GAd07Id0Q42M08A0W@00a5d4@1DM0034GAd01Ed00<AM7@02G@002Ad0Q5hM08A0g@34@03M15d05=d
00<AM7@057@24@]d000TM0034GAd07Ud0Q43M0<AE7@00a5dM00EM0034GAd00Ud000TM0034GAd07Yd
0a4017@A4A5DM0034GAd01Ed00<AM7@02G@002Ad0Q5mM0<A00=d4G@0Dg@00a5dM00DM08A2g@002Ad
00<AM7@0OG@44EAd00<AM7@05G@00a5dM009M00097@00a5dM01nM0<AE7@00a5dM00EM0034GAd00Ud
000KM08A1g@24GmdF14EM0<A2g@001Yd00@AM7@A1W@00a5dM01mM08AEW@00a5dM00EM0034GAd00Ud
000JM0044GAd4@Id00<AM7@0O7@34EId00<AM7@05G@00a5dM009M0006W@0115dM146M08ANg@54EId
00<AM7@057@24@]d000JM0044GAd4@Id00<AM7@0NG@64EId00<AM7@05G@00a5dM009M0006W@0115d
M146M0034GAd07Qd11400g@A4@1FM0034GAd01Ed00<AM7@02G@001]d0Q47M08AN7@64@03M15d05Ed
00<AM7@057@24@]d000TM0034GAd07Id1142M0034G@A05Id00<AM7@05G@00a5dM009M00097@00a5d
M01eM0<A00Md4GAd4G@A05Id00<AM7@05G@00a5dM009M00097@24GEd0a401W@AM7@AM08AEW@00a5d
M00DM08A2g@002Ad00<AM7@0LW@44@9d00DAM7@AM0024EId00<AM7@05G@00a5dM009M00097@00a5d
M01aM0@A0W@01Q5dM7@AM08AEW@00a5dM00EM0034GAd00Ud000TM08ALG@24@03M15d008A0g@00a5d
M0024EId00<AM7@057@24@]d000TM0034GAd06md0Q4017@AM7@24@=d00<AM1400Q5FM0034GAd01Ed
00<AM7@02G@002Ad00<AM7@0KW@0115dM143M0034GAd009d00<AM1400Q5FM0034GAd01Ed00<AM7@0
2G@000Ud0Q43M0034GAd008A0g@24@9d0a47M08AKW@24@9d00<AM7@00Q44M08A00=d4A40EW@00a5d
M00CM0<A2g@000Qd00@AM7@A17@01Q5dM15d4@9d00<AM1400W@00a5dM004M0034GAd06ad0Q42M007
4GAdM15d4@02M08A0WAI4AMd00<AM7@02G@000Qd00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5d
M004M0034GAd06]d00DAM15d4@03M0044GAd4@9d00@AM7Ad0Q5FM0034GAd01Ed00<AM7@02G@000Qd
00@AM7@A17@01Q5dM15d4@9d00<AM7@00W@00a5dM004M08AJg@00a5dM0024@=d00DAM7Ad4@02M003
4GAd00<AEW@00a5dM00DM08A2g@000Qd00@AM7@A17@01Q5dM15d4@9d00<AM1400Q47M0034GAd06Yd
0Q400g@AM003M0034GAd009d0Q4017@A4G@24EId00<AM7@05G@00a5dM009M00027@0115dM144M006
4GAd4G@A0W@0115dM148M0034GAd06Ud00<AM7@0JQ4GM0034GAd00Ud0009M08A1W@24@=d0Q43M0<A
1W@24FYd00@AM7@A17@0115dM7@24@03M15d00=d0Q5FM0034GAd01Ad0Q4;M00097@00a5dM01XM003
4GAd008A17@0115dM143M0034GAd009d0Q5FM0034GAd01Ed00<AM7@02G@002Ad00<AM7@0J7@00a5d
M0024@Ad0a45M0044GAdM08AEW@00a5dM00EM0034GAd00Ud000TM08AJ7@01A5dM7@A00Ed00<AM7@0
1G@24@9d0Q5FM0034GAd01Ad0Q4;M00097@00a5dM01WM0034GAd008A17@24@Md0Q42M08AEW@00a5d
M00EM0034GAd00Ud000TM0034GAd06Id00@AM7Ad0Q42M08A00=d4G@01W@0115d4G@24EId00<AM7@0
5G@00a5dM009M00097@24FMd00PAM7@AM15d4@=d00<AM7@01G@01Q5dM15d4EId00<AM7@057@24@]d
000TM0034GAd06Ed00@AM7Ad1144M0034GAd00Id00<AM7@00Q5FM0034GAd01Ed00<AM7@02G@002Ad
00<AM7@0IG@0115dM7@24@Id00<AM7@01W@00a5dM0024EId00<AM7@05G@00a5dM009M0003W@24@=d
00<AM7@00Q43M0<A1W@24FEd00@AM7Ad0Q400g@A4@04M0034GAd00Id00@AM7AdF14EM0<A2g@000ed
00@AM7@A17@0115dM143M0034GAd00Ed00<AM7@0I7@00a5dM0024@Ad00DAM7Ad4@08M0054GAdM140
EW@00a5dM00EM0034GAd00Ud000=M0044GAd4@Ad00@AM7@A0g@00a5dM005M0034GAd06=d00HAM7@A
M145M0044GAd4@Ud00@AM7@AEW@00a5dM00EM0034GAd00Ud000=M0044GAd4@Ad00@AM7@A0g@00a5d
M005M08AI7@34@03M15d00Id0a49M0044GAd4EId00<AM7@057@24@]d000=M0044GAd4@Ad00@AM7@A
0g@00a5dM005M0034GAd069d0Q43M0034GAd00Md00<AM7@01g@0115dM15FM0034GAd01Ed00<AM7@0
2G@000ed00@AM7@A17@0115dM142M08A1g@00a5dM01RM0054GAdM1402W@34@Md00@AM7@AEW@00a5d
M00EM0034GAd00Ud000>M08A1W@24@Ad00<AM7@01G@24FAd0Q400g@AM009M0044GAd4@Id00@AM7@A
EW@00a5dM00DM08A2g@002Ad00<AM7@0Hg@0115d4A4:M0044GAdM08A1G@34EId00<AM7@05G@00a5d
M009M00097@00a5dM01TM0@A2G@00a5dM003M0034GAd009d0a5FM0034GAd01Ed00<AM7@02G@002Ad
0Q5VM0HA1W@00a5dM003M0HA00=d4G@0EG@00a5dM00DM08A2g@002Ad00<AM7@0IW@00a5dM01]4AMd
00<AM7@02G@002Ad00<AM7@0Ig@24@9d00<AM7@017@00a5dM006M08A00=d4G@0EG@00a5dM00EM003
4GAd00Ud000TM08AJW@00a5dM0024@Ad00<AM7@01g@34EId00<AM7@057@24@]d000TM0034GAd06Yd
00DAM7Ad4@04M0034GAd00Id00<AM140Ea4GM0034GAd00Ud000TM0034GAd06]d00@AM7Ad0Q43M003
4GAd00Id0Q5FM0034GAd01Ed00<AM7@02G@000Ud0Q43M0034GAd008A0g@34@04M14A4@Md0Q5]M08A
0g@24@03M15d00Md0Q5FM0034GAd01=d0a4;M00027@0115dM144M0044GAd4@=d00@AM7@A0W@00a5d
M004M0034GAd06id00<AM7@00W@00a5d4@07M08AEW@00a5dM00EM0034GAd00Ud0008M0044GAd4@Ad
00@AM7@A0g@00a5dM003M0034GAd00Ad00<AM7@0Kg@00a5dM002M0<A1W@24EId00<AM7@05G@00a5d
M009M00027@0115dM144M0044GAd4@=d00<AM7@00g@00a5dM004M08ALG@00a5dM003M0034GAd00Ad
0Q5FM0034GAd01Ad0Q4;M00027@0115dM144M0044GAd4@=d00<AM7@00a47M0034GAd075d0Q44M08A
17@24EId00<AM7@05G@00a5dM009M00027@0115dM144M0044GAd4@9d0Q43M0034GAd00Id00<AM7@0
Lg@01a5dM7@AM1400W@34EId00<AM7@05G@00a5dM009M0002G@24@Id0Q44M0044GAdM0<A1W@24GEd
00HAM7Ad4G@54EId00<AM7@057@24@]d000TM0034GAd07Ed0Q42M0034GAd05XA5g@00a5dM009M000
97@00a5dM01gM0034G@A009d0a5FM0034GAd01Ed00<AM7@02G@002Ad0Q5iM0074G@AM15d4@1FM003
4GAd01Ad0Q4;M00097@00a5dM01iM0064G@A4G@AEW@00a5dM00EM0034GAd00Ud000TM0034GAd07Yd
0Q400g@A4@1FM0034GAd01Ed00<AM7@02G@002Ad0Q5mM0<AEW@00a5dM00DM08A2g@002Ad00<AM7@0
OGAI4AMd00<AM7@02G@002Ad00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M003
4GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0
0g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M003
4GAd00=d00@AM14A0W@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0
0g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM003M003
4GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM009M0003W@24@=d00<AM7@0
0Q42M0@A1WCa4@]d000=M0044GAd4@Ad00@AM7@A0W@00a5dM03oM0=d000=M0044GAd4@Ad00@AM7@A
0g@00a5dM03oM09d000=M0044GAd4@Ad00@AM7@A0g@00a5dM03oM09d000=M0044GAd4@Ad00@AM7@A
17@00a5dM03oM05d000=M0044GAd4@Ad00HAM7@AM142M0034GAd0?md0G@000id0Q46M08A0g@24Omd
17@00?md8G@00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-0.0130387, -0.0252746, \
8.33985*^-5, 0.000333594}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Flexible Lenses", "Subsubsection"],

Cell[CellGroupData[{

Cell["ShowSystem[FlexibleLens, Axes->True];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.49507 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.237324 1.5606 1.51517e-16 1.5606 [
[.13763 .13498 -8.36108 -10.9375 ]
[.13763 .13498 .63892 0 ]
[.24117 .09129 -24.0399 -11 ]
[.24117 .09129 2.46008 0 ]
[.34759 .04639 -19.0345 -10.9375 ]
[.34759 .04639 2.46552 0 ]
[.45702 .00023 -22.8823 -11 ]
[.45702 .00023 3.61771 0 ]
[.01503 1.06963 -15.7145 0 ]
[.01503 1.06963 12.723 10.9375 ]
[.17582 1.19707 -15.2332 0 ]
[.17582 1.19707 13.2043 10.9375 ]
[.31949 1.31093 -4.69119 0 ]
[.31949 1.31093 4.30881 10.9375 ]
[.44865 1.4133 -10.9391 0 ]
[.44865 1.4133 10.5609 10.9375 ]
[.56538 1.50581 -10.7058 0 ]
[.56538 1.50581 10.7942 10.9375 ]
[.07415 .19806 -28.4375 -3.18123 ]
[.07415 .19806 0 7.75627 ]
[.05454 .37645 -28.4375 -3.30628 ]
[.05454 .37645 0 7.63122 ]
[.03316 .57094 -9 -3.44336 ]
[.03316 .57094 0 7.49414 ]
[.00977 .78379 -21.5 -3.5943 ]
[.00977 .78379 0 7.3432 ]
[-0.01593 1.01774 -21.5 -3.7613 ]
[-0.01593 1.01774 0 7.1762 ]
[ 0 0 0 0 ]
[ 1 1.49507 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09401 .17347 m
.50657 0 L
s
.15034 .14978 m
.15669 .15719 L
s
gsave
.13763 .13498 -69.3611 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25349 .10641 m
.25964 .11398 L
s
gsave
.24117 .09129 -85.0399 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.3595 .06184 m
.36545 .06957 L
s
gsave
.34759 .04639 -80.0345 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.46849 .01601 m
.47423 .0239 L
s
gsave
.45702 .00023 -83.8823 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17074 .1412 m
.17453 .14567 L
s
.19126 .13258 m
.19503 .13706 L
s
.21189 .1239 m
.21563 .1284 L
s
.23263 .11518 m
.23635 .1197 L
s
.27445 .0976 m
.27813 .10215 L
s
.29554 .08873 m
.29919 .09331 L
s
.31674 .07982 m
.32036 .08441 L
s
.33806 .07085 m
.34166 .07547 L
s
.38105 .05278 m
.3846 .05743 L
s
.40273 .04366 m
.40625 .04834 L
s
.42453 .0345 m
.42802 .03919 L
s
.44645 .02528 m
.44992 .02999 L
s
.13004 .15832 m
.13387 .16274 L
s
.10985 .16681 m
.11371 .17121 L
s
.49066 .00669 m
.49407 .01144 L
s
.25 Mabswid
0 1.03666 m
.57632 1.49507 L
s
.01707 1.05023 m
.01809 1.04053 L
s
gsave
.01503 1.06963 -76.7145 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.17721 1.17761 m
.1779 1.16788 L
s
gsave
.17582 1.19707 -76.2332 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32032 1.29145 m
.32074 1.2817 L
s
gsave
.31949 1.31093 -65.6912 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.44899 1.39379 m
.44916 1.38404 L
s
gsave
.44865 1.4133 -71.9391 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5653 1.48631 m
.56526 1.47655 L
s
gsave
.56538 1.50581 -71.7058 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.0506 1.0769 m
.05117 1.07108 L
s
.08336 1.10296 m
.08389 1.09713 L
s
.11536 1.12841 m
.11585 1.12258 L
s
.14663 1.15329 m
.14709 1.14745 L
s
.2071 1.20139 m
.20748 1.19555 L
s
.23634 1.22464 m
.23668 1.2188 L
s
.26494 1.24739 m
.26525 1.24155 L
s
.29293 1.26966 m
.29321 1.26381 L
s
.34714 1.31278 m
.34736 1.30693 L
s
.3734 1.33366 m
.37359 1.32781 L
s
.39912 1.35412 m
.39927 1.34827 L
s
.42431 1.37416 m
.42444 1.36831 L
s
.47318 1.41304 m
.47326 1.40718 L
s
.4969 1.4319 m
.49695 1.42604 L
s
.52015 1.45039 m
.52017 1.44454 L
s
.54294 1.46852 m
.54294 1.46267 L
s
.25 Mabswid
.09401 .17347 m
0 1.03666 L
s
.09215 .19053 m
.10115 .18677 L
s
gsave
.07415 .19806 -89.4375 -7.18123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.07268 .36928 m
.08175 .36569 L
s
gsave
.05454 .37645 -89.4375 -7.30628 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.05146 .56416 m
.0606 .56077 L
s
gsave
.03316 .57094 -70 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02823 .77746 m
.03745 .7743 L
s
gsave
.00977 .78379 -82.5 -7.5943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.00269 1.01192 m
.012 1.00902 L
s
gsave
-0.01593 1.01774 -82.5 -7.7613 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.08838 .22509 m
.09379 .22285 L
s
.08456 .26023 m
.08997 .25801 L
s
.08067 .29596 m
.08609 .29376 L
s
.07671 .33231 m
.08214 .33013 L
s
.06858 .4069 m
.07404 .40477 L
s
.06442 .44518 m
.06988 .44307 L
s
.06017 .48413 m
.06564 .48205 L
s
.05585 .52379 m
.06133 .52173 L
s
.04698 .60527 m
.05248 .60326 L
s
.04242 .64713 m
.04793 .64515 L
s
.03778 .68977 m
.0433 .68781 L
s
.03305 .7332 m
.03857 .73128 L
s
.02332 .82256 m
.02886 .82069 L
s
.01831 .86853 m
.02387 .8667 L
s
.01321 .9154 m
.01877 .91359 L
s
.008 .96319 m
.01358 .96141 L
s
0 0 m
1 0 L
1 1.49507 L
0 1.49507 L
closepath
clip
newpath
.5 Mabswid
.556 .73575 m
.51391 .63465 L
s
.58415 .7266 m
.556 .73575 L
s
.556 .73575 m
.50697 .76386 L
s
.5882 .84186 m
.556 .73575 L
s
.60901 .94814 m
.5882 .84186 L
s
.5882 .84186 m
.6165 .83307 L
s
.52922 .83735 m
.5882 .84186 L
s
.6165 .83307 m
.58415 .7266 L
s
.58415 .7266 m
.7231 .68141 L
s
.58415 .7266 m
.5421 .62507 L
s
.53604 .75445 m
.58415 .7266 L
s
.63764 .93965 m
.6165 .83307 L
s
.6165 .83307 m
.75618 .78968 L
s
.55841 .82821 m
.6165 .83307 L
s
.51391 .63465 m
.5421 .62507 L
s
.51391 .63465 m
.46371 .54334 L
s
.47765 .69409 m
.51391 .63465 L
s
.60901 .94814 m
.63764 .93965 L
s
.54323 .91072 m
.60901 .94814 L
s
.5421 .62507 m
.68124 .5778 L
s
.5421 .62507 m
.49212 .5333 L
s
.50675 .68438 m
.5421 .62507 L
s
.63764 .93965 m
.77896 .89775 L
s
.57265 .90178 m
.63764 .93965 L
s
.46371 .54334 m
.49212 .5333 L
s
.44275 .63182 m
.46371 .54334 L
s
.75618 .78968 m
.7231 .68141 L
s
.7231 .68141 m
.87202 .63297 L
s
.7231 .68141 m
.68124 .5778 L
s
.67966 .70796 m
.7231 .68141 L
s
.77896 .89775 m
.75618 .78968 L
s
.75618 .78968 m
.90589 .74318 L
s
.70254 .78302 m
.75618 .78968 L
s
.49212 .5333 m
.63235 .48372 L
s
.472 .62178 m
.49212 .5333 L
s
.5481 .98001 m .64628 1.04134 L .61716 1.04959 L .656 .751 .92 r
F
0 g
.61161 1.14093 m
.61716 1.04959 L
s
.60901 .94814 m
.61492 1.02175 L
s
.68124 .5778 m
.8304 .52712 L
s
.68124 .5778 m
.63235 .48372 L
s
.65049 .6364 m
.68124 .5778 L
s
.5481 .98001 m .57786 .97124 L .64628 1.04134 L .656 .751 .92 r
F
0 g
.64138 1.13282 m
.64628 1.04134 L
s
.63764 .93965 m
.64628 1.04134 L
s
.61716 1.04959 m
.64628 1.04134 L
s
.77896 .89775 m
.93048 .85282 L
s
.52922 .83735 m
.50697 .76386 L
s
.50697 .76386 m
.47765 .69409 L
s
.45395 .79425 m
.50697 .76386 L
s
.87202 .63297 m
.90589 .74318 L
s
.8304 .52712 m
.87202 .63297 L
s
.54323 .91072 m
.52922 .83735 L
s
.4655 .83249 m
.52922 .83735 L
s
.90589 .74318 m
.93048 .85282 L
s
.40751 .46671 m .43353 .57029 L .40401 .58067 L .544 .324 .532 r
F
.40751 .46671 m .4363 .45617 L .43353 .57029 L F
0 g
.43513 .50437 m
.46371 .54334 L
s
.40751 .46671 m
.4363 .45617 L
s
.34788 .4097 m
.40751 .46671 L
s
.4363 .45617 m
.49212 .5333 L
s
.63235 .48372 m
.78277 .43053 L
s
.55841 .82821 m
.53604 .75445 L
s
.48401 .78457 m
.53604 .75445 L
s
.53604 .75445 m
.50675 .68438 L
s
.57265 .90178 m
.55841 .82821 L
s
.49562 .82295 m
.55841 .82821 L
s
.47765 .69409 m
.44275 .63182 L
s
.43861 .7581 m
.47765 .69409 L
s
.37722 .39867 m
.4363 .45617 L
s
.78277 .43053 m
.8304 .52712 L
s
.50675 .68438 m
.472 .62178 L
s
.46868 .74826 m
.50675 .68438 L
s
.72491 .92789 m .94438 .95681 L .79009 1.00056 L .656 .751 .92 r
F
0 g
.78845 1.09277 m
.79009 1.00056 L
s
.77896 .89775 m
.78305 .93555 L
s
.64628 1.04134 m
.79009 1.00056 L
s
.59174 1.2165 m
.61161 1.14093 L
s
.61161 1.14093 m
.64138 1.13282 L
s
.54324 1.04124 m
.61161 1.14093 L
s
.62227 1.20845 m
.64138 1.13282 L
s
.64138 1.13282 m
.78845 1.09277 L
s
.57345 1.03256 m
.64138 1.13282 L
s
.45053 .71622 m
.472 .62178 L
s
.47467 .90603 m .57786 .97124 L .5481 .98001 L .656 .751 .92 r
F
0 g
.54324 1.04124 m
.5481 .98001 L
s
.54323 .91072 m
.54607 .95115 L
s
.5481 .98001 m
.61716 1.04959 L
s
.70254 .78302 m
.67966 .70796 L
s
.63261 .73672 m
.67966 .70796 L
s
.67966 .70796 m
.65049 .6364 L
s
.47467 .90603 m .50509 .89669 L .57786 .97124 L .656 .751 .92 r
F
0 g
.57345 1.03256 m
.57786 .97124 L
s
.57786 .97124 m
.64628 1.04134 L
s
.47257 .87052 m
.54323 .91072 L
s
.57265 .90178 m
.57786 .97124 L
s
.50281 .86109 m
.57265 .90178 L
s
.71795 .85766 m
.70254 .78302 L
s
.6445 .7758 m
.70254 .78302 L
s
.57851 .40413 m .73623 .4639 L .57945 .51901 L .544 .324 .532 r
F
0 g
.61652 .57218 m
.62916 .50154 L
s
.57851 .40413 m .73117 .34827 L .73623 .4639 L .544 .324 .532 r
F
0 g
.4363 .45617 m
.57851 .40413 L
s
.73117 .34827 m
.78277 .43053 L
s
.57851 .40413 m
.73117 .34827 L
s
.52221 .34413 m
.57851 .40413 L
s
.65049 .6364 m
.61652 .57218 L
s
.72491 .92789 m .88286 .88133 L .94438 .95681 L .656 .751 .92 r
F
0 g
.94438 .95681 m
.94637 1.04976 L
s
.93048 .85282 m
.94438 .95681 L
s
.79009 1.00056 m
.94438 .95681 L
s
.71795 .85766 m
.77896 .89775 L
s
.40401 .58067 m .43062 .69049 L .40033 .70068 L .544 .324 .532 r
F
0 g
.42037 .72623 m
.42869 .69114 L
s
.40401 .58067 m .43353 .57029 L .43062 .69049 L .544 .324 .532 r
F
0 g
.40401 .58067 m
.40751 .46671 L
s
.43238 .61812 m
.44275 .63182 L
s
.43083 .68213 m
.44275 .63182 L
s
.43353 .57029 m
.472 .62178 L
s
.43353 .57029 m
.4363 .45617 L
s
.36351 .54408 m
.40401 .58067 L
s
.34788 .4097 m
.37722 .39867 L
s
.34788 .4097 m
.28799 .3772 L
s
.36351 .54408 m
.34788 .4097 L
s
.39342 .53337 m
.43353 .57029 L
s
.77323 1.16867 m
.78845 1.09277 L
s
.78845 1.09277 m
.94637 1.04976 L
s
.72276 .98967 m
.78845 1.09277 L
s
.37722 .39867 m
.52221 .34413 L
s
.37722 .39867 m
.31801 .3657 L
s
.39342 .53337 m
.37722 .39867 L
s
.51743 1.09355 m
.54324 1.04124 L
s
.46715 .93813 m
.54324 1.04124 L
s
.54787 1.08498 m
.57345 1.03256 L
s
.49753 .92892 m
.57345 1.03256 L
s
.55749 1.27047 m
.59174 1.2165 L
s
.59174 1.2165 m
.62227 1.20845 L
s
.51743 1.09355 m
.59174 1.2165 L
s
.4655 .83249 m
.45395 .79425 L
s
.45395 .79425 m
.43861 .7581 L
s
.65551 .85052 m .88286 .88133 L .72491 .92789 L .656 .751 .92 r
F
0 g
.72276 .98967 m
.72491 .92789 L
s
.71795 .85766 m
.71808 .859 L
s
.72491 .92789 m
.79009 1.00056 L
s
.57786 .97124 m
.72491 .92789 L
s
.47257 .87052 m
.4655 .83249 L
s
.58887 1.26238 m
.62227 1.20845 L
s
.62227 1.20845 m
.77323 1.16867 L
s
.54787 1.08498 m
.62227 1.20845 L
s
.43861 .7581 m
.42037 .72623 L
s
.67801 .28553 m
.73117 .34827 L
s
.49562 .82295 m
.48401 .78457 L
s
.48401 .78457 m
.46868 .74826 L
s
.50281 .86109 m
.49562 .82295 L
s
.46868 .74826 m
.45053 .71622 L
s
.36351 .54408 m
.32363 .52507 L
s
.37969 .68316 m
.36351 .54408 L
s
.39645 .82721 m .50509 .89669 L .47467 .90603 L .656 .751 .92 r
F
0 g
.46715 .93813 m
.47467 .90603 L
s
.47257 .87052 m
.4729 .8761 L
s
.47467 .90603 m
.5481 .98001 L
s
.39342 .53337 m
.354 .51406 L
s
.39342 .53337 m
.41018 .67282 L
s
.57945 .51901 m .74157 .58593 L .58043 .64012 L .544 .324 .532 r
F
0 g
.5996 .66671 m
.60589 .63156 L
s
.61734 .69961 m
.65049 .6364 L
s
.57945 .51901 m .73623 .4639 L .74157 .58593 L .544 .324 .532 r
F
0 g
.57851 .40413 m
.57945 .51901 L
s
.43353 .57029 m
.57945 .51901 L
s
.54127 .48044 m
.57945 .51901 L
s
.73117 .34827 m
.73623 .4639 L
s
.46997 1.13337 m
.51743 1.09355 L
s
.44751 .96551 m
.51743 1.09355 L
s
.94637 1.04976 m
.9355 1.12591 L
s
.52221 .34413 m
.67801 .28553 L
s
.52221 .34413 m
.46648 .30879 L
s
.54127 .48044 m
.52221 .34413 L
s
.39645 .82721 m .42755 .81725 L .50509 .89669 L .656 .751 .92 r
F
0 g
.49753 .92892 m
.50509 .89669 L
s
.50509 .89669 m
.57786 .97124 L
s
.44056 .83058 m
.4655 .83249 L
s
.50281 .86109 m
.50509 .89669 L
s
.40033 .70068 m .42755 .81725 L .39645 .82721 L .544 .324 .532 r
F
.40033 .70068 m .43062 .69049 L .42755 .81725 L F
0 g
.40033 .70068 m
.40401 .58067 L
s
.42775 .80927 m
.45395 .79425 L
s
.42859 .77452 m
.43861 .7581 L
s
.43062 .69049 m
.45053 .71622 L
s
.43062 .69049 m
.43353 .57029 L
s
.37969 .68316 m
.40033 .70068 L
s
.50087 1.12478 m
.54787 1.08498 L
s
.47812 .95631 m
.54787 1.08498 L
s
.71118 1.039 m
.72276 .98967 L
s
.65385 .88154 m
.72276 .98967 L
s
.44751 .96551 m
.46715 .93813 L
s
.41018 .67282 m
.43062 .69049 L
s
.65551 .85052 m .81728 .80086 L .88286 .88133 L .656 .751 .92 r
F
0 g
.88286 .88133 m
.94438 .95681 L
s
.65231 .81452 m
.69067 .83973 L
s
.28799 .3772 m
.31801 .3657 L
s
.28799 .3772 m
.23165 .37359 L
s
.32363 .52507 m
.28799 .3772 L
s
.47812 .95631 m
.49753 .92892 L
s
.74414 1.22234 m
.77323 1.16867 L
s
.77323 1.16867 m
.9355 1.12591 L
s
.71118 1.039 m
.77323 1.16867 L
s
.6445 .7758 m
.63261 .73672 L
s
.63261 .73672 m
.61734 .69961 L
s
.65231 .81452 m
.6445 .7758 L
s
.37969 .68316 m
.35978 .67505 L
s
.31801 .3657 m
.46648 .30879 L
s
.31801 .3657 m
.26245 .36168 L
s
.354 .51406 m
.31801 .3657 L
s
.42295 .98435 m
.44751 .96551 L
s
.61734 .69961 m
.5996 .66671 L
s
.32363 .52507 m
.28701 .52597 L
s
.35978 .67505 m
.32363 .52507 L
s
.41018 .67282 m
.39051 .66456 L
s
.45378 .97513 m
.47812 .95631 L
s
.54127 .48044 m
.50425 .45962 L
s
.56101 .62163 m
.54127 .48044 L
s
.42252 1.1518 m
.46997 1.13337 L
s
.46997 1.13337 m
.55749 1.27047 L
s
.42295 .98435 m
.46997 1.13337 L
s
.5073 1.29781 m
.55749 1.27047 L
s
.55749 1.27047 m
.58887 1.26238 L
s
.354 .51406 m
.31791 .51472 L
s
.39051 .66456 m
.354 .51406 L
s
.62621 .24757 m
.67801 .28553 L
s
.58148 .76797 m .81728 .80086 L .65551 .85052 L .656 .751 .92 r
F
0 g
.65385 .88154 m
.65551 .85052 L
s
.65551 .85052 m
.72491 .92789 L
s
.50509 .89669 m
.65551 .85052 L
s
.45393 1.14308 m
.50087 1.12478 L
s
.50087 1.12478 m
.58887 1.26238 L
s
.45378 .97513 m
.50087 1.12478 L
s
.53929 1.28962 m
.58887 1.26238 L
s
.58887 1.26238 m
.74414 1.22234 L
s
.39981 .9917 m
.42295 .98435 L
s
.35978 .67505 m
.34194 .67717 L
s
.69034 1.07207 m
.71118 1.039 L
s
.64729 .90549 m
.71118 1.039 L
s
.58043 .64012 m .74722 .71491 L .58148 .76797 L .544 .324 .532 r
F
.58043 .64012 m .74157 .58593 L .74722 .71491 L F
0 g
.57945 .51901 m
.58043 .64012 L
s
.43062 .69049 m
.58043 .64012 L
s
.73623 .4639 m
.74157 .58593 L
s
.56101 .62163 m
.58043 .64012 L
s
.43089 .98241 m
.45378 .97513 L
s
.39051 .66456 m
.37295 .66657 L
s
.64729 .90549 m
.65385 .88154 L
s
.9355 1.12591 m
.91125 1.17925 L
s
.39645 .82721 m .4017 .95799 L .37009 .96757 L .544 .324 .532 r
F
0 g
.39914 .95877 m
.39981 .9917 L
s
.38202 .98603 m
.38408 .96333 L
s
.39645 .82721 m .42755 .81725 L .4017 .95799 L .544 .324 .532 r
F
0 g
.42115 .8521 m
.47467 .90603 L
s
.41917 .86287 m
.46715 .93813 L
s
.416 .88016 m
.44751 .96551 L
s
.41046 .91031 m
.42295 .98435 L
s
.31294 .74307 m .42755 .81725 L .39645 .82721 L .656 .751 .92 r
F
0 g
.36115 .93842 m
.39645 .82721 L
s
.35003 .9023 m
.39645 .82721 L
s
.33386 .86309 m
.39645 .82721 L
s
.32135 .82147 m
.39645 .82721 L
s
.34194 .67717 m
.38215 .78787 L
s
.39645 .82721 m
.39645 .82721 L
s
.35978 .67505 m
.38785 .79156 L
s
.37969 .68316 m
.39266 .79467 L
s
.39735 .7977 m
.40033 .70068 L
s
.46648 .30879 m
.62621 .24757 L
s
.46648 .30879 m
.41493 .30273 L
s
.50425 .45962 m
.46648 .30879 L
s
.38202 .98603 m
.39981 .9917 L
s
.39981 .9917 m
.42252 1.1518 L
s
.34194 .67717 m
.32747 .68972 L
s
.28701 .52597 m
.34194 .67717 L
s
.31294 .74307 m .34476 .73243 L .42755 .81725 L .656 .751 .92 r
F
0 g
.42755 .81725 m
.43089 .98241 L
s
.41337 .97662 m
.42755 .81725 L
s
.39297 .92864 m
.42755 .81725 L
s
.38196 .89233 m
.42755 .81725 L
s
.36609 .85284 m
.42755 .81725 L
s
.35351 .81105 m
.42755 .81725 L
s
.34623 .76987 m
.42755 .81725 L
s
.34909 .70145 m
.42755 .81725 L
s
.35876 .67905 m
.42755 .81725 L
s
.37295 .66657 m
.42755 .81725 L
s
.42755 .81725 m
.42755 .81725 L
s
.32747 .68972 m
.35328 .74116 L
s
.31752 .71213 m
.33392 .73605 L
s
.31422 .78043 m
.39645 .82721 L
s
.39051 .66456 m
.42755 .81725 L
s
.42755 .81725 m
.45378 .97513 L
s
.42755 .81725 m
.47812 .95631 L
s
.41018 .67282 m
.42755 .81725 L
s
.42755 .81725 m
.49753 .92892 L
s
.42755 .81725 m
.43062 .69049 L
s
.42755 .81725 m
.48401 .78457 L
s
.42755 .81725 m
.49562 .82295 L
s
.42755 .81725 m
.46868 .74826 L
s
.42755 .81725 m
.50281 .86109 L
s
.42755 .81725 m
.45053 .71622 L
s
.42755 .81725 m
.50509 .89669 L
s
.56101 .62163 m
.54258 .61266 L
s
.41337 .97662 m
.43089 .98241 L
s
.43089 .98241 m
.45393 1.14308 L
s
.28701 .52597 m
.25641 .54807 L
s
.23165 .37359 m
.28701 .52597 L
s
.37295 .66657 m
.35876 .67905 L
s
.31791 .51472 m
.37295 .66657 L
s
.38773 1.14362 m
.42252 1.1518 L
s
.42252 1.1518 m
.5073 1.29781 L
s
.63612 .92062 m
.64729 .90549 L
s
.50425 .45962 m
.47088 .45905 L
s
.54258 .61266 m
.50425 .45962 L
s
.58148 .76797 m .74722 .71491 L .81728 .80086 L .656 .751 .92 r
F
0 g
.81728 .80086 m
.88286 .88133 L
s
.23165 .37359 m
.18317 .40207 L
s
.26245 .36168 m
.23165 .37359 L
s
.70171 1.24804 m
.74414 1.22234 L
s
.74414 1.22234 m
.91125 1.17925 L
s
.69034 1.07207 m
.74414 1.22234 L
s
.31791 .51472 m
.28789 .53666 L
s
.26245 .36168 m
.31791 .51472 L
s
.41967 1.13468 m
.45393 1.14308 L
s
.45393 1.14308 m
.53929 1.28962 L
s
.32747 .68972 m
.25641 .54807 L
s
.32747 .68972 m
.31752 .71213 L
s
.66103 1.08561 m
.69034 1.07207 L
s
.63612 .92062 m
.69034 1.07207 L
s
.26245 .36168 m
.21482 .38987 L
s
.41493 .30273 m
.26245 .36168 L
s
.54258 .61266 m
.5264 .61412 L
s
.41337 .97662 m
.41967 1.13468 L
s
.35876 .67905 m
.34909 .70145 L
s
.62096 .9256 m
.63612 .92062 L
s
.57919 .23923 m
.62621 .24757 L
s
.44966 1.29214 m
.5073 1.29781 L
s
.5073 1.29781 m
.53929 1.28962 L
s
.58148 .76797 m .7532 .85143 L .58258 .90316 L .544 .324 .532 r
F
0 g
.61302 .89393 m
.62096 .9256 L
s
.59966 .89798 m
.6027 .91976 L
s
.62524 .89022 m
.63612 .92062 L
s
.63811 .88632 m
.64729 .90549 L
s
.58148 .76797 m .74722 .71491 L .7532 .85143 L .544 .324 .532 r
F
.50232 .67972 m .74722 .71491 L .58148 .76797 L .656 .751 .92 r
F
0 g
.56202 .8767 m
.58148 .76797 L
s
.54256 .84216 m
.58148 .76797 L
s
.52572 .80206 m
.58148 .76797 L
s
.51281 .75944 m
.58148 .76797 L
s
.50482 .7176 m
.58148 .76797 L
s
.51366 .62626 m
.54197 .68541 L
s
.5264 .61412 m
.55246 .68692 L
s
.58148 .76797 m
.58148 .76797 L
s
.54258 .61266 m
.5615 .68822 L
s
.58043 .64012 m
.58085 .691 L
s
.42755 .81725 m
.58148 .76797 L
s
.56101 .62163 m
.57051 .68951 L
s
.37009 .96757 m .39763 1.09939 L .36513 1.10866 L .544 .324 .532 r
F
0 g
.38202 .98603 m
.38371 1.03278 L
s
.38624 1.10264 m
.38773 1.14362 L
s
.37009 .96757 m .4017 .95799 L .39763 1.09939 L .544 .324 .532 r
F
0 g
.37009 .96757 m
.39645 .82721 L
s
.4017 .95799 m
.41337 .97662 L
s
.4017 .95799 m
.42755 .81725 L
s
.36115 .93842 m
.37009 .96757 L
s
.48248 1.28365 m
.53929 1.28962 L
s
.53929 1.28962 m
.70171 1.24804 L
s
.5264 .61412 m
.51366 .62626 L
s
.47088 .45905 m
.5264 .61412 L
s
.39297 .92864 m
.4017 .95799 L
s
.25641 .54807 m
.18317 .40207 L
s
.25641 .54807 m
.23452 .59113 L
s
.6027 .91976 m
.62096 .9256 L
s
.62096 .9256 m
.66103 1.08561 L
s
.47088 .45905 m
.44374 .48015 L
s
.41493 .30273 m
.47088 .45905 L
s
.91125 1.17925 m
.87386 1.20396 L
s
.2236 .65306 m .34476 .73243 L .31294 .74307 L .656 .751 .92 r
F
0 g
.31294 .74307 m
.31422 .78043 L
s
.31719 .71437 m
.31752 .71213 L
s
.28789 .53666 m
.35876 .67905 L
s
.31294 .74307 m
.39645 .82721 L
s
.28789 .53666 m
.21482 .38987 L
s
.28789 .53666 m
.26656 .57966 L
s
.35003 .9023 m
.36115 .93842 L
s
.36115 .93842 m
.34102 1.05243 L
s
.41967 1.13468 m
.48248 1.28365 L
s
.41493 .30273 m
.37163 .32945 L
s
.57919 .23923 m
.41493 .30273 L
s
.2236 .65306 m .25615 .64165 L .34476 .73243 L .656 .751 .92 r
F
0 g
.34476 .73243 m
.34623 .76987 L
s
.34476 .73243 m
.42755 .81725 L
s
.23452 .59113 m
.29996 .68654 L
s
.34476 .73243 m
.34909 .70145 L
s
.26656 .57966 m
.34909 .70145 L
s
.38196 .89233 m
.39297 .92864 L
s
.37394 1.04277 m
.39297 .92864 L
s
.62474 1.0773 m
.66103 1.08561 L
s
.66103 1.08561 m
.70171 1.24804 L
s
.22511 .72974 m
.31422 .78043 L
s
.31422 .78043 m
.32135 .82147 L
s
.33386 .86309 m
.35003 .9023 L
s
.35003 .9023 m
.30116 .98341 L
s
.32135 .82147 m
.23939 .81521 L
s
.32135 .82147 m
.33386 .86309 L
s
.33386 .86309 m
.26548 .90228 L
s
.25809 .71852 m
.34623 .76987 L
s
.34623 .76987 m
.35351 .81105 L
s
.50232 .67972 m .67222 .62288 L .74722 .71491 L .656 .751 .92 r
F
0 g
.50539 .64857 m
.51366 .62626 L
s
.44374 .48015 m
.51366 .62626 L
s
.74722 .71491 m
.81728 .80086 L
s
.50539 .64857 m
.52121 .6734 L
s
.74157 .58593 m
.74722 .71491 L
s
.36609 .85284 m
.38196 .89233 L
s
.33456 .97327 m
.38196 .89233 L
s
.18317 .40207 m
.21482 .38987 L
s
.18317 .40207 m
.14714 .46372 L
s
.64762 1.24093 m
.70171 1.24804 L
s
.70171 1.24804 m
.87386 1.20396 L
s
.35351 .81105 m
.27267 .80429 L
s
.35351 .81105 m
.36609 .85284 L
s
.36609 .85284 m
.29891 .89172 L
s
.21482 .38987 m
.37163 .32945 L
s
.21482 .38987 m
.17965 .4514 L
s
.58258 .90316 m .75954 .99619 L .58375 1.04632 L .544 .324 .532 r
F
0 g
.619 1.03627 m
.62474 1.0773 L
s
.58258 .90316 m .7532 .85143 L .75954 .99619 L .544 .324 .532 r
F
0 g
.58148 .76797 m
.58258 .90316 L
s
.4017 .95799 m
.58258 .90316 L
s
.74722 .71491 m
.7532 .85143 L
s
.56202 .8767 m
.58258 .90316 L
s
.36513 1.10866 m .41725 1.24281 L .38342 1.25181 L .544 .324 .532 r
F
.36513 1.10866 m .39763 1.09939 L .41725 1.24281 L F
0 g
.36513 1.10866 m
.37009 .96757 L
s
.41147 1.20056 m
.44966 1.29214 L
s
.39763 1.09939 m
.41967 1.13468 L
s
.36513 1.10866 m
.38342 1.25181 L
s
.34102 1.05243 m
.36513 1.10866 L
s
.39763 1.09939 m
.4017 .95799 L
s
.44374 .48015 m
.37163 .32945 L
s
.44374 .48015 m
.42528 .52285 L
s
.38342 1.25181 m
.44966 1.29214 L
s
.44966 1.29214 m
.48248 1.28365 L
s
.54079 .26427 m
.57919 .23923 L
s
.39763 1.09939 m
.41725 1.24281 L
s
.37394 1.04277 m
.39763 1.09939 L
s
.41749 .58514 m .67222 .62288 L .50232 .67972 L .656 .751 .92 r
F
0 g
.50232 .67972 m
.50482 .7176 L
s
.42528 .52285 m
.46992 .5929 L
s
.50232 .67972 m
.58148 .76797 L
s
.34476 .73243 m
.50232 .67972 L
s
.41725 1.24281 m
.48248 1.28365 L
s
.48248 1.28365 m
.64762 1.24093 L
s
.54256 .84216 m
.56202 .8767 L
s
.56202 .8767 m
.54107 .99375 L
s
.62474 1.0773 m
.64762 1.24093 L
s
.42159 .6629 m
.50482 .7176 L
s
.50482 .7176 m
.51281 .75944 L
s
.52572 .80206 m
.54256 .84216 L
s
.54256 .84216 m
.50018 .92295 L
s
.87386 1.20396 m
.82464 1.19514 L
s
.51281 .75944 m
.52572 .80206 L
s
.4377 .7501 m
.51281 .75944 L
s
.12779 .55652 m .25615 .64165 L .2236 .65306 L .656 .751 .92 r
F
0 g
.2236 .65306 m
.22511 .72974 L
s
.22881 .62352 m
.23452 .59113 L
s
.2236 .65306 m
.31294 .74307 L
s
.52572 .80206 m
.46466 .83937 L
s
.37163 .32945 m
.54079 .26427 L
s
.37163 .32945 m
.34082 .39032 L
s
.30116 .98341 m
.34102 1.05243 L
s
.34102 1.05243 m
.31353 1.17713 L
s
.12779 .55652 m .1611 .54428 L .25615 .64165 L .656 .751 .92 r
F
0 g
.25615 .64165 m
.25809 .71852 L
s
.1611 .54428 m
.25615 .64165 L
s
.25615 .64165 m
.34476 .73243 L
s
.14714 .46372 m
.23452 .59113 L
s
.25615 .64165 m
.26656 .57966 L
s
.17965 .4514 m
.26656 .57966 L
s
.12779 .55652 m
.2236 .65306 L
s
.33456 .97327 m
.37394 1.04277 L
s
.3479 1.16757 m
.37394 1.04277 L
s
.12779 .55652 m
.14714 .46372 L
s
.17965 .4514 m
.14714 .46372 L
s
.41749 .58514 m .59171 .5241 L .67222 .62288 L .656 .751 .92 r
F
0 g
.67222 .62288 m
.74722 .71491 L
s
.22511 .72974 m
.12822 .67462 L
s
.22511 .72974 m
.23939 .81521 L
s
.1611 .54428 m
.17965 .4514 L
s
.34082 .39032 m
.17965 .4514 L
s
.58375 1.04632 m .76627 1.14995 L .58499 1.19818 L .544 .324 .532 r
F
0 g
.64762 1.24093 m
.82464 1.19514 L
s
.58499 1.19818 m
.64762 1.24093 L
s
.58375 1.04632 m .75954 .99619 L .76627 1.14995 L .544 .324 .532 r
F
0 g
.58258 .90316 m
.58375 1.04632 L
s
.39763 1.09939 m
.58375 1.04632 L
s
.54107 .99375 m
.58375 1.04632 L
s
.58375 1.04632 m
.58499 1.19818 L
s
.7532 .85143 m
.75954 .99619 L
s
.26548 .90228 m
.30116 .98341 L
s
.30116 .98341 m
.24704 1.07213 L
s
.25809 .71852 m
.16221 .66266 L
s
.25809 .71852 m
.27267 .80429 L
s
.38342 1.25181 m
.41725 1.24281 L
s
.31353 1.17713 m
.38342 1.25181 L
s
.29891 .89172 m
.33456 .97327 L
s
.33456 .97327 m
.28171 1.06193 L
s
.23939 .81521 m
.14957 .80835 L
s
.23939 .81521 m
.26548 .90228 L
s
.26548 .90228 m
.19047 .94528 L
s
.41725 1.24281 m
.58499 1.19818 L
s
.3479 1.16757 m
.41725 1.24281 L
s
.51493 .32433 m
.54079 .26427 L
s
.27267 .80429 m
.18404 .79687 L
s
.27267 .80429 m
.29891 .89172 L
s
.32635 .48353 m .59171 .5241 L .41749 .58514 L .656 .751 .92 r
F
0 g
.41749 .58514 m
.42159 .6629 L
s
.41749 .58514 m
.50232 .67972 L
s
.25615 .64165 m
.41749 .58514 L
s
.34082 .39032 m
.40819 .49604 L
s
.29891 .89172 m
.22518 .9344 L
s
.50018 .92295 m
.54107 .99375 L
s
.54107 .99375 m
.51845 1.12013 L
s
.76627 1.14995 m
.82464 1.19514 L
s
.51493 .32433 m
.34082 .39032 L
s
.75954 .99619 m
.76627 1.14995 L
s
.12779 .55652 m
.1611 .54428 L
s
.12779 .55652 m
.12822 .67462 L
s
.3309 .6033 m
.42159 .6629 L
s
.42159 .6629 m
.4377 .7501 L
s
.1611 .54428 m
.16221 .66266 L
s
.46466 .83937 m
.50018 .92295 L
s
.50018 .92295 m
.45386 1.01126 L
s
.24704 1.07213 m
.31353 1.17713 L
s
.31353 1.17713 m
.3479 1.16757 L
s
.58499 1.19818 m
.76627 1.14995 L
s
.51845 1.12013 m
.58499 1.19818 L
s
.4377 .7501 m
.35519 .73985 L
s
.4377 .7501 m
.46466 .83937 L
s
.46466 .83937 m
.39753 .88041 L
s
.28171 1.06193 m
.3479 1.16757 L
s
.3479 1.16757 m
.51845 1.12013 L
s
.32635 .48353 m .50509 .41782 L .59171 .5241 L .656 .751 .92 r
F
0 g
.1611 .54428 m
.32635 .48353 L
s
.32635 .48353 m
.34082 .39032 L
s
.59171 .5241 m
.67222 .62288 L
s
.32635 .48353 m
.41749 .58514 L
s
.50509 .41782 m
.59171 .5241 L
s
.12822 .67462 m
.16221 .66266 L
s
.12822 .67462 m
.14957 .80835 L
s
.50509 .41782 m
.51493 .32433 L
s
.19047 .94528 m
.24704 1.07213 L
s
.24704 1.07213 m
.28171 1.06193 L
s
.16221 .66266 m
.3309 .6033 L
s
.16221 .66266 m
.18404 .79687 L
s
.32635 .48353 m
.50509 .41782 L
s
.32635 .48353 m
.3309 .6033 L
s
.22518 .9344 m
.28171 1.06193 L
s
.28171 1.06193 m
.45386 1.01126 L
s
.70299 1.0688 m
.76627 1.14995 L
s
.14957 .80835 m
.19047 .94528 L
s
.18404 .79687 m
.14957 .80835 L
s
.19047 .94528 m
.22518 .9344 L
s
.45386 1.01126 m
.51845 1.12013 L
s
.51845 1.12013 m
.70299 1.0688 L
s
.18404 .79687 m
.35519 .73985 L
s
.18404 .79687 m
.22518 .9344 L
s
.22518 .9344 m
.39753 .88041 L
s
.3309 .6033 m
.51353 .53904 L
s
.3309 .6033 m
.35519 .73985 L
s
.50509 .41782 m
.51353 .53904 L
s
.39753 .88041 m
.45386 1.01126 L
s
.45386 1.01126 m
.64027 .95639 L
s
.70299 1.0688 m
.64027 .95639 L
s
.35519 .73985 m
.39753 .88041 L
s
.54057 .67809 m
.35519 .73985 L
s
.39753 .88041 m
.58423 .82192 L
s
.54057 .67809 m
.51353 .53904 L
s
.64027 .95639 m
.58423 .82192 L
s
.58423 .82192 m
.54057 .67809 L
s
.25 Mabswid
.09401 .17347 m
.50657 0 L
s
.15034 .14978 m
.15669 .15719 L
s
gsave
.13763 .13498 -69.3611 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25349 .10641 m
.25964 .11398 L
s
gsave
.24117 .09129 -85.0399 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.3595 .06184 m
.36545 .06957 L
s
gsave
.34759 .04639 -80.0345 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.46849 .01601 m
.47423 .0239 L
s
gsave
.45702 .00023 -83.8823 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17074 .1412 m
.17453 .14567 L
s
.19126 .13258 m
.19503 .13706 L
s
.21189 .1239 m
.21563 .1284 L
s
.23263 .11518 m
.23635 .1197 L
s
.27445 .0976 m
.27813 .10215 L
s
.29554 .08873 m
.29919 .09331 L
s
.31674 .07982 m
.32036 .08441 L
s
.33806 .07085 m
.34166 .07547 L
s
.38105 .05278 m
.3846 .05743 L
s
.40273 .04366 m
.40625 .04834 L
s
.42453 .0345 m
.42802 .03919 L
s
.44645 .02528 m
.44992 .02999 L
s
.13004 .15832 m
.13387 .16274 L
s
.10985 .16681 m
.11371 .17121 L
s
.49066 .00669 m
.49407 .01144 L
s
.25 Mabswid
0 1.03666 m
.57632 1.49507 L
s
.01707 1.05023 m
.01809 1.04053 L
s
gsave
.01503 1.06963 -76.7145 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.17721 1.17761 m
.1779 1.16788 L
s
gsave
.17582 1.19707 -76.2332 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32032 1.29145 m
.32074 1.2817 L
s
gsave
.31949 1.31093 -65.6912 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.44899 1.39379 m
.44916 1.38404 L
s
gsave
.44865 1.4133 -71.9391 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5653 1.48631 m
.56526 1.47655 L
s
gsave
.56538 1.50581 -71.7058 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.0506 1.0769 m
.05117 1.07108 L
s
.08336 1.10296 m
.08389 1.09713 L
s
.11536 1.12841 m
.11585 1.12258 L
s
.14663 1.15329 m
.14709 1.14745 L
s
.2071 1.20139 m
.20748 1.19555 L
s
.23634 1.22464 m
.23668 1.2188 L
s
.26494 1.24739 m
.26525 1.24155 L
s
.29293 1.26966 m
.29321 1.26381 L
s
.34714 1.31278 m
.34736 1.30693 L
s
.3734 1.33366 m
.37359 1.32781 L
s
.39912 1.35412 m
.39927 1.34827 L
s
.42431 1.37416 m
.42444 1.36831 L
s
.47318 1.41304 m
.47326 1.40718 L
s
.4969 1.4319 m
.49695 1.42604 L
s
.52015 1.45039 m
.52017 1.44454 L
s
.54294 1.46852 m
.54294 1.46267 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{192.625, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400030000180P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000<1d0030M000`7@00<1d0030M000`7@00<1d
0030M000`7@00<1d0030M000`7@0051d0Q43M0034GAd008A0g@34@04M14A4Ead001?M0044GAd4@Ad
00@AM7@A0g@0115dM142M0034GAd05Ud001?M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd05Ud
001?M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd05Ud001?M0044GAd4@Ad00@AM7@A0g@00a5d
M0034Ead001?M0044GAd4@Ad00@AM7@A0W@24@=d00<AM7@0Fg@0051d0Q46M08A17@0115dM7@34@Id
0Q5CM000JG@24EEd0012M08A0g@00a5dM0024@=d0a4EM08A00=d4G@0E7@0045d00@AM7@A17@0115d
M143M0034GAd015d0a5IM000@G@0115dM144M0044GAd4@=d00<AM7@03g@24@=d00<AM7@0EW@0045d
00@AM7@A17@0115dM143M0034GAd00ad0a400g@AM01KM000@G@0115dM144M0044GAd4@=d00<AM7@0
2W@34F1d0011M0044GAd4@Ad00@AM7@A0W@24@Yd0Q5SM000@W@24@Id0Q44M0034GAd00Ed0a400g@A
M01RM000:g@24@=d00<AM7@00Q43M08A0W@34AMd0Q5XM000:W@0115dM144M0064GAd4G@A0W@00a5d
4@02M0034GAd019d0Q42M0034GAd06Ed000ZM0044GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@0
3g@44F]d000ZM0044GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@03G@24@Ad00<AM7@0J7@002Yd
00@AM7@A17@01Q5dM15d4@9d00<AM1400Q4=M0<A0W@00a5dM01/M000:W@0115dM144M0064GAd4G@A
0W@0115dM14<M08A00=d4G@0LG@002]d0Q46M08A0g@24@=d0a48M08AMW@004Ed0a42M0034GAd07=d
000YM08A67@24@03M15d07Qd000XM0044GAd4AAd0a5mM000:7@0115dM14BM08A0g@00a5dM01jM000
:7@0115dM14@M08A00=d4G@0Og@002Qd00@AM7@A3G@44H=d000XM0044GAd4@]d0Q67M000:G@24@Yd
0Q400g@AM026M000<W@44HYd000`M08ASW@002ed0a42M0034GAd08]d000[M08A00=d4G@0T7@002Ud
0Q6EM0009g@24@9d00<AM7@0TW@002Md00<AM7@0UW@002Md0a6FM0009g@00a5dM02FM0009g@00a5d
M02FM0009W@00a5dM02GM0004W@24@=d00<AM7@00Q42M0@A17@00a5dM02GM0004G@0115dM144M004
4GAd4@9d00<AM7@017@00a5dM02GM0002g@44@9d00@AM7@A17@0115dM143M0034GAd00=d0Q6HM000
4G@0115dM144M0044GAd4@=d00<AM7@00g@00a5dM02GM0004G@0115dM144M0044GAd4@Ad00<AM7@0
0W@00a5dM02GM0004G@0115dM144M0064GAd4G@A0W@00a5dM002M0034GAd04md1A53M0004W@24@Id
0Q43M08A1G@00a5dM01=M0<A17@54Cid000VM0034GAd04Yd1147M08A0W@00a5dM00kM0009W@24DUd
1146M0<A1G@00a5dM00jM0009G@24DMd1A46M08A2G@00a5dM00iM0009G@00a5dM013M0<A00Ed4A5d
4@03M0<A37@24CUd000UM0034GAd045d0Q4017@A4A42M0034GAd008A4G@00a5dM00fM0009G@00a5d
M00nM0<A00=d4A401G@34AAd00<AM7@0=G@002Ed00<AM7@0?7@24@04M14A4@Ed0a4FM08A=W@002Ed
0Q4jM0HA1W@24@03M15d01Ad0Q42M0034GAd03=d000UM0034GAd03Md0Q400g@A4@06M0<A0g@00a5d
M00@M0<A1G@00a5dM00bM0009G@00a5dM00dM0HA1W@24@Ed00<AM7@03W@34@Ud00<AM7@0<G@002Ed
00<AM7@0<G@64@=d1Q47M0034GAd00ad0Q4=M0034GAd031d000UM0034GAd02md1Q400g@AM002M0<A
00Ad4A4A1G@00a5dM00:M0<A3g@00a5dM00`M00097@00a5dM00]M0HA17@0115d4A44M0044GAd4@=d
0Q4:M08A4g@00a5dM00_M00097@24B]d0a4017@A4A45M0<A1g@00a5dM0034@03M15d00Id0a4FM003
4GAd02id000TM08A:7@34@9d0Q400g@AM002M0<A0W@00a5dM005M0@A00Ad4G@A17@34AYd00<AM7@0
;G@002Ad00<AM7@097@34@9d0a42M0034G@A008A1G@00a5dM003M0<A1G@24@9d0Q4NM0034GAd02ad
000TM0034GAd029d0Q42M0<A17@44@Qd00<AM7@00Q42M0034GAd00Ad0a4PM08A;G@002Ad00<AM7@0
7g@34@9d0Q45M0<A0g@00a5dM005M0<A1G@00a5dM0034@03M14A01id0Q400chA4@0/M00097@00a5d
M00LM0PA17@34@9d00DAM7Ad4@04M0@A1g@34@9d00DAM15d4@0JM0<A00<o?Sl00Q4/M00097@24AYd
1A4017@A4G@64@Ad00<AM7@00g@0115d4A44M0034GAd009d0a44M0034G@A009d00<AM7@05G@24@09
EciG?ULn4G@A02]d000TM0034GAd01Md2144M08A00Ad4A4A0g@00a5dM002M0<A1W@00a5d4@024@9d
00<AM7@00W@0115dM142M0034GAd015d0a402Cho?Sln?cho4@02M0034GAd02Qd000SM0034GAd01Id
3Q43M0034GAd00<A0W@34@9d00<AM7@017@24@Id00DAM7Ad4@02M0054GAdM14047@24@0<?ULnEciG
?ULnEchA0W@00a5dM00XM0008g@00a5dM00DM08A00Ad4A4A1G@00a5dM0034@=d00@AM7Ad0a45M004
4GAdM0<A00=d4G@01G@01A5dM7@A009d00<AM7@00W@00a5dM00:M0<A00ho?Sln?cho?Sln?cho4@=d
00<AM7@09g@000id0Q43M0034GAd008A0g@34@Ed00<AM7@04g@00a5d4@024@03M15d00Ed00<AM140
0W@24@03M15d00DA1W@34@Ad00<AM7@017@01A5dM7@A009d00<AM7@00g@00a5dM007M08A015G?ULn
EciG?ULnEciG?ULn4@03M0034GAd02Md000=M0044GAd4@Ad00@AM7@A0g@00a5dM004M0034GAd015d
1Q43M0034GAd00=d00@AM7@A0g@34@03M14A009d0Q42M0<A1g@00a5dM003M0054GAdM1400W@00a5d
M004M0034GAd00=d0a404cho?Sln?cho?Sln?cho?Sln?a4017@00a5dM00VM0001g@44@9d00@AM7@A
17@0115dM143M0034GAd00Ad00<AM7@047@24@=d00<AM1400W@00a5dM003M0054GAd4G@01A400g@A
4@03M0<A0g@00a5dM004M0034GAd00Ad00<AM1400g@00a5dM005M0034GAd008A01HnEciG?ULnEciG
?ULnEciG?ULnEchA1G@00a5dM00UM0003G@0115dM144M0044GAd4@=d00<AM7@017@24A1d00<AM140
0W@0115dM142M0034GAd00Ad00@AM14A17@34@05M14A4G@00Q43M0034GAd00Ed00<AM7@00g@00a5d
4@03M0034GAd00Ed0a4063ln?cho?Sln?cho?Sln?cho?Sln?cho4@Ed00<AM7@09G@000ed00@AM7@A
17@0115dM143M0034GAd00Ad00<AM7@03g@00a5d4@02M0054GAdM1400W@00a5dM002M0@A1G@24@03
M14A00=d00<AM1400g@00a5dM004M0034GAd00=d00<AM1400g@00a5dM002M0<A01ad4ELnEciG?ULn
EciG?ULnEciG?ULnEciG?ULA1G@00a5dM00TM0003G@0115dM144M0044GAd4@9d0Q46M0034GAd00id
00@AM7Ad0Q44M0044GAd4@9d0Q401G@AM7@A00Ad0Q4017@A4A42M0044GAd4@9d00<AM7@017@00a5d
M003M0<A17@44@Ad01/A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q401W@00a5dM00SM0003W@24@Id
0Q44M0034GAd00Ad00<AM7@03W@0115dM7@24@Ed00<AM1400Q44M0034G@A00Ad0Q400g@AM0024@9d
00@AM7@A0W@00a5dM004M0034GAd00<A00AL4A5d0a47M00K4ELnEciG?ULnEciG?ULnEciG?ULnEciG
?ULA00Id00<AM7@08g@002=d00<AM7@03G@00a5dM002M08A1G@44@Ed00<AM1401G@00a5d4@02M004
4GAd4@=d0a46M0<A00M7G4ML4E`A009d00<AM7@01G@06a4n?cho?Sln?cho?Sln?cho?Sln?cho?Sln
4@06M08A97@0029d00<AM7@03W@00a5dM002M08A0g@24@04M15d4@Ed00<AM1401G@0115dM142M003
4G@A00Ed0Q43M0<A1U`00a5L4@02M0034GAd00Ed01/AEciG?ULnEciG?ULnEciG?ULnEciG?ULnEa40
0g@34@03M15d02=d000RM08A3W@00a5dM002M0034GAd00<A0g@0115dM145M0034G@A00=d0Q42M003
4GAd00<A1W@44@0?G4MLAea7G4ML4Ea74G@A00Md01`A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q5d
0Q45M0034GAd025d000RM0034GAd00ed00<AM7@00W@44@Id00<AM1401G@00a5d4@03M08A0W@0115d
M7@34@=d0a4<G0044EaLG08A1g@06Q5G?ULnEciG?ULnEciG?ULnEciG?ULnEciG0Q47M0034GAd025d
000RM0034GAd00ad00@AM7Ad0a43M0034GAd00=d00<AM1401W@24@=d00DAM15d4@04M0034G@A008A
01ELAea7G4MLAea7G4MLAea74DMLAa401g@06a4n?cho?Sln?cho?Sln?cho?Sln?cho?Sln4@09M003
4GAd021d000RM0034GAd00ad11400g@A4@03M0034GAd00Ad00<AM1401G@24@=d00DAM15d4@04M0<A
4U`00a5LG002G0034GAd00Ad01/AEciG?ULnEciG?ULnEciG?ULnEciG?ULnEa402G@00a5dM00PM000
8W@00a5dM00;M08A17@24@Ad00<AM7@00g@00a5d4@05M0034G@A009d00HAM15d4G@34@0LAea7G4ML
Aea7G4MLAea7G4MLAea74DMLAea74@Ed01/A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q402W@00a5d
M00OM0008W@00a5dM00;M08A0g@0115dM143M0034GAd00Ad00<AM1401G@24@06M15dM15d0Q4HG003
4EaL00=L00<AM7@00g@06a5G?ULnEciG?ULnEciG?ULnEciG?ULnEciG4@0:M0034GAd01md000RM003
4GAd00]d0Q43M0054GAdM1400g@00a5dM003M0034G@A00Ed0Q400g@AM0034@0RG4MLAea7G4MLAea7
G4MLAea7G4MLAea7G4LAAea7G4ML4@Ad01/A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q402g@00a5d
M00NM0008W@24@]d00@AM7@A0W@01A5dM7@A00=d00<AM7@017@24@Ed1A4MG0034EaL00EL01lAM7Ad
4ELnEciG?ULnEciG?ULnEciG?ULnEciG?ULA00]d00<AM7@07W@0029d00<AM7@02W@01a5dM7@AM140
17@01A5dM7@A00Ed00<AM1400g@64@0WAea7G4MLAea7G4MLAea7G4MLAea7G4MLAea7G4LAAea7G4ML
Ae`A009d01/A?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Q4037@00a5dM00MM0008G@00a5dM00;M003
4GAd009d0Q45M0044GAd4@Id0Q400g@A4@02M0<A00=d4E`06e`00a5LG007G00M4G@AEciG?ULnEciG
?ULnEciG?ULnEciG?ULnEa4037@00a5dM00MM0008G@00a5dM00;M0034GAd009d00<AM7@017@01A5d
M7@A00Ed0a44M0<A0W@09a57G4MLAea7G4MLAea7G4MLAea7G4MLAea7G4LAAea7G4MLAea7G0024@0J
?Sln?cho?Q4n?cho?Sln?cho?Sln?cho?Q4=M0034GAd01ad000QM0034GAd00]d00<AM7@00W@24@Id
00@AM7@A0W@34@03M14A00Ed0Q43M0034EaL01QL00<AG5`025`24@0JEciG?ULnEciG?ULnEciG?ULn
EciG?ULnEa4=M0034GAd01ad000QM0034GAd00Yd00<AM7@00g@00a5d4@06M0034GAd008A17@24@Ed
1a40@4MLAea7G4MLAea7G4MLAea7G4MLAea7G4ML4Ea7G4MLAea7G4LA?Sln?cho?Sln?cho?Sln?cho
?Sln?cho?Q4>M0034GAd01]d000QM08A2g@00a5dM003M0034G@A00Id1146M08A0g@34@Ad0Q4IG003
4EaL00UL01XA?ULnEciG?ULnEciG?ULnEciG?ULnEciG4@id00<AM7@06g@0025d00<AM7@02W@00a5d
M003M0044GAd4@9d0a401G@AM7@A00Ed2A43M0114G@AAea7G4MLAea7G4MLAea7G4MLAea7G4ML4Ea7
G4MLAea7G4MLAa4n?cho?Sln?cho?Sln?cho?Sln?cho?Q403W@24Aad000QM0034GAd00Yd00<AM7@0
0W@00a5dM002M08A1G@00a5d4@05M0<A17@0115d4A42M0<A5e`00a5LG00;G00I4CiG?ULnEciG?ULn
EciG?ULnEciG?ULn4@0:M0<A00=d4G@06g@0025d00<AM7@02W@00a5dM002M0034G@A008A00=d4G@0
17@0115dM142M08A00=d4A4017@0115dM7@54@0FG4MLAea7G4MLAea7G4MLAea7G4MLA`8A02ILAea7
G4MLAea7G4MLAa4n?cho?Sln?cho?Sln?cho?Sln?cho4@Qd0Q45M0034GAd01Ud000QM0034GAd00Ud
00<AM7@00W@34@Ad00<AM7@017@01A5d4G@A009d0a44M08A17@24@03M15L015L0a400e`AG00=G00H
4ELnEciG?ULnEciG?ULnEciG?ULnEchA1G@34@Md00<AM7@06G@0021d00<AM7@02W@00a5d4@024@03
Aa4A00Ed00<AM7@017@00a5d4@03M0034G@A00Ed00<AM7@00W@34@0@M15LAea7G4MLAea7G4MLA`<A
02]7G4ML4Ea7G4MLAea7G4MLAea7G14o?Sln?cho?Sln?cho?Sln?cho?SlA009d0a4;M0034GAd01Qd
000PM0034GAd00Yd0Q44G0034E`A00Ed00<AM7@00g@24@04M15d4@9d0Q44M0034GAd00=d00DAM15d
4@0;G08A25`00a5LG00=G00E4ELnEciG?ULnEciG?ULnEciG?ULn00<A3W@00a5dM00HM00087@34@Yd
0Q4025a7G4LAAe`A17@00a5dM004M0054G@AM1400g@00a5dM002M08A17@03A5dM15d4Ea7G4MLAe`0
0a40<5a7G4MLAea7G4LAAea7G4MLAea7G4MLAea7G14o?Sln?cho?Sln?cho?Sln?cho4A1d00<AM7@0
67@0021d00<AM7@02W@00a5d4@03G0054EaLG14017@00a5dM002M0054G@AM14017@24@=d0Q44M004
4GAdM0<A0e`34@eL00<AG5`03e`0515G?ULnEciG?ULnEciG?ULnEchA4G@00a5dM00GM00087@00a5d
M00:M00<4GAd4Ea74DMLAe`A17@02A5dM7@AM15d4@05M0044GAdM08A17@00a5dM002M0DA03ILAea7
G4MLAea7G4MLAea74DMLAea7G4MLAea7G4MLAea74Cho?Sln?cho?Sln?cho?Sln?a4AM0034GAd01Md
000GM08A1g@00a5dM00:M0074GAdM15L4@05G0034GAd009d00<AM1400g@00a5d4@04M0044GAdM0<A
17@00a5dM0034@03Ea5L011L00<AG5`045`04a4nEciG?ULnEciG?ULnEciG?Q404G@00a5dM00GM000
5W@0115dM146M0034GAd00Yd00<AM7@00W@24@07Aea7G4ML4@03M0034G@A00=d0a45M0034GAd00<A
17@34@9d03XA?Q4AG4MLAea7G4MLAea7G4MLAa57G4MLAea7G4MLAea7G4MLAea74Cho?Sln?cho?Sln
?cho?SlA4W@00a5dM00FM0005W@0115dM146M0034GAd00Yd00<AM7@00g@00a5LG005G0054GAdM140
17@24@03M15d00=d00HAM7@AM142M0<A0g@34@03?Q4A011L00<AG5`04E`04A4nEciG?ULnEciG?ULn
EchA019d00<AM7@05W@001Id00@AM7@A1W@00a5dM00:M0034GAd00=d0Q4025a7G4MLAe`A0W@24@=d
00@AM14A17@24@03M15d00<A0W@44@0kM14n?a4o4Ea7G4MLAea7G4MLAea7G15LAea7G4MLAea7G4ML
Aea7G4MLAa4n?cho?Sln?cho?Sln?a404g@00a5dM00EM0005W@0115dM146M0034GAd00Yd00<AM7@0
0g@00a5d4@07G0044G@A4@=d00<AM7@00Q44M0HA00=d4A400Q43M0054ELn4Ch00Q4>G0034EaL01=L
00lA?ULnEciG?ULnEciG?Q404g@00a5dM00EM0005W@0115dM145M0034GAd00]d00<AM7@00g@0315d
M15LAea7G4ML4@9d00@AM7@A0W@24@9d2A42M08A0g@01A4n?a4o008A03=7G4MLAea7G4MLAea7G15L
Aea7G4MLAea7G4MLAea7G4MLAe`A?cho?Sln?cho?Sln?a404g@00a5dM00EM0005g@24@Id00<AM7@0
2g@00a5dM003M0054GAdM1401e`00a5dM0024@Ad0a42M0@A00=d4A400W@24@=d00PAEchA?Q5d4@eL
00<AG5`055`03Q5G?ULnEciG?ULnEchA57@00a5dM00DM0007g@00a5dM00;M0034GAd00=d00<AM7@0
0W@02Q5LAea7G15L4G@24@9d0Q400g@AM0064@05M14A4G@00Q43M0054Cho4Cl01140<DMLAea7G4ML
Aea7G15LAea7G4MLAea7G4MLAea7G4MLAea7G14o?Sln?cho?Sln?a4057@00a5dM00DM0007g@00a5d
M00;M0034GAd00=d00<AM7@00g@00a5LG005G0034G@A008A0W@34@=d0a400g@AM0034@09M15dM15G
?Q4n00<A00=d4E`02e`00a5LG00EG00<4ELnEciG?ULnEchA5G@00a5dM00CM0007g@00a5dM00;M003
4GAd00=d00<AM7@017@01Q5LAea7G0PA0W@0315dM7@AM15d4G@AM0<A0W@0214n?a4o4G@A0W@0<157
G4MLAea7G4MLAa57G4MLAea7G4MLAea7G4MLAea7G4MLAe`A?cho?Sln?cho4AAd0Q4EM0007g@00a5d
M00;M0034GAd00=d00<AM7@01G@00a5L4@024@=L0Q46M0044GAdM08A0W@24@04M15d4@9d00LAEchA
?Q5d008A0W@00a5LG008G0034EaL01IL00/A?ULnEciG?ULn4@0AM0<A00=d4G@057@001md0Q4<M003
4GAd00=d00<AM7@017@34@06G4MLAea70a45M08A0W@34@03M15d008A00=d4A400a401ClA?a5d008A
0W@24@0]Aea7G4MLAea74DMLAea7G4MLAea7G4MLAea7G4MLAea7G4LA?Sln?cho?SlA00id0a45M003
4GAd019d000OM0034GAd00]d00<AM7@00g@00a5dM002M08A0g@00a5LG003G0044E`A4@Ed00@AM7Ad
0Q402G@AM15d4G@AM0024@03?Q4n008A0W@01A5d4G@A00QL00<AG5`065`02A4nEciG?ULn4@0;M0<A
27@00a5dM00BM0007g@00a5dM00;M0034GAd00=d00<AM1400Q45M08A00MLAea74DML008A17@24@9d
11401g@AM15d4G@011400clA4@02M00b4G@AM15LAea7G4MLAa57G4MLAea7G4MLAea7G4MLAea7G4ML
Aea7G4LA?Sln?cho?Q46M0@A2g@00a5dM00BM0007g@00a5dM00;M0034GAd009d0a48M0034G@A00=L
00<AG5`00Q45M08A00Md4A4AM15d00@A00Id4A4n4Ch24@=d00DAM7Ad4@08G0034EaL01UL00PA?ULn
EciG4@=d0a4?M0034GAd019d000NM0034GAd00ad00<AM1400Q4017@A4A47M00:4GAd4Ea74DMLA`8A
17@24@9d00DAM14AM0024@03M14A008A00<o4A400Q43M08A0g@0:a5LAea7G4ML4Ea7G4MLAea7G4ML
Aea7G4MLAea7G4MLAea7G14o?Sln?ch0114CM0034GAd015d000NM0034GAd00ad0Q44M0034GAd008A
1G@01a5dM7@AG14015`24@Ad0Q400g@A4@054@03M15d008A00<n4Ch00Q43M0LA0e`0115L4A4LG007
4ELnEciG4@0FM0034GAd015d000NM0034GAd00ad0a43M0034GAd009d0Q43M0034GAd009d0Q401TML
Aea74@Ad00@AM14A0W@0115d4A42M0@A00@n4A5d0Q401g@A4A5d4G@00Q40:E`A4A5L4Ea7G4MLAea7
G4MLAea7G4MLAea7G4MLAea7G4ML4Cln?chA01Id00<AM7@04G@001id0Q4=M0034GAd008A0W@00a5d
M003M0044GAd4@Ed00<AG5`015`00a5dM002M0034G@A00@A00Ad4A5d0a401ChA4A5d00<A0W@74@AL
0Q4MG0054ELnEa405W@00a5dM00AM0007W@00a5dM00=M0044GAdM0<A1W@34@Ed0Q401ea7G4MLAa40
0g@00a5d4@024@05M15d4G@011400cln4@024@9d1a40:g@A4A5LAea74DMLAea74DMLAea7G4MLAea7
G4MLAea7G4MLAea7G14o?Q405g@00a5dM00@M0007W@00a5dM00=M0034GAd00=d00<AM7@01W@24@Ad
00<AM1401U`01a5d4G@AM1400W@01A5d4A5d00<A00<nEa401A4017@A4A43M0044G@A4@=L00<AG5`0
7E`00a5G4@0GM0034GAd011d000NM0034GAd00ed00<AM7@00g@34@Id00@AM14A0W@02Q5dM15LAea7
G4L24@03M15d008A00=d4A400Q42M0044ChA?P<A00Ud4A4AM15d4G@00Q40:G@A4DMLAe`AG4MLAea7
G4MLAea7G4MLAea7G4MLAea7G4MLAea74ChA01Md00<AM7@047@001id00<AM7@03G@00a5dM003M003
4GAd008A17@0115dM7@34@=d00<AG5`00e`0115dM7@34@9d00DAM14AM0044@03?Q4A008A0W@00a5d
M0044@04M15d4@=L00<AG5`07E`24AQd00<AM7@03g@001id00<AM7@03G@00a5dM003M0034GAd009d
0Q42M0034GAd00=d00<AM7@00W@01a5LAea7G1400W@24@03M15d00HA00<n4A400Q42M0034G@A00Ad
00<AM1400W@09a5d4DML4Ea7G4MLAea7G4MLAea7G4MLAea7G4MLAea7G4MLAea74@0HM0034GAd00md
000MM0034GAd00id00<AM7@00g@00a5dM004M0<A1G@34@=d00<AG5`00e`01A5d4A5d00HA00Md4A4A
EchA009d0a43M08A00=d4A400Q42M0044EaL4AaL00=G?UL00Q4GM0034GAd00md000MM08A47@00a5d
M002M0034GAd00Id00<AM7@00g@00a5dM0024@9d00HAG4MLAe`74@03M14A00@A00<n?a400W@24@=d
00<AM1400W@0115d4A42M00U4DLAAea7G4MLAea7G4MLAea7G4MLAea7G4MLAcln?cho?Q574@0FM003
4GAd00md000MM0034GAd00md00<AM7@00g@00a5dM005M0<A0g@00a5dM002M0044GAd4@EL0a400g@A
4@024@03M14A008A00IG?Q5d4G@24@03M15d009d00<AM1400W@24@9d0Q4FG00:EciG?ULnEciG4@9L
00<AM7@057@00a5dM00>M0007G@00a5dM00?M0034GAd00=d00<AM7@01G@00a5dM0024@9d00<AM7@0
0W@24@06M15LAea73A400cho4@034@04M15d4@=d00<AM1400W@00a5d4@044@0RG4MLAea7G4MLAea7
G4MLAea7?cho?Sln?cho?Sln4DML4AEd0Q4@M0007G@00a5dM00?M0034GAd00=d00<AM7@01W@01a5d
M7@AM1401W@34@09G14A4E`AM15d00LA00=G?Q400Q43M0034GAd00=d0Q43M0<A0W@00a5LG00=G00@
EciG?ULnEciG?ULnEciG4@=L00<AM7@03g@34@03M15d00md000MM0034GAd00md00<AM7@00g@00a5d
M006M0034GAd009d0Q46M0@A00MLAa57G15d00<A00Ed4A4A?`0:4@Ad00@AM15d0Q42M0<A02ALAea7
G4MLAea7G4Lo?Sln?cho?Sln?cho?Sln?chAAea7G14=M0<A17@00a5dM00>M0007G@00a5dM00@M003
4GAd009d00<AM7@01W@00a5dM003M0<A00Md4A4AM15d008A0U`00a5L4@024@03M15d008A00IG4A4A
M143M0034G@A00XA17@24@QL01IG?ULnEciG?ULnEciG?ULnEciG?ULA1E`00a5dM007M0<A27@00a5d
M00=M0007G@00a5dM00@M0034GAd009d00<AM7@01W@00a5dM003M0@A17@0115dM7@34@03G15L00dA
00Ed4GAd4@05M08A0W@94@0SAea7?cho?Sln?cho?Sln?cho?Sln?cho?Sln4DMLAea7G14017@44@]d
00<AM7@03G@001ed00<AM7@047@00a5dM002M0034GAd00Id00@AM7Ad0a43M08A0W@00a5dM002M08A
0U`00a5L4@0;4@03M15d009d00<AM7@00a401G@AM7@A00Ad0a4075LnEciG?ULnEciG?ULnEciG?ULn
EciG?ULnEa47G0@A3g@00a5dM00=M00077@34A5d00<AM7@00g@00a5dM006M0<A0W@00a5dM003M0<A
1G@44@03Ae`A008A00<o4A400Q4017@A4A44M0@A00Ad4G@A0W@00a5dM0054@0U?Sln?cho?Sln?cho
?Sln?cho?Sln?cho?Sln4DMLAea7G4ML4@0AM0034GAd00ed000LM0034GAd015d00<AM7@00g@00a5d
M002M0DA17@00a5dM005M0034GAd00=d0Q400e`A4@02G0PA00=d4A400g@34@Ad0Q400g@A4@074@0L
EciG?ULnEciG?ULnEciG?ULnEciG?ULnEciG4@QL00<AM7@03g@00a5dM00=M00077@00a5dM00AM003
4GAd00=d00<AM1400Q44M0034GAd00=d00<AM7@017@34@=d00XAM14AAa57G14o1A4017@A4G@54@Ad
0a42M08A0W@34@0V?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Sln?a5LAea7G4MLAa4AM0034GAd00ad
0007M08A0g@00a5dM0024@=d0a45M0034GAd019d00@AM7Ad1A45M0034GAd00=d00<AM7@017@00a5d
M0024@9d00DAM14AG0024@03G14A00DA00=d4A400Q43M0DA00=d4A400Q43M0<A01eG?ULnEciG?ULn
EciG?ULnEciG?ULnEciG?ULn4@09G0034GAd00id00<AM7@037@000Id00@AM7@A17@0115dM143M003
4GAd00Ad00<AM7@04W@01Q5d4A5d4@=d2143M0034GAd00Ad00<AM7@00W@34@9d00HAG4ML4E`94@=d
0a43M0034G@A009d00@AM7Ad0a40:3ho?Sln?cho?Sln?cho?Sln?cho?Sln?cho?SlAG4MLAea7G4ML
Aa4?M0034GAd00ad0006M0044GAd4@Ad00@AM7@A0g@00a5dM004M0034GAd019d2147M0034G@A00TA
00=d4G@017@24@03M14A00=L1Q400g@A4@044@9d00@AM7Ad0a43M0044G@AM08A01eG?ULnEciG?ULn
EciG?ULnEciG?ULnEciG?ULn4@0;G0034GAd00ad00<AM7@037@000Id00@AM7@A17@0115dM143M003
4GAd00Ad00<AM7@04W@00a5dM003M0034G@A00dA1G@=4@04G4MLA`TA17@0215d4A5d4G@A0W@0115d
4G@24@0Z?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Sln?a5LAea7G4MLAea7G4LA3W@00a5dM00;M000
1W@0115dM144M0044GAd4@=d00<AM7@017@24AAd00<AM7@00W@00a5dM006M0034GAd00=d3Q43M0lA
17@24@=d00<AM1400W@24@9d0a4073iG?ULnEciG?ULnEciG?ULnEciG?ULnEciG?Q4<G0034GAd00ad
00<AM7@02g@000Id00@AM7@A17@0115dM142M08A1W@00a5dM00CM0034GAd00=d00<AM7@01W@00a5d
M002M0034GAd00Ad00<AM7@017@74@03?chA00@A0W@<4@9d00@AM7@A0W@34@0Z?cho?Sln?cho?Sln
?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4MLAe`A3G@00a5dM00;M0001g@24@Id0Q44M0034GAd00Ad
00<AM7@04g@00a5dM003M0034GAd00Id00<AM7@00W@00a5dM005M0034GAd00=d00@AM7Ad1A400chA
4@0<4@Ad2a4073iG?ULnEciG?ULnEciG?ULnEciG?ULnEciG?Q4>G0034GAd00Yd00<AM7@02g@001ad
00<AM7@057@00a5dM002M0034GAd00Id00<AM7@00g@00a5dM004M0034GAd00=d00<AM14011400cln
4@054@04M14A4@Ad2a40<G@AM14n4Cho?Sln?cho?Sln?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4ML
Aea7G1402g@00a5dM00;M0006g@00a5dM00EM0034GAd009d00<AM7@01W@00a5dM003M0034GAd00Ed
00<AM7@00W@24@9d0a400ciG4@0:4@=d00<AM7@011400g@AM0054@0MEa5G?ULnEciG?ULnEciG?ULn
EciG?ULnEciG?Q403e`00a5dM00:M0034GAd00Yd000KM0034GAd01Ed00<AM7@00g@00a5dM006M003
4GAd009d00<AM7@01G@0115dM7@74@03?SlA00HA00EL4G@AM0064@9d00@AM14A0W@24@0`M14n?a4o
?Sln?cho?Sln?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4MLAea7G4LA2g@00a5dM00:M0006g@00a5d
M00EM0034GAd00=d00<AM7@01W@00a5dM003M0034GAd00Ed0a42M0034G@A008A00=G?Q401A400e`A
G0084@Ad0Q400g@AM0024@0OM15G?Q4nEciG?ULnEciG?ULnEciG?ULnEciG?ULn4@0AG0034GAd00Md
0Q4<M0006g@00a5dM00FM0034GAd009d00<AM7@01W@00a5dM003M0034GAd00Ed00<AM7@011401W@A
4ChA?P@A00=L4A401144M0034GAd009d00DAM7@AM0024@0bM14n?a4o?Sln?cho?Sln?cho?Sln?cho
?Sln?cho4Ea7G4MLAea7G4MLAea7G4MLAa44M0@A00=d4G@02g@001]d0Q4GM0034GAd00=d00<AM7@0
1G@00a5dM004M0034GAd009d1A43M0034G@A008A00<n4A401A401E`AG5`A00Ad0a42M0044GAdM08A
0W@07Q5G?ULAEciG?ULnEciG?ULnEciG?ULnEciG?ULn4A=L1145M0034GAd00Yd000KM0034GAd01Id
00<AM7@00g@00a5dM006M0034GAd00=d00<AM7@00Q4017@A4A43M0<A00=d4A401A402G@AAa574DML
4@03M0034GAd00<A0g@54@0a?Sln4Cho?Sln?cho?Sln?cho?Sln?cho?Sln?a5LAea7G4MLAea7G4ML
Aea7G4ML4@09M0034GAd00Ud000KM0034GAd01Md00<AM7@00W@00a5dM006M0034GAd00=d0a400g@A
4@02M0044GAd4@9d00<AM1402Q42G0@A0W@01A5dM15d008A00=d4A400Q407g@AEciG?Q4nEciG?ULn
EciG?ULnEciG?ULnEciG?Q4055`00a5dM006M0034GAd00Ud000KM0034GAd01Md00<AM7@00g@00a5d
M005M0034GAd00=d1144M0054GAd4G@01Q400chA4@034@08M157G15L4E`34@9d00<AM1400Q42M08A
03Ed4Cho?SlA?cho?Q4n?cho?Sln?cho?Sln?cho?SlAG4MLAea7G4MLAea7G4MLAea7G4ML4@07M003
4GAd00Ud000KM0034GAd01Md00<AM7@00g@00a5dM005M0044GAdM08A00=d4G@01G@54@07M14A?ULA
E`034@05M15dM1400U`0115L4E`64@03M15d00@A01md4ELnEchA?Q4nEciG?ULnEciG?ULnEciG?ULn
EchA01IL00<AM7@017@00a5dM009M0006W@00a5dM00IM0034GAd009d00<AM7@01W@34@04M14A4@Ad
1A42M0<A00@o?Q4n0a4017@A4G@24@06Ae`A4DML1142M0034GAd00DA03Dn?a4o?Q4n?cho?Sln?cho
?Sln?cho?Sln?cho4Ea7G4MLAea7G4MLAea7G4MLAea7G4ML4@05M0034GAd00Ud000JM0034GAd01Ud
00<AM7@00W@00a5dM006M0044G@A4@=d1143M0044GAdM0<A00<n4Ch01A402g@AM15d4E`AG15L008A
0W@24@04M15d4@9d0Q407ELnEciG4ELnEciG?ULnEciG?ULnEciG?ULnEchA01ML00<AM7@00g@00a5d
M009M0006W@00a5dM00IM0034GAd00=d00<AM7@00g@44@=d0a45M08A0g@0215d4ClA?a5d0a4027@A
4G@AM1570Q4015`AG143M0PA03Hn?cho?SlA?cho?Sln?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4ML
Aea7G4MLAea7G4MLAa45M0034GAd00Qd000JM08A6W@00a5dM003M0044GAdM0@A00=d4A400Q43M003
4GAd009d00@AM15d0Q401G@A4A4n00DA00=d4G@00Q4017@A4E`34@9L00<AM1401142M08A01eG?ULn
EchA?ULnEciG?ULnEciG?ULnEciG?ULn4@0IG0034GAd009d00<AM7@027@001Yd00<AM7@06W@00a5d
M002M0034G@A00LA1W@01A5dM7@A009d00TAM15d4ChA?Sl00a401g@AM15d4G@00Q401W@A4A57G0<A
0W@01A5d4A5d008A03Pn?cho?Sln4Cho?Sln?cho?Sln?cho?Sln?cho4Ea7G4MLAea7G4MLAea7G4ML
Aea7G4MLAea74@=d00<AM7@027@001Yd00<AM7@06W@00a5dM003M0DA17@00a5dM004M0044GAd4@9d
010AM15d4ELAEchAM15d4G@A0W@24@=d1143G0044G@A4@9d0a407ELnEciG?ULAEciG?ULnEciG?ULn
EciG?ULnEchA01]L00@AM7@A2W@001Yd00<AM7@06W@0115dM7@44@Md00<AM7@017@00a5d4@04M008
4GAd4ChA?Sl34@06M14AM15d21401Ea7G4ML00<A0g@24@0l?Sln?cho?Q4n?cho?Sln?cho?Sln?cho
?Sln?chAAea7G4MLAea7G4MLAea7G4MLAea7G4MLAea74G@A2W@001Yd00<AM7@06g@44@03M15d00Qd
00<AM7@00g@00a5d4@03M08A0W@01A5G4A4n008A00Ed4A4AM0054@9d00@AM14A15`34@=d0Q407ULn
EciG?ULn4CiG?ULnEciG?ULnEciG?ULnEciG4@=L00<AG5`05E`00a5d4@0:M0006W@00a5dM00KM08A
17@00a5dM006M0034GAd00Ad00<AM7@00W@24@9d00<A?Q400Q400g@AM0054@06M15d4G@A0g@01Q57
G4MLA`8A0g@24@0m?Sln?cho?SlA?cho?Sln?cho?Sln?cho?Sln?chAAea7G4MLAea7G4MLAea7G4ML
Aea7G4MLAea7G15d4@09M0006W@00a5dM00KM0034GAd00=d00<AM7@01W@00a5dM003M08A0g@01A5d
4A5d008A00@nEa5d11401G@A4G@A009d0Q44M0034EaL009L0Q43M08A01iG?ULnEciG?ULAEciG?ULn
EciG?ULnEciG?ULnEa4MG08A2G@001Ud00<AM7@07G@00a5dM003M0034GAd00Id00<AM7@00W@00a5d
4@02M0034G@A008A00@o4Cln0a42M0034G@A008A0g@00a5dM003M08A00I7G4LAAa42M08A00Pn?cho
?Sln?`8A034n?cho?Sln?cho?Sln?cho?Sln4DMLAea7G4MLAea7G4MLAea7G4MLAea7G4MLAea7008A
2G@001Ud0Q4NM0034GAd00=d00<AM7@01W@01A5dM7@A009d00DAM15d4@02M0054ChA?UL00a42M003
4GAd008A00=d4A400Q45M08A0U`01A5LG15d008A00AG?ULn11405ULn4CiG?ULnEciG?ULnEciG?ULn
Ea4IG0@A00=d4G@027@001Ud00<AM7@07W@00a5dM003M0034GAd00Id00@AM7@A0g@24@09M15dM14o
4Cln00@A00Ad4A5d0a400g@AM0024@Ed0Q401DLAAea700<A03<n4A4A?Sln?cho4Cln?cho?Sln?cho
?Sln?cho?Q57G4MLAea7G4MLAea7G4MLAea7G4L01145M0034GAd00Md000IM0034GAd01id00<AM7@0
0g@00a5dM006M0034G@A00Ad00@AM7@A0W@01a4n4CiG4G@00Q400g@A4@034@9d00DAM15d4@04M0@A
0e`44@0L?ULnEciG?ULnEa5G?ULnEciG?ULnEciG?ULnE`8A45`44@Ud00<AM7@01g@001Ud00<AM7@0
7g@00a5dM003M0034GAd00Id0Q43M08A0W@02Q5dM14o4Cln4G@64@04M15d4@=d0Q45M0HA02mL4A4n
?cho?Sln?cho?Q4n?cho?Sln?cho?Sln?cho?Q5d4DMLAea7G4MLAea7G0034@ed00<AM7@01g@001Ud
00<AM7@07g@00a5dM003M0034GAd00Id00<AM7@00W@01A5d4G@A009d00LA?Q4nEa5d008A00Ad4G@A
0W@24@=d00<AM14017@44@=L0Q407ULnEciG?ULnEciG?Q4nEciG?ULnEciG?ULnEciG4@9d00<AG5`0
1E`44A1d00<AM7@01g@001Ud00<AM7@07g@00a5dM004M0034GAd00Ad00<AM1400W@01Q5dM15d4@9d
0Q400cho?P044@07M15dM15d4@05M0034G@A00<A00Md4A5d4DML008A01hn?cho?Sln?cho?SlA?cho
?Sln?cho?Sln?cho?Q43M0034DML00@A57@00a5dM007M0006G@00a5dM00PM0034GAd00=d00<AM7@0
17@00a5d4@02M0054GAdM1400g@24@07EciG4G@AM0024@9d00@AM14A0g@34@03M15d009d0a400g@A
G0024@0NEciG?ULnEciG?ULnEa5G?ULnEciG?ULnEciG?ULA0g@34AQd00<AM7@01g@001Ud00<AM7@0
87@00a5dM003M0034GAd00=d00@AM7Ad0Q44M0044GAdM08A00Xn?chAM15d4G@A0W@00a5d4@034@9d
00<AM1400g@34@9d0a407Cho?Sln?cho?Sln?chA?Sln?cho?Sln?cho?Sln00@A00=d4G@067@00a5d
M007M00067@34B9d00<AM7@00g@01A5dM7@A00Ad0Q44M08A0W@24@0;EciG4G@AM15d4G@01A44M007
4GAd4G@AM0034@9d0Q407ULnEciG?ULnEciG?ULn4CiG?ULnEciG?ULnEciG4@Ad00<AM7@05g@00a5d
M007M00067@00a5dM00RM0034GAd00=d00DAM7Ad4@04M08A17@24@9d0Q401Sho?Q5d4@9d0a42M0<A
1G@00a5dM0024@03M15d008A025d4A4n?cho?Sln?cho?Sln?a4o?Sln?cho?Sln?cho?Q4017@00a5d
M00GM0034GAd00Md000HM0034GAd02=d00<AM7@00g@00a5d4@04M0044GAd4@=d00@AM15d0Q400eLn
E`074@=d00@AM14A17@01a5dM7@AM1400W@44@0NEciG?ULnEciG?ULnEciG4ELnEciG?ULnEciG?ULA
17@00a5dM00GM0034GAd00Md0003M08A0g@00a5dM0024@9d1145M0034GAd02=d00<AM7@00g@00a5d
4@04M0044GAd4@=d00LAM15d4Cln00DA0W@24@Ad0a45M0064GAd4G@A0g@34@0N?Sln?cho?Sln?cho
?Sln4Cho?Sln?cho?Sln?chA17@00a5dM00GM0034GAd00Md0002M0044GAd4@Ad00@AM7@A0W@00a5d
M005M0034GAd02=d00<AM7@017@00a5dM002M0034GAd009d00<AM1400g@44@03?Q5d008A0g@00a5d
M002M08A00=d4G@00g@00a5dM0034@=d0a407ULnEciG4ELnEciG?ULnEchA?ULnEciG?ULnEciG4@Ad
00<AM7@05g@00a5dM007M0000W@0115dM144M0044GAd4@=d00<AM7@017@0115dM14SM0034GAd009d
0Q43M0034GAd00Ad0Q400g@A4@024@05?cho4G@00Q43M0034GAd00=d0a45M0054G@AM1400g@34@0N
?Sln?cho?Sln?cho?Sln?a4o?Sln?cho?Sln?chA17@00a5dM00GM0034GAd00Md0002M0044GAd4@Ad
00@AM7@A0g@00a5dM005M0034G@A02=d00<AM7@00W@00a5d4@02M0034GAd00Ad0a42M08A00DnEchA
M0024@=d0Q44M08A00=d4G@00g@24@04M15d4@9d0a407ULnEciG?ULnEciG?ULnEciG4ELnEciG?ULn
EciG4@Ad00<AM7@05g@00a5dM007M0000W@0115dM144M0044GAd4@Ad00<AM7@01G@24BAd00@AM7@A
0W@00a5d4@03M0@A00=d4G@00W@24@05?cho4G@00Q44M0034GAd00=d00<AM1401G@0115d4G@44@0P
M14n?cho?Sln?cho?Sln?cho?Q4n?cho?Sln?cho?Q44M0034GAd01Id0Q49M0000W@0115dM144M006
4GAd4G@A0W@00a5dM007M0034GAd025d00<AM14017@54@Ed00@AM7Ad0a401eLn4G@AM1400g@00a5d
M003M0044GAd4@Ad11400g@A4@02M00N4ELnEciG?ULnEciG?ULnEciG?Q4nEciG?ULnEciG0Q43M003
4GAd019d11400g@AM008M0000g@24@Id0Q43M08A2g@00a5dM00QM08A00=d4A400a48M08A0W@02Q4n
4Cho4G@AM143M0034GAd00Ad00@AM15d1A43M08A0W@08A4n?cho?Sln?cho?Sln?cho?SlA?cho?Sln
?cho?Q5d4@02M0034GAd00id1145M0034GAd00Md000NM0034G@A021d0a44M0034GAd00Ed00<AM140
0W@02Q5G?Q4n4G@AM143M0034GAd00Ad1143M08A0g@24@9d01<AEciG?ULnEciG?ULnEciG?ULn008A
00aG?ULnEciG?ULAM142M0034GAd00Yd1149M0034GAd00Md000OM08A8G@00a5dM003M0034GAd00Ed
00/AM7@AM14n?a4o4@02M08A0g@24@=d114017@AM7@24@04M15d4@9d014AM14n?cho?Sln?cho?Sln
?`044@0A?SlA?cho?Sln?cho4G@AM1402G@34@ad00<AM7@027@0025d00<AM7@07W@00a5dM004M003
4GAd00Ad00TAM7@AM15G?UL00Q42M08A17@44@=d00HAM7@AM142M0034G@A00=d0Q402eLnEciG?ULn
EciG00<A015G?ULnEciG4ELnEciG?ULn4@02M08A1G@44@md00<AM7@027@0029d00<AM7@07W@00a5d
M004M0034GAd00=d00TAM7@AM14n?ch00Q42M08A00=d4A400Q46M08A00Ad4G@A0g@00a5dM002M08A
00Ln?cho?Sln00@A01@o?Sln?cho?Sln?a4o?Sln?cho4@9d0Q400g@A4@024A=d00<AM7@027@002=d
00<AM7@07G@00a5dM004M0034GAd009d00<AM7@00W@24@06EciG?Q5d1143M08A1G@24@9d0Q42M003
4G@A00Ad00DAEciG?P034@0H?ULnEciG?ULnEciG?ULn4CiG?ULnEchA0W@34AMd00<AM7@027@001Ad
0Q43M0034GAd008A0W@74Aed00<AM7@017@01A5dM7@A00Ad0Q4013ho?Sl24@03M14A00Ad0Q46M0<A
00Ad4G@A0W@00a5dM002M0034ChA008A01Xn?cho?Sln?cho?Sln?cho?Sln4Cho?Sln?`<A00=d4G@0
5g@00a5dM008M0004g@0115dM144M0044GAd4@9d00<AM7@00W@00a5dM00LM0034GAd00Ad00@AM7@A
17@24@04EciG?P8A00=d4A4017@24@Id0Q42M08A17@00a5d4@034@0N?ULnEciG?ULnEciG?ULnEciG
?ULnEchA?ULnEchA0g@00a5dM00FM0034GAd00Qd000>M0@A00Ed4GAd4@04M0044GAd4@=d00<AM7@0
0W@00a5dM00KM0034GAd00Ad00@AM7@A17@24@04?Sln?`8A00=d4A4017@00a5d4@04M08A00Ed4A5d
4@03M0<A0W@0814n?cho?Sln?cho?Sln?cho?Sln?cho?Sln4Cho?SlA0W@00a5dM00FM0034GAd00Ud
000CM0044GAd4@Ad00@AM7@A0g@00a5dM003M08A77@00a5dM004M08A1G@24@06EciG?Q5d0a44M003
4G@A00=d00<AM7@00a400g@A4@024@9d02<AM7@AEciG?ULnEciG?ULnEciG?ULnEciG?ULnEchA?ULn
4@02M0034GAd01Id00<AM7@02G@001=d00@AM7@A17@0115dM144M0034GAd00Ad0Q4JM0034GAd00Ad
0Q44M00:4G@A?Sln?chAM08A1G@24@9d00<AM7@01A400g@AM004M00R4G@A?Sln?cho?Sln?cho?Sln
?cho?Sln?cho?Sln4Cho4@9d00<AM7@05G@24@]d000CM0044GAd4@Ad00HAM7@AM142M0034GAd00Ed
00<AM7@06G@00a5dM004M0034GAd009d00XAM15G?ULnEa5d0Q45M0034G@A00DA00Ad4G@A0W@00a5d
M003M00Q4G@A?ULnEciG?ULnEciG?ULnEciG?ULnEciG?ULAEchA009d00<AM7@04G@44@03M15d00Yd
000DM08A1W@24@=d0Q49M0034GAd01Ud00<AM7@00g@24@=d00TAM14n?cho?Q400W@34@=d1145M006
4GAd4G@A1G@08a5d4Cln?cho?Sln?cho?Sln?cho?Sln?cho?Sln?a4o4G@A015d0a44M0034GAd00Yd
000]M08A6G@00a5dM002M0034G@A00=d00TAM7@A?ULnEa400W@00a5d4@054@03M15d00Ed00HAM7@A
M145M08A01`nEciG?ULnEciG?ULnEciG?ULnEciG?ULnEciG0Q400g@AM00=M0<A1g@00a5dM00:M000
;g@24AQd00DAM7Ad4@02M0044GAd4@9d00DA?cho?P074@=d00<AM1401W@01a5dM7@AM14017@24@0L
?cho?Sln?cho?Sln?cho?Sln?cho?Sln?cho?P8A00=d4G@02G@44@Ud00<AM7@02g@0031d00<AM7@0
5g@0115dM143M08A0g@00a4n4@034@04M14A4@Ed00@AM7@A1W@0115dM7@24@Ed01TA?ULnEciG?ULn
EciG?ULnEciG?ULnEciG00@A00Ad4A4A1g@34@ed00<AM7@02g@0035d00<AM7@05W@0115dM143M08A
00=d4A400Q401Cho?SlA009d0Q45M0044GAd4@Id00@AM7Ad0Q44M00F4Cln?cho?Sln?cho?Sln?cho
?Sln?`<A1G@44@=d0a4?M0034GAd00ad000bM08A00=d4G@057@24@Ad0a42M0074CiG?ULn4@02M08A
1G@0115dM146M0044GAdM08A17@04a4nEciG?ULnEciG?ULnEciG?UL00a400g@AM006M0034G@A00<A
4W@00a5dM00<M000=7@24AEd0Q4017@A4A42M00:4GAd4Cln?cho4@=d00<AM7@017@0115dM146M004
4GAdM08A0g@03a4o?Sln?cho?Sln?cho?P044@Ad00<AM7@00g@44@9d00<AM7@047@00a5dM00=M000
=G@00a5dM00DM08A1W@02A5d4CiG?ULn4@03M08A1G@01A5dM7@A00Ed00<AM7@00W@24@9d00`A?ULn
EciG?ULnEch34@03M15d00Ed00<AM1400a400g@AM004M0034GAd00id0Q4?M000=W@00a5dM00DM003
4GAd00Ed0Q401Sln?cho4@Ad00<AM7@017@0115dM146M0034GAd009d00`AM7@A?cho?Sln?ch34@Ad
00<AM7@00W@44@Ed00<AM7@017@24@Yd1A4@M000=g@24AEd00<AM7@01G@24@05EciG?Q401G@00a5d
M003M0054GAdM1401W@00a5dM002M0074G@A?ULnE`054@Id1A43M0034GAd009d00<AM7@01g@00a5d
M004M0<A0W@24A5d000iM08A57@00a5dM005M0074Cho?Sln4@04M0034GAd00Ad00DAM7Ad4@05M003
4GAd00=d0Q400clA4@024@04M15d4@=d1A46M0034GAd009d00<AM7@01g@74@Ad00<AM7@04G@003Yd
00<AM7@04g@00a5dM004M08A00DnEciG4@04M08A1W@0115dM146M0044GAdM0DA0W@24@9d1144M003
4GAd00Ed00@AM7@A1W@;4@=d00<AM7@04W@003]d00<AM7@04g@00a5dM003M08A00Do?Sln4@05M08A
1G@01A5dM7@A00Ed1142M0<A0W@54@Md00<AM7@01G@0115dM142M0PA1g@34AEd000lM08A57@00a5d
M002M0064ELAEciG0Q44M08A1W@01A5dM15d00@A00=d4G@00g@24@04M14A4@=d00<AM7@01G@00a5d
M005M0034G@A00<A00Ad4A4A1g@44AQd000nM08A4W@00a5dM002M0064Cho4Cln0Q45M08A1G@54@Id
00<AM7@00W@24@03M14A00=d00<AM7@01W@00a5dM003M0PA1W@44Aad000oM0034GAd015d00dAM7Ad
4ELnEa5G4G@A00Ad0Q42M0DA0g@00a5dM003M0054GAdM1400g@34@=d00<AM7@01G@00a5d4@074@Id
114PM000<7@24@=d00<AM7@00Q43M0DA4W@02Q5dM14n?cho4Cl24@Ad1144M0054GAdM1401W@0115d
M142M0054GAdM1400W@00a5dM003M0XA17@44BAd000_M0044GAd4@Ad00@AM7@A0g@01A5dM7@A019d
00PAM7@A?ULnE`LA00Ad4G@A1G@01A5dM7@A00Id0Q43M0034GAd009d0a400g@A4@064@9d0Q42M0@A
:7@002Ud1142M0044GAd4@Ad00@AM7@A0g@00a5dM002M08A4G@01a5d4Cln?ch01144M0034G@A00Id
00DAM7Ad4@05M0054GAdM1401G@84@=d1a4/M000;g@0115dM144M0044GAd4@=d00<AM7@00g@00a5d
M00@M08A00@n4A4A0W@24@Ed00<AM1401G@01A5dM7@A00Ed0Q4017@AM7@74@Ad1a4`M000;g@0115d
M144M0044GAd4@=d00<AM7@017@24A5d0Q47M0034GAd009d00@AM7@A1G@01A5dM7@A00=d00<AM140
1a47M0@A=7@002md00@AM7@A17@0115dM142M08A27@00a5dM00?M08A1W@24@=d00@AM7@A1G@00a5d
M002M0034G@A00HA1g@44CQd000`M08A1W@24@Ad00<AM7@01g@24A5d0Q44M0044G@A4@9d00@AM7@A
1G@00a5d4@074@Id114lM000BG@00a5dM00AM08A0g@01Q5dM15d4@9d00@AM7Ad1142M0@A17@44D1d
001:M08A4g@24@03M15d009d0a400g@A4@024@=d0a4017@AM7@44DAd001<M08A4g@34@9d1a43M08A
00=d4A400a58M000CG@00a5dM00CM0DA17@84Dad001>M0034GAd01Md215@M000Cg@24Fmd001AM08A
KG@0059d00<AM7@0Jg@005=d00<AM7@0JW@005Ad0a5YM000EW@00a5dM01WM000Eg@00a5dM01VM000
Bg@24@]d0Q5VM000BW@0115dM14<M08AI7@004Yd00@AM7@A3G@00a5dM01RM000BW@0115dM14>M003
4GAd065d001:M0044GAd4@md0a5PM000BW@0115dM14AM0034GAd05id001;M08A4g@00a5dM01MM000
HG@00a5d4@1LM000HW@24Ead001TM0034GAd05Ud001UM0034GAd05Qd001VM08AF7@006Md0Q5GM000
JG@00a5dM01DM000JW@24EAd001[M0034GAd059d001/M08ADW@005]d0Q43M0034GAd008A0g@34@=d
0Q5@M000FW@0115dM144M0044GAd4@=d00<AM7@00g@00a5dM01>M000FW@0115dM144M0044GAd4@=d
00<AM7@017@24Did001JM0044GAd4@Ad00@AM7@A0g@00a5dM006M08AC7@005Yd00@AM7@A17@0115d
M143M0034GAd00Md00<AM7@0BW@005Yd00@AM7@A17@0115dM142M08A2W@00a5d4@19M000Fg@24@Id
0Q44M0034GAd00Ud0Q59M000MW@24DQd001hM0034GAd04Ed0030M000`7@00<1d0030M000`7@00<1d
001_M08A0g@00a5dM0024@9d1151M000KW@0115dM144M0044GAd4@9d00<AM7@0@G@006id00@AM7@A
17@0115dM143M0034GAd041d001^M0044GAd4@Ad00@AM7@A0g@00a5dM010M000KW@0115dM144M004
4GAd4@Ad00<AM7@0?g@006id00@AM7@A17@01Q5dM15d4@9d00<AM7@0?g@006md0Q46M08A0g@24D9d
0030M000`7@00<1d0030M000`7@00<1d0000\
\>"],
  ImageRangeCache->{{{0, 191.625}, {287, 0}} -> {0.0595904, -0.0667112, \
0.00382656, 0.00382656}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[LensSurfaces, Axes->True];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5175 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.247638 1.58239 -1.94072e-17 1.58239 [
[.13847 .13053 -8.34633 -10.9375 ]
[.13847 .13053 .65367 0 ]
[.24417 .08593 -23.9965 -11 ]
[.24417 .08593 2.5035 0 ]
[.35281 .04009 -18.9993 -10.9375 ]
[.35281 .04009 2.50074 0 ]
[.46453 -0.00703 -22.8389 -11 ]
[.46453 -0.00703 3.66112 0 ]
[.01532 1.08294 -15.6886 0 ]
[.01532 1.08294 12.7489 10.9375 ]
[.17878 1.21308 -15.2086 0 ]
[.17878 1.21308 13.2289 10.9375 ]
[.32483 1.32936 -4.68376 0 ]
[.32483 1.32936 4.31624 10.9375 ]
[.4561 1.43388 -10.9222 0 ]
[.4561 1.43388 10.5778 10.9375 ]
[.57473 1.52833 -10.6897 0 ]
[.57473 1.52833 10.8103 10.9375 ]
[.0741 .1946 -28.4375 -3.18123 ]
[.0741 .1946 0 7.75627 ]
[.05445 .3764 -28.4375 -3.30628 ]
[.05445 .3764 0 7.63122 ]
[.03302 .57462 -9 -3.44336 ]
[.03302 .57462 0 7.49414 ]
[.00958 .79158 -21.5 -3.5943 ]
[.00958 .79158 0 7.3432 ]
[-0.01618 1.03008 -21.5 -3.7613 ]
[-0.01618 1.03008 0 7.1762 ]
[ 0 0 0 0 ]
[ 1 1.5175 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09421 .16958 m
.49753 0 L
s
.15133 .14557 m
.15775 .15308 L
s
gsave
.13847 .13053 -69.3463 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25663 .10129 m
.26286 .10897 L
s
gsave
.24417 .08593 -84.9965 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.36485 .05578 m
.37088 .06363 L
s
gsave
.35281 .04009 -79.9993 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.47613 .009 m
.48193 .01701 L
s
gsave
.46453 -0.00703 -83.8389 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17216 .13681 m
.17599 .14134 L
s
.1931 .128 m
.19691 .13255 L
s
.21416 .11914 m
.21795 .12371 L
s
.23534 .11024 m
.2391 .11483 L
s
.27804 .09229 m
.28175 .09692 L
s
.29956 .08324 m
.30325 .08789 L
s
.32121 .07414 m
.32487 .07881 L
s
.34297 .06499 m
.34661 .06967 L
s
.38686 .04653 m
.39045 .05126 L
s
.40899 .03723 m
.41255 .04197 L
s
.43125 .02787 m
.43478 .03264 L
s
.45362 .01846 m
.45713 .02325 L
s
.13061 .15428 m
.13449 .15877 L
s
.11 .16294 m
.1139 .16741 L
s
.25 Mabswid
0 1.0494 m
.58581 1.5175 L
s
.01735 1.06326 m
.01837 1.05342 L
s
gsave
.01532 1.08294 -76.6886 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18016 1.19335 m
.18084 1.18349 L
s
gsave
.17878 1.21308 -76.2086 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32563 1.3096 m
.32604 1.29972 L
s
gsave
.32483 1.32936 -65.6838 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.45641 1.4141 m
.45657 1.40421 L
s
gsave
.4561 1.43388 -71.9222 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.57462 1.50855 m
.57456 1.49866 L
s
gsave
.57473 1.52833 -71.6897 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05145 1.09051 m
.05201 1.0846 L
s
.08475 1.11711 m
.08527 1.1112 L
s
.11728 1.14311 m
.11777 1.1372 L
s
.14908 1.16852 m
.14953 1.1626 L
s
.21055 1.21764 m
.21092 1.21171 L
s
.24027 1.24138 m
.24061 1.23546 L
s
.26934 1.26462 m
.26965 1.25869 L
s
.29779 1.28735 m
.29806 1.28142 L
s
.35289 1.33138 m
.3531 1.32545 L
s
.37958 1.35271 m
.37976 1.34677 L
s
.40572 1.37359 m
.40587 1.36766 L
s
.43133 1.39405 m
.43145 1.38812 L
s
.481 1.43375 m
.48107 1.42781 L
s
.5051 1.453 m
.50514 1.44707 L
s
.52873 1.47188 m
.52874 1.46595 L
s
.55189 1.49039 m
.55188 1.48446 L
s
.25 Mabswid
.09421 .16958 m
0 1.0494 L
s
.09235 .18697 m
.10147 .18315 L
s
gsave
.0741 .1946 -89.4375 -7.18123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.07284 .36913 m
.08204 .36549 L
s
gsave
.05445 .3764 -89.4375 -7.30628 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.05157 .56775 m
.06085 .56432 L
s
gsave
.03302 .57462 -70 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02829 .78517 m
.03765 .78196 L
s
gsave
.00958 .79158 -82.5 -7.5943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.0027 1.02418 m
.01214 1.02123 L
s
gsave
-0.01618 1.03008 -82.5 -7.7613 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.08857 .22219 m
.09406 .21992 L
s
.08474 .25799 m
.09023 .25575 L
s
.08084 .29441 m
.08634 .29218 L
s
.07687 .33145 m
.08238 .32925 L
s
.06873 .40747 m
.07426 .40531 L
s
.06456 .44648 m
.07009 .44435 L
s
.06031 .48619 m
.06585 .48408 L
s
.05598 .5266 m
.06153 .52452 L
s
.04709 .60965 m
.05266 .60761 L
s
.04252 .65232 m
.0481 .65031 L
s
.03786 .69578 m
.04346 .6938 L
s
.03312 .74005 m
.03873 .7381 L
s
.02337 .83114 m
.02899 .82925 L
s
.01835 .87801 m
.02399 .87614 L
s
.01324 .92578 m
.01888 .92395 L
s
.00802 .9745 m
.01367 .9727 L
s
0 0 m
1 0 L
1 1.5175 L
0 1.5175 L
closepath
clip
newpath
.5 Mabswid
.56398 .74349 m
.59682 .85168 L
s
.51426 .77206 m
.56398 .74349 L
s
.52111 .64038 m
.56398 .74349 L
s
.59682 .85168 m
.61811 .96003 L
s
.53696 .847 m
.59682 .85168 L
s
.57832 .73882 m
.61124 .8472 L
s
.52907 .76726 m
.57832 .73882 L
s
.53547 .6355 m
.57832 .73882 L
s
.61124 .8472 m
.63269 .95571 L
s
.55183 .84234 m
.61124 .8472 L
s
.4844 .7009 m
.52111 .64038 L
s
.47002 .54724 m
.52111 .64038 L
s
.49922 .69596 m
.53547 .6355 L
s
.48449 .54212 m
.53547 .6355 L
s
.61811 .96003 m
.62653 1.06345 L
s
.55129 .9218 m
.61811 .96003 L
s
.63269 .95571 m
.64137 1.05925 L
s
.56628 .91725 m
.63269 .95571 L
s
.71962 .69287 m
.75328 .80308 L
s
.67511 .71999 m
.71962 .69287 L
s
.67696 .58742 m
.71962 .69287 L
s
.75328 .80308 m
.7764 .9131 L
s
.6984 .79639 m
.75328 .80308 L
s
.44888 .63738 m
.47002 .54724 L
s
.41286 .46904 m
.47002 .54724 L
s
.46378 .63226 m
.48449 .54212 L
s
.42752 .46367 m
.48449 .54212 L
s
.64539 .64717 m
.67696 .58742 L
s
.6271 .4917 m
.67696 .58742 L
s
.62653 1.06345 m
.55634 .99243 L
s
.62653 1.06345 m
.62105 1.15654 L
s
.62653 1.06345 m
.62653 1.06345 L
s
.64137 1.05925 m
.5715 .98796 L
s
.64137 1.05925 m
.63621 1.15241 L
s
.64137 1.05925 m
.64137 1.05925 L
s
.7764 .9131 m
.78761 1.01778 L
s
.71403 .87237 m
.7764 .9131 L
s
.87107 .64361 m
.90554 .75579 L
s
.83185 .66925 m
.87107 .64361 L
s
.82865 .53589 m
.87107 .64361 L
s
.53696 .847 m
.51426 .77206 L
s
.4605 .80295 m
.51426 .77206 L
s
.51426 .77206 m
.4844 .7009 L
s
.90554 .75579 m
.93049 .86741 L
s
.85572 .74706 m
.90554 .75579 L
s
.55129 .9218 m
.53696 .847 L
s
.47228 .84194 m
.53696 .847 L
s
.61074 .58182 m
.6271 .4917 L
s
.57214 .41075 m
.6271 .4917 L
s
.55183 .84234 m
.52907 .76726 L
s
.47581 .79802 m
.52907 .76726 L
s
.52907 .76726 m
.49922 .69596 L
s
.56628 .91725 m
.55183 .84234 L
s
.48762 .83708 m
.55183 .84234 L
s
.40948 .58518 m
.41286 .46904 L
s
.35225 .41084 m
.41286 .46904 L
s
.41286 .46904 m
.41286 .46904 L
s
.4844 .7009 m
.44888 .63738 L
s
.44487 .76608 m
.4844 .7009 L
s
.42452 .5799 m
.42752 .46367 L
s
.36719 .40522 m
.42752 .46367 L
s
.42752 .46367 m
.42752 .46367 L
s
.8023 .5948 m
.82865 .53589 L
s
.78006 .43762 m
.82865 .53589 L
s
.49922 .69596 m
.46378 .63226 L
s
.46018 .76107 m
.49922 .69596 L
s
.55634 .99243 m
.55129 .9218 L
s
.47951 .88071 m
.55129 .9218 L
s
.78761 1.01778 m
.72103 .94388 L
s
.78761 1.01778 m
.78576 1.11168 L
s
.78761 1.01778 m
.78761 1.01778 L
s
.5715 .98796 m
.56628 .91725 L
s
.49491 .87592 m
.56628 .91725 L
s
.93049 .86741 m
.9445 .97329 L
s
.87266 .8242 m
.93049 .86741 L
s
.62105 1.15654 m
.60099 1.23355 L
s
.5515 1.05483 m
.62105 1.15654 L
s
.63621 1.15241 m
.61655 1.22945 L
s
.56689 1.05041 m
.63621 1.15241 L
s
.44888 .63738 m
.40948 .58518 L
s
.42631 .73357 m
.44888 .63738 L
s
.46378 .63226 m
.42452 .5799 L
s
.44167 .72847 m
.46378 .63226 L
s
.5515 1.05483 m
.55634 .99243 L
s
.55634 .99243 m
.4817 .91691 L
s
.55634 .99243 m
.55634 .99243 L
s
.6984 .79639 m
.67511 .71999 L
s
.6269 .74936 m
.67511 .71999 L
s
.67511 .71999 m
.64539 .64717 L
s
.5715 .98796 m
.5715 .98796 L
s
.56689 1.05041 m
.5715 .98796 L
s
.5715 .98796 m
.49719 .91216 L
s
.76855 .52766 m
.78006 .43762 L
s
.72737 .35394 m
.78006 .43762 L
s
.71403 .87237 m
.6984 .79639 L
s
.63901 .78915 m
.6984 .79639 L
s
.57289 .52775 m
.57214 .41075 L
s
.51462 .34976 m
.57214 .41075 L
s
.57214 .41075 m
.57214 .41075 L
s
.64539 .64717 m
.61074 .58182 L
s
.61135 .7116 m
.64539 .64717 L
s
.9445 .97329 m
.88163 .89654 L
s
.9445 .97329 m
.94634 1.06795 L
s
.9445 .97329 m
.9445 .97329 L
s
.72103 .94388 m
.71403 .87237 L
s
.64692 .82856 m
.71403 .87237 L
s
.40948 .58518 m
.36832 .54782 L
s
.40593 .70749 m
.40948 .58518 L
s
.40948 .58518 m
.40948 .58518 L
s
.36832 .54782 m
.35225 .41084 L
s
.29141 .37761 m
.35225 .41084 L
s
.42452 .5799 m
.38355 .54237 L
s
.42136 .7023 m
.42452 .5799 L
s
.42452 .5799 m
.42452 .5799 L
s
.78576 1.11168 m
.77004 1.18899 L
s
.71871 1.0068 m
.78576 1.11168 L
s
.38355 .54237 m
.36719 .40522 L
s
.3067 .37175 m
.36719 .40522 L
s
.52532 1.10814 m
.5515 1.05483 L
s
.47408 .94964 m
.5515 1.05483 L
s
.61074 .58182 m
.57289 .52775 L
s
.59325 .67813 m
.61074 .58182 L
s
.54072 1.1038 m
.56689 1.05041 L
s
.48944 .94498 m
.56689 1.05041 L
s
.71871 1.0068 m
.72103 .94388 L
s
.72103 .94388 m
.65014 .86521 L
s
.72103 .94388 m
.72103 .94388 L
s
.60099 1.23355 m
.56631 1.28852 L
s
.52532 1.10814 m
.60099 1.23355 L
s
.85572 .74706 m
.83185 .66925 L
s
.78932 .69706 m
.83185 .66925 L
s
.83185 .66925 m
.8023 .5948 L
s
.87266 .8242 m
.85572 .74706 L
s
.80174 .73761 m
.85572 .74706 L
s
.47228 .84194 m
.4605 .80295 L
s
.4605 .80295 m
.44487 .76608 L
s
.40218 .83646 m
.4605 .80295 L
s
.61655 1.22945 m
.5823 1.2844 L
s
.54072 1.1038 m
.61655 1.22945 L
s
.47951 .88071 m
.47228 .84194 L
s
.40218 .83646 m
.47228 .84194 L
s
.73231 .47172 m
.72737 .35394 L
s
.67304 .29017 m
.72737 .35394 L
s
.72737 .35394 m
.72737 .35394 L
s
.48762 .83708 m
.47581 .79802 L
s
.47581 .79802 m
.46018 .76107 L
s
.41802 .83139 m
.47581 .79802 L
s
.49491 .87592 m
.48762 .83708 L
s
.41802 .83139 m
.48762 .83708 L
s
.44487 .76608 m
.42631 .73357 L
s
.40218 .83646 m
.44487 .76608 L
s
.8023 .5948 m
.76855 .52766 L
s
.77385 .65841 m
.8023 .5948 L
s
.4817 .91691 m
.47951 .88071 L
s
.40218 .83646 m
.47951 .88071 L
s
.46018 .76107 m
.44167 .72847 L
s
.41802 .83139 m
.46018 .76107 L
s
.49719 .91216 m
.49491 .87592 L
s
.41802 .83139 m
.49491 .87592 L
s
.88163 .89654 m
.87266 .8242 L
s
.81036 .77764 m
.87266 .8242 L
s
.36832 .54782 m
.32781 .52837 L
s
.38495 .68961 m
.36832 .54782 L
s
.42631 .73357 m
.40593 .70749 L
s
.40218 .83646 m
.42631 .73357 L
s
.38355 .54237 m
.34328 .52277 L
s
.40048 .68434 m
.38355 .54237 L
s
.57368 .65108 m
.57289 .52775 L
s
.57289 .52775 m
.57289 .52775 L
s
.57289 .52775 m
.53389 .48854 L
s
.44167 .72847 m
.42136 .7023 L
s
.41802 .83139 m
.44167 .72847 L
s
.47408 .94964 m
.4817 .91691 L
s
.4817 .91691 m
.40218 .83646 L
s
.4817 .91691 m
.4817 .91691 L
s
.94634 1.06795 m
.93503 1.14551 L
s
.88187 .95994 m
.94634 1.06795 L
s
.53389 .48854 m
.51462 .34976 L
s
.45766 .31388 m
.51462 .34976 L
s
.47706 1.14871 m
.52532 1.10814 L
s
.45412 .97753 m
.52532 1.10814 L
s
.48944 .94498 m
.49719 .91216 L
s
.49719 .91216 m
.41802 .83139 L
s
.49719 .91216 m
.49719 .91216 L
s
.49274 1.14435 m
.54072 1.1038 L
s
.46962 .97288 m
.54072 1.1038 L
s
.76855 .52766 m
.73231 .47172 L
s
.75624 .624 m
.76855 .52766 L
s
.70677 1.05705 m
.71871 1.0068 L
s
.64838 .8968 m
.71871 1.0068 L
s
.40593 .70749 m
.40218 .83646 L
s
.40593 .70749 m
.40593 .70749 L
s
.40593 .70749 m
.38495 .68961 L
s
.42136 .7023 m
.41802 .83139 L
s
.42136 .7023 m
.42136 .7023 L
s
.42136 .7023 m
.40048 .68434 L
s
.45412 .97753 m
.47408 .94964 L
s
.40218 .83646 m
.47408 .94964 L
s
.88187 .95994 m
.88163 .89654 L
s
.88163 .89654 m
.81462 .81473 L
s
.88163 .89654 m
.88163 .89654 L
s
.46962 .97288 m
.48944 .94498 L
s
.41802 .83139 m
.48944 .94498 L
s
.77004 1.18899 m
.74017 1.24369 L
s
.70677 1.05705 m
.77004 1.18899 L
s
.32781 .52837 m
.29141 .37761 L
s
.2342 .37383 m
.29141 .37761 L
s
.63901 .78915 m
.6269 .74936 L
s
.57452 .78128 m
.6269 .74936 L
s
.6269 .74936 m
.61135 .7116 L
s
.64692 .82856 m
.63901 .78915 L
s
.57452 .78128 m
.63901 .78915 L
s
.34328 .52277 m
.3067 .37175 L
s
.2499 .36776 m
.3067 .37175 L
s
.61135 .7116 m
.59325 .67813 L
s
.57452 .78128 m
.61135 .7116 L
s
.38495 .68961 m
.36472 .68131 L
s
.40218 .83646 m
.38495 .68961 L
s
.65014 .86521 m
.64692 .82856 L
s
.57452 .78128 m
.64692 .82856 L
s
.42914 .99672 m
.45412 .97753 L
s
.40218 .83646 m
.45412 .97753 L
s
.40048 .68434 m
.38038 .67596 L
s
.41802 .83139 m
.40048 .68434 L
s
.44477 .99205 m
.46962 .97288 L
s
.41802 .83139 m
.46962 .97288 L
s
.32781 .52837 m
.29063 .52923 L
s
.36472 .68131 m
.32781 .52837 L
s
.53389 .48854 m
.49605 .46741 L
s
.55384 .63229 m
.53389 .48854 L
s
.59325 .67813 m
.57368 .65108 L
s
.57452 .78128 m
.59325 .67813 L
s
.73752 .59599 m
.73231 .47172 L
s
.73231 .47172 m
.73231 .47172 L
s
.73231 .47172 m
.69554 .43066 L
s
.34328 .52277 m
.30637 .5235 L
s
.38038 .67596 m
.34328 .52277 L
s
.69554 .43066 m
.67304 .29017 L
s
.62006 .25164 m
.67304 .29017 L
s
.42884 1.16746 m
.47706 1.14871 L
s
.47706 1.14871 m
.56631 1.28852 L
s
.42914 .99672 m
.47706 1.14871 L
s
.56631 1.28852 m
.5154 1.31634 L
s
.64838 .8968 m
.65014 .86521 L
s
.65014 .86521 m
.57452 .78128 L
s
.65014 .86521 m
.65014 .86521 L
s
.4448 1.16302 m
.49274 1.14435 L
s
.49274 1.14435 m
.5823 1.2844 L
s
.44477 .99205 m
.49274 1.14435 L
s
.5823 1.2844 m
.53157 1.3122 L
s
.68538 1.09076 m
.70677 1.05705 L
s
.64162 .92121 m
.70677 1.05705 L
s
.87293 1.01026 m
.88187 .95994 L
s
.81418 .84654 m
.88187 .95994 L
s
.40563 1.0042 m
.42914 .99672 L
s
.40218 .83646 m
.42914 .99672 L
s
.36472 .68131 m
.34662 .68344 L
s
.40218 .83646 m
.36472 .68131 L
s
.57368 .65108 m
.57452 .78128 L
s
.57368 .65108 m
.57368 .65108 L
s
.57368 .65108 m
.55384 .63229 L
s
.4214 .99949 m
.44477 .99205 L
s
.41802 .83139 m
.44477 .99205 L
s
.38038 .67596 m
.36241 .67804 L
s
.41802 .83139 m
.38038 .67596 L
s
.64162 .92121 m
.64838 .8968 L
s
.57452 .78128 m
.64838 .8968 L
s
.93503 1.14551 m
.91007 1.19987 L
s
.87293 1.01026 m
.93503 1.14551 L
s
.80174 .73761 m
.78932 .69706 L
s
.74303 .72733 m
.78932 .69706 L
s
.78932 .69706 m
.77385 .65841 L
s
.81036 .77764 m
.80174 .73761 L
s
.74303 .72733 m
.80174 .73761 L
s
.49605 .46741 m
.45766 .31388 L
s
.40492 .30783 m
.45766 .31388 L
s
.40218 .83646 m
.40218 .83646 L
s
.40218 .83646 m
.34662 .68344 L
s
.40218 .83646 m
.33195 .6962 L
s
.40218 .83646 m
.32188 .71904 L
s
.40218 .83646 m
.31728 .75057 L
s
.40218 .83646 m
.31863 .78865 L
s
.40218 .83646 m
.32594 .8305 L
s
.40218 .83646 m
.3387 .87294 L
s
.40218 .83646 m
.35516 .91294 L
s
.40218 .83646 m
.36645 .94979 L
s
.40218 .83646 m
.3755 .97954 L
s
.40218 .83646 m
.38758 .99839 L
s
.40218 .83646 m
.40563 1.0042 L
s
.77385 .65841 m
.75624 .624 L
s
.74303 .72733 m
.77385 .65841 L
s
.41802 .83139 m
.41802 .83139 L
s
.41802 .83139 m
.36241 .67804 L
s
.41802 .83139 m
.34789 .69077 L
s
.41802 .83139 m
.33796 .7136 L
s
.41802 .83139 m
.33349 .74515 L
s
.41802 .83139 m
.33494 .78327 L
s
.41802 .83139 m
.34232 .82519 L
s
.41802 .83139 m
.35511 .86771 L
s
.41802 .83139 m
.37129 .9079 L
s
.41802 .83139 m
.38255 .94484 L
s
.41802 .83139 m
.39151 .97469 L
s
.41802 .83139 m
.40348 .99362 L
s
.41802 .83139 m
.4214 .99949 L
s
.81462 .81473 m
.81036 .77764 L
s
.74303 .72733 m
.81036 .77764 L
s
.38758 .99839 m
.40563 1.0042 L
s
.40563 1.0042 m
.42884 1.16746 L
s
.55384 .63229 m
.535 .62319 L
s
.57452 .78128 m
.55384 .63229 L
s
.34662 .68344 m
.33195 .6962 L
s
.29063 .52923 m
.34662 .68344 L
s
.40348 .99362 m
.4214 .99949 L
s
.4214 .99949 m
.4448 1.16302 L
s
.69554 .43066 m
.66044 .40784 L
s
.71885 .57629 m
.69554 .43066 L
s
.36241 .67804 m
.34789 .69077 L
s
.30637 .5235 m
.36241 .67804 L
s
.75624 .624 m
.73752 .59599 L
s
.74303 .72733 m
.75624 .624 L
s
.63017 .93663 m
.64162 .92121 L
s
.57452 .78128 m
.64162 .92121 L
s
.49605 .46741 m
.4619 .4669 L
s
.535 .62319 m
.49605 .46741 L
s
.29063 .52923 m
.2596 .5517 L
s
.2342 .37383 m
.29063 .52923 L
s
.39353 1.15907 m
.42884 1.16746 L
s
.42884 1.16746 m
.5154 1.31634 L
s
.81418 .84654 m
.81462 .81473 L
s
.81462 .81473 m
.74303 .72733 L
s
.81462 .81473 m
.81462 .81473 L
s
.74017 1.24369 m
.69669 1.26992 L
s
.68538 1.09076 m
.74017 1.24369 L
s
.30637 .5235 m
.27564 .54589 L
s
.2499 .36776 m
.30637 .5235 L
s
.40976 1.15453 m
.4448 1.16302 L
s
.4448 1.16302 m
.53157 1.3122 L
s
.18503 .40276 m
.2342 .37383 L
s
.85484 1.04362 m
.87293 1.01026 L
s
.80896 .87093 m
.87293 1.01026 L
s
.65536 1.10459 m
.68538 1.09076 L
s
.63017 .93663 m
.68538 1.09076 L
s
.20116 .39655 m
.2499 .36776 L
s
.3755 .97954 m
.38758 .99839 L
s
.38758 .99839 m
.39353 1.15907 L
s
.73752 .59599 m
.74303 .72733 L
s
.73752 .59599 m
.73752 .59599 L
s
.73752 .59599 m
.71885 .57629 L
s
.535 .62319 m
.51843 .62471 L
s
.57452 .78128 m
.535 .62319 L
s
.33195 .6962 m
.2596 .5517 L
s
.33195 .6962 m
.32188 .71904 L
s
.39151 .97469 m
.40348 .99362 L
s
.40348 .99362 m
.40976 1.15453 L
s
.80896 .87093 m
.81418 .84654 L
s
.74303 .72733 m
.81418 .84654 L
s
.34789 .69077 m
.27564 .54589 L
s
.34789 .69077 m
.33796 .7136 L
s
.61464 .94173 m
.63017 .93663 L
s
.57452 .78128 m
.63017 .93663 L
s
.66044 .40784 m
.62006 .25164 L
s
.57192 .24326 m
.62006 .25164 L
s
.57452 .78128 m
.57452 .78128 L
s
.57452 .78128 m
.51843 .62471 L
s
.57452 .78128 m
.50538 .6371 L
s
.57452 .78128 m
.49687 .65983 L
s
.57452 .78128 m
.49368 .69156 L
s
.57452 .78128 m
.49617 .73012 L
s
.57452 .78128 m
.50427 .77272 L
s
.57452 .78128 m
.5174 .81609 L
s
.57452 .78128 m
.53456 .8569 L
s
.57452 .78128 m
.55441 .89203 L
s
.57452 .78128 m
.57541 .91894 L
s
.57452 .78128 m
.59597 .93581 L
s
.57452 .78128 m
.61464 .94173 L
s
.5154 1.31634 m
.45689 1.31047 L
s
.71885 .57629 m
.70143 .56639 L
s
.74303 .72733 m
.71885 .57629 L
s
.53157 1.3122 m
.47347 1.30619 L
s
.37067 1.12335 m
.3755 .97954 L
s
.3755 .97954 m
.3755 .97954 L
s
.36645 .94979 m
.3755 .97954 L
s
.32188 .71904 m
.31728 .75057 L
s
.23745 .59556 m
.32188 .71904 L
s
.51843 .62471 m
.50538 .6371 L
s
.4619 .4669 m
.51843 .62471 L
s
.38713 1.11866 m
.39151 .97469 L
s
.39151 .97469 m
.39151 .97469 L
s
.38255 .94484 m
.39151 .97469 L
s
.79916 .88611 m
.80896 .87093 L
s
.74303 .72733 m
.80896 .87093 L
s
.33796 .7136 m
.33349 .74515 L
s
.25377 .58972 m
.33796 .7136 L
s
.66044 .40784 m
.62942 .40593 L
s
.70143 .56639 m
.66044 .40784 L
s
.59597 .93581 m
.61464 .94173 L
s
.61464 .94173 m
.65536 1.10459 L
s
.4619 .4669 m
.43409 .48845 L
s
.40492 .30783 m
.4619 .4669 L
s
.2596 .5517 m
.18503 .40276 L
s
.2596 .5517 m
.23745 .59556 L
s
.91007 1.19987 m
.87171 1.2251 L
s
.85484 1.04362 m
.91007 1.19987 L
s
.37067 1.12335 m
.39353 1.15907 L
s
.39353 1.15907 m
.45689 1.31047 L
s
.27564 .54589 m
.20116 .39655 L
s
.27564 .54589 m
.25377 .58972 L
s
.38713 1.11866 m
.40976 1.15453 L
s
.40976 1.15453 m
.47347 1.30619 L
s
.31728 .75057 m
.22645 .65867 L
s
.31728 .75057 m
.31863 .78865 L
s
.31728 .75057 m
.31728 .75057 L
s
.36057 .33513 m
.40492 .30783 L
s
.82816 1.05663 m
.85484 1.04362 L
s
.79916 .88611 m
.85484 1.04362 L
s
.35516 .91294 m
.36645 .94979 L
s
.36645 .94979 m
.34623 1.06597 L
s
.70143 .56639 m
.68645 .56728 L
s
.74303 .72733 m
.70143 .56639 L
s
.33349 .74515 m
.24303 .65286 L
s
.33349 .74515 m
.33494 .78327 L
s
.33349 .74515 m
.33349 .74515 L
s
.37129 .9079 m
.38255 .94484 L
s
.38255 .94484 m
.36287 1.06109 L
s
.61823 1.09619 m
.65536 1.10459 L
s
.65536 1.10459 m
.69669 1.26992 L
s
.50538 .6371 m
.43409 .48845 L
s
.50538 .6371 m
.49687 .65983 L
s
.78527 .89073 m
.79916 .88611 L
s
.74303 .72733 m
.79916 .88611 L
s
.31863 .78865 m
.22809 .73684 L
s
.31863 .78865 m
.32594 .8305 L
s
.57541 .91894 m
.59597 .93581 L
s
.59597 .93581 m
.61823 1.09619 L
s
.3387 .87294 m
.35516 .91294 L
s
.35516 .91294 m
.30568 .99555 L
s
.33494 .78327 m
.24489 .73112 L
s
.33494 .78327 m
.34232 .82519 L
s
.74303 .72733 m
.74303 .72733 L
s
.74303 .72733 m
.68645 .56728 L
s
.74303 .72733 m
.67505 .57926 L
s
.74303 .72733 m
.66815 .60187 L
s
.74303 .72733 m
.6664 .63377 L
s
.74303 .72733 m
.67006 .6728 L
s
.74303 .72733 m
.67896 .71611 L
s
.74303 .72733 m
.69246 .7604 L
s
.74303 .72733 m
.70953 .80224 L
s
.74303 .72733 m
.72883 .83844 L
s
.74303 .72733 m
.74887 .86635 L
s
.74303 .72733 m
.76813 .88411 L
s
.74303 .72733 m
.78527 .89073 L
s
.35511 .86771 m
.37129 .9079 L
s
.37129 .9079 m
.32269 .99038 L
s
.32594 .8305 m
.3387 .87294 L
s
.24272 .82399 m
.32594 .8305 L
s
.3387 .87294 m
.26934 .91279 L
s
.69669 1.26992 m
.64135 1.26276 L
s
.34232 .82519 m
.35511 .86771 L
s
.25967 .81843 m
.34232 .82519 L
s
.14854 .46554 m
.18503 .40276 L
s
.35511 .86771 m
.28636 .90741 L
s
.68645 .56728 m
.67505 .57926 L
s
.62942 .40593 m
.68645 .56728 L
s
.49687 .65983 m
.49368 .69156 L
s
.41512 .53197 m
.49687 .65983 L
s
.1651 .45927 m
.20116 .39655 L
s
.76813 .88411 m
.78527 .89073 L
s
.78527 .89073 m
.82816 1.05663 L
s
.57635 1.06471 m
.57541 .91894 L
s
.57541 .91894 m
.57541 .91894 L
s
.55441 .89203 m
.57541 .91894 L
s
.62942 .40593 m
.60492 .42652 L
s
.57192 .24326 m
.62942 .40593 L
s
.23745 .59556 m
.22645 .65867 L
s
.14854 .46554 m
.23745 .59556 L
s
.43409 .48845 m
.36057 .33513 L
s
.43409 .48845 m
.41512 .53197 L
s
.25377 .58972 m
.24303 .65286 L
s
.1651 .45927 m
.25377 .58972 L
s
.37067 1.12335 m
.38959 1.26928 L
s
.37067 1.12335 m
.37067 1.12335 L
s
.34623 1.06597 m
.37067 1.12335 L
s
.53254 .26886 m
.57192 .24326 L
s
.45689 1.31047 m
.38959 1.26928 L
s
.40683 1.2647 m
.38713 1.11866 L
s
.38713 1.11866 m
.38713 1.11866 L
s
.36287 1.06109 m
.38713 1.11866 L
s
.49368 .69156 m
.40704 .59541 L
s
.49368 .69156 m
.49617 .73012 L
s
.49368 .69156 m
.49368 .69156 L
s
.47347 1.30619 m
.40683 1.2647 L
s
.7942 1.04695 m
.82816 1.05663 L
s
.82816 1.05663 m
.87171 1.2251 L
s
.67505 .57926 m
.60492 .42652 L
s
.67505 .57926 m
.66815 .60187 L
s
.53456 .8569 m
.55441 .89203 L
s
.55441 .89203 m
.53277 1.01126 L
s
.57635 1.06471 m
.61823 1.09619 L
s
.61823 1.09619 m
.64135 1.26276 L
s
.74887 .86635 m
.76813 .88411 L
s
.76813 .88411 m
.7942 1.04695 L
s
.49617 .73012 m
.4111 .67458 L
s
.49617 .73012 m
.50427 .77272 L
s
.5174 .81609 m
.53456 .8569 L
s
.53456 .8569 m
.49106 .93923 L
s
.87171 1.2251 m
.8213 1.21622 L
s
.50427 .77272 m
.5174 .81609 L
s
.42743 .76335 m
.50427 .77272 L
s
.5174 .81609 m
.45486 .8542 L
s
.32894 .39717 m
.36057 .33513 L
s
.22645 .65867 m
.12903 .56011 L
s
.22645 .65867 m
.22809 .73684 L
s
.22645 .65867 m
.22645 .65867 L
s
.66815 .60187 m
.6664 .63377 L
s
.58923 .46965 m
.66815 .60187 L
s
.24303 .65286 m
.146 .55387 L
s
.24303 .65286 m
.24489 .73112 L
s
.24303 .65286 m
.24303 .65286 L
s
.75505 1.01375 m
.74887 .86635 L
s
.74887 .86635 m
.74887 .86635 L
s
.72883 .83844 m
.74887 .86635 L
s
.30568 .99555 m
.34623 1.06597 L
s
.34623 1.06597 m
.31853 1.19305 L
s
.41512 .53197 m
.40704 .59541 L
s
.32894 .39717 m
.41512 .53197 L
s
.60492 .42652 m
.53254 .26886 L
s
.60492 .42652 m
.58923 .46965 L
s
.32269 .99038 m
.36287 1.06109 L
s
.36287 1.06109 m
.33604 1.18818 L
s
.12903 .56011 m
.14854 .46554 L
s
.6664 .63377 m
.58415 .53336 L
s
.6664 .63377 m
.67006 .6728 L
s
.6664 .63377 m
.6664 .63377 L
s
.64135 1.26276 m
.57734 1.21933 L
s
.146 .55387 m
.1651 .45927 L
s
.57635 1.06471 m
.57734 1.21933 L
s
.57635 1.06471 m
.57635 1.06471 L
s
.53277 1.01126 m
.57635 1.06471 L
s
.70953 .80224 m
.72883 .83844 L
s
.72883 .83844 m
.71352 .95824 L
s
.75505 1.01375 m
.7942 1.04695 L
s
.7942 1.04695 m
.8213 1.21622 L
s
.22809 .73684 m
.12964 .6805 L
s
.22809 .73684 m
.24272 .82399 L
s
.24489 .73112 m
.14695 .6744 L
s
.24489 .73112 m
.25967 .81843 L
s
.67006 .6728 m
.59069 .61349 L
s
.67006 .6728 m
.67896 .71611 L
s
.26934 .91279 m
.30568 .99555 L
s
.30568 .99555 m
.25086 1.08592 L
s
.69246 .7604 m
.70953 .80224 L
s
.70953 .80224 m
.67299 .88396 L
s
.38959 1.26928 m
.38959 1.26928 L
s
.38959 1.26928 m
.31853 1.19305 L
s
.28636 .90741 m
.32269 .99038 L
s
.32269 .99038 m
.26853 1.08072 L
s
.67896 .71611 m
.60874 .70382 L
s
.67896 .71611 m
.69246 .7604 L
s
.69246 .7604 m
.63699 .79668 L
s
.40683 1.2647 m
.40683 1.2647 L
s
.40683 1.2647 m
.33604 1.18818 L
s
.24272 .82399 m
.26934 .91279 L
s
.15152 .81686 m
.24272 .82399 L
s
.26934 .91279 m
.19324 .95651 L
s
.50593 .3301 m
.53254 .26886 L
s
.25967 .81843 m
.16907 .81101 L
s
.25967 .81843 m
.28636 .90741 L
s
.40704 .59541 m
.31398 .49212 L
s
.40704 .59541 m
.4111 .67458 L
s
.40704 .59541 m
.40704 .59541 L
s
.28636 .90741 m
.21092 .95097 L
s
.58923 .46965 m
.58415 .53336 L
s
.50593 .3301 m
.58923 .46965 L
s
.49106 .93923 m
.53277 1.01126 L
s
.53277 1.01126 m
.5094 1.13996 L
s
.8213 1.21622 m
.76162 1.1703 L
s
.31398 .49212 m
.32894 .39717 L
s
.71352 .95824 m
.75505 1.01375 L
s
.75505 1.01375 m
.76162 1.1703 L
s
.75505 1.01375 m
.75505 1.01375 L
s
.12964 .6805 m
.12903 .56011 L
s
.12903 .56011 m
.12903 .56011 L
s
.4111 .67458 m
.31842 .61407 L
s
.4111 .67458 m
.42743 .76335 L
s
.14695 .6744 m
.146 .55387 L
s
.146 .55387 m
.146 .55387 L
s
.45486 .8542 m
.49106 .93923 L
s
.49106 .93923 m
.4435 1.02922 L
s
.57734 1.21933 m
.57734 1.21933 L
s
.57734 1.21933 m
.5094 1.13996 L
s
.31853 1.19305 m
.25086 1.08592 L
s
.42743 .76335 m
.45486 .8542 L
s
.34303 .75306 m
.42743 .76335 L
s
.45486 .8542 m
.3861 .89609 L
s
.33604 1.18818 m
.26853 1.08072 L
s
.58415 .53336 m
.49566 .42533 L
s
.58415 .53336 m
.59069 .61349 L
s
.58415 .53336 m
.58415 .53336 L
s
.67299 .88396 m
.71352 .95824 L
s
.71352 .95824 m
.69697 1.08779 L
s
.49566 .42533 m
.50593 .3301 L
s
.15152 .81686 m
.12964 .6805 L
s
.16907 .81101 m
.14695 .6744 L
s
.59069 .61349 m
.50404 .54875 L
s
.59069 .61349 m
.60874 .70382 L
s
.31842 .61407 m
.31398 .49212 L
s
.31398 .49212 m
.31398 .49212 L
s
.25086 1.08592 m
.19324 .95651 L
s
.63699 .79668 m
.67299 .88396 L
s
.67299 .88396 m
.63297 .97345 L
s
.26853 1.08072 m
.21092 .95097 L
s
.76162 1.1703 m
.76162 1.1703 L
s
.76162 1.1703 m
.69697 1.08779 L
s
.60874 .70382 m
.53146 .69029 L
s
.60874 .70382 m
.63699 .79668 L
s
.5094 1.13996 m
.4435 1.02922 L
s
.19324 .95651 m
.15152 .81686 L
s
.63699 .79668 m
.57586 .83665 L
s
.21092 .95097 m
.16907 .81101 L
s
.34303 .75306 m
.31842 .61407 L
s
.50404 .54875 m
.49566 .42533 L
s
.49566 .42533 m
.49566 .42533 L
s
.4435 1.02922 m
.3861 .89609 L
s
.69697 1.08779 m
.63297 .97345 L
s
.3861 .89609 m
.34303 .75306 L
s
.53146 .69029 m
.50404 .54875 L
s
.63297 .97345 m
.57586 .83665 L
s
.57586 .83665 m
.53146 .69029 L
s
.25 Mabswid
.09421 .16958 m
.49753 0 L
s
.15133 .14557 m
.15775 .15308 L
s
gsave
.13847 .13053 -69.3463 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25663 .10129 m
.26286 .10897 L
s
gsave
.24417 .08593 -84.9965 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.36485 .05578 m
.37088 .06363 L
s
gsave
.35281 .04009 -79.9993 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.47613 .009 m
.48193 .01701 L
s
gsave
.46453 -0.00703 -83.8389 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.015) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17216 .13681 m
.17599 .14134 L
s
.1931 .128 m
.19691 .13255 L
s
.21416 .11914 m
.21795 .12371 L
s
.23534 .11024 m
.2391 .11483 L
s
.27804 .09229 m
.28175 .09692 L
s
.29956 .08324 m
.30325 .08789 L
s
.32121 .07414 m
.32487 .07881 L
s
.34297 .06499 m
.34661 .06967 L
s
.38686 .04653 m
.39045 .05126 L
s
.40899 .03723 m
.41255 .04197 L
s
.43125 .02787 m
.43478 .03264 L
s
.45362 .01846 m
.45713 .02325 L
s
.13061 .15428 m
.13449 .15877 L
s
.11 .16294 m
.1139 .16741 L
s
.25 Mabswid
0 1.0494 m
.58581 1.5175 L
s
.01735 1.06326 m
.01837 1.05342 L
s
gsave
.01532 1.08294 -76.6886 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18016 1.19335 m
.18084 1.18349 L
s
gsave
.17878 1.21308 -76.2086 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32563 1.3096 m
.32604 1.29972 L
s
gsave
.32483 1.32936 -65.6838 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.45641 1.4141 m
.45657 1.40421 L
s
gsave
.4561 1.43388 -71.9222 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.57462 1.50855 m
.57456 1.49866 L
s
gsave
.57473 1.52833 -71.6897 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05145 1.09051 m
.05201 1.0846 L
s
.08475 1.11711 m
.08527 1.1112 L
s
.11728 1.14311 m
.11777 1.1372 L
s
.14908 1.16852 m
.14953 1.1626 L
s
.21055 1.21764 m
.21092 1.21171 L
s
.24027 1.24138 m
.24061 1.23546 L
s
.26934 1.26462 m
.26965 1.25869 L
s
.29779 1.28735 m
.29806 1.28142 L
s
.35289 1.33138 m
.3531 1.32545 L
s
.37958 1.35271 m
.37976 1.34677 L
s
.40572 1.37359 m
.40587 1.36766 L
s
.43133 1.39405 m
.43145 1.38812 L
s
.481 1.43375 m
.48107 1.42781 L
s
.5051 1.453 m
.50514 1.44707 L
s
.52873 1.47188 m
.52874 1.46595 L
s
.55189 1.49039 m
.55188 1.48446 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{189.75, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002m000180P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000;ed002mM000_G@00;ed002mM000_G@00;ed
002mM000_G@00;ed002mM000_G@0051d0Q43M0034GAd008A0g@34@04M14A4EUd001?M0044GAd4@Ad
00@AM7@A0g@0115dM142M0034GAd05Id001?M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd05Id
001?M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd05Id001?M0044GAd4@Ad00@AM7@A0g@00a5d
M0034EUd001?M0044GAd4@Ad00@AM7@A0W@24@=d00<AM7@0F7@0051d0Q46M08A17@0115dM7@34EQd
001YM08ADW@0049d0Q43M0034GAd008A0g@34AAd0a5DM000@G@0115dM144M0044GAd4@=d00<AM7@0
4W@24EId0011M0044GAd4@Ad00@AM7@A0g@00a5dM00?M0<A0W@00a5dM01CM000@G@0115dM144M004
4GAd4@=d00<AM7@037@34@03M15d05Qd0011M0044GAd4@Ad00@AM7@A0g@00a5dM00:M0<AGG@0045d
00@AM7@A17@0115dM142M08A2W@24F1d0012M08A1W@24@Ad00<AM7@017@01Q5d4A5d4F1d000[M08A
0g@00a5dM0024@=d0Q42M0<A5g@34FAd000ZM0044GAd4@Ad00HAM7@AM142M0034G@A009d00<AM7@0
4W@24FMd000ZM0044GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@03g@34@03M15d06Id000ZM004
4GAd4@Ad00HAM7@AM142M0034GAd009d00<AM7@03G@34F]d000ZM0044GAd4@Ad00HAM7@AM142M003
4G@A008A3W@24Fid000ZM0044GAd4@Ad00HAM7@AM142M0044GAd4@ad115_M000:g@24@Id0Q43M08A
0g@34@Qd0a5bM000AG@34GEd000YM08A67@24@03M15d07Ed000XM0044GAd4AEd0Q5jM000:7@0115d
M14BM0<A0W@00a5dM01gM000:7@0115dM14?M0<A00=d4G@0O7@002Qd00@AM7@A3G@44H1d000XM004
4GAd4@]d0Q64M000:G@24@Ud0a400g@AM023M000<W@44HMd000`M08ARg@002ed0a42M0034GAd08Qd
000[M08A00=d4G@0SG@002Ud0Q6BM0009g@24IAd000WM0034GAd09=d000WM08AU7@002Md00<AM7@0
Tg@002Md00<AM7@0Tg@002Id00<AM7@0U7@0015d0Q43M0034GAd008A0W@44@Ed00<AM7@0U7@0011d
00@AM7@A17@0115dM142M0034GAd00Ed00<AM7@0U7@000Yd1142M0044GAd4@Ad00@AM7@A0g@00a5d
M004M08AUG@0011d00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@0U7@0011d00@AM7@A17@0115d
M144M0034GAd00=d00<AM7@0U7@0011d00@AM7@A17@01Q5dM15d4@9d00<AM7@00g@00a5dM02DM000
4G@24@Id0Q43M08A1W@00a5dM01=M0@A@g@002Id00<AM7@0Bg@34@=d1A4nM0009W@24DYd0Q43M003
4GAd00Ad0Q4mM0009G@00a5dM018M08A1G@00a5dM004M0034G@A03ad000UM0034GAd04Md00<AM7@0
1G@00a5dM005M0034G@A03]d000UM0034GAd04Md00<AM7@01W@00a5dM004M0034GAd008A>G@002Ed
00<AM7@0AW@00a5d4@07M0034GAd00Ad00<AM7@00W@00a5dM00fM0009G@00a5dM016M0034G@A00Md
00<AM7@017@00a5dM003M0034GAd03Ed000UM08AAW@01A5dM7@A00Md00<AM7@017@00a5dM003M003
4GAd03Ad000UM0034GAd04Ed00DAM7Ad4@07M0034GAd00Ad00<AM7@00g@24CEd000UM0034GAd04Ed
00<AM7@00W@00a5dM004M0034GAd00Ad00<AM7@00g@00a5d4@0dM0009G@00a5dM00bM0XA27@00a5d
M003M0034GAd00Ed00<AM7@00g@00a5dM004M0034G@A03=d000UM0034GAd031d0a48M0<A1W@00a5d
M004M0034GAd00Ad00<AM7@017@00a5dM003M0044GAd4C9d000TM0034GAd02md0Q43M0034GAd00Ed
00@AM7@A17@00a5dM005M0034GAd00Ad00<AM7@017@00a5dM003M0044GAd4C9d000TM08A;W@24@Ed
00<AM7@01W@00a5dM0024@9d00<AM7@01W@00a5dM004M0034GAd00=d00<AM7@00g@01A5dM7@A035d
000TM0034GAd02ad00<AM7@01W@00a5dM005M0034GAd009d00@AM14A1g@00a5dM004M0034GAd00=d
00<AM7@00g@00a5dM002M0034GAd02id000TM0034GAd02ad00<AM7@01W@00a5dM005M0034GAd00=d
0a48M0034GAd00=d00<AM7@00g@00a5dM003M0034GAd00=d00<AM7@0;G@002Ad00<AM7@0:g@00a5d
4@07M0034GAd00Ed00<AM7@017@34@Md00<AM7@017@00a5dM003M0034GAd00=d00<AM7@00g@00a5d
M00/M00097@00a5dM00[M0034G@A00Qd00<AM7@01G@00a5dM003M0<A1g@00a5dM004M0034GAd00=d
00<AM7@00g@00a5dM004M08A;7@002Ad00<AM7@0:W@01A5dM7@A00Md00<AM7@01G@00a5dM002M005
4G@AM1401g@00a5dM003M0034GAd00=d00<AM7@00g@00a5dM004M08A;7@002Ad0Q4KM0DA2g@01A5d
M7@A00Md00<AM7@01G@00a5dM002M0064GAd4G@A1W@00a5dM004M0034GAd009d00<AM7@00g@00a5d
M004M08A;7@002Ad00<AM7@05g@54@=d1A45M0034GAd00=d00<AM7@01G@00a5dM004M0034GAd009d
00DAM7@AM0024@Id00<AM7@00g@00a5dM003M0034GAd009d00<AM7@017@00a5d4@0[M0008g@00a5d
M00FM0<A0g@74@04M14A4@=d00<AM7@00g@00a5dM005M0034GAd00Ed00DAM7Ad4@02M0034GAd008A
1G@00a5dM003M0034GAd00=d00<AM7@00W@00a5dM004M0044GAd4BYd000SM0034GAd01Ad0a42M004
4GAd4@Ed0a42M0<A1g@00a5dM005M0034GAd00Ad00DAM7Ad4@02M0064GAd4G@A1G@00a5dM003M003
4GAd009d00<AM7@00g@00a5dM003M0044GAd4BYd000>M08A0g@00a5dM0024@=d0a45M0034GAd01=d
0a43M0044GAd4@Ed00<AM7@00Q42M0034GAd00Ed00<AM7@01G@00a5dM004M0054GAdM1400W@01a5d
M7@AM14017@00a5dM003M0034GAd009d00<AM7@00g@00a5dM003M0054GAdM140:G@000ed00@AM7@A
17@0115dM143M0034GAd00Ad00<AM7@04G@34@Ed00DAM7Ad4@05M0044G@AM08A00=d4A401W@00a5d
M004M0034GAd00Ad00DAM7Ad4@02M0034GAd009d00<AM14017@00a5dM002M0034GAd00=d00<AM7@0
0W@00a5dM003M0054GAdM140:G@000Md1142M0044GAd4@Ad00@AM7@A0g@00a5dM004M0034GAd011d
00@AM14A1W@0115dM145M0034G@A009d0a400g@A4@04M0034GAd00Ed00<AM7@00g@01A5dM7@A00=d
00DAM7Ad4@02M0054GAdM1401G@00a5dM002M0034GAd009d00<AM7@00g@00a5dM002M0034GAd02Id
000=M0044GAd4@Ad00@AM7@A0g@00a5dM004M08A47@24@04M15d4@Ed00@AM7@A1G@00a5d4@02M08A
00Ed4A5d4@04M0034GAd00Ad00<AM7@017@00a5d4@04M0034GAd009d00@AM7@A0g@00a5dM002M0HA
17@00a5dM003M0034GAd00=d00<AM7@09G@000ed00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@0
3g@00a5d4@02M0034GAd00=d00DAM7Ad4@04M0034GAd008A0W@00a5d4@034@=d00<AM7@01G@00a5d
M003M0034G@A00Ad00<AM7@00g@0115d4A42M0034GAd00<A17@34@9d00<AM7@017@00a5dM002M003
4GAd02Ed000=M0044GAd4@Ad00@AM7@A0W@24@Id00<AM7@03W@0115dM143M0034GAd00=d00@AM7@A
1G@0115d4A43M08A00Ad4G@A0g@00a5dM004M0034GAd00=d00<AM14017@00a5dM003M0044G@A4@=d
0Q43M0034GAd009d00<AM1400W@00a5dM003M0034GAd00=d00<AM7@097@000id0Q46M08A17@00a5d
M004M0034GAd00id00DAM15d4@02M0034GAd00=d00@AM7@A1G@0115d4A43M08A00Ed4A5d4@02M003
4GAd00Ad00<AM7@00g@00a5d4@04M0034GAd00Ad0Q401G@AM7@A00Ad00<AM7@00W@00a5dM0034@Ed
00<AM7@017@00a5dM00SM0008g@00a5dM00=M0034G@A009d00DAM7Ad4@04M0054GAdM14017@0115d
4A44M0034GAd008A00Ed4GAd4@06M0034GAd00=d0a43M0034GAd00Ad0Q42M0034G@A00Ed00DAM7Ad
4@04M0034GAd00=d00<AM7@017@00a5dM00SM0008W@00a5dM00=M0044GAd4@=d00@AM7@A1G@0115d
M144M0044GAd4@Ad00LAM7@AM15d00<A1W@00a5dM003M08A00=d4G@00W@00a5dM004M0034GAd008A
00=d4G@00g@01A5dM7@A00Ad0Q44M0034GAd00Ed00<AM7@08W@0029d0Q4>M0034G@A00Ad00DAM7Ad
4@04M0044GAd4@Ed00<AM1401G@00a5d4@02M0034GAd008A1G@00a5dM003M08A00=d4G@00W@00a5d
M004M08A0W@00a5d4@04M0034GAd009d00LAM7Ad4G@A00=d00<AM7@01G@00a5dM00RM0008W@00a5d
M00<M0044GAd4@Ed00@AM7@A17@01A5dM7@A00Ad0a45M0<A0g@0115dM146M0034GAd009d0Q42M004
4GAd4@Id0Q42M0044GAd4@Ad00DAM7Ad4@03M0044GAd4@9d00<AM7@01G@24B=d000RM0034GAd00ad
00<AM1401W@01A5dM7@A00Ad00@AM7@A17@34@Ed0a44M0044GAd4@Ed00<AM7@00g@01a5dM7@AM140
1W@0115d4G@24@03M15d00=d00DAM7Ad4@04M0064GAd4G@A1g@24B=d000RM0034GAd00]d00<AM7@0
0Q46M0044GAd4@Ad00DAM7Ad4@03M08A00=d4G@00g@00a5d4@05M0044G@A4@Ed00<AM7@00W@24@=d
0Q46M0044G@A4@9d00<AM1400g@01A5dM7@A00Ad00@AM7Ad0Q46M0044GAd4B9d000RM0034GAd00]d
0Q400g@A4@06M0054GAdM14017@0115dM144M0034G@A00Ad00@AM14A1G@0115d4A44M0LA17@00a5d
M004M0044GAd4@9d00<AM14017@01A5dM7@A00=d00<AM7@00W@00a5dM004M0044GAd4B9d000RM003
4GAd00]d0a42M0034GAd00Ad00@AM7@A17@0115dM144M0034G@A00Ad00@AM14A1G@44@9d0a44M0@A
0g@00a5dM003M0034GAd008A0W@00a5d4@03M0054GAdM1400g@00a5dM002M08A1G@01A5dM7@A025d
000RM0034GAd00Yd00@AM7@A0g@00a5dM003M0054GAdM1400g@01A5dM7@A009d0Q400g@AM003M003
4GAd008A17@64@=d00<AM7@00W@00a5dM0024@03M15d00Ad00<AM7@00Q43M08A17@0115dM143M003
4GAd009d0Q45M0054GAdM1408G@0029d0Q4;M0034GAd008A0W@00a5dM004M0044GAd4@Ad00@AM7@A
0W@24@9d00DAM7Ad4@02M0034G@A00=d00HAM14AM143M0034GAd009d00<AM7@00W@34@Ad00HAM7@A
M142M0034G@A00=d00@AM7@A0g@00a5dM002M0034G@A00Ad00<AM7@00W@00a5dM00NM0008W@00a5d
M00:M0034GAd008A0g@00a5dM003M0054GAdM1400g@0115dM142M0<A00=d4G@00W@01Q5dM15d4@=d
00HAM14AM143M0034GAd009d00<AM7@00g@34@=d00HAM7@AM143M08A0g@01A5dM7@A00=d00LAM7Ad
4G@A00Ad00<AM7@00W@00a5dM00NM0008G@00a5dM00;M0064GAd4G@A0W@00a5dM004M0044GAd4@=d
00HAM7Ad4G@34@03M15d009d00@AM7@A0W@01A5dM15d00<A00=d4G@00W@01A5dM7@A00Ed00@AM14A
0W@0115dM142M0064GAd4G@A0g@0115dM143M0054GAdM1400W@01A5dM7@A00Ed00<AM7@07G@0025d
00<AM7@02g@0115dM142M0044GAd4@Ed00DAM7Ad4@03M00:4GAd4G@AM15d4@=d00@AM7@A0W@0215d
M15d4G@A0W@0115dM143M08A17@00a5dM0024@04M15d4@Ad00<AM1400Q43M0044GAd4@=d00DAM7Ad
4@03M0044GAd4@Ed00<AM7@07G@0025d00<AM7@02g@00a5d4@03M0054GAdM1401G@0115dM143M007
4GAd4G@AM0024@05M15dM1400W@01Q5dM7@AM0<A0W@01Q5dM15d4@=d0Q44M0054GAd4G@00Q400g@A
M003M08A00Ad4G@A0g@0115dM142M0054GAdM1400g@00a5d4@07M0034GAd01ad000QM0034GAd00Yd
00@AM7@A17@0115dM145M0054GAdM1400W@0115dM7@24@9d0a43M0034G@A00Ad1142M08A00Ed4GAd
4@02M08A1G@00a5dM0034@03M15d00Ad00<AM7@00Q43M0044GAd4@9d00DAM7Ad4@04M08A1g@00a5d
M00LM0008G@24@]d00@AM7@A1G@0115dM145M0044GAd4@=d00<AM7@02142M0044GAd4@=d0Q400g@A
M002M0064GAd4G@A0g@24@Ad00@AM7Ad0Q400g@AM004M0064GAd4G@A0W@0115dM142M0054GAdM140
17@24@Qd00<AM7@06g@0025d00<AM7@02W@0115dM145M0054GAdM14017@01A5dM7@A009d21400g@A
4@034@9d00@AM7Ad0Q400g@AM002M08A0W@24@=d0Q44M0034GAd009d0a45M08A0W@24@=d00<AM140
0g@0115dM145M0034GAd00Id00<AM7@06g@0025d00<AM7@02W@0115dM146M0044GAd4@Ed00DAM7@A
M0034@9d00<AM7@00a400g@AM0024@03M15d009d1144M08A00Ad4G@A0W@24@Ad00<AM7@00W@34@Ed
0Q42M0034G@A009d00@AM7@A0W@01A5dM7@A00Ad0Q48M0034GAd01Yd000QM0034GAd00Yd00<AM140
27@0115dM144M0034GAd00<A00Ed4GAd4@02M0034GAd00@A00=d4A400g@44@Ad0Q42M08A0W@24@Ad
00<AM7@00W@44@=d00@AM7@A0W@24@9d00@AM7@A0W@01A5dM7@A00Ad0Q48M0034GAd01Yd000QM003
4GAd00Ud00@AM7@A2G@0115dM144M08A00Ed4GAd4@02M0084GAdM15d4G@24@9d0Q42M08A00=d4G@0
17@24@03M14A009d00<AM1400g@00a5dM002M0054G@AM1400W@02A5dM7@AM15d4@02M0034G@A009d
00DAM7Ad4@04M0034G@A00Id00<AM1406g@0021d00<AM7@02W@0115dM149M0044GAd4@Ad00@AM14A
0g@0115d4A42M0034G@A009d0Q401G@AM15d008A00=d4G@017@64@04M14A4@=d00<AM7@00W@00a5d
4@024@9d00DAM7Ad4@02M08A0W@00a5d4@02M0054GAdM14017@00a5d4@06M0034G@A01]d000PM003
4GAd00Yd00<AM7@00Q49M0044GAd4@=d0a401G@AM7@A009d00HAM7@AM142M0@A0W@34@03M14A00Ed
0Q42M0044G@AM08A0W@00a5dM002M0084G@A4G@AM144M0054G@AM1400W@01A5d4G@A00=d00DAM7Ad
4@03M0034GAd009d00DAM7Ad4@0JM00087@34@Yd0Q4017@AM149M0034G@A009d00<AM1400W@0115d
M142M08A00Qd4GAd4G@AM0<A0W@24@04M15d4@=d114017@A4G@24@05M15dM1400g@01Q5d4G@AM08A
17@00a5dM0024@9d0a42M0044GAd4@=d00DAM7Ad4@04M0054GAdM1406W@0021d00<AM7@02W@0115d
4A42M0034GAd00Id00LAM7@AM15d008A0W@01A5dM15d008A0W@00a5d4@02M0034G@A008A00=d4G@0
0Q400g@AM002M0044G@A4@9d00TAM15d4G@AM1400g@00a5d4@02M0<A1G@0115d4G@34@03M14A008A
0W@01A5dM7@A00Ad00DAM7Ad4@03M0034GAd01Qd000PM0034GAd00Yd00@AM7@A0g@00a5dM006M008
4GAd4G@AM142M0054GAd4G@00Q42M0034G@A009d00DAM7@AM0024@9d00@AM7@A0W@01Q5d4G@AM0<A
00Ad4GAd0Q43M0054GAd4G@00Q400g@AM004M0044G@A4@9d00DAM15d4@02M0054GAdM14017@0115d
M145M0034GAd01Md000GM08A1g@00a5dM00:M0034GAd008A0g@00a5dM006M0054G@AM1400W@0115d
M142M08A00Id4G@AM142M0034GAd008A00Ad4GAd0Q42M0044G@AM0<A0W@24@03M15d009d0Q42M004
4GAd4@9d00<AM1401G@0115d4A42M0044G@AM08A00=d4G@00W@00a5dM003M0034G@A00Ed00<AM7@0
5g@001Id00@AM7@A1W@00a5dM00:M0064GAd4G@A0g@00a5dM005M08A00=d4G@00W@0115dM142M08A
00Ad4G@A0W@00a5d4@02M0034G@A008A00=d4A400W@02A5d4A5d4G@AM0024@9d00PAM7@AM15d4@9d
00<AM7@00Q400g@AM004M00;4G@A4G@AM15d4G@00Q43M0034GAd00=d0Q46M0034GAd01Md000FM004
4GAd4@Id00<AM7@02W@0115dM142M0054GAdM1401g@0115d4A43M0054GAd4G@00Q402G@AM7@AM15d
4@02M0054GAd4G@00Q401g@AM7@AM1400W@24@03M14A009d00@AM7@A0W@24@9d00<AM7@00Q42M003
4GAd009d1142M08A00Ed4GAd4@03M0034GAd00Ad00<AM7@01G@00a5dM00FM0005W@0115dM146M003
4GAd00Yd00@AM7@A0g@01A5dM7@A00Id1143M0044GAd4@9d00XAM7@AM15d4G@A0W@00a5dM0044@9d
00DAM15d4@02M0044G@AM08A00Ed4GAd4@03M08A00Ad4G@A0W@0115dM144M00;4G@A4G@AM15d4G@0
0Q42M0034GAd00Ad00<AM7@01G@00a5dM00FM0005W@0115dM145M08A37@0115dM144M0054GAdM140
1G@34@03M15d009d00HAM7@AM142M0074G@AM15d4@02M0054GAd4G@00Q42M0034G@A008A0g@24@03
M14A008A0W@01Q5dM7@AM08A00Ed4GAd4@03M0034GAd00DA00Md4G@AM15d008A00=d4G@01G@00a5d
4@07M0034GAd01Ed000FM0044GAd4@Ed00<AM7@02g@0115dM145M0054GAdM1400g@0115dM142M004
4GAd4@9d00PAM14AM15d4@9d0Q43M0034G@A009d0Q42M08A00=d4G@00W@00a5d4@034@05M15dM140
0W@01Q5dM15d4@=d00HAM7Ad4G@34@04M14AM08A00Ed4G@AM0024@Id00<AM1401g@00a5dM00EM000
5g@24@Id00<AM7@02g@0115dM146M0054GAdM1400W@00a5dM0024@03M15d009d00<AM7@0114027@A
M15d4G@A0W@00a5d4@02M0034G@A009d0a44M08A00=d4G@00Q42M0044GAd4@9d0a44M0034GAd00<A
0W@34@08M14AM15d4G@24@Ed00DAM7Ad4@06M0034GAd01Ed000OM0034GAd00]d00@AM7@A1g@02a5d
M7@AM15d4G@A009d00@AM7@A0W@34@09M14AM15d4G@A009d00<AM1400W@34@06M14A4G@A0g@00a5d
4@074@9d00DAM7@AM0024@=d00@AM7Ad0Q42M08A00Ad4A5d0Q401G@AM7@A00Ed00DAM7Ad4@07M003
4GAd01Ad000OM0034GAd00]d00@AM7@A27@0115dM7@24@05M15dM1400W@0115dM142M0<A00Qd4A4A
M15d4@9d00<AM1400W@00a5d4@024@05M15dM1400g@34@9d00@AM7@A0W@01A5dM7@A009d00PAM7Ad
4G@AM08A0W@34@06M14A4G@A0W@24@=d00<AM7@00W@00a5dM005M0034GAd01Ad000OM0034GAd00]d
00@AM7@A2G@01a5dM7@AM1400g@01Q5dM15d4@9d0a42M08A0W@24@9d00<AM1400W@00a5dM0024@05
M14AM1400g@00a5d4@044@05M14AM1400g@01A5dM7@A009d00@AM15d0Q42M0<A00Ad4A5d0Q42M08A
0g@00a5dM003M0034GAd00Ed00<AM7@04g@001md00<AM7@02g@0115dM14:M0044G@AM08A17@00a5d
4@02M0094GAd4G@AM15d00@A0W@01A5d4G@A00Ad00@AM14A0W@00a5d4@054@05M15d4G@00Q43M003
4GAd009d0Q401g@AM7@AM1400W@54@03M14A009d00DAM15d4@06M0034GAd00Ed00<AM7@04g@001md
0Q4<M0044GAd4@]d0Q42M0034GAd009d00HAM7@AM142M0034G@A009d0Q400g@A4@02M0<A00=d4G@0
0g@24@9d00TAM15d4G@AM1400W@00a5d4@02M0054GAdM1401W@24@9d00<AM1400g@24@03M14A008A
0W@01A5d4G@A00Md00<AM7@00W@34AEd000OM0034GAd00]d00@AM7@A37@00a5dM0024@Ad00LAM7@A
M15d00<A0W@24@05M14A4G@00a400g@AM002M0064G@A4G@A0W@01A5d4A5d008A00Ad4A4A0W@24@9d
00<AM7@017@34@9d00<AM1400W@74@03M15d009d00<AM7@01W@01A5dM7@A00=d00<AM7@04W@001md
00<AM7@02g@0115dM14<M08A00Ad4G@A17@01Q5d4G@AM08A00=d4G@00Q42M0044G@AM08A00=d4G@0
0W@00a5d4@024@03M15d00<A00Ad4A4A0W@0115d4G@24@04M15d4@Ad00<AM7@00Q401G@AM7@A009d
1Q400g@AM002M0034GAd00Md0a44M0034GAd019d000OM0034GAd00]d00@AM7@A37@0115d4A42M005
4GAdM1400W@0115d4G@34@9d0Q4017@A4G@34@03M15d009d00<AM1400Q42M0<A00=d4A400a401g@A
M15d4G@00Q400g@AM003M0044GAdM0<A0g@0115d4G@34@03M14A009d00<AM14027@00a5dM004M003
4GAd019d000NM0034GAd00ad00@AM7@A37@0115dM143M0054GAdM1400W@24@06M14AM15d1A42M08A
00=d4G@00W@24@9d0Q4017@A4G@24@05M14A4G@00a401g@AM7@AM1400g@00a5dM002M0034G@A00Ad
00<AM1401Q42M0034G@A00Id0a47M0034GAd015d000NM0034GAd00ad00<AM7@00a4:M0034GAd008A
0g@0215dM7@AM15d0Q400g@A4@0<4@9d00<AM1400W@01Q5d4G@AM08A00Ed4A4AM0034@07M15dM15d
4@03M0034GAd009d00@AM14A0g@00a5d4@064@03M15d009d00<AM7@00W@01A5dM7@A00Id00<AM7@0
4G@001id00<AM7@037@44@9d0Q48M0064GAd4G@A0g@0115dM142M0LA00=d4G@00Q42M08A00Md4A5d
4G@A00=d00DAM14AM0024@9d0a401G@A4G@A009d0a42M0034GAd00Ad0Q400g@A4@02M0034G@A00DA
00=d4G@00W@01A5dM7@A00Ad00<AM7@017@00a5dM00AM0007W@24@ed00<AM7@00Q43M08A1W@0115d
M142M0054GAdM1400W@00a5dM0024@9d0Q4017@AM7@24@03M15d008A00Ed4A5d4@03M0034G@A008A
0W@0115d4G@64@08M15d4G@AM146M08A0g@00a5dM0074@03M15d00=d0a45M0034GAd00Ed00<AM7@0
47@001id00<AM7@03G@00a5dM0034@=d00<AM7@00g@0115dM143M0054GAdM1400W@01A5dM15d00<A
00Id4A5d4G@24@03M14A009d0Q45M0044G@A4@=d00DAM14AM0074@04M14A4@Qd0Q43M0XA1G@00a5d
M006M0034GAd00Ad00<AM7@047@001id00<AM7@03G@0115dM142M0044GAdM08A0g@0115dM144M005
4GAdM1400W@00a5d4@024@07M15dM15d4@02M0HA00Ad4A4A0W@24@04M15d4@9d00@AM15d1A400g@A
M0054@Md0Q42M0@A00=d4A400Q400g@AM002M0<A27@00a5dM004M0034GAd011d000NM0034GAd00ed
00@AM7@A0g@24@=d0Q401G@AM7@A00Ed00HAM7Ad4G@24@04M15dM08A00Ad4G@A0W@64@04M15dM0<A
00Ad4A5d0Q42M0DA00Ed4A5d4@03M0034GAd00HA0W@34@Ad1Q42M08A0g@00a5dM005M0034GAd00Ed
00<AM7@03g@001id00<AM7@03G@0115dM145M08A0g@24@9d00<AM7@017@0215dM7@AM15d0Q42M003
4G@A009d00@AM15d0Q4017@AM143M0DA0W@24@03M14A008A00Id4A4AM142M0<A1g@54@Ed1A400g@A
M004M0034GAd00Ed00<AM7@01G@00a5dM00?M0007W@00a5dM00=M0044GAd4@Md0Q42M0@A1g@0115d
M7@54@9d00LAM7@AM15d00@A00=d4A4017@00a5d4@024@9d00@AM15d1a401g@AM7@AM1401g@34@9d
2a46M0034GAd00Id00<AM7@017@00a5dM00?M0007G@00a5dM00>M0044GAd4@Ud0a42M0034GAd00Id
00@AM7Ad0a402W@AM7@AM15d4G@24@05M14AM1400g@00a5d4@02M0044GAd4@9d00<AM1401Q42M004
4GAd4@Ed0Q43M0034GAd00Ed1a45M0034GAd00Ed00<AM7@01G@00a5dM00>M0007G@24A1d00<AM140
2g@00a5dM0034@Md00@AM15d0Q402W@A4G@AM15d4G@24@04M14AM08A0W@00a5d4@02M0<A00Md4G@A
M15d00DA0W@01A5dM7@A00=d00<AM7@00g@00a5dM005M0DA0W@84@Ed00<AM7@01G@00a5dM00>M000
7G@00a5dM00?M0034G@A00]d1142M08A1W@24@9d0Q400g@AM0084@03M14A00<A00Ad4G@A17@0115d
4A42M0034G@A00DA00=d4G@00g@0115d4A46M08A17@24@03M14A00<A1W@00a5dM0044@9d00<AM7@0
17@00a5dM00>M0007G@00a5dM00?M0044GAd4@Yd00<AM7@00Q43M0034GAd00Ad00<AM7@00Q401W@A
4G@AM0DA00Ad4A4A0W@34@Ed00DAM7Ad4@02M0TA17@24@Ud00DAM7Ad4@03M0HA1G@00a5dM004M0HA
17@00a5dM00=M0007G@00a5dM00?M0044GAd4@]d00<AM7@00Q43M08A17@24@03M14A00/A00=d4A40
0Q4017@AM145M08A0W@;4@Ad0a49M0@A0g@64@03M14A00=d00<AM7@01W@0115dM7@54@md000MM003
4GAd00md00@AM7@A2g@01A5dM15d008A0g@24@9d00<AM1400Q400g@A4@0@4@Id0Q43M0XA0W@24@9d
0Q48M08A1G@74@9d00DAM7Ad4@07M0034GAd00Ed00<AM7@03G@001ed00<AM7@047@00a5d4@0;M004
4GAd4@=d0Q43M0034G@A009d00DAM14AM0084@05M14A4G@01a43M0DA0W@94@Ad0Q47M0<A17@00a5d
4@064@9d00@AM7@A1g@00a5dM005M0034GAd00ed000MM0034GAd011d00<AM1402g@0115dM145M004
4GAdM08A0W@34@03M14A00<A00=d4A4021400g@AM002M0TA0W@74@Id00<AM7@017@00a5dM0024@=d
00<AM1401A4017@AM7@34@Qd00<AM7@01G@00a5dM00<M0007G@00a5dM00@M0034G@A00]d00@AM7@A
1W@24@9d11400g@AM00:4@03M14A00<A00=d4G@017@34@9d00<AM1402146M0034GAd009d0Q43M08A
0W@00a5dM0074@03M15d009d00<AM7@01W@00a5dM005M0034GAd00ad000LM0<A4G@00a5d4@0<M003
4G@A00Qd0a42M0054GAd4G@00Q400g@A4@044@04M14AM08A0W@00a5dM0034@03M14A009d00<AM7@0
31400g@A4@02M0034GAd00=d0Q42M0034GAd00HA00Ad4G@A0W@34@Id00<AM7@01G@00a5dM00<M000
77@00a5dM00AM0044GAd4@]d00<AM1402W@00a5dM0054@03M14A00HA00Id4A4AM142M0@A0g@24@9d
00<AM7@01a45M0LA1G@00a5d4@03M0DA00=d4A400W@00a5d4@02M0034GAd00=d00<AM7@01G@00a5d
M00<M00077@00a5dM00AM0044GAd4@]d00<AM1402W@44@9d0Q400g@A4@084@04M15dM0@A1G@24@9d
0a400g@A4@064@Ed00<AM7@00W@:4@04M14AM0@A00Id4G@AM143M0034GAd009d00<AM7@01G@00a5d
M00<M0001g@24@=d00<AM7@00Q43M0<A1G@00a5dM00BM0034G@A00]d00@AM7@A2G@00a5dM0024@05
M15d4G@02a42M0@A1G@01A5d4G@A00=d1a4017@AM7@34@Ud0Q43M0LA00Qd4G@AM15d4@=d0Q42M003
4GAd00Id00<AM7@02g@000Id00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@04W@00a5d4@034@Ud
00<AM1402G@0115dM7@44@03M14A00PA0W@34@=d00<AM7@00g@34@04M15dM0PA00=d4A400W@24@Qd
0a43M0034G@A00<A00Ad4G@A0W@24@Ed00@AM7@A1g@00a5dM00;M0001W@0115dM144M0044GAd4@=d
00<AM7@017@00a5dM00BM0hA00Ad4G@A2W@0115dM142M0034GAd00TA00=d4A400W@0115dM145M08A
0W@0115d4G@94@05M15dM14027@00a5d4@02M0034GAd008A00Md4A5d4G@A009d00<AM7@017@34@Md
00<AM7@02g@000Id00@AM7@A17@0115dM143M0034GAd00Ad00<AM7@04W@0115dM144M10A17@0115d
M142M0<A00=d4A402A42M0044GAd4@=d0a401g@AM15d4G@02143M0<A27@24@04M15d4@9d0Q401g@A
4G@AM1400W@24@Md00<AM7@01G@00a5dM00;M0001W@0115dM144M0044GAd4@=d00<AM7@017@00a5d
M00CM0034G@A00]d00@AM15d6a43M0034G@A009d00@AM14A0g@24@03M14A009d1a400g@AM003M08A
1W@00a5d4@02M08A0W@03Q5d4A5d4G@AM15d4G@A1W@24@Md00<AM7@02W@000Id00@AM7@A17@0115d
M142M08A1W@00a5dM00CM0034G@A00ad00<AM1401W@;4@03M14A00/A0W@0115dM145M08A0W@00a5d
M0084@03M15d009d0a45M0034G@A009d0Q42M0044G@AM08A00Ad4GAd0Q42M0034GAd00=d00@AM14A
1G@00a5dM00:M0001g@24@Id0Q44M0034GAd00Ad00<AM7@04g@0115dM14;M0034G@A00Ud00DAM7Ad
4@02M2<A00Ad4A5d0Q42M0034GAd008A00=d4G@00W@0115dM143M0074GAd4G@AM0024@9d00@AM14A
0W@00a5dM003M0054GAdM14017@00a5dM00:M00077@00a5dM00CM0044GAd4@]d00<AM1402W@0115d
M143M0034GAd00TA0W@34@9d00<AM7@02Q400g@A4@064@9d00HAM15d4G@24@05M15dM1400g@24@0:
M15d4G@AM15d4@9d00DAM7Ad4@05M0054GAdM1400g@00a5dM00:M0006g@00a5dM00EM0034G@A00]d
00@AM7@A2G@0115dM143M0<A00=d4A401A4017@A4A42M0034G@A00Md00@AM15d1a4017@AM142M004
4G@A4@=d0Q42M0044GAdM08A00Qd4G@AM15d4@9d00@AM14A0g@00a5dM002M0034GAd009d00@AM7@A
37@001]d00<AM7@05G@00a5d4@0<M0034G@A00Ud00@AM7@A0W@34@03M14A00/A00Ad4G@A1g@00a5d
M0024@03M14A00<A00Ad4G@A0g@24@07M15dM15d4@02M0054GAd4G@00Q4017@AM7@24@9d00@AM14A
17@01A5dM7@A00Ed0Q400g@AM00:M0006g@00a5dM00EM0044GAd4@]d00<AM1402G@0115dM7@44@03
M15d00XA00Ad4A4A0W@00a5dM003M08A0W@24@05M15d4G@00Q4017@AM143M0054G@AM1400g@34@03
M15d009d00PAM7@AM15d4@9d00@AM7@A17@0115dM147M08A2g@001]d00<AM7@05G@0115dM14;M004
4GAd4@Ud1143M0/A00Ed4A4AM0044@Ed00@AM15d0Q401G@AM15d008A00Ad4G@A0g@34@03M15d00Ad
00<AM1400g@24@06M15d4G@A0W@0115dM145M0034G@A00Qd00<AM7@02G@001]d0Q4GM0034G@A00]d
00@AM7@A2G@44@=d00<AM1402A400g@A4@034@03M15d00=d00HAM7@AM142M0034G@A00HA00Id4GAd
4G@24@Id0a43M0094G@A4G@AM15d008A0g@00a5dM002M0034G@A00Qd00<AM7@02G@001]d00<AM7@0
5W@0115dM14;M0044GAd4@Id0a43M0034G@A00LA00Ed4A5d4@02M08A00=d4G@00a42M0034GAd00@A
00Ad4GAd1Q42M08A0g@00a5dM004M0044G@A4@9d00<AM7@00Q400g@AM0024@05M15dM1401G@00a5d
4@07M0034GAd00Ud000KM0034GAd01Id00@AM7@A2g@0115dM144M0<A0W@01a5dM15d4G@02Q401W@A
M7@AM0<A0W@24@=d114017@AM7@44@04M14AM08A0g@24@Ed00LAM15d4G@A009d00<AM1400a42M005
4GAdM1401G@24@Md00<AM7@02G@001]d00<AM7@05W@0115dM14;M0044GAd4@9d0a44M0064GAdM15d
2A401W@AM7@AM0<A00Md4A5d4G@A009d00HAM14AM142M0<A00Ad4A4A0W@01Q5dM15d4@Ed00<AM140
0W@24@9d00HAM7@AM143M0054GAdM1401G@00a5dM005M0034GAd00Ud000KM0034GAd01Md00@AM7@A
2W@0115dM7@34@Md00DAM14AM0094@04M14AM08A00Id4A5d4G@24@9d0a401G@A4G@A009d00@AM15d
0Q400g@AM0024@05M15dM14017@00a5d4@03M08A00Ed4A5d4@02M0044GAd4@=d00<AM7@00g@24@Md
00<AM7@027@001Yd00<AM7@067@0115dM14;M0@A2G@0115d4G@24@03M14A00<A00Ed4GAd4@02M0HA
00=d4G@00Q42M0HA0W@0115d4G@24@03M15d00<A0g@24@=d0Q44M0034G@A008A0W@00a5d4@03M005
4GAdM14017@00a5d4@06M0034GAd00Qd000JM0034GAd01Qd00@AM7@A2g@44@Yd00<AM140214017@A
M7@24@9d0a400g@A4@04M0034GAd00DA0W@01Q5d4A5d4@9d00@AM7@A17@24@=d00<AM7@00W@01A5d
M7@A009d00<AM1400g@01A5dM7@A00Ad00<AM1401W@00a5dM008M0006W@00a5dM00HM0044GAd4@Ud
0a43M0034GAd00Id0Q400g@AM0084@0;M15d4G@AM15d4G@00Q45M0<A0W@34@9d00@AM15d0Q4017@A
M7@24@=d00<AM1400W@00a5dM002M0054GAdM1400W@0115dM142M0034GAd009d00DAM7Ad4@02M003
4GAd00=d00<AM7@027@001Yd0Q4JM0044GAd4@Id0a42M0044GAd4@Qd00@AM15d2A4017@AM7@24@9d
11400g@AM005M0034GAd00<A0W@0115d4G@44@04M15d4@Ad0Q42M0034GAd009d00DAM7Ad4@02M004
4GAd4@=d00<AM7@00W@0115dM143M0034GAd009d00<AM7@027@001Yd00<AM7@06G@0115dM144M0<A
17@01A5dM7@A00Id00DAM7@AM0094@07M15dM15d4@02M0<A0W@00a5dM003M0DA00Ed4A4AM0024@04
M14AM08A0W@02A5dM7@AM15d4@04M0054GAdM1400g@00a5d4@03M0034GAd009d00@AM7@A17@01A5d
M7@A00Yd000JM0034GAd01Ud00@AM7@A0W@34@Md00@AM7@A1W@01a5d4A5d4G@01a400g@A4@02M003
4G@A00<A00Ed4GAd4@04M0034GAd008A0g@64@9d00DAM7Ad4@04M0044G@A4@Ad00DAM7Ad4@03M004
4GAd4@=d00<AM7@00W@00a5d4@04M0054GAdM1402W@001Yd00<AM7@06G@0115dM7@34@Ud00DAM7Ad
4@04M0074GAd4G@AM0064@03M15d008A0W@01A5d4A5d008A00Ed4GAd4@02M08A0W@44@03M15d00DA
00=d4A400g@01Q5dM7@AM0<A17@00a5dM0024@9d00@AM7@A0g@00a5dM002M0034G@A00Ed00@AM7@A
2W@001Yd00<AM7@06W@44@ad00@AM7@A17@00a5d4@02M0034G@A00DA00Ed4GAd4@02M0034GAd008A
00Ed4GAd4@02M0@A0W@24@9d0Q42M0@A00=d4A4017@0115dM7@44@Ad00DAM7Ad4@02M0044GAd4@Ad
00<AM7@00W@24@Id00@AM7@A2G@001Yd00<AM7@06W@0115dM14<M0044GAd4@=d00<AM1400g@00a5d
4@044@03M14A009d0Q42M08A00=d4G@00Q42M0044GAdM08A0g@0115dM7@84@9d00DAM7Ad4@03M0<A
00=d4G@00W@01A5dM7@A00=d00@AM7@A0g@00a5dM002M08A1g@00a5d4@09M0006W@00a5dM00JM005
4GAdM1402g@01a5dM7@AM1400W@0315dM7@AM15d4G@AM08A0W@24@9d00@AM14A0W@01A5dM7@A009d
0a42M0054GAdM1400W@54@9d00<AM7@00W@0115dM7@24@9d00@AM7@A0g@01A5dM7@A009d00<AM7@0
0W@00a5dM002M0034GAd00Ed00<AM1402G@001Ud00<AM7@077@0115dM14<M0084GAd4G@AM144M0<A
00Ed4G@AM0024@9d0Q42M0<A00Ed4GAd4@03M08A0W@0115dM144M0054G@A4G@00Q43M0034GAd009d
00<AM7@00Q43M0034G@A00=d00DAM7Ad4@02M0034GAd009d00<AM7@00W@24@Md0Q49M0006G@24Aed
00DAM7Ad4@0;M0054GAdM1400W@01Q5dM7@AM0@A00Ed4GAd4@02M0064G@A4G@A0g@0115d4A43M003
4GAd008A00=d4G@00g@01A5d4A5d008A0g@00a5dM002M0034GAd00<A0g@24@=d00DAM7Ad4@03M005
4GAdM14017@24@Qd00<AM7@01g@001Ud00<AM7@07G@0115dM14<M0064GAd4G@A17@00a5d4@054@9d
0Q42M0HA0g@00a5d4@03M08A00=d4G@00Q44M0044G@AM0@A0g@00a5dM002M0034G@A008A0g@24@=d
00<AM7@00W@0115dM144M0044GAd4@9d00<AM7@01G@00a5dM007M0006G@00a5dM00MM0054GAdM140
2g@0115d4G@24@Ad00<AM1401A42M08A00=d4A400a400g@AM002M0044GAd4@9d00@AM14A0W@00a5d
M002M0044G@AM0@A0g@00a5dM002M08A00Ad4G@A0g@0115dM7@24@=d00DAM7Ad4@03M0044GAd4@9d
00<AM7@01G@00a5dM007M0006G@00a5dM00NM0044GAd4@ad0Q400g@AM004M0034G@A00<A00Ad4A5d
1A400g@A4@02M0064GAdM15d0Q401G@AM7@A009d0Q43M0034GAd00<A00=d4G@00g@00a5dM002M003
4G@A009d00<AM7@00Q43M0054GAdM1400g@00a5dM002M0034G@A00=d00<AM7@017@00a5dM007M000
6G@00a5dM00NM0054GAdM1402g@01A5d4G@A00Ad00@AM15d0Q400g@AM0044@03M15d008A0W@00a5d
M002M0044G@A4@=d0Q4017@A4A42M0034GAd00<A00=d4A400g@00a5dM002M0<A0g@01A5d4G@A009d
00DAM7Ad4@03M0034GAd009d00<AM1400g@00a5dM004M0034GAd00Md000IM0034GAd01md00@AM7@A
2W@01Q5d4A5d4@Ad00@AM15d1A4017@A4A42M0<A0g@01Q5dM7@AM08A0g@00a5d4@024@04M15d4@9d
00<AM1400W@00a5dM002M0044GAdM0<A0g@00a5d4@02M0034G@A00Ad00DAM7Ad4@04M0034GAd00=d
00<AM7@00g@00a5dM007M0006G@00a5dM00OM0054GAdM1402G@00a5d4@03M0044GAd4@9d00HAM14A
M142M0064G@A4G@A0W@0115dM144M0044G@A4@9d00<AM7@00Q42M08A0W@01Q5d4A5d4@Ad00LAM7Ad
4G@A00Ad0Q43M08A17@01A5dM7@A00Ad00<AM7@00g@00a5dM003M0034GAd00Md000IM0034GAd021d
00@AM7@A27@00a5dM0024@9d00DAM7@AM0024@05M14AM1400W@01Q5d4A5d4@9d00DAM7Ad4@04M0@A
00Ad4GAd0Q43M0054GAd4G@00Q42M0034GAd009d00DAM7@AM0024@Ad00<AM7@00W@24@=d00DAM7Ad
4@04M0034GAd00Ad00<AM7@00W@00a5dM007M00067@34B5d00@AM7@A27@00a5d4@02M0074GAd4G@A
M0024@05M14AM1400g@24@04M15d4@9d00@AM7@A17@24@07M15d4G@AM0024@9d0Q400g@AM0024@9d
00<AM7@00W@01A5dM15d008A17@24@=d00<AM7@00W@00a5dM002M0064GAd4G@A1W@01A5dM7@A00Ud
000HM0034GAd025d00DAM7Ad4@06M0034G@A00=d00LAM7@AM15d008A00Ad4A5d0Q42M0064G@A4G@A
0g@0115dM144M0044GAd4@9d00DAM15d4@02M0034G@A009d00<AM7@00Q44M08A00Ed4GAd4@03M003
4G@A009d0Q44M0054GAdM1400W@00a5d4@06M0054GAdM1402G@001Qd00<AM7@08W@0115dM145M004
4GAd4@Ad00<AM7@00Q4017@A4G@24@03M14A009d00@AM15d0Q43M0044GAd4@=d00@AM15d0Q4017@A
M142M0034G@A008A0W@01A5dM7@A00Ad0Q400g@AM002M0044GAd4@9d1144M0074GAdM15d4@03M003
4GAd00Ad00@AM7@A2G@000=d0Q43M0034GAd008A0W@44@Ed00<AM7@08W@01A5dM7@A00Ad00<AM140
1G@00a5dM0024@04M14AM08A00=d4A400W@01a5d4G@AM1400g@0115dM142M0034GAd00DA00=d4G@0
0W@24@05M14AM1400g@24@Ad00<AM1400g@0115dM144M08A17@00a5dM002M08A0g@00a5dM004M004
4GAd4@Ud0002M0044GAd4@Ad00@AM7@A0W@00a5dM005M0034GAd02=d00@AM7@A0g@0115dM146M003
4G@A008A00=d4G@00Q400g@A4@02M0054GAd4G@00Q43M0074GAdM15d4@02M08A00Ed4A5d4@04M006
4GAd4G@A0g@24@Ad00<AM14017@00a5d4@04M0<A0g@0115dM7@24@Ed00<AM7@017@00a5d4@09M000
0W@0115dM144M0044GAd4@=d00<AM7@017@0115dM14RM0054GAdM1400W@00a5d4@08M0@A00Ad4G@A
0W@24@9d00DAM7@AM0024@Ad00HAM7@AM143M0064GAd4G@A17@24@03M14A008A0g@24@=d0Q46M08A
17@24@05M14A4G@00a400g@AM004M0034GAd00Ad00<AM1402G@0009d00@AM7@A17@0115dM143M003
4GAd00Ed00<AM1408g@0215dM15d4G@A2G@24@06M15d4G@A0W@24@9d00@AM7@A0W@24@=d00@AM7Ad
0Q43M08A00Ad4A4A17@01A5d4A5d008A0g@24@=d0Q46M08A17@24@Ad0Q44M0034GAd00=d00<AM7@0
17@24@Ud0002M0044GAd4@Ad00@AM7@A17@00a5dM005M08A8g@01A5dM7@A009d00<AM7@027@01a5d
4G@AM1400W@24@=d00@AM7@A0W@00a5dM002M0034GAd008A0W@01A5d4A5d008A17@01A5dM15d008A
17@24@9d0Q47M0034GAd009d00<AM14017@00a5dM002M0034GAd00=d00<AM7@017@24@Ud0002M004
4GAd4@Ad00HAM7@AM142M0034GAd00Md00<AM7@08G@01Q5dM15d4@]d00<AM1400Q401g@AM7@AM140
0W@0115dM142M0034GAd00=d00@AM7@A0W@0115dM142M08A17@0115d4G@24@Ad0Q401G@AM7@A00Id
00<AM7@00W@00a5d4@05M0054GAdM1401W@00a5dM004M0034GAd00Md0003M08A1W@24@=d0Q4;M003
4GAd021d00@AM15d0Q4;M08A00Ed4A5d4@03M08A0W@0115dM142M08A17@01Q5d4A5d4@9d00@AM15d
0a43M0074G@AM15d4@03M0044G@A4@9d00<AM7@017@24@=d00<AM1401G@00a5dM002M0034GAd00=d
00<AM7@017@00a5dM007M0007W@00a5d4@0PM08A00=d4G@02W@00a5d4@02M0044G@A4@9d0Q42M004
4GAd4@=d00<AM7@00g@24@03M14A009d00<AM7@00a402g@A4G@AM15d4G@A00Ad0a43M0034GAd00=d
00<AM1400W@00a5d4@05M0034GAd009d00<AM7@017@00a5dM003M0034GAd00Md000OM08A87@01A5d
M7@A00Yd00LAM14AM15d008A0W@24@9d00DAM7Ad4@02M08A17@24@05M15dM1400g@24@04M15dM08A
00Id4G@AM144M0034G@A00=d00<AM7@00g@00a5d4@02M0034G@A00Ed00<AM7@00g@00a5dM003M003
4GAd00=d00<AM7@01g@0025d00<AM7@07W@0115dM14:M0074G@A4G@AM0024@9d0Q42M0054GAdM140
0W@00a5d4@04M0064G@A4G@A17@0115dM142M0<A00Ad4G@A0W@34@9d00DAM7Ad4@05M0074G@AM15d
4@06M0034GAd009d00<AM7@017@00a5dM002M0034GAd00Md000RM0034GAd01ed00DAM7Ad4@09M005
4G@A4G@01142M08A0g@0115dM143M08A17@24@03M14A00Ed0Q401W@AM7@AM0@A00=d4A400g@0115d
M142M0034GAd00=d00<AM7@00Q42M0034GAd00=d00<AM7@00W@00a5dM004M0034GAd009d00<AM7@0
1g@002=d00<AM7@07G@01A5dM7@A00Md00<AM1400W@54@9d00<AM1400W@01A5dM7@A009d00<AM140
0g@24@9d00<AM7@00g@24@9d00PAM15d4G@AM08A17@01A5dM7@A009d00<AM7@00W@00a5dM0024@9d
00<AM7@00g@00a5dM003M0034GAd00Ad00DAM7Ad4@09M00057@24@=d00<AM7@00Q42M0LA7G@0115d
M147M0034G@A009d0Q400g@A4@02M0034G@A009d00DAM7Ad4@02M0044GAd4@9d00HAM14AM144M006
4G@AM15d0Q400g@AM002M0034GAd009d00DAM7Ad4@02M0034GAd009d00DAM7Ad4@02M0034GAd00=d
00<AM7@00g@00a5dM004M0044GAd4@Yd000CM0044GAd4@Ad00@AM7@A0W@00a5dM002M0034GAd01]d
00DAM7Ad4@06M0034G@A00=d00@AM14A0W@00a5d4@02M0054GAdM1400g@01Q5d4G@AM08A0W@00a5d
M002M00:4GAd4G@AM15d4@=d00<AM7@00g@01A5dM7@A009d00DAM7Ad4@03M0044GAd4@Id00<AM7@0
0W@00a5dM005M0034G@A00Yd000>M0@A00Ed4GAd4@04M0044GAd4@=d00<AM7@00W@00a5dM00KM005
4GAdM1401G@00a5d4@03M0044G@A4@9d00<AM1400W@00a5dM002M0054GAd4G@01142M0044GAd4@=d
00@AM7@A0W@24@03M15d00=d00<AM7@00W@00a5dM002M0034G@A00=d00DAM7Ad4@02M0034GAd00Ad
00<AM7@00g@00a5dM004M0034G@A00Yd000CM0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd01]d
00@AM7@A17@0115dM143M0044G@A4@9d00<AM1400W@00a5dM002M0034GAd008A00=d4A400g@0115d
M143M0064GAdM15d0Q400g@AM003M0034GAd009d00<AM7@00g@24@=d00@AM7@A0g@00a5dM004M003
4GAd00=d00<AM7@01G@24@Yd000CM0044GAd4@Ad00@AM7@A17@00a5dM003M0<A6W@01A5dM7@A00=d
00@AM7@A0g@54@04M15d4@9d00<AM7@00W@00a5dM0034@03M15d00=d00@AM7@A0W@00a5dM002M005
4G@AM14017@00a5dM003M0034GAd00=d0Q42M0044GAd4@Ad00<AM7@00g@00a5dM003M0034GAd00Ed
0Q4:M0004g@0115dM144M0064GAd4G@A0W@00a5dM005M0034GAd01Ud00@AM7@A0g@00a5d4@04M08A
00=d4G@00Q400g@AM002M0034GAd009d1143M0034GAd009d00HAM7@AM145M0@A17@00a5dM003M003
4GAd00Ad00@AM7@A0W@00a5dM002M0034GAd00Ad00<AM7@00g@00a5dM005M0034GAd00Qd000DM08A
1W@24@=d0Q49M0034GAd01Qd00DAM7Ad4@02M0034G@A00Ad00DAM14AM0024@9d00@AM7@A0g@34@9d
00DAM7Ad4@03M0064GAd4G@A1G@44@Ed00<AM7@00W@00a5dM004M08A00Ed4GAd4@04M0034GAd00Ad
00<AM7@00g@00a5dM004M0034GAd00Ud000]M0034GAd01Qd00@AM7Ad0Q42M0034GAd00=d0a42M0@A
0W@44@9d00@AM7@A0g@00a5dM002M0034GAd008A1W@00a5d4@05M0034GAd00=d00<AM7@017@01A5d
4G@A00Ed00<AM7@017@00a5dM003M0034GAd00Ad00<AM7@02G@002id0a4HM0034GAd008A0W@00a5d
M003M0034G@A00<A0W@54@Ad00DAM7Ad4@03M0034GAd009d00@AM14A1W@34@Ed00<AM7@00g@00a5d
M005M08A00=d4G@017@00a5dM004M0034GAd00Ad00<AM7@00W@00a5dM00:M000<7@00a5dM00FM005
4GAdM1400W@00a5dM003M0034G@A009d1A42M0034GAd00=d00DAM7Ad4@03M0054GAdM1400W@00a5d
M004M0<A1G@00a5dM003M0034GAd00Ed0Q400g@AM005M0034GAd00Ad00<AM7@00g@00a5dM002M003
4GAd00Yd000aM0034GAd01Id00<AM7@00a46M0044G@A4@9d00@AM7@A0W@00a5dM004M0044GAd4@Ad
00HAM7Ad4G@24@Ad00<AM1401W@00a5dM004M0034GAd00Ed0a46M0034GAd00Ad00<AM7@017@0115d
M14=M000<W@00a5dM00FM08A00=d4A401W@0115dM143M0034G@A00=d00<AM7@00g@01A5dM7@A00=d
00HAM7Ad4G@24@Ad00<AM1401g@00a5dM003M0034GAd00Ed1145M0034GAd00Ad00<AM7@017@0115d
M14=M000<g@34AEd0Q42M0034GAd00Ad00<AM7@00Q42M0044GAd4@9d00<AM7@017@01A5dM7@A00=d
00@AM7Ad0Q400g@AM002M0034G@A00Md00<AM7@017@00a5dM005M0044GAd4@Ad00<AM7@017@00a5d
M004M0034G@A00id000eM0034GAd01Ad00DAM7Ad4@05M0034GAd008A0g@00a5d4@03M0034GAd00Ad
00@AM7@A17@01a5dM7@AM1400g@00a5d4@07M0034GAd00Ad00<AM7@01G@01A5dM7@A00=d00<AM7@0
1G@00a5dM004M08A3W@003Id00<AM7@057@01A5dM7@A00Ad00HAM7@AM142M0044GAd4@9d00<AM7@0
17@01A5dM7@A00Ad00@AM7@A0W@0115d4G@24@Md00<AM7@017@00a5dM004M0034GAd00=d00@AM7@A
1g@00a5dM004M0034GAd00ed000gM0034GAd01Ad00DAM7Ad4@04M0054G@AM1400g@00a5d4@03M003
4GAd00Ad00DAM7Ad4@04M0044G@A4@9d0Q4017@AM147M0034GAd00Ad00<AM7@00g@00a5dM004M08A
00=d4G@01G@00a5dM002M08A47@003Qd0a4DM0054GAdM1400g@00a5d4@02M0044GAd4@9d00@AM7@A
1g@0115dM144M0064G@AM15d0Q4017@AM147M0034GAd00Ad00<AM7@00W@00a5dM007M08A1W@01A5d
M7@A019d000jM0034GAd01=d00DAM7Ad4@02M0064GAd4G@A0W@01A5dM7@A009d00<AM7@017@01A5d
M7@A00Ad0Q402G@AM7@AM15d4@07M0034GAd00Ad00<AM7@00W@00a5dM008M0@A17@34A=d000kM003
4GAd01=d00LAM7Ad4G@A009d00<AM1400g@0115dM143M0034GAd00Ad00@AM7@A1G@00a5dM0044@9d
00<AM7@01G@00a5dM005M0044GAd4@md1A4EM000?7@00a5dM00CM0064GAd4G@A0W@0115dM142M005
4GAdM1400W@00a5dM004M0054GAdM1401G@44@05M15dM1401g@00a5dM005M0044GAd4BUd000mM0<A
4W@0115dM7@24@9d00@AM7@A0g@0115dM143M0034GAd00Ad00DAM7Ad4@06M0<A0g@00a5dM006M003
4GAd00Ad00<AM140:W@003md00<AM7@04G@01A5dM7@A009d00DAM7Ad4@02M0054GAdM1400W@00a5d
M005M0044GAd4@Id0a43M0034GAd00Id00<AM7@01G@24BYd000`M08A0g@00a5dM0024@=d114CM003
4GAd008A00=d4G@00W@01A5dM7@A00=d00@AM7@A1W@01A5dM7@A00Ed1143M0034GAd00Ed00<AM7@0
1G@00a5dM00YM000;g@0115dM144M0044GAd4@=d00@AM7@A4g@00a5dM0024@03M15d009d00@AM7@A
0g@0115dM147M0054GAdM1400g@00a5d4@02M0044GAd4@Md00<AM7@00g@24Bad000YM0@A0W@0115d
M144M0044GAd4@=d00@AM7Ad0a4AM0044G@AM08A0g@0115dM144M0044GAd4@Md00@AM7@A0W@00a5d
4@04M0<A27@00a5dM0024Bid000_M0044GAd4@Ad00@AM7@A0g@00a5dM003M0034GAd011d0Q42M005
4GAdM1400g@01A5dM7@A00=d00<AM7@017@02A5dM7@AM15d4@06M0DA17@34C1d000_M0044GAd4@Ad
00@AM7@A0g@00a5dM004M0034GAd011d00@AM7Ad0Q42M0044GAd4@Ad00@AM7@A1g@01a5dM7@AM140
37@54C9d000_M0044GAd4@Ad00@AM7@A0W@24@Md00<AM7@047@24@=d00<AM1400g@01A5dM7@A00=d
00<AM7@01G@01Q5d4A5d4D=d000`M08A1W@24@Ad00<AM7@01W@00a5d4@0AM0044GAdM0<A0W@00a5d
M002M0044GAd4@Md00DAM15d4@14M000B7@24A9d0Q43M08A0W@00a5dM002M0044GAd4@Id1155M000
BW@00a5dM00AM08A0W@24@03M15d00=d00@AM7@A17@44DMd001;M0034G@A019d00@AM15d0a44M005
4GAd4G@01159M000C7@24A=d0a42M0HA0W@44D]d001=M08A57@=4Ded001?M0034GAd06]d001@M003
4G@A06Yd001AM08AJW@0059d0Q5YM000E7@00a5d4@1VM000EG@24FId001FM0034GAd06Ad001;M08A
2W@24FAd001:M0044GAd4@]d0Q5RM000BW@0115dM14<M0034GAd061d001:M0044GAd4@ed00<AM7@0
Gg@004Yd00@AM7@A3W@24@03M15d05ad001:M0044GAd4A1d0Q5MM000Bg@24A9d00<AM7@0Fg@0061d
00@AM7@AFG@0065d0a5IM000Hg@00a5dM01GM000I7@00a5dM01FM000IG@00a5d4@1EM000IW@24EEd
001XM0034GAd059d001YM0034G@A055d001ZM08ADG@006]d0Q5@M000Fg@24@=d00<AM7@00Q43M0<A
0W@00a5d4@1=M000FW@0115dM144M0044GAd4@=d00<AM7@00W@24Ded001JM0044GAd4@Ad00@AM7@A
0g@00a5dM003M0034GAd04]d001JM0044GAd4@Ad00@AM7@A0g@00a5dM004M0<ABW@005Yd00@AM7@A
17@0115dM143M0034GAd00Id00<AM7@0B7@005Yd00@AM7@A17@0115dM142M08A2G@0115dM156M000
Fg@24@Id0Q44M0034GAd00Qd00<AM140AW@007Ed0Q56M000Mg@00a5dM013M000N7@00a5dM012M000
_G@00;ed002mM000_G@00;ed002mM000Kg@24@=d00<AM7@00Q42M0@A?W@006id00@AM7@A17@0115d
M142M0034GAd03id001^M0044GAd4@Ad00@AM7@A0g@00a5dM00mM000KW@0115dM144M0044GAd4@=d
00<AM7@0?G@006id00@AM7@A17@0115dM144M0034GAd03ad001^M0044GAd4@Ad00HAM7@AM142M003
4GAd03ad001_M08A1W@24@=d0Q4oM000_G@00;ed002mM000_G@00;ed0000\
\>"],
  ImageRangeCache->{{{0, 188.75}, {287, 0}} -> {0.0637148, -0.0704175, \
0.00383968, 0.00383968}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Systems", "Subsection"],

Cell[CellGroupData[{

Cell["Source Position", "Subsubsection"],

Cell["This is the orientation and position of the light source.", "Text"],

Cell["\<\
Clear[TwistAngleSource,PositionSource,
\tAngleXYSource,AngleYZSource,WavelengthSource,TiltVectorSource];
TwistAngleSource = 0;
PositionSource = {0,Deltax,Deltay};
AngleXYSource = 0 40.;
AngleYZSource = 0 20.;
WavelengthSource = 0.450;
TiltVectorSource={
\tSqrt[1-(Sin[AngleXYSource Pi/180.])^2-(Sin[AngleYZSource Pi/180.])^2],
\tSin[AngleXYSource Pi/180.],
\tSin[AngleYZSource Pi/180.]};\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lens Positions", "Subsubsection"],

Cell["The lens is oriented as follows.", "Text"],

Cell["\<\
Clear[TwistAngleLens,PositionLens,AngleXYLens,AngleYZLens,\
TiltVectorLens];
TwistAngleLens=0;
PositionLens={25,0,0} R0;
AngleXYLens=0 10.;
AngleYZLens=0 30.;
TiltVectorLens={
\tSqrt[1-(Sin[AngleXYLens Pi/180.])^2-(Sin[AngleYZLens Pi/180.])^2],
\tSin[AngleXYLens Pi/180.],
\tSin[AngleYZLens Pi/180.]};\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Ray-Trace", "Subsubsection"],

Cell["\<\
Clear[PressureLensSystem,PressureLensSurfacesSystem];
PressureLensSystem := 
{
\tBoundary[{-2,-4,-3} R0,{35,9,12} R0, GraphicDesign -> Off],
\tMove3D[PointOfRays[3,
\t\tWaveLength->WavelengthSource,
\t\tNumberOfRays->3
\t],PositionSource,TiltVectorSource,TwistAngleSource],
\tMove3D[FlexibleLens,PositionLens,TiltVectorLens,TwistAngleLens],
\tBoundary[{-2,-4,-3} R0,{35,9,12} R0, GraphicDesign -> Off]
};
PressureLensSurfacesSystem := 
{
\tBoundary[{-2,-4,-3} R0,{35,9,12} R0, GraphicDesign -> Off],
\tMove3D[PointOfRays[3,
\t\tWaveLength->WavelengthSource,
\t\tNumberOfRays->3
\t],PositionSource,TiltVectorSource,TwistAngleSource],
\tMove3D[LensSurfaces,PositionLens,TiltVectorLens,TwistAngleLens],
\tBoundary[{-2,-4,-3} R0,{35,9,12} R0, GraphicDesign -> Off]
};\
\>", "Input"],

Cell["\<\
Clear[PressureLensTraced,PressureLensSurfacesTraced];
PressureLensTraced = PropagateSystem[PressureLensSystem];
PressureLensSurfacesTraced = \
PropagateSystem[PressureLensSurfacesSystem];\
\>", "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Drawings", "Subsection"],

Cell[CellGroupData[{

Cell["ShowSystem[PressureLensTraced, Axes->True];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .46345 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0452603 1.04526 -0.277379 1.04526 [
[.0304 .28899 -4.09187 -10.9375 ]
[.0304 .28899 4.90813 0 ]
[.26397 .21136 -7.88704 -10.9375 ]
[.26397 .21136 8.61296 0 ]
[.51208 .12891 -8.31006 -10.9375 ]
[.51208 .12891 8.18994 0 ]
[.77614 .04119 -8.77663 -10.9375 ]
[.77614 .04119 7.72337 0 ]
[.95422 -0.00237 0 -7.2795 ]
[.95422 -0.00237 28.4375 3.658 ]
[.9659 .0149 0 -7.26618 ]
[.9659 .0149 28.4375 3.67132 ]
[.97743 .03197 0 -7.25306 ]
[.97743 .03197 9 3.68444 ]
[.98883 .04883 0 -7.24013 ]
[.98883 .04883 21.5 3.69737 ]
[1.0001 .06549 0 -7.22738 ]
[1.0001 .06549 21.5 3.71012 ]
[1.00148 .06956 0 -7.22455 ]
[1.00148 .06956 28.4375 3.71295 ]
[1.00402 .09292 0 -7.20938 ]
[1.00402 .09292 28.4375 3.72812 ]
[1.00659 .11651 0 -7.19408 ]
[1.00659 .11651 9 3.74342 ]
[1.00918 .14033 0 -7.17863 ]
[1.00918 .14033 21.5 3.75887 ]
[1.0118 .1644 0 -7.16303 ]
[1.0118 .1644 21.5 3.77447 ]
[ 0 0 0 0 ]
[ 1 .46345 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00938 .30858 m
.94064 0 L
s
.02922 .302 m
.02863 .30851 L
s
gsave
.0304 .28899 -65.0919 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.26339 .22441 m
.26311 .23094 L
s
gsave
.26397 .21136 -68.887 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51218 .14197 m
.51222 .14851 L
s
gsave
.51208 .12891 -69.3101 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77697 .05423 m
.77739 .06075 L
s
gsave
.77614 .04119 -69.7766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07495 .28685 m
.07463 .29076 L
s
.12122 .27152 m
.12094 .27543 L
s
.16805 .256 m
.1678 .25992 L
s
.21543 .2403 m
.21522 .24422 L
s
.31194 .20832 m
.31181 .21224 L
s
.36108 .19204 m
.36098 .19596 L
s
.41082 .17556 m
.41077 .17948 L
s
.46119 .15887 m
.46117 .16279 L
s
.56381 .12487 m
.56388 .12879 L
s
.61609 .10754 m
.6162 .11146 L
s
.66903 .09 m
.66919 .09392 L
s
.72266 .07223 m
.72286 .07614 L
s
.83199 .036 m
.83229 .03991 L
s
.88773 .01753 m
.88807 .02144 L
s
.25 Mabswid
.94064 0 m
.98878 .07115 L
s
.94182 .00174 m
.93562 .00379 L
s
gsave
.95422 -0.00237 -61 -11.2795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.95348 .01898 m
.94728 .02102 L
s
gsave
.9659 .0149 -61 -11.2662 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.96501 .03602 m
.9588 .03805 L
s
gsave
.97743 .03197 -61 -11.2531 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9764 .05286 m
.97019 .05487 L
s
gsave
.98883 .04883 -61 -11.2401 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98766 .06949 m
.98144 .07149 L
s
gsave
1.0001 .06549 -61 -11.2274 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.94416 .0052 m
.94044 .00643 L
s
.9465 .00866 m
.94278 .00989 L
s
.94883 .01211 m
.94511 .01334 L
s
.95116 .01555 m
.94744 .01677 L
s
.9558 .02241 m
.95208 .02363 L
s
.95811 .02582 m
.95439 .02704 L
s
.96042 .02923 m
.95669 .03045 L
s
.96272 .03263 m
.95899 .03385 L
s
.9673 .0394 m
.96357 .04062 L
s
.96958 .04278 m
.96586 .04399 L
s
.97186 .04615 m
.96813 .04736 L
s
.97413 .04951 m
.97041 .05071 L
s
.97866 .0562 m
.97493 .05741 L
s
.98092 .05954 m
.97719 .06074 L
s
.98317 .06286 m
.97944 .06407 L
s
.98542 .06618 m
.98169 .06738 L
s
.25 Mabswid
.98878 .07115 m
1 .17453 L
s
.98904 .07356 m
.98282 .07555 L
s
gsave
1.00148 .06956 -61 -11.2246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99157 .09688 m
.98534 .09886 L
s
gsave
1.00402 .09292 -61 -11.2094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99413 .12044 m
.9879 .1224 L
s
gsave
1.00659 .11651 -61 -11.1941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99671 .14423 m
.99048 .14618 L
s
gsave
1.00918 .14033 -61 -11.1786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99932 .16826 m
.99308 .1702 L
s
gsave
1.0118 .1644 -61 -11.163 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98954 .0782 m
.98581 .0794 L
s
.99005 .08286 m
.98631 .08405 L
s
.99055 .08752 m
.98682 .08872 L
s
.99106 .0922 m
.98733 .09339 L
s
.99208 .10157 m
.98834 .10276 L
s
.99259 .10628 m
.98885 .10746 L
s
.9931 .11099 m
.98936 .11217 L
s
.99361 .11571 m
.98988 .11689 L
s
.99464 .12518 m
.9909 .12636 L
s
.99516 .12993 m
.99142 .1311 L
s
.99567 .13469 m
.99193 .13586 L
s
.99619 .13945 m
.99245 .14063 L
s
.99723 .14902 m
.99349 .15019 L
s
.99775 .15381 m
.99401 .15498 L
s
.99827 .15862 m
.99453 .15978 L
s
.9988 .16344 m
.99505 .1646 L
s
.99984 .1731 m
.9961 .17426 L
s
0 0 m
1 0 L
1 .46345 L
0 .46345 L
closepath
clip
newpath
.001 .092 .901 r
.5 Mabswid
.06311 .40741 m
.67214 .21474 L
s
.06311 .40741 m
.68513 .22337 L
s
.06311 .40741 m
.67115 .20515 L
s
.06311 .40741 m
.67168 .21844 L
s
.06311 .40741 m
.67769 .21933 L
s
0 g
.68825 .1704 m
.6827 .15664 L
s
.69217 .16914 m
.68825 .1704 L
s
.68825 .1704 m
.68275 .17397 L
s
.69267 .18488 m
.68825 .1704 L
s
.69569 .19913 m
.69267 .18488 L
s
.69267 .18488 m
.6966 .18363 L
s
.68572 .18367 m
.69267 .18488 L
s
.69217 .16914 m
.68663 .15538 L
s
.71121 .16303 m
.69217 .16914 L
s
.69217 .16914 m
.6867 .17271 L
s
.6966 .18363 m
.69217 .16914 L
s
.69962 .19788 m
.6966 .18363 L
s
.6966 .18363 m
.71565 .17755 L
s
.68966 .18241 m
.6966 .18363 L
s
.6827 .15664 m
.68663 .15538 L
s
.6827 .15664 m
.67639 .1445 L
s
.67904 .16476 m
.6827 .15664 L
s
.69569 .19913 m
.69962 .19788 L
s
.68773 .19322 m
.69569 .19913 L
s
.68663 .15538 m
.70566 .14923 L
s
.68663 .15538 m
.68032 .14322 L
s
.68298 .16349 m
.68663 .15538 L
s
.69962 .19788 m
.7187 .19183 L
s
.69168 .19196 m
.69962 .19788 L
s
.67639 .1445 m
.68032 .14322 L
s
.67481 .15664 m
.67639 .1445 L
s
.71121 .16303 m
.70566 .14923 L
s
.73099 .15668 m
.71121 .16303 L
s
.71121 .16303 m
.70581 .16658 L
s
.71565 .17755 m
.71121 .16303 L
s
.7187 .19183 m
.71565 .17755 L
s
.71565 .17755 m
.73544 .17123 L
s
.70879 .1763 m
.71565 .17755 L
s
.68032 .14322 m
.69938 .13704 L
s
.67875 .15537 m
.68032 .14322 L
s
.68866 .20197 m .70104 .21098 L .69709 .21222 L .656 .751 .92 r
F
0 g
.69678 .22328 m
.69709 .21222 L
s
.69569 .19913 m
.69661 .20776 L
s
.70566 .14923 m
.72545 .14284 L
s
.70566 .14923 m
.69938 .13704 L
s
.7021 .15733 m
.70566 .14923 L
s
.68866 .20197 m .69262 .20071 L .70104 .21098 L .656 .751 .92 r
F
0 g
.70073 .22204 m
.70104 .21098 L
s
.69962 .19788 m
.70104 .21098 L
s
.69709 .21222 m
.70104 .21098 L
s
.7187 .19183 m
.73852 .18554 L
s
.68572 .18367 m
.68275 .17397 L
s
.68275 .17397 m
.67904 .16476 L
s
.67721 .17758 m
.68275 .17397 L
s
.73099 .15668 m
.73544 .17123 L
s
.72545 .14284 m
.73099 .15668 L
s
.68773 .19322 m
.68572 .18367 L
s
.67869 .18245 m
.68572 .18367 L
s
.73544 .17123 m
.73852 .18554 L
s
.66973 .13478 m .6743 .14888 L .67035 .15016 L .544 .324 .532 r
F
.66973 .13478 m .67367 .1335 L .6743 .14888 L F
0 g
.67398 .14098 m
.67639 .1445 L
s
.67367 .1335 m
.68032 .14322 L
s
.66973 .13478 m
.67367 .1335 L
s
.66316 .12815 m
.66973 .13478 L
s
.69938 .13704 m
.71919 .13061 L
s
.68966 .18241 m
.6867 .17271 L
s
.6867 .17271 m
.68298 .16349 L
s
.68117 .17631 m
.6867 .17271 L
s
.69168 .19196 m
.68966 .18241 L
s
.68266 .18119 m
.68966 .18241 L
s
.67904 .16476 m
.67481 .15664 L
s
.67534 .17295 m
.67904 .16476 L
s
.6671 .12686 m
.67367 .1335 L
s
.71919 .13061 m
.72545 .14284 L
s
.68298 .16349 m
.67875 .15537 L
s
.6793 .17168 m
.68298 .16349 L
s
.71179 .19463 m .74002 .19867 L .72015 .20494 L .656 .751 .92 r
F
0 g
.71991 .21601 m
.72015 .20494 L
s
.7187 .19183 m
.71913 .19568 L
s
.70104 .21098 m
.72015 .20494 L
s
.69476 .23156 m
.69678 .22328 L
s
.69678 .22328 m
.70073 .22204 L
s
.68843 .20934 m
.69678 .22328 L
s
.69873 .23032 m
.70073 .22204 L
s
.70073 .22204 m
.71991 .21601 L
s
.6924 .20809 m
.70073 .22204 L
s
.67717 .16761 m
.67875 .15537 L
s
.68016 .19164 m .69262 .20071 L .68866 .20197 L .656 .751 .92 r
F
0 g
.68843 .20934 m
.68866 .20197 L
s
.68773 .19322 m
.68818 .19748 L
s
.68866 .20197 m
.69709 .21222 L
s
.70879 .1763 m
.70581 .16658 L
s
.70581 .16658 m
.7021 .15733 L
s
.70037 .17015 m
.70581 .16658 L
s
.68016 .19164 m .68413 .19037 L .69262 .20071 L .656 .751 .92 r
F
0 g
.6924 .20809 m
.69262 .20071 L
s
.69262 .20071 m
.70104 .21098 L
s
.6797 .18725 m
.68397 .19042 L
s
.68448 .1908 m
.68773 .19322 L
s
.69168 .19196 m
.69262 .20071 L
s
.68367 .18598 m
.69168 .19196 L
s
.71083 .18586 m
.70879 .1763 L
s
.70186 .17504 m
.70879 .1763 L
s
.69276 .12727 m .71337 .13622 L .69346 .14267 L .544 .324 .532 r
F
0 g
.69789 .14918 m
.6989 .14091 L
s
.69276 .12727 m .7126 .12081 L .71337 .13622 L .544 .324 .532 r
F
0 g
.67367 .1335 m
.69276 .12727 L
s
.7126 .12081 m
.71919 .13061 L
s
.69276 .12727 m
.7126 .12081 L
s
.68625 .1206 m
.69276 .12727 L
s
.7021 .15733 m
.69789 .14918 L
s
.71179 .19463 m .73172 .18831 L .74002 .19867 L .656 .751 .92 r
F
0 g
.73983 .20975 m
.74002 .19867 L
s
.73852 .18554 m
.74002 .19867 L
s
.72015 .20494 m
.74002 .19867 L
s
.71083 .18586 m
.7187 .19183 L
s
.67035 .15016 m .67494 .16436 L .67097 .16564 L .544 .324 .532 r
F
0 g
.67321 .16888 m
.67375 .16475 L
s
.67413 .16185 m
.67481 .15664 L
s
.67035 .15016 m .6743 .14888 L .67494 .16436 L .544 .324 .532 r
F
0 g
.66973 .13478 m
.67035 .15016 L
s
.67461 .15635 m
.67481 .15664 L
s
.6743 .14888 m
.67875 .15537 L
s
.66596 .14577 m
.67035 .15016 L
s
.67367 .1335 m
.6743 .14888 L
s
.66316 .12815 m
.6671 .12686 L
s
.66316 .12815 m
.65711 .12508 L
s
.66596 .14577 m
.66316 .12815 L
s
.66992 .14448 m
.6743 .14888 L
s
.71796 .22429 m
.71991 .21601 L
s
.71991 .21601 m
.73983 .20975 L
s
.71161 .20201 m
.71991 .21601 L
s
.6671 .12686 m
.68625 .1206 L
s
.6671 .12686 m
.66107 .12378 L
s
.66992 .14448 m
.6671 .12686 L
s
.68563 .2153 m
.68843 .20934 L
s
.67946 .19551 m
.68843 .20934 L
s
.68957 .21405 m
.6924 .20809 L
s
.6834 .19425 m
.6924 .20809 L
s
.69114 .23648 m
.69476 .23156 L
s
.69476 .23156 m
.69873 .23032 L
s
.68563 .2153 m
.69476 .23156 L
s
.67869 .18245 m
.67721 .17758 L
s
.67721 .17758 m
.67534 .17295 L
s
.70336 .18424 m .73172 .18831 L .71179 .19463 L .656 .751 .92 r
F
0 g
.71161 .20201 m
.71179 .19463 L
s
.71179 .19463 m
.72015 .20494 L
s
.69262 .20071 m
.71179 .19463 L
s
.6797 .18725 m
.67869 .18245 L
s
.69513 .23523 m
.69873 .23032 L
s
.69873 .23032 m
.71796 .22429 L
s
.68957 .21405 m
.69873 .23032 L
s
.67534 .17295 m
.67321 .16888 L
s
.70614 .11409 m
.7126 .12081 L
s
.68266 .18119 m
.68117 .17631 L
s
.68117 .17631 m
.6793 .17168 L
s
.68367 .18598 m
.68266 .18119 L
s
.6793 .17168 m
.67717 .16761 L
s
.66596 .14577 m
.66193 .14376 L
s
.66877 .16346 m
.66596 .14577 L
s
.6716 .18122 m .68413 .19037 L .68016 .19164 L .656 .751 .92 r
F
0 g
.67946 .19551 m
.68016 .19164 L
s
.68016 .19164 m
.68866 .20197 L
s
.66992 .14448 m
.6659 .14247 L
s
.66992 .14448 m
.67274 .16218 L
s
.69346 .14267 m .71413 .15173 L .69416 .15817 L .544 .324 .532 r
F
0 g
.69638 .16143 m
.69689 .15729 L
s
.6985 .16551 m
.7021 .15733 L
s
.69346 .14267 m .71337 .13622 L .71413 .15173 L .544 .324 .532 r
F
0 g
.69276 .12727 m
.69346 .14267 L
s
.6743 .14888 m
.69346 .14267 L
s
.7126 .12081 m
.71337 .13622 L
s
.68911 .13825 m
.69346 .14267 L
s
.68025 .21946 m
.68563 .2153 L
s
.67729 .19872 m
.68563 .2153 L
s
.73983 .20975 m
.73795 .21802 L
s
.68625 .1206 m
.70614 .11409 L
s
.68625 .1206 m
.68027 .11749 L
s
.68911 .13825 m
.68625 .1206 L
s
.6716 .18122 m .67558 .17995 L .68413 .19037 L .656 .751 .92 r
F
0 g
.6834 .19425 m
.68413 .19037 L
s
.68413 .19037 m
.69262 .20071 L
s
.67746 .18224 m
.67869 .18245 L
s
.68367 .18598 m
.68413 .19037 L
s
.67097 .16564 m .67558 .17995 L .6716 .18122 L .544 .324 .532 r
F
0 g
.67287 .17152 m
.67321 .16888 L
s
.67416 .17555 m
.67534 .17295 L
s
.67523 .17886 m
.67721 .17758 L
s
.67097 .16564 m .67494 .16436 L .67558 .17995 L .544 .324 .532 r
F
0 g
.67035 .15016 m
.67097 .16564 L
s
.67494 .16436 m
.67717 .16761 L
s
.66877 .16346 m
.67097 .16564 L
s
.6743 .14888 m
.67494 .16436 L
s
.68421 .21821 m
.68957 .21405 L
s
.68124 .19746 m
.68957 .21405 L
s
.71029 .20751 m
.71161 .20201 L
s
.67729 .19872 m
.67946 .19551 L
s
.67274 .16218 m
.67494 .16436 L
s
.70336 .18424 m .72334 .17787 L .73172 .18831 L .656 .751 .92 r
F
0 g
.70326 .18793 m
.71161 .20201 L
s
.73172 .18831 m
.74002 .19867 L
s
.70288 .17984 m
.70711 .18305 L
s
.65711 .12508 m
.66107 .12378 L
s
.65711 .12508 m
.652 .12581 L
s
.66193 .14376 m
.65711 .12508 L
s
.68124 .19746 m
.6834 .19425 L
s
.71443 .22919 m
.71796 .22429 L
s
.71796 .22429 m
.73795 .21802 L
s
.71029 .20751 m
.71796 .22429 L
s
.70186 .17504 m
.70037 .17015 L
s
.70037 .17015 m
.6985 .16551 L
s
.70288 .17984 m
.70186 .17504 L
s
.001 .092 .901 r
.68513 .22337 m
.68866 .22191 L
s
0 0 0 r
2 Mabswid
.68513 .22337 Mdot
0 g
.5 Mabswid
.66877 .16346 m
.66676 .16248 L
s
.66107 .12378 m
.68027 .11749 L
s
.66107 .12378 m
.65598 .12451 L
s
.6659 .14247 m
.66107 .12378 L
s
.67458 .20078 m
.67729 .19872 L
s
.6985 .16551 m
.69638 .16143 L
s
.66193 .14376 m
.65854 .1443 L
s
.66676 .16248 m
.66193 .14376 L
s
.67274 .16218 m
.67073 .16119 L
s
.001 .092 .901 r
.68866 .22191 m
.70907 .21342 L
s
0 0 0 r
2 Mabswid
.68866 .22191 Mdot
.001 .092 .901 r
.5 Mabswid
.68866 .22191 m
.68866 .22191 L
s
0 0 0 r
2 Mabswid
.68866 .22191 Mdot
0 g
.5 Mabswid
.67854 .19953 m
.68124 .19746 L
s
.68911 .13825 m
.68513 .13622 L
s
.69198 .15597 m
.68911 .13825 L
s
.67513 .22076 m
.68025 .21946 L
s
.68025 .21946 m
.69114 .23648 L
s
.67458 .20078 m
.68025 .21946 L
s
.68587 .23775 m
.69114 .23648 L
s
.69114 .23648 m
.69513 .23523 L
s
.6659 .14247 m
.66252 .14301 L
s
.67073 .16119 m
.6659 .14247 L
s
.70022 .11095 m
.70614 .11409 L
s
.69486 .17377 m .72334 .17787 L .70336 .18424 L .656 .751 .92 r
F
0 g
.70326 .18793 m
.70336 .18424 L
s
.70336 .18424 m
.71179 .19463 L
s
.68413 .19037 m
.70336 .18424 L
s
.67911 .21951 m
.68421 .21821 L
s
.68421 .21821 m
.69513 .23523 L
s
.67854 .19953 m
.68421 .21821 L
s
.68983 .23651 m
.69513 .23523 L
s
.69513 .23523 m
.71443 .22919 L
s
.67213 .20137 m
.67458 .20078 L
s
.66676 .16248 m
.66507 .16277 L
s
.70791 .21073 m
.71029 .20751 L
s
.70259 .19067 m
.71029 .20751 L
s
.001 .092 .901 r
.67769 .21933 m
.68135 .21788 L
s
0 0 0 r
2 Mabswid
.67769 .21933 Mdot
.69416 .15817 m .7149 .16735 L .69486 .17377 L .544 .324 .532 r
F
.69416 .15817 m .71413 .15173 L .7149 .16735 L F
0 g
.5 Mabswid
.69346 .14267 m
.69416 .15817 L
s
.67494 .16436 m
.69416 .15817 L
s
.69198 .15597 m
.69416 .15817 L
s
.71337 .13622 m
.71413 .15173 L
s
.6761 .20011 m
.67854 .19953 L
s
.67073 .16119 m
.66905 .16149 L
s
.70259 .19067 m
.70326 .18793 L
s
.73795 .21802 m
.73449 .22291 L
s
.001 .092 .901 r
.68135 .21788 m
.70503 .20849 L
s
0 0 0 r
2 Mabswid
.68135 .21788 Mdot
.001 .092 .901 r
.5 Mabswid
.68135 .21788 m
.68135 .21788 L
s
0 0 0 r
2 Mabswid
.68135 .21788 Mdot
.6716 .18122 m .6734 .19653 L .66944 .19779 L .544 .324 .532 r
F
0 g
.5 Mabswid
.67202 .19697 m
.67213 .20137 L
s
.67042 .20034 m
.6706 .19742 L
s
.001 .092 .901 r
.06311 .40741 m
.66971 .19568 L
s
.6716 .18122 m .67558 .17995 L .6734 .19653 L .544 .324 .532 r
F
0 g
.67489 .18522 m
.68016 .19164 L
s
.67468 .18681 m
.67946 .19551 L
s
.67432 .18957 m
.67729 .19872 L
s
.67365 .19467 m
.67458 .20078 L
s
.66297 .17073 m .67558 .17995 L .6716 .18122 L .656 .751 .92 r
F
0 g
.66877 .19405 m
.6716 .18122 L
s
.66774 .1896 m
.6716 .18122 L
s
.66594 .1849 m
.6716 .18122 L
s
.66444 .17998 m
.6716 .18122 L
s
.66507 .16277 m
.6696 .17558 L
s
.6716 .18122 m
.6716 .18122 L
s
.66676 .16248 m
.67027 .17606 L
s
.66877 .16346 m
.67085 .17649 L
s
.67097 .16564 m
.67143 .17691 L
s
.68027 .11749 m
.70022 .11095 L
s
.68027 .11749 m
.67524 .1182 L
s
.68513 .13622 m
.68027 .11749 L
s
.67042 .20034 m
.67213 .20137 L
s
.67213 .20137 m
.67513 .22076 L
s
.66507 .16277 m
.65854 .1443 L
s
.66507 .16277 m
.66383 .16432 L
s
.66297 .17073 m .66696 .16944 L .67558 .17995 L .656 .751 .92 r
F
0 g
.67558 .17995 m
.6761 .20011 L
s
.67438 .19908 m
.67558 .17995 L
s
.67274 .19279 m
.67558 .17995 L
s
.6717 .18834 m
.67558 .17995 L
s
.66994 .18362 m
.67558 .17995 L
s
.66843 .1787 m
.67558 .17995 L
s
.66742 .17386 m
.67558 .17995 L
s
.6671 .16575 m
.67558 .17995 L
s
.66781 .16304 m
.67558 .17995 L
s
.66905 .16149 m
.67558 .17995 L
s
.67558 .17995 m
.67558 .17995 L
s
.66383 .16432 m
.66628 .16966 L
s
.66311 .16704 m
.66494 .17009 L
s
.66342 .17514 m
.6716 .18122 L
s
.67073 .16119 m
.67558 .17995 L
s
.67558 .17995 m
.67854 .19953 L
s
.67558 .17995 m
.68124 .19746 L
s
.67274 .16218 m
.67558 .17995 L
s
.67558 .17995 m
.6834 .19425 L
s
.67494 .16436 m
.67558 .17995 L
s
.67558 .17995 m
.68117 .17631 L
s
.67558 .17995 m
.68266 .18119 L
s
.67558 .17995 m
.6793 .17168 L
s
.67558 .17995 m
.68367 .18598 L
s
.67558 .17995 m
.67717 .16761 L
s
.67558 .17995 m
.68413 .19037 L
s
.69198 .15597 m
.68999 .15498 L
s
.67438 .19908 m
.6761 .20011 L
s
.6761 .20011 m
.67911 .21951 L
s
.001 .092 .901 r
.67366 .19459 m
.67591 .19419 L
s
.67115 .20515 m
.67511 .20435 L
s
0 g
.65854 .1443 m
.652 .12581 L
s
.65854 .1443 m
.65603 .14737 L
s
.66905 .16149 m
.66252 .14301 L
s
.66905 .16149 m
.66781 .16304 L
s
.6718 .21871 m
.67513 .22076 L
s
.67513 .22076 m
.68587 .23775 L
s
.70139 .19226 m
.70259 .19067 L
s
.68513 .13622 m
.68179 .13674 L
s
.68999 .15498 m
.68513 .13622 L
s
.001 .092 .901 r
.67214 .21474 m
.67612 .21348 L
s
.69486 .17377 m .7149 .16735 L .72334 .17787 L .656 .751 .92 r
F
0 g
.72334 .17787 m
.73172 .18831 L
s
.001 .092 .901 r
.67591 .19419 m
.69846 .19023 L
s
0 0 0 r
2 Mabswid
.67591 .19419 Mdot
.001 .092 .901 r
.5 Mabswid
.67591 .19419 m
.67591 .19419 L
s
0 0 0 r
2 Mabswid
.67591 .19419 Mdot
.001 .092 .901 r
.5 Mabswid
.67511 .20435 m
.70078 .19921 L
s
0 0 0 r
2 Mabswid
.67511 .20435 Mdot
.001 .092 .901 r
.5 Mabswid
.67511 .20435 m
.67511 .20435 L
s
0 0 0 r
2 Mabswid
.67511 .20435 Mdot
0 g
.5 Mabswid
.652 .12581 m
.6482 .13035 L
s
.65598 .12451 m
.652 .12581 L
s
.70953 .23034 m
.71443 .22919 L
s
.71443 .22919 m
.73449 .22291 L
s
.70791 .21073 m
.71443 .22919 L
s
.66252 .14301 m
.65598 .12451 L
s
.66252 .14301 m
.66001 .14607 L
s
.67579 .21746 m
.67911 .21951 L
s
.67911 .21951 m
.68983 .23651 L
s
.001 .092 .901 r
.67612 .21348 m
.70233 .20518 L
s
0 0 0 r
2 Mabswid
.67612 .21348 Mdot
.001 .092 .901 r
.5 Mabswid
.67612 .21348 m
.67612 .21348 L
s
0 0 0 r
2 Mabswid
.67612 .21348 Mdot
.001 .092 .901 r
.5 Mabswid
.70907 .21342 m
.72784 .20551 L
s
.70907 .21342 m
.70907 .21342 L
s
0 g
.66383 .16432 m
.65603 .14737 L
s
.66383 .16432 m
.66311 .16704 L
s
.70463 .21145 m
.70791 .21073 L
s
.70139 .19226 m
.70791 .21073 L
s
.65598 .12451 m
.67524 .1182 L
s
.65598 .12451 m
.65219 .12904 L
s
.68999 .15498 m
.68833 .15526 L
s
.67438 .19908 m
.67579 .21746 L
s
.66781 .16304 m
.6671 .16575 L
s
.69974 .1926 m
.70139 .19226 L
s
.69527 .11163 m
.70022 .11095 L
s
.68005 .23501 m
.68587 .23775 L
s
.68587 .23775 m
.68983 .23651 L
s
.69486 .17377 m .71568 .18307 L .69557 .18947 L .544 .324 .532 r
F
0 g
.69868 .18848 m
.69974 .1926 L
s
.69732 .18891 m
.69776 .19165 L
s
.69992 .18809 m
.70139 .19226 L
s
.70281 .18717 m
.70326 .18793 L
s
.70122 .18767 m
.70259 .19067 L
s
.69486 .17377 m .7149 .16735 L .71568 .18307 L .544 .324 .532 r
F
.6863 .16322 m .7149 .16735 L .69486 .17377 L .656 .751 .92 r
F
0 g
.69333 .18622 m
.69486 .17377 L
s
.69119 .18211 m
.69486 .17377 L
s
.6893 .17742 m
.69486 .17377 L
s
.68779 .17248 m
.69486 .17377 L
s
.68677 .16764 m
.69486 .17377 L
s
.68711 .15681 m
.6903 .16379 L
s
.68833 .15526 m
.6914 .16395 L
s
.69486 .17377 m
.69486 .17377 L
s
.68999 .15498 m
.69235 .16409 L
s
.69416 .15817 m
.69444 .16439 L
s
.67558 .17995 m
.69486 .17377 L
s
.69198 .15597 m
.69332 .16423 L
s
.66944 .19779 m .67404 .21232 L .67006 .21358 L .544 .324 .532 r
F
0 g
.67042 .20034 m
.67047 .20106 L
s
.67138 .21316 m
.6718 .21871 L
s
.66944 .19779 m .6734 .19653 L .67404 .21232 L .544 .324 .532 r
F
0 g
.66944 .19779 m
.6716 .18122 L
s
.6734 .19653 m
.67438 .19908 L
s
.66877 .19405 m
.66944 .19779 L
s
.6734 .19653 m
.67558 .17995 L
s
.68403 .23376 m
.68983 .23651 L
s
.68983 .23651 m
.70953 .23034 L
s
.68833 .15526 m
.68179 .13674 L
s
.68833 .15526 m
.68711 .15681 L
s
.67274 .19279 m
.6734 .19653 L
s
.001 .092 .901 r
.70503 .20849 m
.70503 .20849 L
s
0 g
.65603 .14737 m
.6482 .13035 L
s
.65603 .14737 m
.65457 .15277 L
s
.001 .092 .901 r
.67168 .21844 m
.67563 .21703 L
s
0 g
.69776 .19165 m
.69974 .1926 L
s
.69974 .1926 m
.70463 .21145 L
s
.68179 .13674 m
.67524 .1182 L
s
.68179 .13674 m
.67933 .13979 L
s
.73449 .22291 m
.72966 .22404 L
s
.65427 .16015 m .66696 .16944 L .66297 .17073 L .656 .751 .92 r
F
0 g
.66297 .17073 m
.66342 .17514 L
s
.66001 .14607 m
.66781 .16304 L
s
.66297 .17073 m
.6716 .18122 L
s
0 0 0 r
2 Mabswid
.67563 .21703 Mdot
.001 .092 .901 r
.5 Mabswid
.67563 .21703 m
.67563 .21703 L
s
0 0 0 r
2 Mabswid
.67563 .21703 Mdot
0 g
.5 Mabswid
.66001 .14607 m
.65219 .12904 L
s
.66001 .14607 m
.65856 .15147 L
s
.66774 .1896 m
.66877 .19405 L
s
.66877 .19405 m
.66807 .2063 L
s
.001 .092 .901 r
.69846 .19023 m
.69846 .19023 L
s
0 g
.67524 .1182 m
.69527 .11163 L
s
.67524 .1182 m
.67152 .12272 L
s
.65427 .16015 m .65828 .15886 L .66696 .16944 L .656 .751 .92 r
F
0 g
.66696 .16944 m
.66742 .17386 L
s
.66696 .16944 m
.67558 .17995 L
s
.65457 .15277 m
.65822 .15887 L
s
.65856 .15147 m
.6671 .16575 L
s
.66696 .16944 m
.6671 .16575 L
s
.001 .092 .901 r
.70078 .19921 m
.70078 .19921 L
s
0 g
.6717 .18834 m
.67274 .19279 L
s
.67205 .20504 m
.67274 .19279 L
s
.70067 .2096 m
.70463 .21145 L
s
.70463 .21145 m
.70953 .23034 L
s
.001 .092 .901 r
.72784 .20551 m
.93792 .10344 L
s
0 0 0 r
2 Mabswid
.72784 .20551 Mdot
0 g
.5 Mabswid
.65517 .16901 m
.66342 .17514 L
s
.66342 .17514 m
.66444 .17998 L
s
.001 .092 .901 r
.70233 .20518 m
.70233 .20518 L
s
0 g
.66594 .1849 m
.66774 .1896 L
s
.66774 .1896 m
.66402 .198 L
s
.66444 .17998 m
.6572 .17872 L
s
.66444 .17998 m
.66594 .1849 L
s
.66594 .1849 m
.66022 .18862 L
s
.65918 .16771 m
.66742 .17386 L
s
.66742 .17386 m
.66843 .1787 L
s
.6863 .16322 m .7064 .15675 L .7149 .16735 L .656 .751 .92 r
F
0 g
.68642 .15952 m
.68711 .15681 L
s
.67933 .13979 m
.68711 .15681 L
s
.7149 .16735 m
.72334 .17787 L
s
.68642 .15952 m
.68824 .16259 L
s
.71413 .15173 m
.7149 .16735 L
s
.66994 .18362 m
.6717 .18834 L
s
.66804 .19672 m
.6717 .18834 L
s
.6482 .13035 m
.65219 .12904 L
s
.6482 .13035 m
.64598 .13842 L
s
.70359 .22763 m
.70953 .23034 L
s
.70953 .23034 m
.72966 .22404 L
s
.66843 .1787 m
.66121 .17743 L
s
.66843 .1787 m
.66994 .18362 L
s
.66994 .18362 m
.66423 .18733 L
s
.65219 .12904 m
.67152 .12272 L
s
.65219 .12904 m
.64998 .13711 L
s
.69557 .18947 m .71646 .19889 L .69629 .20527 L .544 .324 .532 r
F
0 g
.69979 .20417 m
.70067 .2096 L
s
.001 .092 .901 r
.70503 .20849 m
.72406 .20084 L
s
.69557 .18947 m .71568 .18307 L .71646 .19889 L .544 .324 .532 r
F
0 g
.69486 .17377 m
.69557 .18947 L
s
.6734 .19653 m
.69557 .18947 L
s
.001 .092 .901 r
.71589 .1873 m
.71928 .18673 L
s
.71633 .19619 m
.72149 .19519 L
s
.70233 .20518 m
.72243 .19881 L
s
0 g
.69333 .18622 m
.69557 .18947 L
s
.7149 .16735 m
.71568 .18307 L
s
.67006 .21358 m .67753 .22731 L .67351 .22857 L .544 .324 .532 r
F
0 g
.67634 .22768 m
.68005 .23501 L
s
.67006 .21358 m .67404 .21232 L .67753 .22731 L .544 .324 .532 r
F
.001 .092 .901 r
.06311 .40741 m
.67199 .22195 L
s
0 g
.66944 .19779 m
.67006 .21358 L
s
.001 .092 .901 r
.67563 .21703 m
.70118 .20788 L
s
0 g
.67404 .21232 m
.67579 .21746 L
s
.67579 .21746 m
.68403 .23376 L
s
.66807 .2063 m
.67006 .21358 L
s
.67006 .21358 m
.67351 .22857 L
s
.6734 .19653 m
.67404 .21232 L
s
.001 .092 .901 r
.70118 .20788 m
.72175 .20046 L
s
.70118 .20788 m
.70118 .20788 L
s
0 g
.67933 .13979 m
.67152 .12272 L
s
.67933 .13979 m
.67792 .14519 L
s
.001 .092 .901 r
.67596 .22056 m
.67697 .22019 L
s
.72406 .20084 m
.93835 .10405 L
s
0 0 0 r
2 Mabswid
.72406 .20084 Mdot
0 g
.5 Mabswid
.67351 .22857 m
.68005 .23501 L
s
.68005 .23501 m
.68403 .23376 L
s
.69161 .11614 m
.69527 .11163 L
s
.001 .092 .901 r
.71928 .18673 m
.96412 .16453 L
s
0 0 0 r
2 Mabswid
.71928 .18673 Mdot
0 g
.5 Mabswid
.67205 .20504 m
.67404 .21232 L
s
.67404 .21232 m
.67753 .22731 L
s
.001 .092 .901 r
.67697 .22019 m
.69945 .21193 L
s
0 0 0 r
2 Mabswid
.67697 .22019 Mdot
.001 .092 .901 r
.5 Mabswid
.67697 .22019 m
.67697 .22019 L
s
0 0 0 r
2 Mabswid
.67697 .22019 Mdot
.67767 .15258 m .7064 .15675 L .6863 .16322 L .656 .751 .92 r
F
0 g
.5 Mabswid
.6863 .16322 m
.68677 .16764 L
s
.67792 .14519 m
.68274 .15332 L
s
.6863 .16322 m
.69486 .17377 L
s
.66696 .16944 m
.6863 .16322 L
s
.67753 .22731 m
.68403 .23376 L
s
.68403 .23376 m
.70359 .22763 L
s
.69119 .18211 m
.69333 .18622 L
s
.69333 .18622 m
.69179 .19877 L
s
.001 .092 .901 r
.72149 .19519 m
.96383 .16347 L
s
0 0 0 r
2 Mabswid
.72149 .19519 Mdot
0 g
.5 Mabswid
.70067 .2096 m
.70359 .22763 L
s
.001 .092 .901 r
.72243 .19881 m
.95352 .12555 L
s
0 0 0 r
2 Mabswid
.72243 .19881 Mdot
0 g
.5 Mabswid
.6786 .16145 m
.68677 .16764 L
s
.68677 .16764 m
.68779 .17248 L
s
.6893 .17742 m
.69119 .18211 L
s
.69119 .18211 m
.68749 .19052 L
s
.72966 .22404 m
.72378 .22129 L
s
.68779 .17248 m
.68065 .17119 L
s
.68779 .17248 m
.6893 .17742 L
s
.64551 .14949 m .65828 .15886 L .65427 .16015 L .656 .751 .92 r
F
0 g
.65427 .16015 m
.65517 .16901 L
s
.65444 .15604 m
.65457 .15277 L
s
.65427 .16015 m
.66297 .17073 L
s
.6893 .17742 m
.68369 .18111 L
s
.001 .092 .901 r
.72175 .20046 m
.95838 .10966 L
s
0 0 0 r
2 Mabswid
.72175 .20046 Mdot
0 g
.5 Mabswid
.67152 .12272 m
.69161 .11614 L
s
.67152 .12272 m
.66937 .13078 L
s
.66402 .198 m
.66807 .2063 L
s
.66807 .2063 m
.66669 .21887 L
s
.64551 .14949 m .64952 .14819 L .65828 .15886 L .656 .751 .92 r
F
0 g
.65828 .15886 m
.65918 .16771 L
s
.64952 .14819 m
.65828 .15886 L
s
.65828 .15886 m
.66696 .16944 L
s
.64598 .13842 m
.65457 .15277 L
s
.64998 .13711 m
.65856 .15147 L
s
.65828 .15886 m
.65856 .15147 L
s
.64551 .14949 m
.65427 .16015 L
s
.001 .092 .901 r
.69945 .21193 m
.69945 .21193 L
s
0 g
.66804 .19672 m
.67205 .20504 L
s
.67072 .21759 m
.67205 .20504 L
s
.64598 .13842 m
.64998 .13711 L
s
.64551 .14949 m
.64598 .13842 L
s
.67767 .15258 m .69783 .14606 L .7064 .15675 L .656 .751 .92 r
F
0 g
.7064 .15675 m
.7149 .16735 L
s
.70359 .22763 m
.72378 .22129 L
s
.65517 .16901 m
.64684 .16281 L
s
.65517 .16901 m
.6572 .17872 L
s
.64998 .13711 m
.66937 .13078 L
s
.64952 .14819 m
.64998 .13711 L
s
.69629 .20527 m .71725 .21481 L .69701 .22118 L .544 .324 .532 r
F
0 g
.69701 .22118 m
.70359 .22763 L
s
.69629 .20527 m .71646 .19889 L .71725 .21481 L .544 .324 .532 r
F
0 g
.69557 .18947 m
.69629 .20527 L
s
.67404 .21232 m
.69629 .20527 L
s
.001 .092 .901 r
.71679 .20551 m
.72016 .20426 L
s
0 g
.69179 .19877 m
.69629 .20527 L
s
.69629 .20527 m
.69701 .22118 L
s
.71568 .18307 m
.71646 .19889 L
s
.66022 .18862 m
.66402 .198 L
s
.66402 .198 m
.66018 .20651 L
s
.65918 .16771 m
.65086 .16151 L
s
.65918 .16771 m
.66121 .17743 L
s
.66669 .21887 m
.67351 .22857 L
s
.67351 .22857 m
.67753 .22731 L
s
.66423 .18733 m
.66804 .19672 L
s
.66804 .19672 m
.66421 .20523 L
s
.6572 .17872 m
.64989 .17745 L
s
.6572 .17872 m
.66022 .18862 L
s
.66022 .18862 m
.65444 .19237 L
s
.001 .092 .901 r
.72016 .20426 m
.95852 .10921 L
s
0 0 0 r
2 Mabswid
.72016 .20426 Mdot
0 g
.5 Mabswid
.67072 .21759 m
.67753 .22731 L
s
.67753 .22731 m
.69701 .22118 L
s
.68953 .1242 m
.69161 .11614 L
s
.66121 .17743 m
.65392 .17616 L
s
.66121 .17743 m
.66423 .18733 L
s
.66897 .14186 m .69783 .14606 L .67767 .15258 L .656 .751 .92 r
F
0 g
.67767 .15258 m
.6786 .16145 L
s
.67767 .15258 m
.6863 .16322 L
s
.65828 .15886 m
.67767 .15258 L
s
.66937 .13078 m
.6766 .14297 L
s
.66423 .18733 m
.65847 .19108 L
s
.68749 .19052 m
.69179 .19877 L
s
.69179 .19877 m
.69023 .21143 L
s
.71725 .21481 m
.72378 .22129 L
s
.66937 .13078 m
.68953 .1242 L
s
.71646 .19889 m
.71725 .21481 L
s
.64551 .14949 m
.64952 .14819 L
s
.64551 .14949 m
.64684 .16281 L
s
.67036 .1552 m
.6786 .16145 L
s
.6786 .16145 m
.68065 .17119 L
s
.64952 .14819 m
.65086 .16151 L
s
.68369 .18111 m
.68749 .19052 L
s
.68749 .19052 m
.68375 .19902 L
s
.66018 .20651 m
.66669 .21887 L
s
.66669 .21887 m
.67072 .21759 L
s
.69023 .21143 m
.69701 .22118 L
s
.69701 .22118 m
.71725 .21481 L
s
.68065 .17119 m
.67344 .16988 L
s
.68065 .17119 m
.68369 .18111 L
s
.68369 .18111 m
.67801 .18484 L
s
.66421 .20523 m
.67072 .21759 L
s
.67072 .21759 m
.69023 .21143 L
s
.66897 .14186 m .68919 .13529 L .69783 .14606 L .656 .751 .92 r
F
0 g
.68919 .13529 m
.69783 .14606 L
s
.64952 .14819 m
.66897 .14186 L
s
.66897 .14186 m
.66937 .13078 L
s
.69783 .14606 m
.7064 .15675 L
s
.66897 .14186 m
.67767 .15258 L
s
.64684 .16281 m
.65086 .16151 L
s
.64684 .16281 m
.64989 .17745 L
s
.68919 .13529 m
.68953 .1242 L
s
.65444 .19237 m
.66018 .20651 L
s
.66018 .20651 m
.66421 .20523 L
s
.65086 .16151 m
.67036 .1552 L
s
.65086 .16151 m
.65392 .17616 L
s
.66897 .14186 m
.68919 .13529 L
s
.66897 .14186 m
.67036 .1552 L
s
.65847 .19108 m
.66421 .20523 L
s
.66421 .20523 m
.68375 .19902 L
s
.71052 .20502 m
.71725 .21481 L
s
.64989 .17745 m
.65392 .17616 L
s
.64989 .17745 m
.65444 .19237 L
s
.65444 .19237 m
.65847 .19108 L
s
.68375 .19902 m
.69023 .21143 L
s
.69023 .21143 m
.71052 .20502 L
s
.65392 .17616 m
.67344 .16988 L
s
.65392 .17616 m
.65847 .19108 L
s
.65847 .19108 m
.67801 .18484 L
s
.67036 .1552 m
.69062 .14865 L
s
.67036 .1552 m
.67344 .16988 L
s
.68919 .13529 m
.69062 .14865 L
s
.67801 .18484 m
.68375 .19902 L
s
.68375 .19902 m
.70405 .19257 L
s
.71052 .20502 m
.70405 .19257 L
s
.67344 .16988 m
.69374 .16335 L
s
.67344 .16988 m
.67801 .18484 L
s
.67801 .18484 m
.69832 .17834 L
s
.69374 .16335 m
.69062 .14865 L
s
.70405 .19257 m
.69832 .17834 L
s
.69832 .17834 m
.69374 .16335 L
s
0 0 0 r
2 Mabswid
.95852 .10921 Mdot
.95838 .10966 Mdot
.95352 .12555 Mdot
.96383 .16347 Mdot
.96412 .16453 Mdot
.93835 .10405 Mdot
.93792 .10344 Mdot
0 g
.25 Mabswid
.00938 .30858 m
.94064 0 L
s
.02922 .302 m
.02863 .30851 L
s
gsave
.0304 .28899 -65.0919 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.26339 .22441 m
.26311 .23094 L
s
gsave
.26397 .21136 -68.887 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51218 .14197 m
.51222 .14851 L
s
gsave
.51208 .12891 -69.3101 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77697 .05423 m
.77739 .06075 L
s
gsave
.77614 .04119 -69.7766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07495 .28685 m
.07463 .29076 L
s
.12122 .27152 m
.12094 .27543 L
s
.16805 .256 m
.1678 .25992 L
s
.21543 .2403 m
.21522 .24422 L
s
.31194 .20832 m
.31181 .21224 L
s
.36108 .19204 m
.36098 .19596 L
s
.41082 .17556 m
.41077 .17948 L
s
.46119 .15887 m
.46117 .16279 L
s
.56381 .12487 m
.56388 .12879 L
s
.61609 .10754 m
.6162 .11146 L
s
.66903 .09 m
.66919 .09392 L
s
.72266 .07223 m
.72286 .07614 L
s
.83199 .036 m
.83229 .03991 L
s
.88773 .01753 m
.88807 .02144 L
s
.25 Mabswid
.98878 .07115 m
1 .17453 L
s
.98904 .07356 m
.98282 .07555 L
s
gsave
1.00148 .06956 -61 -11.2246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99157 .09688 m
.98534 .09886 L
s
gsave
1.00402 .09292 -61 -11.2094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99413 .12044 m
.9879 .1224 L
s
gsave
1.00659 .11651 -61 -11.1941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99671 .14423 m
.99048 .14618 L
s
gsave
1.00918 .14033 -61 -11.1786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99932 .16826 m
.99308 .1702 L
s
gsave
1.0118 .1644 -61 -11.163 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98954 .0782 m
.98581 .0794 L
s
.99005 .08286 m
.98631 .08405 L
s
.99055 .08752 m
.98682 .08872 L
s
.99106 .0922 m
.98733 .09339 L
s
.99208 .10157 m
.98834 .10276 L
s
.99259 .10628 m
.98885 .10746 L
s
.9931 .11099 m
.98936 .11217 L
s
.99361 .11571 m
.98988 .11689 L
s
.99464 .12518 m
.9909 .12636 L
s
.99516 .12993 m
.99142 .1311 L
s
.99567 .13469 m
.99193 .13586 L
s
.99619 .13945 m
.99245 .14063 L
s
.99723 .14902 m
.99349 .15019 L
s
.99775 .15381 m
.99401 .15498 L
s
.99827 .15862 m
.99453 .15978 L
s
.9988 .16344 m
.99505 .1646 L
s
.99984 .1731 m
.9961 .17426 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{299.688, 138.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000RPP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md;7@00?md;7@00?md;7@00?md;7@00?md
;7@00?md;7@00?md;7@00?md2g@24@=d00<AM7@00Q42M0@A4G@00?md2W@0115dM144M0044GAd4@9d
00<AM7@04G@00?md17@44@9d00@AM7@A17@0115dM143M0034GAd011d003lM08A2g@0115dM144M004
4GAd4@=d00<AM7@047@00?Ud1Q4:M0044GAd4@Ad00@AM7@A17@00a5dM00?M000mW@34@Ad0Q4:M003
4GAd00<A0W@24@04M14A4@9d114>M000lg@34@Md00<AM1402W@34@9d00<AM7@00a42M08A0W@00a5d
M00=M000l7@34@]d00<AM1401G@44@9d00@AM7@A17@0115dM143M0034GAd00ed003;M08A0g@00a5d
4@024AQd0a4?M08A2g@0115dM144M0044GAd4@=d00<AM7@03G@00<Yd00@AM7@A1g@00a5dM00BM0<A
0W@00a5dM00<M0044GAd4@Yd00@AM7@A17@0115dM143M0034GAd00ed003:M0044GAd4@Md00<AM7@0
3g@34AId0a47M0<A0W@00a5dM002M0044GAd4@9d0Q4?M000bW@0115dM145M08A3g@34AYd0Q46M003
4GAd00<A1W@24@Ad00<AM7@03G@00<Yd00@AM7@A1g@00a5dM009M0<A7W@24@Ed00@AM7@A7W@00<Yd
00@AM7@A17@0115dM148M0<A8G@34@Ad00@AM7@A7W@00<]d0Q46M08A1W@34@9d00<AM7@087@34@=d
00<AM7@00a43M0034GAd008A0g@34@id003HM0<A:7@34@=d00@AM7@A0W@00a5dM002M0044GAd4@=d
00<AM7@03G@00=Ed0a4/M0<A0g@34@9d00<AM7@00W@0115dM143M0034GAd00ed003BM0<A<7@34@Ad
00@AM7@A17@0115dM143M0034GAd00ed003?M0<A<g@00a5d4@04M0044GAd4@Ad00@AM7@A0g@00a5d
M00=M000c7@34@9d00<AM7@0<W@34@=d00<AM7@00a42M08A00=d4A401a4;M000bG@34C]d0a43M0<A
0W@00a5dM0044@03M14A008A00=d4A400W@44@Ad0036M0<A?g@24@Ed00@AM7@A0g@24@03M14A00=d
00@AM7@A0W@00a5dM004M000`g@34D9d0a44M0DA0W@24@03M14A00=d00@AM7@A0g@00a5dM003M000
`7@34DEd0a44M0044GAd4@=d0Q400g@A4@03M08A00=d4G@00W@00a5dM003M000_7@44@9d00<AM7@0
AG@00a5dM002M0044GAd4@=d0Q401W@A4G@AM08A00=d4G@00g@00a5dM002M000^G@34Ded0Q45M08A
17@0115d4A43M08A0W@00a5d4@02M0034GAd009d002fM0<AD7@24@ad0a43M0034G@A008A0W@44@=d
002cM0<ADg@34@]d00@AM7@A17@0115dM143M0034GAd009d002`M0<A00=d4G@0Dg@34@Ed1142M004
4GAd4@Ad00@AM7@A0g@00a5dM002M000[G@34EYd0Q4;M0044GAd4@Ad00@AM7@A0g@00a5dM002M000
ZW@34Did0Q4<M0034G@A00]d00@AM7@A17@0115dM143M0034GAd009d002WM0<ADG@00a@A4@0<M08A
2g@0115dM144M0044GAd4@9d0Q44M000Q7@24@=d00<AM1400a4EM0<ADW@01A@HM7@A00=d0Q47M08A
37@24@Id0Q44M0034GAd009d0023M0044GAd4@Ed00<AM7@04W@34@03M15d01=d0a4jM00351=d00Id
00<C51401g@24@Ed0Q4HM000Pg@0115dM146M0034GAd00id0a4FM0@A0W@24CId00<D67@01W@00aPD
600:M0034GAd009d00@AM7@A5g@008=d00@AM7@A1W@00a5dM00;M0<A5W@54@06M14A4G@A<g@00a<D
4`06M00451<D4`]d0Q44M0044GAd4AMd0023M0044GAd4@Md00<AM7@01g@34AId2A43M0<A<7@00aPD
6005M00461@H50Ad0Q47M0<A17@0115dM14GM000Pg@0115dM144M0044GAd4@Id0a4GM0hA00@o?Q4A
;G@00a<D4`05M0034a@C00Id00<D4a4027@34@=d00@AM7@A5g@008Ad0Q46M08A17@34@9d00<AM7@0
57@=4@04?ULnE`<A:W@00aPD6004M00451PD60Ed00<H51P02g@34@=d00@AM7@A5g@008md0a4LM0dA
00Do?Sln?`024BQd00<C51<00g@011<D4a@5M00351<D00md0Q44M0<A0g@00a5dM0024@=d0a49M000
S7@34Aid3Q4023iG?ULn4G@A97@011@H51P3M00461@H50Ad00<H51P04G@00a5d4@04M0044GAd4@Ad
00@AM7@A0g@00a5dM008M000RG@34B5d2Q4035a74A4o4Cln?a5d4B9d00<D4a@00g@011@C51<4M003
51<D01Ed0Q44M0044GAd4@Ad00@AM7@A0g@00a5dM008M000QW@44B=d2Q42G0074E`AEciG?P044Amd
00<D61@00g@00a@H5003M00451PD61Md0a44M0044GAd4@Ad00@AM7@A0g@00a5dM008M000Pg@34@=d
00<AM7@08G@94@0;Ae`A4DML4Cln?a400W@00a5dM00KM00351<D009d00@C51<D0W@00a<D4`0MM003
4GAd009d00@AM7@A17@0115dM143M0034GAd00Qd0020M0<A:W@;4@03G15L009L00@AEchA0g@00a5d
M00GM00961@H57@D61@H009d00<D61@07g@24@Ad00@AM7@A17@0115dM142M08A2W@007ed0a4]M0/A
00U74DMLAe`A?a400W@24AMd00dC51<DM1@C51=d4a@C029d0Q45M0<A0g@00a5d4@024@9d1148M000
NW@34C5d2Q42G0034EaL009L11400g@AM00DM00<61@H51PD61Ad51PD9G@34@Ad00@AM7@A17@0115d
M142M0034GAd00Qd001gM0<A0W@00a5dM00_M0dA00ALAea70Q43M0034GAd015d00/C51<D4a@CM1<D
4`0KM0044a@C50<A1W@34@Ad00@AM7@A17@0115dM143M0034GAd00Md001dM0<A=g@=4@EL00<AM7@0
0W@00a5dM00=M00;51PD61@H51PD61@04g@03A@H51PD61@H51PD61@00g@24@Md0Q44M0044GAd4@Ad
00@AM7@A0g@00a5dM007M000LG@34CYd3A401Ea7G3ho008A0W@24@ed00XD4a@C51<D4a@C2g@04A<D
4a@C51<D4a@C51<D4a@C019d00<AM14017@0115dM144M0044GAd4@Ad00<AM7@01W@006id0a4mM003
4G@A00/A00AG?ULn11400g@AM00:M00951PD61@H51PD00=d00/D61@H51PD61@H5002M00761@H51PD
600KM08A17@0115dM144M0064GAd4G@A0W@00a5dM006M000Jg@44Cmd3Q401cho?SlAG1400W@00a5d
M007M00>51<D4a@C51<D4a@C51<6M00751<D4a@C500YM08A1W@24@=d0Q49M000J7@34D=d00<AM140
2a401ELnEchA009L014AM7@A51PD61@H51PD61@H5008M00761@H51PD6018M000IG@34DMd3Q400cln
?`034@0451<D4`=d00HC51<D4a@5M00751<D4a@C501?M000@W@24@=d00<AM7@00a4EM0<ABW@00a5d
4@054@03G14A00<A01PnEchAG15L4G@AM1PD61@H51PD61@H51QFM000@G@0115dM146M0034GAd015d
0a5>M0hA00<n?a400Q402Ua74A<D4a@C51=NM000@G@0115dM146M0034GAd00id0a42M0034GAd04ad
314015Ln4Ch34@0651PD61@HHW@0045d00@AM7@A1W@00a5dM00;M0<AE7@00a4D4@094@04?SlA?`<A
00DD4a@C4@1SM000@G@0115dM146M0034GAd00Qd0a5DM00451PDM0HA00<D4A400Q400eLn4@064@9d
00<AM7@0HG@0045d00@AM7@A1G@24@Md0a5DM0034a@C00=d00<C4A401a402a<A4A4n?a4D4G@A009d
00<AM7@0HG@0049d0Q47M0034GAd009d115DM00361Ad009d00<D61@00W@54@03514A008A00AG?ULn
0Q42M0@AHg@004ed0a5EM00351<D009d00<C51<01G@64@084a@A4Cho?Sl44@=d00<AM7@0HG@004Yd
0a5EM00361@H009d00<D61@01W@00aPD60044@03514A008A00=G4A400a43M08AI7@004Md0a5EM003
51<D009d00<C51<01W@01a@C51<D4a@04Q5UM000A7@34EEd00<H51P00W@00a@H5005M00;51PD61@H
51PD61@0415WM000@7@44@9d00<AM7@0D7@00a@C5002M0034a@C00Ed00dC51<D4a@C51<D4a@C009d
3A5YM000?G@34EId00<H51P00W@00a@H5005M00=51PD61@H51PDM1@H5006M0PAKG@003Yd0a5FM003
51<D009d00<C51<01G@03A<D4a@C51<D4a@C51<02g@34G1d000gM0<AEg@01a@HM7@D61@01G@031@H
51PD61@H51PD689d000dM0<A0W@00a5dM01BM0074a@CM1<D4`05M00<4a@C51<D4aAd51<DQG@0035d
0a5GM00751PDM1@H5005M00<51PD61@H51PD61@HR7@002id0a5GM0074a@CM1<D4`04M00<51<D4a@C
51<D4a@CS7@002]d0a5GM00751PDM1@H5004M00<61@H51PD61@H51PDSg@002Qd0a42M0034GAd059d
00LC51=d4a@C00Ad00`D4a@C51<D4a@C51>BM0009G@34EMd00LD61Ad51PD00Ad00/H51PD61@H51PD
602FM0001g@24AUd0a5GM0074a@CM1<D4`04M00;51<D4a@C51<D4a@0VG@000Id00@AM7@A5G@34EQd
00HH57@D61@4M00:61@H51PD61@H59ed0006M0044GAd4A9d0a400g@AM01EM00651<D4a@C0g@02a<D
4a@C51<D4a@C0:1d0006M0044GAd4@md0a5HM00661@H51PD0g@02a@H51PD61@H51PD0:=d0006M004
4GAd4@ad0a5HM00651<D4a@C0g@02Q<D4a@C51<D4aBWM0001W@0115dM149M0<AF7@01QPD61@H50=d
00XD61@H51PD61@HZW@000Md0Q47M0<A00=d4G@0EG@01Q@C51<D4`=d00XC51<D4a@C51<D[G@000ed
0a5HM00661@H51PD0g@02A@H51PD61@H502aM0002W@34EQd00HD4a@C51<3M0094a@C51<D4a@C0;Ad
0007M0<AF7@01QPD61@H509d00XH51PD61@H51PD]g@000Ad115HM0054a@C51<00W@02A@C51<D4a@C
502kM0000W@24@=d00<AM7@0Dg@01A@H51PD009d00TH51PD61@H51P0_W@005Yd010C51<D4aAd51<D
4a@C51<D`G@005Md00lD61@H51Qd61@H51PD61@0aG@005Ad00lC51<D4aAd51<D4a@C51<0b7@0055d
00hD61@H51PD61@H51PD6<ad001>M00>4a@C51<D4a@C51<D4aC?M000Bg@03Q@H51PD61@H51PD61@H
dW@004Ud00`D4a@C51<D4a@C51?FM000AW@031PD61@H51PD61@H5=Ud0013M00<51<D4a@C51<D4a@C
g7@0041d00/H51PD61@H51PD603PM000?G@02a@C51<D4a@C51<D0>=d000jM00;61@H51PD61@H51P0
iW@003Md00XD4a@C51<D4a@CjW@003Ad00XH51PD61@H51PDkG@0039d00PC51<D4a@C5?5d000_M008
51PD61@H51SdM000;7@021<D4a@C51<Dmg@002Ud00LD61@H51PD0?]d000VM0074a@C51<D4`3nM000
8g@01a@H51PD61@0og@2M00087@01Q<D4a@C5?md1W@001ed00HD61@H51SoM0Ud000KM00551<D4a@0
og@<M00067@011PD61CoM11d000EM00451<D4omd4g@0019d00@H51PDog@FM00047@00a<DM03oM1Ud
003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad
003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad003oM2ad0000\
\>"],
  ImageRangeCache->{{{0, 298.688}, {137.875, 0}} -> {0.0432957, 0.227963, \
0.00355432, 0.00355432}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[PressureLensSurfacesTraced, Axes->True];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .46357 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0452609 1.04526 -0.277318 1.04526 [
[.03041 .28899 -4.09187 -10.9375 ]
[.03041 .28899 4.90813 0 ]
[.26397 .21136 -7.88704 -10.9375 ]
[.26397 .21136 8.61296 0 ]
[.51208 .12891 -8.31006 -10.9375 ]
[.51208 .12891 8.18994 0 ]
[.77613 .04119 -8.77663 -10.9375 ]
[.77613 .04119 7.72337 0 ]
[.95421 -0.00237 0 -7.27954 ]
[.95421 -0.00237 28.4375 3.65796 ]
[.96588 .0149 0 -7.26622 ]
[.96588 .0149 28.4375 3.67128 ]
[.97742 .03197 0 -7.2531 ]
[.97742 .03197 9 3.6844 ]
[.98882 .04883 0 -7.24017 ]
[.98882 .04883 21.5 3.69733 ]
[1.00008 .06549 0 -7.22742 ]
[1.00008 .06549 21.5 3.71008 ]
[1.00146 .06957 0 -7.22459 ]
[1.00146 .06957 28.4375 3.71291 ]
[1.00401 .09292 0 -7.20942 ]
[1.00401 .09292 28.4375 3.72808 ]
[1.00657 .11651 0 -7.19412 ]
[1.00657 .11651 9 3.74338 ]
[1.00917 .14033 0 -7.17867 ]
[1.00917 .14033 21.5 3.75883 ]
[1.01179 .16439 0 -7.16308 ]
[1.01179 .16439 21.5 3.77442 ]
[ 0 0 0 0 ]
[ 1 .46357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00939 .30858 m
.94063 0 L
s
.02923 .302 m
.02864 .30851 L
s
gsave
.03041 .28899 -65.0919 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.2634 .22441 m
.26311 .23093 L
s
gsave
.26397 .21136 -68.887 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51217 .14197 m
.51222 .14851 L
s
gsave
.51208 .12891 -69.3101 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77696 .05423 m
.77738 .06075 L
s
gsave
.77613 .04119 -69.7766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07496 .28685 m
.07464 .29076 L
s
.12123 .27152 m
.12095 .27543 L
s
.16805 .256 m
.16781 .25991 L
s
.21544 .2403 m
.21523 .24421 L
s
.31194 .20832 m
.31181 .21224 L
s
.36108 .19204 m
.36099 .19596 L
s
.41083 .17556 m
.41077 .17948 L
s
.46119 .15887 m
.46117 .16279 L
s
.5638 .12487 m
.56387 .12879 L
s
.61608 .10754 m
.6162 .11146 L
s
.66903 .09 m
.66919 .09392 L
s
.72265 .07223 m
.72285 .07614 L
s
.83198 .036 m
.83228 .03991 L
s
.88771 .01753 m
.88806 .02144 L
s
.25 Mabswid
.94063 0 m
.98876 .07115 L
s
.9418 .00174 m
.9356 .00379 L
s
gsave
.95421 -0.00237 -61 -11.2795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.95347 .01898 m
.94726 .02102 L
s
gsave
.96588 .0149 -61 -11.2662 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.965 .03602 m
.95879 .03805 L
s
gsave
.97742 .03197 -61 -11.2531 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97639 .05286 m
.97017 .05487 L
s
gsave
.98882 .04883 -61 -11.2402 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98764 .06949 m
.98142 .07149 L
s
gsave
1.00008 .06549 -61 -11.2274 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.94415 .0052 m
.94043 .00643 L
s
.94649 .00866 m
.94277 .00989 L
s
.94882 .01211 m
.9451 .01334 L
s
.95115 .01555 m
.94743 .01677 L
s
.95579 .02241 m
.95206 .02363 L
s
.9581 .02582 m
.95437 .02704 L
s
.9604 .02923 m
.95668 .03045 L
s
.9627 .03263 m
.95898 .03385 L
s
.96729 .0394 m
.96356 .04062 L
s
.96957 .04278 m
.96584 .04399 L
s
.97185 .04615 m
.96812 .04736 L
s
.97412 .04951 m
.97039 .05071 L
s
.97865 .0562 m
.97492 .05741 L
s
.98091 .05953 m
.97718 .06074 L
s
.98316 .06286 m
.97943 .06407 L
s
.9854 .06618 m
.98167 .06738 L
s
.25 Mabswid
.98876 .07115 m
1 .17466 L
s
.98902 .07356 m
.9828 .07556 L
s
gsave
1.00146 .06957 -61 -11.2246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99156 .09688 m
.98533 .09886 L
s
gsave
1.00401 .09292 -61 -11.2094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99411 .12044 m
.98788 .1224 L
s
gsave
1.00657 .11651 -61 -11.1941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9967 .14423 m
.99046 .14618 L
s
gsave
1.00917 .14033 -61 -11.1787 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99931 .16826 m
.99307 .17019 L
s
gsave
1.01179 .16439 -61 -11.1631 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98953 .07821 m
.9858 .0794 L
s
.99003 .08286 m
.9863 .08406 L
s
.99054 .08753 m
.98681 .08872 L
s
.99105 .0922 m
.98731 .09339 L
s
.99207 .10158 m
.98833 .10276 L
s
.99258 .10628 m
.98884 .10746 L
s
.99309 .11099 m
.98935 .11217 L
s
.9936 .11571 m
.98986 .11689 L
s
.99463 .12518 m
.99089 .12636 L
s
.99514 .12993 m
.9914 .1311 L
s
.99566 .13469 m
.99192 .13586 L
s
.99618 .13945 m
.99244 .14063 L
s
.99722 .14902 m
.99347 .15019 L
s
.99774 .15381 m
.99399 .15498 L
s
.99826 .15862 m
.99452 .15978 L
s
.99878 .16344 m
.99504 .1646 L
s
.99983 .1731 m
.99609 .17425 L
s
0 0 m
1 0 L
1 .46357 L
0 .46357 L
closepath
clip
newpath
.001 .092 .901 r
.5 Mabswid
.06312 .40741 m
.67213 .21474 L
s
.06312 .40741 m
.672 .19488 L
s
.06312 .40741 m
.67307 .22162 L
s
.06312 .40741 m
.68512 .22337 L
s
.06312 .40741 m
.67115 .20515 L
s
.06312 .40741 m
.67168 .21844 L
s
.06312 .40741 m
.67769 .21933 L
s
0 g
.68824 .17041 m
.69267 .18488 L
s
.68275 .17398 m
.68824 .17041 L
s
.68269 .15665 m
.68824 .17041 L
s
.69267 .18488 m
.69568 .19913 L
s
.68571 .18367 m
.69267 .18488 L
s
.69021 .16978 m
.69463 .18426 L
s
.68472 .17334 m
.69021 .16978 L
s
.68466 .15601 m
.69021 .16978 L
s
.69463 .18426 m
.69765 .19851 L
s
.68769 .18304 m
.69463 .18426 L
s
.67903 .16476 m
.68269 .15665 L
s
.67639 .1445 m
.68269 .15665 L
s
.681 .16413 m
.68466 .15601 L
s
.67835 .14387 m
.68466 .15601 L
s
.69568 .19913 m
.69709 .21222 L
s
.68773 .19322 m
.69568 .19913 L
s
.69765 .19851 m
.69906 .2116 L
s
.6897 .19259 m
.69765 .19851 L
s
.70923 .16367 m
.71367 .17818 L
s
.70383 .16721 m
.70923 .16367 L
s
.70369 .14987 m
.70923 .16367 L
s
.71367 .17818 m
.71672 .19246 L
s
.7068 .17694 m
.71367 .17818 L
s
.6748 .15664 m
.67639 .1445 L
s
.66972 .13478 m
.67639 .1445 L
s
.67678 .156 m
.67835 .14387 L
s
.67169 .13414 m
.67835 .14387 L
s
.70011 .15797 m
.70369 .14987 L
s
.6974 .13768 m
.70369 .14987 L
s
.69709 .21222 m
.68865 .20197 L
s
.69709 .21222 m
.69677 .22328 L
s
.69709 .21222 m
.69709 .21222 L
s
.69906 .2116 m
.69063 .20134 L
s
.69906 .2116 m
.69875 .22266 L
s
.69906 .2116 m
.69906 .2116 L
s
.71672 .19246 m
.71817 .20557 L
s
.70884 .1865 m
.71672 .19246 L
s
.729 .15732 m
.73345 .17187 L
s
.72368 .16084 m
.729 .15732 L
s
.72346 .14348 m
.729 .15732 L
s
.68571 .18367 m
.68275 .17398 L
s
.68275 .17398 m
.67903 .16476 L
s
.6772 .17758 m
.68275 .17398 L
s
.73345 .17187 m
.73653 .18617 L
s
.72667 .17059 m
.73345 .17187 L
s
.68773 .19322 m
.68571 .18367 L
s
.67869 .18245 m
.68571 .18367 L
s
.6959 .14982 m
.6974 .13768 L
s
.69078 .12792 m
.6974 .13768 L
s
.68769 .18304 m
.68472 .17334 L
s
.68472 .17334 m
.681 .16413 L
s
.67918 .17695 m
.68472 .17334 L
s
.6897 .19259 m
.68769 .18304 L
s
.68067 .18182 m
.68769 .18304 L
s
.67034 .15016 m
.66972 .13478 L
s
.66315 .12815 m
.66972 .13478 L
s
.66972 .13478 m
.66972 .13478 L
s
.67903 .16476 m
.6748 .15664 L
s
.67533 .17295 m
.67903 .16476 L
s
.67232 .14952 m
.67169 .13414 L
s
.66512 .12751 m
.67169 .13414 L
s
.67169 .13414 m
.67169 .13414 L
s
.71997 .15158 m
.72346 .14348 L
s
.71719 .13126 m
.72346 .14348 L
s
.681 .16413 m
.67678 .156 L
s
.67731 .17232 m
.681 .16413 L
s
.68865 .20197 m
.68773 .19322 L
s
.6797 .18725 m
.68773 .19322 L
s
.71817 .20557 m
.7098 .19526 L
s
.71817 .20557 m
.71791 .21664 L
s
.71817 .20557 m
.71817 .20557 L
s
.69063 .20134 m
.6897 .19259 L
s
.68168 .18661 m
.6897 .19259 L
s
.73653 .18617 m
.73802 .1993 L
s
.72872 .18017 m
.73653 .18617 L
s
.69677 .22328 m
.69475 .23156 L
s
.68843 .20934 m
.69677 .22328 L
s
.69875 .22266 m
.69674 .23094 L
s
.69041 .20872 m
.69875 .22266 L
s
.6748 .15664 m
.67034 .15016 L
s
.67321 .16888 m
.6748 .15664 L
s
.67678 .156 m
.67232 .14952 L
s
.67519 .16824 m
.67678 .156 L
s
.68843 .20934 m
.68865 .20197 L
s
.68865 .20197 m
.68016 .19164 L
s
.68865 .20197 m
.68865 .20197 L
s
.70383 .16721 m
.70011 .15797 L
s
.70383 .16721 m
.69837 .17079 L
s
.7068 .17694 m
.70383 .16721 L
s
.69041 .20872 m
.69063 .20134 L
s
.69063 .20134 m
.68214 .191 L
s
.69063 .20134 m
.69063 .20134 L
s
.71577 .1434 m
.71719 .13126 L
s
.71061 .12146 m
.71719 .13126 L
s
.70884 .1865 m
.7068 .17694 L
s
.69986 .17568 m
.7068 .17694 L
s
.69147 .14332 m
.69078 .12792 L
s
.68426 .12125 m
.69078 .12792 L
s
.69078 .12792 m
.69078 .12792 L
s
.70011 .15797 m
.6959 .14982 L
s
.6965 .16615 m
.70011 .15797 L
s
.73802 .1993 m
.72971 .18894 L
s
.73802 .1993 m
.73783 .21037 L
s
.73802 .1993 m
.73802 .1993 L
s
.7098 .19526 m
.70884 .1865 L
s
.70088 .18048 m
.70884 .1865 L
s
.67034 .15016 m
.66595 .14577 L
s
.67097 .16564 m
.67034 .15016 L
s
.67034 .15016 m
.67034 .15016 L
s
.66595 .14577 m
.66315 .12815 L
s
.6571 .12508 m
.66315 .12815 L
s
.67232 .14952 m
.66793 .14512 L
s
.67295 .165 m
.67232 .14952 L
s
.67232 .14952 m
.67232 .14952 L
s
.71791 .21664 m
.71596 .22491 L
s
.70961 .20264 m
.71791 .21664 L
s
.66793 .14512 m
.66512 .12751 L
s
.65908 .12443 m
.66512 .12751 L
s
.68562 .2153 m
.68843 .20934 L
s
.67946 .19551 m
.68843 .20934 L
s
.6959 .14982 m
.69147 .14332 L
s
.69438 .16207 m
.6959 .14982 L
s
.68758 .21468 m
.69041 .20872 L
s
.68141 .19489 m
.69041 .20872 L
s
.70961 .20264 m
.7098 .19526 L
s
.7098 .19526 m
.70136 .18488 L
s
.7098 .19526 m
.7098 .19526 L
s
.69475 .23156 m
.69114 .23648 L
s
.68562 .2153 m
.69475 .23156 L
s
.72368 .16084 m
.71997 .15158 L
s
.72368 .16084 m
.71831 .1644 L
s
.72667 .17059 m
.72368 .16084 L
s
.72872 .18017 m
.72667 .17059 L
s
.71981 .1693 m
.72667 .17059 L
s
.67869 .18245 m
.6772 .17758 L
s
.6772 .17758 m
.67533 .17295 L
s
.6716 .18122 m
.6772 .17758 L
s
.69674 .23094 m
.69313 .23586 L
s
.68758 .21468 m
.69674 .23094 L
s
.6797 .18725 m
.67869 .18245 L
s
.6716 .18122 m
.67869 .18245 L
s
.71136 .13687 m
.71061 .12146 L
s
.70414 .11475 m
.71061 .12146 L
s
.71061 .12146 m
.71061 .12146 L
s
.68067 .18182 m
.67918 .17695 L
s
.67918 .17695 m
.67731 .17232 L
s
.67358 .18059 m
.67918 .17695 L
s
.68168 .18661 m
.68067 .18182 L
s
.67358 .18059 m
.68067 .18182 L
s
.67533 .17295 m
.67321 .16888 L
s
.6716 .18122 m
.67533 .17295 L
s
.71997 .15158 m
.71577 .1434 L
s
.71645 .15975 m
.71997 .15158 L
s
.68016 .19164 m
.6797 .18725 L
s
.6716 .18122 m
.6797 .18725 L
s
.67731 .17232 m
.67519 .16824 L
s
.67358 .18059 m
.67731 .17232 L
s
.68214 .191 m
.68168 .18661 L
s
.67358 .18059 m
.68168 .18661 L
s
.72971 .18894 m
.72872 .18017 L
s
.72084 .17411 m
.72872 .18017 L
s
.66595 .14577 m
.66193 .14376 L
s
.66877 .16346 m
.66595 .14577 L
s
.67321 .16888 m
.67097 .16564 L
s
.6716 .18122 m
.67321 .16888 L
s
.66793 .14512 m
.66391 .14312 L
s
.67075 .16282 m
.66793 .14512 L
s
.69147 .14332 m
.68711 .13889 L
s
.69216 .15881 m
.69147 .14332 L
s
.69147 .14332 m
.69147 .14332 L
s
.67519 .16824 m
.67295 .165 L
s
.67358 .18059 m
.67519 .16824 L
s
.67946 .19551 m
.68016 .19164 L
s
.68016 .19164 m
.6716 .18122 L
s
.68016 .19164 m
.68016 .19164 L
s
.73783 .21037 m
.73594 .21865 L
s
.72956 .19633 m
.73783 .21037 L
s
.68711 .13889 m
.68426 .12125 L
s
.67827 .11814 m
.68426 .12125 L
s
.68024 .21946 m
.68562 .2153 L
s
.67728 .19872 m
.68562 .2153 L
s
.68141 .19489 m
.68214 .191 L
s
.68214 .191 m
.67358 .18059 L
s
.68214 .191 m
.68214 .191 L
s
.68221 .21884 m
.68758 .21468 L
s
.67925 .19809 m
.68758 .21468 L
s
.71577 .1434 m
.71136 .13687 L
s
.71434 .15565 m
.71577 .1434 L
s
.70829 .20814 m
.70961 .20264 L
s
.70126 .18857 m
.70961 .20264 L
s
.6716 .18122 m
.67097 .16564 L
s
.67097 .16564 m
.67097 .16564 L
s
.67097 .16564 m
.66877 .16346 L
s
.67358 .18059 m
.67295 .165 L
s
.67295 .165 m
.67295 .165 L
s
.67295 .165 m
.67075 .16282 L
s
.67728 .19872 m
.67946 .19551 L
s
.6716 .18122 m
.67946 .19551 L
s
.72956 .19633 m
.72971 .18894 L
s
.72971 .18894 m
.72133 .17851 L
s
.72971 .18894 m
.72971 .18894 L
s
.67925 .19809 m
.68141 .19489 L
s
.67358 .18059 m
.68141 .19489 L
s
.71596 .22491 m
.71242 .22982 L
s
.70829 .20814 m
.71596 .22491 L
s
.66193 .14376 m
.6571 .12508 L
s
.652 .12581 m
.6571 .12508 L
s
.69986 .17568 m
.69837 .17079 L
s
.69837 .17079 m
.6965 .16615 L
s
.69286 .17441 m
.69837 .17079 L
s
.70088 .18048 m
.69986 .17568 L
s
.69286 .17441 m
.69986 .17568 L
s
.66391 .14312 m
.65908 .12443 L
s
.65398 .12516 m
.65908 .12443 L
s
.6965 .16615 m
.69438 .16207 L
s
.69286 .17441 m
.6965 .16615 L
s
.001 .092 .901 r
.68512 .22337 m
.68688 .22264 L
s
0 0 0 r
2 Mabswid
.68512 .22337 Mdot
0 g
.5 Mabswid
.66877 .16346 m
.66676 .16248 L
s
.6716 .18122 m
.66877 .16346 L
s
.70136 .18488 m
.70088 .18048 L
s
.69286 .17441 m
.70088 .18048 L
s
.67457 .20078 m
.67728 .19872 L
s
.6716 .18122 m
.67728 .19872 L
s
.67075 .16282 m
.66874 .16184 L
s
.67358 .18059 m
.67075 .16282 L
s
.001 .092 .901 r
.68688 .22264 m
.70719 .2142 L
s
0 0 0 r
2 Mabswid
.68688 .22264 Mdot
0 g
.5 Mabswid
.67654 .20016 m
.67925 .19809 L
s
.67358 .18059 m
.67925 .19809 L
s
.66193 .14376 m
.65854 .1443 L
s
.66676 .16248 m
.66193 .14376 L
s
.68711 .13889 m
.68313 .13687 L
s
.68998 .15661 m
.68711 .13889 L
s
.69438 .16207 m
.69216 .15881 L
s
.69286 .17441 m
.69438 .16207 L
s
.71136 .13687 m
.70704 .13242 L
s
.71212 .15238 m
.71136 .13687 L
s
.71136 .13687 m
.71136 .13687 L
s
.66391 .14312 m
.66052 .14365 L
s
.66874 .16184 m
.66391 .14312 L
s
.70704 .13242 m
.70414 .11475 L
s
.69822 .11161 m
.70414 .11475 L
s
.67512 .22076 m
.68024 .21946 L
s
.68024 .21946 m
.69114 .23648 L
s
.67457 .20078 m
.68024 .21946 L
s
.69114 .23648 m
.68586 .23775 L
s
.70126 .18857 m
.70136 .18488 L
s
.70136 .18488 m
.69286 .17441 L
s
.70136 .18488 m
.70136 .18488 L
s
.67711 .22014 m
.68221 .21884 L
s
.68221 .21884 m
.69313 .23586 L
s
.67654 .20016 m
.68221 .21884 L
s
.69313 .23586 m
.68783 .23714 L
s
.70591 .21136 m
.70829 .20814 L
s
.70059 .1913 m
.70829 .20814 L
s
.72829 .20182 m
.72956 .19633 L
s
.72125 .1822 m
.72956 .19633 L
s
.67213 .20137 m
.67457 .20078 L
s
.6716 .18122 m
.67457 .20078 L
s
.66676 .16248 m
.66507 .16277 L
s
.6716 .18122 m
.66676 .16248 L
s
.69286 .17441 m
.69216 .15881 L
s
.69216 .15881 m
.69216 .15881 L
s
.69216 .15881 m
.68998 .15661 L
s
.6741 .20075 m
.67654 .20016 L
s
.67358 .18059 m
.67654 .20016 L
s
.66874 .16184 m
.66706 .16213 L
s
.67358 .18059 m
.66874 .16184 L
s
.001 .092 .901 r
.67769 .21933 m
.67951 .21861 L
s
0 0 0 r
2 Mabswid
.67769 .21933 Mdot
0 g
.5 Mabswid
.70059 .1913 m
.70126 .18857 L
s
.69286 .17441 m
.70126 .18857 L
s
.73594 .21865 m
.73247 .22354 L
s
.72829 .20182 m
.73594 .21865 L
s
.001 .092 .901 r
.67951 .21861 m
.70312 .20924 L
s
0 0 0 r
2 Mabswid
.67951 .21861 Mdot
0 g
.5 Mabswid
.71981 .1693 m
.71831 .1644 L
s
.71831 .1644 m
.71645 .15975 L
s
.71289 .16799 m
.71831 .1644 L
s
.72084 .17411 m
.71981 .1693 L
s
.71289 .16799 m
.71981 .1693 L
s
.68313 .13687 m
.67827 .11814 L
s
.67324 .11885 m
.67827 .11814 L
s
.6716 .18122 m
.6716 .18122 L
s
.6716 .18122 m
.66507 .16277 L
s
.6716 .18122 m
.66382 .16433 L
s
.6716 .18122 m
.6631 .16704 L
s
.6716 .18122 m
.66297 .17073 L
s
.6716 .18122 m
.66342 .17514 L
s
.6716 .18122 m
.66443 .17998 L
s
.6716 .18122 m
.66593 .1849 L
s
.6716 .18122 m
.66773 .1896 L
s
.6716 .18122 m
.66877 .19405 L
s
.6716 .18122 m
.66943 .19779 L
s
.6716 .18122 m
.67041 .20034 L
s
.6716 .18122 m
.67213 .20137 L
s
.71645 .15975 m
.71434 .15565 L
s
.71289 .16799 m
.71645 .15975 L
s
.67358 .18059 m
.67358 .18059 L
s
.67358 .18059 m
.66706 .16213 L
s
.67358 .18059 m
.66581 .16368 L
s
.67358 .18059 m
.6651 .1664 L
s
.67358 .18059 m
.66496 .17009 L
s
.67358 .18059 m
.66541 .1745 L
s
.67358 .18059 m
.66643 .17934 L
s
.67358 .18059 m
.66793 .18426 L
s
.67358 .18059 m
.66969 .18897 L
s
.67358 .18059 m
.67074 .19342 L
s
.67358 .18059 m
.6714 .19717 L
s
.67358 .18059 m
.67239 .19972 L
s
.67358 .18059 m
.6741 .20075 L
s
.72133 .17851 m
.72084 .17411 L
s
.71289 .16799 m
.72084 .17411 L
s
.67041 .20034 m
.67213 .20137 L
s
.67213 .20137 m
.67512 .22076 L
s
.68998 .15661 m
.68799 .15562 L
s
.69286 .17441 m
.68998 .15661 L
s
.66507 .16277 m
.65854 .1443 L
s
.66507 .16277 m
.66382 .16433 L
s
.67239 .19972 m
.6741 .20075 L
s
.6741 .20075 m
.67711 .22014 L
s
.70704 .13242 m
.7031 .13037 L
s
.70996 .15017 m
.70704 .13242 L
s
.66706 .16213 m
.66052 .14365 L
s
.66706 .16213 m
.66581 .16368 L
s
.71434 .15565 m
.71212 .15238 L
s
.71289 .16799 m
.71434 .15565 L
s
.69939 .1929 m
.70059 .1913 L
s
.69286 .17441 m
.70059 .1913 L
s
.68313 .13687 m
.67979 .13739 L
s
.68799 .15562 m
.68313 .13687 L
s
.001 .092 .901 r
.672 .19488 m
.67394 .19453 L
s
0 0 0 r
2 Mabswid
.672 .19488 Mdot
.001 .092 .901 r
.5 Mabswid
.67115 .20515 m
.67312 .20475 L
s
0 0 0 r
2 Mabswid
.67115 .20515 Mdot
0 g
.5 Mabswid
.65854 .1443 m
.65602 .14737 L
s
.652 .12581 m
.65854 .1443 L
s
.6718 .21871 m
.67512 .22076 L
s
.67512 .22076 m
.68586 .23775 L
s
.72125 .1822 m
.72133 .17851 L
s
.72133 .17851 m
.71289 .16799 L
s
.72133 .17851 m
.72133 .17851 L
s
.001 .092 .901 r
.67394 .19453 m
.69638 .19059 L
s
0 0 0 r
2 Mabswid
.67394 .19453 Mdot
.001 .092 .901 r
.5 Mabswid
.67312 .20475 m
.69872 .19962 L
s
0 0 0 r
2 Mabswid
.67312 .20475 Mdot
.001 .092 .901 r
.5 Mabswid
.67213 .21474 m
.67412 .21411 L
s
0 0 0 r
2 Mabswid
.67213 .21474 Mdot
0 g
.5 Mabswid
.71242 .22982 m
.70752 .23097 L
s
.70591 .21136 m
.71242 .22982 L
s
.66052 .14365 m
.65801 .14672 L
s
.65398 .12516 m
.66052 .14365 L
s
.67378 .21809 m
.67711 .22014 L
s
.67711 .22014 m
.68783 .23714 L
s
.001 .092 .901 r
.70719 .2142 m
.72594 .20629 L
s
0 0 0 r
2 Mabswid
.70719 .2142 Mdot
.001 .092 .901 r
.5 Mabswid
.67412 .21411 m
.70032 .20581 L
s
0 0 0 r
2 Mabswid
.67412 .21411 Mdot
0 g
.5 Mabswid
.6482 .13035 m
.652 .12581 L
s
.72595 .20504 m
.72829 .20182 L
s
.7206 .18494 m
.72829 .20182 L
s
.70262 .21209 m
.70591 .21136 L
s
.69939 .1929 m
.70591 .21136 L
s
.65019 .1297 m
.65398 .12516 L
s
.66943 .19779 m
.67041 .20034 L
s
.67041 .20034 m
.6718 .21871 L
s
.71289 .16799 m
.71212 .15238 L
s
.71212 .15238 m
.71212 .15238 L
s
.71212 .15238 m
.70996 .15017 L
s
.68799 .15562 m
.68632 .15591 L
s
.69286 .17441 m
.68799 .15562 L
s
.66382 .16433 m
.65602 .14737 L
s
.66382 .16433 m
.6631 .16704 L
s
.6714 .19717 m
.67239 .19972 L
s
.67239 .19972 m
.67378 .21809 L
s
.7206 .18494 m
.72125 .1822 L
s
.71289 .16799 m
.72125 .1822 L
s
.66581 .16368 m
.65801 .14672 L
s
.66581 .16368 m
.6651 .1664 L
s
.69774 .19323 m
.69939 .1929 L
s
.69286 .17441 m
.69939 .1929 L
s
.7031 .13037 m
.69822 .11161 L
s
.69325 .11229 m
.69822 .11161 L
s
.69286 .17441 m
.69286 .17441 L
s
.69286 .17441 m
.68632 .15591 L
s
.69286 .17441 m
.6851 .15746 L
s
.69286 .17441 m
.68441 .16017 L
s
.69286 .17441 m
.68429 .16386 L
s
.69286 .17441 m
.68476 .16828 L
s
.69286 .17441 m
.68578 .17313 L
s
.69286 .17441 m
.68729 .17806 L
s
.69286 .17441 m
.68918 .18275 L
s
.69286 .17441 m
.69132 .18686 L
s
.69286 .17441 m
.69356 .19011 L
s
.69286 .17441 m
.69575 .19228 L
s
.69286 .17441 m
.69774 .19323 L
s
.68586 .23775 m
.68005 .23501 L
s
.70996 .15017 m
.70799 .14917 L
s
.71289 .16799 m
.70996 .15017 L
s
.68783 .23714 m
.68202 .23439 L
s
.66877 .19405 m
.66943 .19779 L
s
.66943 .19779 m
.67006 .21358 L
s
.66943 .19779 m
.66943 .19779 L
s
.6631 .16704 m
.65456 .15277 L
s
.6631 .16704 m
.66297 .17073 L
s
.68632 .15591 m
.67979 .13739 L
s
.68632 .15591 m
.6851 .15746 L
s
.67074 .19342 m
.6714 .19717 L
s
.6714 .19717 m
.67204 .21295 L
s
.6714 .19717 m
.6714 .19717 L
s
.71942 .18653 m
.7206 .18494 L
s
.71289 .16799 m
.7206 .18494 L
s
.6651 .1664 m
.65656 .15212 L
s
.6651 .1664 m
.66496 .17009 L
s
.7031 .13037 m
.6998 .13088 L
s
.70799 .14917 m
.7031 .13037 L
s
.001 .092 .901 r
.70312 .20924 m
.72214 .2016 L
s
0 0 0 r
2 Mabswid
.70312 .20924 Mdot
0 g
.5 Mabswid
.69575 .19228 m
.69774 .19323 L
s
.69774 .19323 m
.70262 .21209 L
s
.67979 .13739 m
.67732 .14045 L
s
.67324 .11885 m
.67979 .13739 L
s
.65602 .14737 m
.6482 .13035 L
s
.65602 .14737 m
.65456 .15277 L
s
.73247 .22354 m
.72764 .22467 L
s
.72595 .20504 m
.73247 .22354 L
s
.67006 .21358 m
.6718 .21871 L
s
.6718 .21871 m
.68005 .23501 L
s
.001 .092 .901 r
.67168 .21844 m
.67365 .21774 L
s
0 0 0 r
2 Mabswid
.67168 .21844 Mdot
0 g
.5 Mabswid
.65801 .14672 m
.65019 .1297 L
s
.65801 .14672 m
.65656 .15212 L
s
.001 .092 .901 r
.69638 .19059 m
.7172 .1871 L
s
0 0 0 r
2 Mabswid
.69638 .19059 Mdot
.001 .092 .901 r
.5 Mabswid
.67365 .21774 m
.69913 .20861 L
s
0 0 0 r
2 Mabswid
.67365 .21774 Mdot
0 g
.5 Mabswid
.67204 .21295 m
.67378 .21809 L
s
.67378 .21809 m
.68202 .23439 L
s
.66297 .17073 m
.65427 .16015 L
s
.66297 .17073 m
.66342 .17514 L
s
.66297 .17073 m
.66297 .17073 L
s
.66951 .12337 m
.67324 .11885 L
s
.72271 .20575 m
.72595 .20504 L
s
.71942 .18653 m
.72595 .20504 L
s
.66773 .1896 m
.66877 .19405 L
s
.66877 .19405 m
.66807 .2063 L
s
.70799 .14917 m
.70635 .14944 L
s
.71289 .16799 m
.70799 .14917 L
s
.66496 .17009 m
.65627 .1595 L
s
.66496 .17009 m
.66541 .1745 L
s
.66496 .17009 m
.66496 .17009 L
s
.001 .092 .901 r
.69872 .19962 m
.71941 .19561 L
s
0 0 0 r
2 Mabswid
.69872 .19962 Mdot
0 g
.5 Mabswid
.66969 .18897 m
.67074 .19342 L
s
.67074 .19342 m
.67004 .20567 L
s
.69865 .21023 m
.70262 .21209 L
s
.70262 .21209 m
.70752 .23097 L
s
.6851 .15746 m
.67732 .14045 L
s
.6851 .15746 m
.68441 .16017 L
s
.001 .092 .901 r
.72594 .20629 m
.93784 .10334 L
s
0 0 0 r
2 Mabswid
.72594 .20629 Mdot
0 g
.5 Mabswid
.7178 .18685 m
.71942 .18653 L
s
.71289 .16799 m
.71942 .18653 L
s
.001 .092 .901 r
.70032 .20581 m
.72041 .19945 L
s
0 0 0 r
2 Mabswid
.70032 .20581 Mdot
0 g
.5 Mabswid
.66342 .17514 m
.65516 .16901 L
s
.66342 .17514 m
.66443 .17998 L
s
.69356 .19011 m
.69575 .19228 L
s
.69575 .19228 m
.69865 .21023 L
s
.66593 .1849 m
.66773 .1896 L
s
.66773 .1896 m
.66402 .198 L
s
.66541 .1745 m
.65717 .16836 L
s
.66541 .1745 m
.66643 .17934 L
s
.71289 .16799 m
.71289 .16799 L
s
.71289 .16799 m
.70635 .14944 L
s
.71289 .16799 m
.70515 .15099 L
s
.71289 .16799 m
.70448 .1537 L
s
.71289 .16799 m
.70438 .15739 L
s
.71289 .16799 m
.70486 .16182 L
s
.71289 .16799 m
.7059 .16668 L
s
.71289 .16799 m
.70741 .17162 L
s
.71289 .16799 m
.7093 .17632 L
s
.71289 .16799 m
.71143 .18044 L
s
.71289 .16799 m
.71366 .18371 L
s
.71289 .16799 m
.71583 .18589 L
s
.71289 .16799 m
.7178 .18685 L
s
.66793 .18426 m
.66969 .18897 L
s
.66969 .18897 m
.66602 .19736 L
s
.66443 .17998 m
.65719 .17872 L
s
.66443 .17998 m
.66593 .1849 L
s
.66593 .1849 m
.66021 .18862 L
s
.70752 .23097 m
.70157 .22826 L
s
.66643 .17934 m
.6592 .17808 L
s
.66643 .17934 m
.66793 .18426 L
s
.64597 .13842 m
.6482 .13035 L
s
.66793 .18426 m
.66222 .18798 L
s
.70635 .14944 m
.6998 .13088 L
s
.70635 .14944 m
.70515 .15099 L
s
.68441 .16017 m
.67591 .14585 L
s
.68441 .16017 m
.68429 .16386 L
s
.64797 .13777 m
.65019 .1297 L
s
.71583 .18589 m
.7178 .18685 L
s
.7178 .18685 m
.72271 .20575 L
s
.69132 .18686 m
.69356 .19011 L
s
.69356 .19011 m
.69427 .20591 L
s
.69356 .19011 m
.69356 .19011 L
s
.6998 .13088 m
.69739 .13392 L
s
.69325 .11229 m
.6998 .13088 L
s
.65456 .15277 m
.64597 .13842 L
s
.65456 .15277 m
.65427 .16015 L
s
.67732 .14045 m
.66951 .12337 L
s
.67732 .14045 m
.67591 .14585 L
s
.001 .092 .901 r
.69913 .20861 m
.71969 .20119 L
s
0 0 0 r
2 Mabswid
.69913 .20861 Mdot
.001 .092 .901 r
.5 Mabswid
.72214 .2016 m
.93827 .10396 L
s
0 0 0 r
2 Mabswid
.72214 .2016 Mdot
0 g
.5 Mabswid
.65656 .15212 m
.64797 .13777 L
s
.65656 .15212 m
.65627 .1595 L
s
.66807 .2063 m
.67006 .21358 L
s
.67006 .21358 m
.6735 .22857 L
s
.67006 .21358 m
.67006 .21358 L
s
.68959 .1168 m
.69325 .11229 L
s
.001 .092 .901 r
.7172 .1871 m
.96416 .1647 L
s
0 0 0 r
2 Mabswid
.7172 .1871 Mdot
.001 .092 .901 r
.5 Mabswid
.67307 .22162 m
.67501 .22091 L
s
0 0 0 r
2 Mabswid
.67307 .22162 Mdot
0 g
.5 Mabswid
.68005 .23501 m
.6735 .22857 L
s
.67004 .20567 m
.67204 .21295 L
s
.67204 .21295 m
.67551 .22794 L
s
.67204 .21295 m
.67204 .21295 L
s
.68429 .16386 m
.67565 .15323 L
s
.68429 .16386 m
.68476 .16828 L
s
.68429 .16386 m
.68429 .16386 L
s
.001 .092 .901 r
.67501 .22091 m
.69738 .21269 L
s
0 0 0 r
2 Mabswid
.67501 .22091 Mdot
0 g
.5 Mabswid
.68202 .23439 m
.67551 .22794 L
s
.71879 .20387 m
.72271 .20575 L
s
.72271 .20575 m
.72764 .22467 L
s
.70515 .15099 m
.69739 .13392 L
s
.70515 .15099 m
.70448 .1537 L
s
.68918 .18275 m
.69132 .18686 L
s
.69132 .18686 m
.68977 .19941 L
s
.001 .092 .901 r
.71941 .19561 m
.96386 .16363 L
s
0 0 0 r
2 Mabswid
.71941 .19561 Mdot
0 g
.5 Mabswid
.69427 .20591 m
.69865 .21023 L
s
.69865 .21023 m
.70157 .22826 L
s
.001 .092 .901 r
.72041 .19945 m
.9535 .12555 L
s
0 0 0 r
2 Mabswid
.72041 .19945 Mdot
0 g
.5 Mabswid
.71366 .18371 m
.71583 .18589 L
s
.71583 .18589 m
.71879 .20387 L
s
.68476 .16828 m
.67658 .1621 L
s
.68476 .16828 m
.68578 .17313 L
s
.68729 .17806 m
.68918 .18275 L
s
.68918 .18275 m
.68547 .19117 L
s
.72764 .22467 m
.72175 .22193 L
s
.68578 .17313 m
.67863 .17183 L
s
.68578 .17313 m
.68729 .17806 L
s
.68729 .17806 m
.68167 .18176 L
s
.66736 .13144 m
.66951 .12337 L
s
.65427 .16015 m
.6455 .14949 L
s
.65427 .16015 m
.65516 .16901 L
s
.65427 .16015 m
.65427 .16015 L
s
.001 .092 .901 r
.71969 .20119 m
.95839 .10959 L
s
0 0 0 r
2 Mabswid
.71969 .20119 Mdot
0 g
.5 Mabswid
.70448 .1537 m
.69602 .13932 L
s
.70448 .1537 m
.70438 .15739 L
s
.65627 .1595 m
.64751 .14884 L
s
.65627 .1595 m
.65717 .16836 L
s
.65627 .1595 m
.65627 .1595 L
s
.71143 .18044 m
.71366 .18371 L
s
.71366 .18371 m
.71443 .19953 L
s
.71366 .18371 m
.71366 .18371 L
s
.66402 .198 m
.66807 .2063 L
s
.66807 .2063 m
.66669 .21887 L
s
.001 .092 .901 r
.69738 .21269 m
.71809 .20502 L
s
0 0 0 r
2 Mabswid
.69738 .21269 Mdot
0 g
.5 Mabswid
.67591 .14585 m
.66736 .13144 L
s
.67591 .14585 m
.67565 .15323 L
s
.69739 .13392 m
.68959 .1168 L
s
.69739 .13392 m
.69602 .13932 L
s
.66602 .19736 m
.67004 .20567 L
s
.67004 .20567 m
.6687 .21823 L
s
.6455 .14949 m
.64597 .13842 L
s
.70438 .15739 m
.6958 .14671 L
s
.70438 .15739 m
.70486 .16182 L
s
.70438 .15739 m
.70438 .15739 L
s
.70157 .22826 m
.69498 .22182 L
s
.64751 .14884 m
.64797 .13777 L
s
.68977 .19941 m
.69427 .20591 L
s
.69427 .20591 m
.69498 .22182 L
s
.69427 .20591 m
.69427 .20591 L
s
.7093 .17632 m
.71143 .18044 L
s
.71143 .18044 m
.70996 .193 L
s
.71443 .19953 m
.71879 .20387 L
s
.71879 .20387 m
.72175 .22193 L
s
.65516 .16901 m
.64683 .16281 L
s
.65516 .16901 m
.65719 .17872 L
s
.65717 .16836 m
.64884 .16216 L
s
.65717 .16836 m
.6592 .17808 L
s
.70486 .16182 m
.69676 .15559 L
s
.70486 .16182 m
.7059 .16668 L
s
.66021 .18862 m
.66402 .198 L
s
.66402 .198 m
.66018 .20651 L
s
.70741 .17162 m
.7093 .17632 L
s
.7093 .17632 m
.70567 .18473 L
s
.6735 .22857 m
.66669 .21887 L
s
.6735 .22857 m
.6735 .22857 L
s
.66222 .18798 m
.66602 .19736 L
s
.66602 .19736 m
.66219 .20587 L
s
.7059 .16668 m
.69883 .16535 L
s
.7059 .16668 m
.70741 .17162 L
s
.70741 .17162 m
.70188 .17529 L
s
.001 .092 .901 r
.71809 .20502 m
.95852 .10914 L
s
0 0 0 r
2 Mabswid
.71809 .20502 Mdot
0 g
.5 Mabswid
.67551 .22794 m
.6687 .21823 L
s
.67551 .22794 m
.67551 .22794 L
s
.65719 .17872 m
.64988 .17745 L
s
.65719 .17872 m
.66021 .18862 L
s
.66021 .18862 m
.65444 .19237 L
s
.68751 .12486 m
.68959 .1168 L
s
.6592 .17808 m
.6519 .1768 L
s
.6592 .17808 m
.66222 .18798 L
s
.67565 .15323 m
.66695 .14252 L
s
.67565 .15323 m
.67658 .1621 L
s
.67565 .15323 m
.67565 .15323 L
s
.66222 .18798 m
.65645 .19173 L
s
.69602 .13932 m
.68751 .12486 L
s
.69602 .13932 m
.6958 .14671 L
s
.68547 .19117 m
.68977 .19941 L
s
.68977 .19941 m
.6882 .21206 L
s
.72175 .22193 m
.71521 .21545 L
s
.66695 .14252 m
.66736 .13144 L
s
.70996 .193 m
.71443 .19953 L
s
.71443 .19953 m
.71521 .21545 L
s
.71443 .19953 m
.71443 .19953 L
s
.64683 .16281 m
.6455 .14949 L
s
.6455 .14949 m
.6455 .14949 L
s
.67658 .1621 m
.66833 .15586 L
s
.67658 .1621 m
.67863 .17183 L
s
.64884 .16216 m
.64751 .14884 L
s
.64751 .14884 m
.64751 .14884 L
s
.68167 .18176 m
.68547 .19117 L
s
.68547 .19117 m
.68172 .19967 L
s
.69498 .22182 m
.6882 .21206 L
s
.69498 .22182 m
.69498 .22182 L
s
.66669 .21887 m
.66018 .20651 L
s
.67863 .17183 m
.67141 .17053 L
s
.67863 .17183 m
.68167 .18176 L
s
.68167 .18176 m
.67598 .18548 L
s
.6687 .21823 m
.66219 .20587 L
s
.6958 .14671 m
.68716 .13595 L
s
.6958 .14671 m
.69676 .15559 L
s
.6958 .14671 m
.6958 .14671 L
s
.70567 .18473 m
.70996 .193 L
s
.70996 .193 m
.70848 .20566 L
s
.68716 .13595 m
.68751 .12486 L
s
.64988 .17745 m
.64683 .16281 L
s
.6519 .1768 m
.64884 .16216 L
s
.69676 .15559 m
.68858 .1493 L
s
.69676 .15559 m
.69883 .16535 L
s
.66833 .15586 m
.66695 .14252 L
s
.66695 .14252 m
.66695 .14252 L
s
.66018 .20651 m
.65444 .19237 L
s
.70188 .17529 m
.70567 .18473 L
s
.70567 .18473 m
.70201 .19322 L
s
.66219 .20587 m
.65645 .19173 L
s
.71521 .21545 m
.70848 .20566 L
s
.71521 .21545 m
.71521 .21545 L
s
.69883 .16535 m
.6917 .164 L
s
.69883 .16535 m
.70188 .17529 L
s
.6882 .21206 m
.68172 .19967 L
s
.65444 .19237 m
.64988 .17745 L
s
.70188 .17529 m
.69628 .17899 L
s
.65645 .19173 m
.6519 .1768 L
s
.67141 .17053 m
.66833 .15586 L
s
.68858 .1493 m
.68716 .13595 L
s
.68716 .13595 m
.68716 .13595 L
s
.68172 .19967 m
.67598 .18548 L
s
.70848 .20566 m
.70201 .19322 L
s
.67598 .18548 m
.67141 .17053 L
s
.6917 .164 m
.68858 .1493 L
s
.70201 .19322 m
.69628 .17899 L
s
.69628 .17899 m
.6917 .164 L
s
0 0 0 r
2 Mabswid
.95852 .10914 Mdot
.95839 .10959 Mdot
.9535 .12555 Mdot
.96386 .16363 Mdot
.96416 .1647 Mdot
.93827 .10396 Mdot
.93784 .10334 Mdot
0 g
.25 Mabswid
.00939 .30858 m
.94063 0 L
s
.02923 .302 m
.02864 .30851 L
s
gsave
.03041 .28899 -65.0919 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.2634 .22441 m
.26311 .23093 L
s
gsave
.26397 .21136 -68.887 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51217 .14197 m
.51222 .14851 L
s
gsave
.51208 .12891 -69.3101 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77696 .05423 m
.77738 .06075 L
s
gsave
.77613 .04119 -69.7766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07496 .28685 m
.07464 .29076 L
s
.12123 .27152 m
.12095 .27543 L
s
.16805 .256 m
.16781 .25991 L
s
.21544 .2403 m
.21523 .24421 L
s
.31194 .20832 m
.31181 .21224 L
s
.36108 .19204 m
.36099 .19596 L
s
.41083 .17556 m
.41077 .17948 L
s
.46119 .15887 m
.46117 .16279 L
s
.5638 .12487 m
.56387 .12879 L
s
.61608 .10754 m
.6162 .11146 L
s
.66903 .09 m
.66919 .09392 L
s
.72265 .07223 m
.72285 .07614 L
s
.83198 .036 m
.83228 .03991 L
s
.88771 .01753 m
.88806 .02144 L
s
.25 Mabswid
.98876 .07115 m
1 .17466 L
s
.98902 .07356 m
.9828 .07556 L
s
gsave
1.00146 .06957 -61 -11.2246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99156 .09688 m
.98533 .09886 L
s
gsave
1.00401 .09292 -61 -11.2094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99411 .12044 m
.98788 .1224 L
s
gsave
1.00657 .11651 -61 -11.1941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9967 .14423 m
.99046 .14618 L
s
gsave
1.00917 .14033 -61 -11.1787 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99931 .16826 m
.99307 .17019 L
s
gsave
1.01179 .16439 -61 -11.1631 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98953 .07821 m
.9858 .0794 L
s
.99003 .08286 m
.9863 .08406 L
s
.99054 .08753 m
.98681 .08872 L
s
.99105 .0922 m
.98731 .09339 L
s
.99207 .10158 m
.98833 .10276 L
s
.99258 .10628 m
.98884 .10746 L
s
.99309 .11099 m
.98935 .11217 L
s
.9936 .11571 m
.98986 .11689 L
s
.99463 .12518 m
.99089 .12636 L
s
.99514 .12993 m
.9914 .1311 L
s
.99566 .13469 m
.99192 .13586 L
s
.99618 .13945 m
.99244 .14063 L
s
.99722 .14902 m
.99347 .15019 L
s
.99774 .15381 m
.99399 .15498 L
s
.99826 .15862 m
.99452 .15978 L
s
.99878 .16344 m
.99504 .1646 L
s
.99983 .1731 m
.99609 .17425 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{299.688, 138.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000RPP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md;7@00?md;7@00?md;7@00?md;7@00?md
;7@00?md;7@00?md;7@00?md2g@24@=d00<AM7@00Q42M0@A4G@00?md2W@0115dM144M0044GAd4@9d
00<AM7@04G@00?md17@44@9d00@AM7@A17@0115dM143M0034GAd011d003lM08A2g@0115dM144M004
4GAd4@=d00<AM7@047@00?Ud1Q4:M0044GAd4@Ad00@AM7@A17@00a5dM00?M000mW@34@Ad0Q4:M003
4GAd00<A0W@24@04M14A4@9d114>M000lg@34@Md00<AM1402W@34@9d00<AM7@00a42M08A0W@00a5d
M00=M000l7@34@]d00<AM1401G@44@9d00@AM7@A17@0115dM143M0034GAd00ed003;M08A0g@00a5d
4@024AQd0a4?M08A2g@0115dM144M0044GAd4@=d00<AM7@03G@00<Yd00@AM7@A1g@00a5dM00BM0<A
0W@00a5dM00<M0044G@A4@Yd00@AM7@A17@0115dM143M0034GAd00ed003:M0044GAd4@Md00<AM7@0
3g@34AId0a47M0<A0W@00a5dM002M0044GAd4@9d0Q4?M000bW@0115dM145M08A3g@34AYd0Q46M003
4GAd00<A1W@24@Ad00<AM7@03G@00<Yd00@AM7@A1g@00a5dM009M0<A7W@24@Ed00@AM7@A7W@00<Yd
00@AM7@A17@0115dM148M0<A8G@34@Ad00@AM7@A7W@00<]d0Q46M08A1W@34@9d00<AM7@087@34@=d
00<AM7@00a43M0034GAd008A0g@34@id003HM0<A:7@34@=d00@AM7@A0W@00a5dM002M0044GAd4@=d
00<AM7@03G@00=Ed0a4/M0<A0g@34@9d00<AM7@00W@0115dM143M0034GAd00ed003BM0<A<7@34@Ad
00@AM7@A17@0115dM143M0034GAd00ed003?M0<A<g@00a5d4@04M0044GAd4@Ad00@AM7@A0g@00a5d
M00=M000c7@34@9d00<AM7@0<W@34@=d00<AM7@00a42M08A00=d4A401a4;M000bG@34C]d0a43M0<A
0W@00a5dM0044@03M14A008A00=d4A400W@44@Ad0036M0<A?g@24@Ed00@AM7@A0g@24@03M14A00=d
00@AM7@A0W@00a5dM004M000`g@34D9d0a44M0DA0W@24@03M14A00=d00@AM7@A0g@00a5dM003M000
`7@34DEd0a44M0044GAd4@=d0Q400g@A4@03M08A00=d4G@00W@00a5dM003M000_7@44@9d00<AM7@0
AG@00a5dM002M0044GAd4@=d0Q401W@A4G@AM08A00=d4G@00g@00a5dM002M000^G@34Ded0Q45M08A
17@0115d4A43M08A0W@00a5d4@02M0034GAd009d002fM0<AD7@24@ad0a43M0034G@A008A0W@44@=d
002cM0<ADg@34@]d00@AM7@A17@0115dM143M0034GAd009d002`M0<A00=d4G@0Dg@34@Ed1142M004
4GAd4@Ad00@AM7@A0g@00a5dM002M000[G@34EYd0Q4;M0044GAd4@Ad00@AM7@A0g@00a5dM002M000
ZW@34Did0Q4<M0034G@A00]d00@AM7@A17@0115dM143M0034GAd009d002WM0<ADG@00a@A4@0<M08A
2g@0115dM144M0044GAd4@9d0Q44M000Q7@24@=d00<AM1400a4EM0<ADW@01A@HM7@A00=d0Q47M08A
1G@24@Ed0Q46M08A17@00a5dM002M000Pg@0115dM145M0034GAd019d0a400g@AM00CM08A>g@00a@C
M006M0034a@A00Md0Q44M0044GAd4AMd0023M0044GAd4@Id00<AM7@03W@34AUd114gM00351Qd00Ed
00@D61@H2W@00a5dM002M0044GAd4AMd0023M0044GAd4@Id00<AM7@02g@34AMd0Q42M0034G@A00<A
<g@00a<D4`06M00451<D4`]d0Q44M0044GAd4AMd0023M0044GAd4@Md00<AM7@01g@34AUd1Q401W@A
4A5d4C1d00<H51P01G@011PD61@4M08A1g@34@Ad00@AM7@A5g@008=d00@AM7@A17@0115dM146M0<A
5g@84@05M14A4G@01A4]M0034a@C00Ad00@D4a@C1W@00a@C4@08M0<A0g@0115dM14GM000Q7@24@Id
0Q44M0<A0W@00a5dM00DM0HA00=d4A4011400g@A4@024@03M15d02Ud00<H51P017@011@H51P5M003
61@H00]d0a44M08A67@008md0a4LM18A00=d4G@09g@00a<D4`03M0044a@C50Ed00<D4a@03g@24@Ed
0Q43M0034GAd008A0g@34@Ud002<M0<A7W@?4@06M14A4G@A9G@011@H51P2M00551PD61@00g@011@H
51PAM0034G@A00Ad00@AM7@A17@0115dM143M0034GAd00Qd0029M0<A8G@D4@03M15d025d00@D4a@C
0W@011@C51<3M0034a@C01Id0Q44M0044GAd4@Ad00@AM7@A0g@00a5dM008M000QW@44B=d41401W@A
4A5d4B1d00TD61@HM1PD61@00g@00a@H500HM0<A17@0115dM144M0044GAd4@=d00<AM7@027@008=d
0a43M0034GAd025d51400g@A4@0MM00951<D4a@C51<D009d00<C51<07G@00a5dM002M0044GAd4@Ad
00@AM7@A0g@00a5dM008M000P7@34BYd5A400g@AM00IM00961@H51PD61@H009d00<D61@07g@24@Ad
00@AM7@A17@0115dM142M08A2W@007ed0a4]M1DA00=d4A405g@03A<DM1@C51<D4g@C51<08W@24@Ed
0a43M0034G@A008A0W@44@Qd001jM0<A<G@00a5d4@0@4@04M15d4AEd00`H57@D61@H57@D61@UM0<A
17@0115dM144M0044GAd4@9d00<AM7@027@007Md0a42M0034GAd02md00<AM1402Q400g@A4@054@03
M15d019d00/C57@D4a@C51<D4`0KM0044a@C50<A1W@34@Ad00@AM7@A17@0115dM143M0034GAd00Md
001dM0<A=g@D4@04M15d4@md00XD61@H51PD61@H57@03A@H51PD61@H51PD61@00g@24@Md0Q44M004
4GAd4@Ad00@AM7@A0g@00a5dM007M000LG@34CYd00<AM1405A4=M00951<D4a@C51<D00ad010C51<D
4a@C51<D4a@C51<D4g@00a5d4@04M0044GAd4@Ad00@AM7@A17@00a5dM006M000KW@34Ced3a400g@A
4@044@03M15d00Yd00PD61@H51PD60Ad00/D61@H51PD61@H5002M00761@H51PD600KM08A17@0115d
M144M0064GAd4G@A0W@00a5dM006M000Jg@44Cmd6149M00>51<D4a@C51<D4a@C51<5M0084a@C51<D
4a@YM08A1W@24@=d0Q49M000J7@34D=d5a403W@A51PD61@H51PD61@H27@01a@H51PD61@0BG@006Ed
0a57M0034G@A00`A00TC4A4A4a@C51<00g@01a<D4a@C51<00g@01a<D4a@C51<0D7@0049d0Q43M003
4GAd00<A5G@34DYd2Q400a@A4@094@0?M15d61@H51PD61@H51PD05Md0011M0044GAd4@Id00<AM7@0
4G@34Did1a400a@A4@0;4@0851<D4a@C51=NM000@G@0115dM146M0034GAd00id0a42M0034GAd04ad
00<AM1402a400g@A4@024@0851PD61Ad51QPM000@G@0115dM146M0034GAd00]d0a5DM1<A00HD4g@A
51=RM000@G@0115dM146M0034GAd00Qd0a5DM00451PDM0DA00<H51401Q4011@A4AP24@0351Qd06=d
0011M0044GAd4@Ed0Q47M0<AE7@00a<D4`03M0034a4A00XA00<D4a4011400a<A4@1TM000@W@24@Md
00<AM7@00W@44EAd00<H57@00W@00a@H5002M0DA00<D61402A4017@A4A5TM000CG@34EEd00<D4a@0
0W@00a<D4`05M0@A00@C51<D1A4021@A4A5d4G@AI7@004Yd0a5EM00361@H009d00<D61@01W@00aPD
60044@0357@A00HA00Ed4A4AM0024FAd0017M0<AEG@00a@C5002M0034a@C00Id00TD4a@C51<D4A@0
1a401G@A4A5d00@AIG@004Ad0a5EM00361@H009d00<D61@01G@02a@H51PD61@H51PD00TA00Ad4A4A
0W@00a5dM01UM000@7@44@9d00<AM7@0D7@00a@C5002M0034a@C00Ed00dC51<D4a@C51<D4a@C009d
0Q4017@A4G@54F]d000mM0<AEW@00aPD6002M00351PD00Ed00dD61@H51PD61@H51PD00Id11400g@A
M01^M000>W@34EId00<D4a@00W@00a<D4`05M00=4a@C51<D4a@C51<D4`0;M0<AL7@003Md0a5GM007
51QdM1@H5005M00<51PD61@H51PD61@HPW@003Ad0a42M0034GAd059d00LC51=d4a@C00Ed00`C51<D
4a@C51<D4aB5M000<G@34EMd00LD61Ad51PD00Ed00`D61@H51PD61@H51R8M000;W@34EMd00LC51=d
4a@C00Ad00`D4a@C51<D4a@C51><M000:g@34EMd00LD61Ad51PD00Ad00`H51PD61@H51PD61B?M000
:7@34@9d00<AM7@0DW@01a<D4g@C51<017@031@C51<D4a@C51<D4i9d000UM0<AEg@01a@H57@D61@0
17@02aPD61@H51PD61@H09Id0007M08A6G@34EMd00LC51=d4a@C00Ad00/D4a@C51<D4a@C502IM000
1W@0115dM14EM0<AF7@01QPDM1@H50Ad00XH51PD61@H51PDWG@000Id00@AM7@A4W@34@03M15d05Ed
00HD4a@C51<3M00;4a@C51<D4a@C51<0X7@000Id00@AM7@A3g@34EQd00HH51PD61@3M00;51PD61@H
51PD61@0Xg@000Id00@AM7@A37@34EQd00HD4a@C51<3M00:4a@C51<D4a@C5:Md0006M0044GAd4@Ud
0a5HM00661@H51PD0g@02Q@H51PD61@H51RZM0001g@24@Md0a400g@AM01EM00651<D4a@C0g@02Q<D
4a@C51<D4aB]M0003G@34EQd00HH51PD61@3M00951PD61@H51PD0;5d000:M0<AF7@01Q@C51<D4`=d
00TC51<D4a@C51<0]7@000Md0a5HM00661@H51PD0W@02QPD61@H51PD61BgM00017@44EQd00DC51<D
4`02M00951<D4a@C51<D0;]d0002M08A0g@00a5dM01CM00551PD61@00W@02APD61@H51PD602nM000
FW@041<D4a@C57@D4a@C51<D4aC1M000Eg@03a@H51PD67@H51PD61@H5035M000E7@03a<D4a@C57@D
4a@C51<D4`38M000DG@03Q@H51PD61@H51PD61@Hc7@004id00hC51<D4a@C51<D4a@C5<md001;M00>
51PD61@H51PD61@H51SBM000BG@031@C51<D4a@C51<D4mId0016M00<61@H51PD61@H51PDfG@004=d
00`D4a@C51<D4a@C51?LM000@7@02aPD61@H51PD61@H0>1d000mM00;51<D4a@C51<D4a@0hg@003Yd
00/H51PD61@H51PD603VM000=g@02Q@C51<D4a@C51?ZM000=7@02QPD61@H51PD61C]M000<W@021<D
4a@C51<DlG@002md00PD61@H51PD6?Ad000/M0084a@C51<D4aCgM000:G@01a@H51PD61@0ng@002Id
00LC51<D4a@C0?id000SM00751PD61@H503oM09d000PM0064a@C51<Dog@6M0007G@01Q@H51PD6?md
2G@001]d00DD4a@C503oM0ad000HM00461@H5?md47@001Ed00@D4a@Cog@CM0004W@011PD61CoM1Id
000@M0034aAd0?md6G@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md
;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00?md;7@00001
\
\>"],
  ImageRangeCache->{{{0, 298.688}, {137.875, 0}} -> {0.0432963, 0.227965, \
0.00355429, 0.00355429}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[PressureLensSurfacesTraced, PlotType -> TopView, 
\tShowLabels -> False, PlotRange -> {{0.24, 0.3}, {-0.025, 0.025}},
\tRayPointSize -> 6];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-4 16.6667 0.416667 16.6667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .08333 m
.16667 .08333 L
.16667 .19444 L
.16667 .19444 L
.16667 .08333 L
s
.16667 .19444 m
.16667 .19444 L
.16667 .30556 L
.16667 .30556 L
.16667 .19444 L
s
.16667 .30556 m
.16667 .30556 L
.16667 .41667 L
.16667 .41667 L
.16667 .30556 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .52778 L
.16667 .52778 L
.16667 .41667 L
s
.16667 .52778 m
.16667 .52778 L
.16667 .63889 L
.16667 .63889 L
.16667 .52778 L
s
.16667 .63889 m
.16667 .63889 L
.16667 .75 L
.16667 .75 L
.16667 .63889 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.14914 .41667 L
.14914 .41667 L
.16667 .41667 L
s
.14914 .41667 m
.14914 .41667 L
.14914 .41667 L
.14914 .41667 L
.14914 .41667 L
s
.14914 .41667 m
.14914 .41667 L
.16667 .41667 L
.16667 .41667 L
.14914 .41667 L
s
.17917 .08333 m
.17917 .08333 L
.17917 .19444 L
.17917 .19444 L
.17917 .08333 L
s
.17917 .19444 m
.17917 .19444 L
.17917 .30556 L
.17917 .30556 L
.17917 .19444 L
s
.17917 .30556 m
.17917 .30556 L
.17917 .41667 L
.17917 .41667 L
.17917 .30556 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .52778 L
.17917 .52778 L
.17917 .41667 L
s
.17917 .52778 m
.17917 .52778 L
.17917 .63889 L
.17917 .63889 L
.17917 .52778 L
s
.17917 .63889 m
.17917 .63889 L
.17917 .75 L
.17917 .75 L
.17917 .63889 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .41667 L
.1615 .41667 L
.1615 .41667 L
.17917 .41667 L
s
.1615 .41667 m
.1615 .41667 L
.1615 .41667 L
.1615 .41667 L
.1615 .41667 L
s
.1615 .41667 m
.1615 .41667 L
.17917 .41667 L
.17917 .41667 L
.1615 .41667 L
s
.3 .08333 m
.3 .08333 L
.3 .19444 L
.3 .19444 L
.3 .08333 L
s
.3 .19444 m
.3 .19444 L
.3 .30556 L
.3 .30556 L
.3 .19444 L
s
.3 .30556 m
.3 .30556 L
.3 .41667 L
.3 .41667 L
.3 .30556 L
s
.3 .41667 m
.3 .41667 L
.3 .52778 L
.3 .52778 L
.3 .41667 L
s
.3 .52778 m
.3 .52778 L
.3 .63889 L
.3 .63889 L
.3 .52778 L
s
.3 .63889 m
.3 .63889 L
.3 .75 L
.3 .75 L
.3 .63889 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.425 .08333 m
.425 .08333 L
.425 .19444 L
.425 .19444 L
.425 .08333 L
s
.425 .19444 m
.425 .19444 L
.425 .30556 L
.425 .30556 L
.425 .19444 L
s
.425 .30556 m
.425 .30556 L
.425 .41667 L
.425 .41667 L
.425 .30556 L
s
.425 .41667 m
.425 .41667 L
.425 .52778 L
.425 .52778 L
.425 .41667 L
s
.425 .52778 m
.425 .52778 L
.425 .63889 L
.425 .63889 L
.425 .52778 L
s
.425 .63889 m
.425 .63889 L
.425 .75 L
.425 .75 L
.425 .63889 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.16667 .41667 m
.16667 .52778 L
.16302 .52399 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16302 .52399 L
.15372 .51289 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.15372 .51289 L
.14439 .49523 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14439 .49523 L
.13957 .47222 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.13957 .47222 L
.14143 .44542 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14143 .44542 L
.14914 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14914 .41667 L
.15912 .38791 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.15912 .38791 L
.16608 .36111 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16608 .36111 L
.16667 .3381 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .3381 L
.16667 .32044 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .32044 L
.16667 .30934 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30934 L
.16667 .30556 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30556 L
.16667 .30934 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30934 L
.16667 .32044 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .32044 L
.16667 .3381 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .3381 L
.16667 .36111 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .36111 L
.16667 .38791 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .38791 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .44542 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .44542 L
.16667 .47222 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .47222 L
.16667 .49523 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .49523 L
.16667 .51289 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .51289 L
.16667 .52399 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .52399 L
.16667 .52778 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .52778 m
.16667 .63889 L
.16667 .63132 L
.16302 .52399 L
.16667 .52778 L
s
.16302 .52399 m
.16667 .63132 L
.15762 .60912 L
.15372 .51289 L
.16302 .52399 L
s
.15372 .51289 m
.15762 .60912 L
.13908 .5738 L
.14439 .49523 L
.15372 .51289 L
s
.14439 .49523 m
.13908 .5738 L
.12793 .52778 L
.13957 .47222 L
.14439 .49523 L
s
.13957 .47222 m
.12793 .52778 L
.13232 .47418 L
.14143 .44542 L
.13957 .47222 L
s
.14143 .44542 m
.13232 .47418 L
.14914 .41667 L
.14914 .41667 L
.14143 .44542 L
s
.14914 .41667 m
.14914 .41667 L
.16499 .35915 L
.15912 .38791 L
.14914 .41667 L
s
.15912 .38791 m
.16499 .35915 L
.16667 .30556 L
.16608 .36111 L
.15912 .38791 L
s
.16608 .36111 m
.16667 .30556 L
.16667 .25953 L
.16667 .3381 L
.16608 .36111 L
s
.16667 .3381 m
.16667 .25953 L
.16667 .22422 L
.16667 .32044 L
.16667 .3381 L
s
.16667 .32044 m
.16667 .22422 L
.16667 .20202 L
.16667 .30934 L
.16667 .32044 L
s
.16667 .30934 m
.16667 .20202 L
.16667 .19444 L
.16667 .30556 L
.16667 .30934 L
s
.16667 .30556 m
.16667 .19444 L
.16667 .20202 L
.16667 .30934 L
.16667 .30556 L
s
.16667 .30934 m
.16667 .20202 L
.16667 .22422 L
.16667 .32044 L
.16667 .30934 L
s
.16667 .32044 m
.16667 .22422 L
.16667 .25953 L
.16667 .3381 L
.16667 .32044 L
s
.16667 .3381 m
.16667 .25953 L
.16667 .30556 L
.16667 .36111 L
.16667 .3381 L
s
.16667 .36111 m
.16667 .30556 L
.16667 .35915 L
.16667 .38791 L
.16667 .36111 L
s
.16667 .38791 m
.16667 .35915 L
.16667 .41667 L
.16667 .41667 L
.16667 .38791 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .47418 L
.16667 .44542 L
.16667 .41667 L
s
.16667 .44542 m
.16667 .47418 L
.16667 .52778 L
.16667 .47222 L
.16667 .44542 L
s
.16667 .47222 m
.16667 .52778 L
.16667 .5738 L
.16667 .49523 L
.16667 .47222 L
s
.16667 .49523 m
.16667 .5738 L
.16667 .60912 L
.16667 .51289 L
.16667 .49523 L
s
.16667 .51289 m
.16667 .60912 L
.16667 .63132 L
.16667 .52399 L
.16667 .51289 L
s
.16667 .52399 m
.16667 .63132 L
.16667 .63889 L
.16667 .52778 L
.16667 .52399 L
s
.16667 .63889 m
.16667 .75 L
.16667 .73864 L
.16667 .63132 L
.16667 .63889 L
s
.16667 .63132 m
.16667 .73864 L
.16667 .70534 L
.15762 .60912 L
.16667 .63132 L
s
.15762 .60912 m
.16667 .70534 L
.16667 .65237 L
.13908 .5738 L
.15762 .60912 L
s
.13908 .5738 m
.16667 .65237 L
.16479 .58333 L
.12793 .52778 L
.13908 .5738 L
s
.12793 .52778 m
.16479 .58333 L
.16603 .50294 L
.13232 .47418 L
.12793 .52778 L
s
.13232 .47418 m
.16603 .50294 L
.16667 .41667 L
.14914 .41667 L
.13232 .47418 L
s
.14914 .41667 m
.16667 .41667 L
.16667 .33039 L
.16499 .35915 L
.14914 .41667 L
s
.16499 .35915 m
.16667 .33039 L
.16667 .25 L
.16667 .30556 L
.16499 .35915 L
s
.16667 .30556 m
.16667 .25 L
.16667 .18096 L
.16667 .25953 L
.16667 .30556 L
s
.16667 .25953 m
.16667 .18096 L
.16667 .12799 L
.16667 .22422 L
.16667 .25953 L
s
.16667 .22422 m
.16667 .12799 L
.16667 .09469 L
.16667 .20202 L
.16667 .22422 L
s
.16667 .20202 m
.16667 .09469 L
.16667 .08333 L
.16667 .19444 L
.16667 .20202 L
s
.16667 .19444 m
.16667 .08333 L
.16667 .09469 L
.16667 .20202 L
.16667 .19444 L
s
.16667 .20202 m
.16667 .09469 L
.16667 .12799 L
.16667 .22422 L
.16667 .20202 L
s
.16667 .22422 m
.16667 .12799 L
.16667 .18096 L
.16667 .25953 L
.16667 .22422 L
s
.16667 .25953 m
.16667 .18096 L
.16667 .25 L
.16667 .30556 L
.16667 .25953 L
s
.16667 .30556 m
.16667 .25 L
.16667 .33039 L
.16667 .35915 L
.16667 .30556 L
s
.16667 .35915 m
.16667 .33039 L
.16667 .41667 L
.16667 .41667 L
.16667 .35915 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .50294 L
.16667 .47418 L
.16667 .41667 L
s
.16667 .47418 m
.16667 .50294 L
.16667 .58333 L
.16667 .52778 L
.16667 .47418 L
s
.16667 .52778 m
.16667 .58333 L
.16667 .65237 L
.16667 .5738 L
.16667 .52778 L
s
.16667 .5738 m
.16667 .65237 L
.16667 .70534 L
.16667 .60912 L
.16667 .5738 L
s
.16667 .60912 m
.16667 .70534 L
.16667 .73864 L
.16667 .63132 L
.16667 .60912 L
s
.16667 .63132 m
.16667 .73864 L
.16667 .75 L
.16667 .63889 L
.16667 .63132 L
s
.17917 .41667 m
.17917 .52778 L
.17533 .52399 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17533 .52399 L
.16607 .51289 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.16607 .51289 L
.15677 .49523 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.15677 .49523 L
.15197 .47222 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.15197 .47222 L
.15382 .44542 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.15382 .44542 L
.1615 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.1615 .41667 L
.17144 .38791 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17144 .38791 L
.17837 .36111 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17837 .36111 L
.17917 .3381 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .3381 L
.17917 .32044 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .32044 L
.17917 .30934 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .30934 L
.17917 .30556 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .30556 L
.17917 .30934 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .30934 L
.17917 .32044 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .32044 L
.17917 .3381 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .3381 L
.17917 .36111 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .36111 L
.17917 .38791 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .38791 L
.17917 .41667 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .44542 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .44542 L
.17917 .47222 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .47222 L
.17917 .49523 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .49523 L
.17917 .51289 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .51289 L
.17917 .52399 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .41667 m
.17917 .52399 L
.17917 .52778 L
.17917 .41667 L
.17917 .41667 L
s
.17917 .52778 m
.17917 .63889 L
.17917 .63132 L
.17533 .52399 L
.17917 .52778 L
s
.17533 .52399 m
.17917 .63132 L
.16995 .60912 L
.16607 .51289 L
.17533 .52399 L
s
.16607 .51289 m
.16995 .60912 L
.15148 .5738 L
.15677 .49523 L
.16607 .51289 L
s
.15677 .49523 m
.15148 .5738 L
.14038 .52778 L
.15197 .47222 L
.15677 .49523 L
s
.15197 .47222 m
.14038 .52778 L
.14475 .47418 L
.15382 .44542 L
.15197 .47222 L
s
.15382 .44542 m
.14475 .47418 L
.1615 .41667 L
.1615 .41667 L
.15382 .44542 L
s
.1615 .41667 m
.1615 .41667 L
.17729 .35915 L
.17144 .38791 L
.1615 .41667 L
s
.17144 .38791 m
.17729 .35915 L
.17917 .30556 L
.17837 .36111 L
.17144 .38791 L
s
.17837 .36111 m
.17917 .30556 L
.17917 .25953 L
.17917 .3381 L
.17837 .36111 L
s
.17917 .3381 m
.17917 .25953 L
.17917 .22422 L
.17917 .32044 L
.17917 .3381 L
s
.17917 .32044 m
.17917 .22422 L
.17917 .20202 L
.17917 .30934 L
.17917 .32044 L
s
.17917 .30934 m
.17917 .20202 L
.17917 .19444 L
.17917 .30556 L
.17917 .30934 L
s
.17917 .30556 m
.17917 .19444 L
.17917 .20202 L
.17917 .30934 L
.17917 .30556 L
s
.17917 .30934 m
.17917 .20202 L
.17917 .22422 L
.17917 .32044 L
.17917 .30934 L
s
.17917 .32044 m
.17917 .22422 L
.17917 .25953 L
.17917 .3381 L
.17917 .32044 L
s
.17917 .3381 m
.17917 .25953 L
.17917 .30556 L
.17917 .36111 L
.17917 .3381 L
s
.17917 .36111 m
.17917 .30556 L
.17917 .35915 L
.17917 .38791 L
.17917 .36111 L
s
.17917 .38791 m
.17917 .35915 L
.17917 .41667 L
.17917 .41667 L
.17917 .38791 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .47418 L
.17917 .44542 L
.17917 .41667 L
s
.17917 .44542 m
.17917 .47418 L
.17917 .52778 L
.17917 .47222 L
.17917 .44542 L
s
.17917 .47222 m
.17917 .52778 L
.17917 .5738 L
.17917 .49523 L
.17917 .47222 L
s
.17917 .49523 m
.17917 .5738 L
.17917 .60912 L
.17917 .51289 L
.17917 .49523 L
s
.17917 .51289 m
.17917 .60912 L
.17917 .63132 L
.17917 .52399 L
.17917 .51289 L
s
.17917 .52399 m
.17917 .63132 L
.17917 .63889 L
.17917 .52778 L
.17917 .52399 L
s
.17917 .63889 m
.17917 .75 L
.17917 .73864 L
.17917 .63132 L
.17917 .63889 L
s
.17917 .63132 m
.17917 .73864 L
.17917 .70534 L
.16995 .60912 L
.17917 .63132 L
s
.16995 .60912 m
.17917 .70534 L
.17917 .65237 L
.15148 .5738 L
.16995 .60912 L
s
.15148 .5738 m
.17917 .65237 L
.17709 .58333 L
.14038 .52778 L
.15148 .5738 L
s
.14038 .52778 m
.17709 .58333 L
.17832 .50294 L
.14475 .47418 L
.14038 .52778 L
s
.14475 .47418 m
.17832 .50294 L
.17917 .41667 L
.1615 .41667 L
.14475 .47418 L
s
.1615 .41667 m
.17917 .41667 L
.17917 .33039 L
.17729 .35915 L
.1615 .41667 L
s
.17729 .35915 m
.17917 .33039 L
.17917 .25 L
.17917 .30556 L
.17729 .35915 L
s
.17917 .30556 m
.17917 .25 L
.17917 .18096 L
.17917 .25953 L
.17917 .30556 L
s
.17917 .25953 m
.17917 .18096 L
.17917 .12799 L
.17917 .22422 L
.17917 .25953 L
s
.17917 .22422 m
.17917 .12799 L
.17917 .09469 L
.17917 .20202 L
.17917 .22422 L
s
.17917 .20202 m
.17917 .09469 L
.17917 .08333 L
.17917 .19444 L
.17917 .20202 L
s
.17917 .19444 m
.17917 .08333 L
.17917 .09469 L
.17917 .20202 L
.17917 .19444 L
s
.17917 .20202 m
.17917 .09469 L
.17917 .12799 L
.17917 .22422 L
.17917 .20202 L
s
.17917 .22422 m
.17917 .12799 L
.17917 .18096 L
.17917 .25953 L
.17917 .22422 L
s
.17917 .25953 m
.17917 .18096 L
.17917 .25 L
.17917 .30556 L
.17917 .25953 L
s
.17917 .30556 m
.17917 .25 L
.17917 .33039 L
.17917 .35915 L
.17917 .30556 L
s
.17917 .35915 m
.17917 .33039 L
.17917 .41667 L
.17917 .41667 L
.17917 .35915 L
s
.17917 .41667 m
.17917 .41667 L
.17917 .50294 L
.17917 .47418 L
.17917 .41667 L
s
.17917 .47418 m
.17917 .50294 L
.17917 .58333 L
.17917 .52778 L
.17917 .47418 L
s
.17917 .52778 m
.17917 .58333 L
.17917 .65237 L
.17917 .5738 L
.17917 .52778 L
s
.17917 .5738 m
.17917 .65237 L
.17917 .70534 L
.17917 .60912 L
.17917 .5738 L
s
.17917 .60912 m
.17917 .70534 L
.17917 .73864 L
.17917 .63132 L
.17917 .60912 L
s
.17917 .63132 m
.17917 .73864 L
.17917 .75 L
.17917 .63889 L
.17917 .63132 L
s
.3 .41667 m
.3 .52778 L
.3 .52399 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .52399 L
.3 .51289 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .51289 L
.3 .49523 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .49523 L
.3 .47222 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .47222 L
.3 .44542 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .44542 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .38791 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .38791 L
.3 .36111 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .36111 L
.3 .3381 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .3381 L
.3 .32044 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .32044 L
.3 .30934 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .30934 L
.3 .30556 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .30556 L
.3 .30934 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .30934 L
.3 .32044 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .32044 L
.3 .3381 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .3381 L
.3 .36111 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .36111 L
.3 .38791 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .38791 L
.3 .41667 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .41667 L
.3 .44542 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .44542 L
.3 .47222 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .47222 L
.3 .49523 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .49523 L
.3 .51289 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .51289 L
.3 .52399 L
.3 .41667 L
.3 .41667 L
s
.3 .41667 m
.3 .52399 L
.3 .52778 L
.3 .41667 L
.3 .41667 L
s
.3 .52778 m
.3 .63889 L
.3 .63132 L
.3 .52399 L
.3 .52778 L
s
.3 .52399 m
.3 .63132 L
.3 .60912 L
.3 .51289 L
.3 .52399 L
s
.3 .51289 m
.3 .60912 L
.3 .5738 L
.3 .49523 L
.3 .51289 L
s
.3 .49523 m
.3 .5738 L
.3 .52778 L
.3 .47222 L
.3 .49523 L
s
.3 .47222 m
.3 .52778 L
.3 .47418 L
.3 .44542 L
.3 .47222 L
s
.3 .44542 m
.3 .47418 L
.3 .41667 L
.3 .41667 L
.3 .44542 L
s
.3 .41667 m
.3 .41667 L
.3 .35915 L
.3 .38791 L
.3 .41667 L
s
.3 .38791 m
.3 .35915 L
.3 .30556 L
.3 .36111 L
.3 .38791 L
s
.3 .36111 m
.3 .30556 L
.3 .25953 L
.3 .3381 L
.3 .36111 L
s
.3 .3381 m
.3 .25953 L
.3 .22422 L
.3 .32044 L
.3 .3381 L
s
.3 .32044 m
.3 .22422 L
.3 .20202 L
.3 .30934 L
.3 .32044 L
s
.3 .30934 m
.3 .20202 L
.3 .19444 L
.3 .30556 L
.3 .30934 L
s
.3 .30556 m
.3 .19444 L
.3 .20202 L
.3 .30934 L
.3 .30556 L
s
.3 .30934 m
.3 .20202 L
.3 .22422 L
.3 .32044 L
.3 .30934 L
s
.3 .32044 m
.3 .22422 L
.3 .25953 L
.3 .3381 L
.3 .32044 L
s
.3 .3381 m
.3 .25953 L
.3 .30556 L
.3 .36111 L
.3 .3381 L
s
.3 .36111 m
.3 .30556 L
.3 .35915 L
.3 .38791 L
.3 .36111 L
s
.3 .38791 m
.3 .35915 L
.3 .41667 L
.3 .41667 L
.3 .38791 L
s
.3 .41667 m
.3 .41667 L
.3 .47418 L
.3 .44542 L
.3 .41667 L
s
.3 .44542 m
.3 .47418 L
.3 .52778 L
.3 .47222 L
.3 .44542 L
s
.3 .47222 m
.3 .52778 L
.3 .5738 L
.3 .49523 L
.3 .47222 L
s
.3 .49523 m
.3 .5738 L
.3 .60912 L
.3 .51289 L
.3 .49523 L
s
.3 .51289 m
.3 .60912 L
.3 .63132 L
.3 .52399 L
.3 .51289 L
s
.3 .52399 m
.3 .63132 L
.3 .63889 L
.3 .52778 L
.3 .52399 L
s
.3 .63889 m
.3 .75 L
.3 .73864 L
.3 .63132 L
.3 .63889 L
s
.3 .63132 m
.3 .73864 L
.3 .70534 L
.3 .60912 L
.3 .63132 L
s
.3 .60912 m
.3 .70534 L
.3 .65237 L
.3 .5738 L
.3 .60912 L
s
.3 .5738 m
.3 .65237 L
.3 .58333 L
.3 .52778 L
.3 .5738 L
s
.3 .52778 m
.3 .58333 L
.3 .50294 L
.3 .47418 L
.3 .52778 L
s
.3 .47418 m
.3 .50294 L
.3 .41667 L
.3 .41667 L
.3 .47418 L
s
.3 .41667 m
.3 .41667 L
.3 .33039 L
.3 .35915 L
.3 .41667 L
s
.3 .35915 m
.3 .33039 L
.3 .25 L
.3 .30556 L
.3 .35915 L
s
.3 .30556 m
.3 .25 L
.3 .18096 L
.3 .25953 L
.3 .30556 L
s
.3 .25953 m
.3 .18096 L
.3 .12799 L
.3 .22422 L
.3 .25953 L
s
.3 .22422 m
.3 .12799 L
.3 .09469 L
.3 .20202 L
.3 .22422 L
s
.3 .20202 m
.3 .09469 L
.3 .08333 L
.3 .19444 L
.3 .20202 L
s
.3 .19444 m
.3 .08333 L
.3 .09469 L
.3 .20202 L
.3 .19444 L
s
.3 .20202 m
.3 .09469 L
.3 .12799 L
.3 .22422 L
.3 .20202 L
s
.3 .22422 m
.3 .12799 L
.3 .18096 L
.3 .25953 L
.3 .22422 L
s
.3 .25953 m
.3 .18096 L
.3 .25 L
.3 .30556 L
.3 .25953 L
s
.3 .30556 m
.3 .25 L
.3 .33039 L
.3 .35915 L
.3 .30556 L
s
.3 .35915 m
.3 .33039 L
.3 .41667 L
.3 .41667 L
.3 .35915 L
s
.3 .41667 m
.3 .41667 L
.3 .50294 L
.3 .47418 L
.3 .41667 L
s
.3 .47418 m
.3 .50294 L
.3 .58333 L
.3 .52778 L
.3 .47418 L
s
.3 .52778 m
.3 .58333 L
.3 .65237 L
.3 .5738 L
.3 .52778 L
s
.3 .5738 m
.3 .65237 L
.3 .70534 L
.3 .60912 L
.3 .5738 L
s
.3 .60912 m
.3 .70534 L
.3 .73864 L
.3 .63132 L
.3 .60912 L
s
.3 .63132 m
.3 .73864 L
.3 .75 L
.3 .63889 L
.3 .63132 L
s
.425 .41667 m
.425 .52778 L
.425 .52399 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .52399 L
.425 .51289 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .51289 L
.425 .49523 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .49523 L
.425 .47222 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .47222 L
.425 .44542 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .44542 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .38791 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .38791 L
.425 .36111 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .36111 L
.425 .3381 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .3381 L
.425 .32044 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .32044 L
.425 .30934 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .30934 L
.425 .30556 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .30556 L
.425 .30934 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .30934 L
.425 .32044 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .32044 L
.425 .3381 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .3381 L
.425 .36111 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .36111 L
.425 .38791 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .38791 L
.425 .41667 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .41667 L
.425 .44542 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .44542 L
.425 .47222 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .47222 L
.425 .49523 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .49523 L
.425 .51289 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .51289 L
.425 .52399 L
.425 .41667 L
.425 .41667 L
s
.425 .41667 m
.425 .52399 L
.425 .52778 L
.425 .41667 L
.425 .41667 L
s
.425 .52778 m
.425 .63889 L
.425 .63132 L
.425 .52399 L
.425 .52778 L
s
.425 .52399 m
.425 .63132 L
.425 .60912 L
.425 .51289 L
.425 .52399 L
s
.425 .51289 m
.425 .60912 L
.425 .5738 L
.425 .49523 L
.425 .51289 L
s
.425 .49523 m
.425 .5738 L
.425 .52778 L
.425 .47222 L
.425 .49523 L
s
.425 .47222 m
.425 .52778 L
.425 .47418 L
.425 .44542 L
.425 .47222 L
s
.425 .44542 m
.425 .47418 L
.425 .41667 L
.425 .41667 L
.425 .44542 L
s
.425 .41667 m
.425 .41667 L
.425 .35915 L
.425 .38791 L
.425 .41667 L
s
.425 .38791 m
.425 .35915 L
.425 .30556 L
.425 .36111 L
.425 .38791 L
s
.425 .36111 m
.425 .30556 L
.425 .25953 L
.425 .3381 L
.425 .36111 L
s
.425 .3381 m
.425 .25953 L
.425 .22422 L
.425 .32044 L
.425 .3381 L
s
.425 .32044 m
.425 .22422 L
.425 .20202 L
.425 .30934 L
.425 .32044 L
s
.425 .30934 m
.425 .20202 L
.425 .19444 L
.425 .30556 L
.425 .30934 L
s
.425 .30556 m
.425 .19444 L
.425 .20202 L
.425 .30934 L
.425 .30556 L
s
.425 .30934 m
.425 .20202 L
.425 .22422 L
.425 .32044 L
.425 .30934 L
s
.425 .32044 m
.425 .22422 L
.425 .25953 L
.425 .3381 L
.425 .32044 L
s
.425 .3381 m
.425 .25953 L
.425 .30556 L
.425 .36111 L
.425 .3381 L
s
.425 .36111 m
.425 .30556 L
.425 .35915 L
.425 .38791 L
.425 .36111 L
s
.425 .38791 m
.425 .35915 L
.425 .41667 L
.425 .41667 L
.425 .38791 L
s
.425 .41667 m
.425 .41667 L
.425 .47418 L
.425 .44542 L
.425 .41667 L
s
.425 .44542 m
.425 .47418 L
.425 .52778 L
.425 .47222 L
.425 .44542 L
s
.425 .47222 m
.425 .52778 L
.425 .5738 L
.425 .49523 L
.425 .47222 L
s
.425 .49523 m
.425 .5738 L
.425 .60912 L
.425 .51289 L
.425 .49523 L
s
.425 .51289 m
.425 .60912 L
.425 .63132 L
.425 .52399 L
.425 .51289 L
s
.425 .52399 m
.425 .63132 L
.425 .63889 L
.425 .52778 L
.425 .52399 L
s
.425 .63889 m
.425 .75 L
.425 .73864 L
.425 .63132 L
.425 .63889 L
s
.425 .63132 m
.425 .73864 L
.425 .70534 L
.425 .60912 L
.425 .63132 L
s
.425 .60912 m
.425 .70534 L
.425 .65237 L
.425 .5738 L
.425 .60912 L
s
.425 .5738 m
.425 .65237 L
.425 .58333 L
.425 .52778 L
.425 .5738 L
s
.425 .52778 m
.425 .58333 L
.425 .50294 L
.425 .47418 L
.425 .52778 L
s
.425 .47418 m
.425 .50294 L
.425 .41667 L
.425 .41667 L
.425 .47418 L
s
.425 .41667 m
.425 .41667 L
.425 .33039 L
.425 .35915 L
.425 .41667 L
s
.425 .35915 m
.425 .33039 L
.425 .25 L
.425 .30556 L
.425 .35915 L
s
.425 .30556 m
.425 .25 L
.425 .18096 L
.425 .25953 L
.425 .30556 L
s
.425 .25953 m
.425 .18096 L
.425 .12799 L
.425 .22422 L
.425 .25953 L
s
.425 .22422 m
.425 .12799 L
.425 .09469 L
.425 .20202 L
.425 .22422 L
s
.425 .20202 m
.425 .09469 L
.425 .08333 L
.425 .19444 L
.425 .20202 L
s
.425 .19444 m
.425 .08333 L
.425 .09469 L
.425 .20202 L
.425 .19444 L
s
.425 .20202 m
.425 .09469 L
.425 .12799 L
.425 .22422 L
.425 .20202 L
s
.425 .22422 m
.425 .12799 L
.425 .18096 L
.425 .25953 L
.425 .22422 L
s
.425 .25953 m
.425 .18096 L
.425 .25 L
.425 .30556 L
.425 .25953 L
s
.425 .30556 m
.425 .25 L
.425 .33039 L
.425 .35915 L
.425 .30556 L
s
.425 .35915 m
.425 .33039 L
.425 .41667 L
.425 .41667 L
.425 .35915 L
s
.425 .41667 m
.425 .41667 L
.425 .50294 L
.425 .47418 L
.425 .41667 L
s
.425 .47418 m
.425 .50294 L
.425 .58333 L
.425 .52778 L
.425 .47418 L
s
.425 .52778 m
.425 .58333 L
.425 .65237 L
.425 .5738 L
.425 .52778 L
s
.425 .5738 m
.425 .65237 L
.425 .70534 L
.425 .60912 L
.425 .5738 L
s
.425 .60912 m
.425 .70534 L
.425 .73864 L
.425 .63132 L
.425 .60912 L
s
.425 .63132 m
.425 .73864 L
.425 .75 L
.425 .63889 L
.425 .63132 L
s
.001 .092 .901 r
0 .55236 m
.1322 .55409 L
s
0 0 0 r
6 Mabswid
.1322 .55409 Mdot
.001 .092 .901 r
.5 Mabswid
0 .47382 m
.1322 .47295 L
s
0 0 0 r
6 Mabswid
.1322 .47295 Mdot
.001 .092 .901 r
.5 Mabswid
0 .47382 m
.1322 .47295 L
s
0 0 0 r
6 Mabswid
.1322 .47295 Mdot
.001 .092 .901 r
.5 Mabswid
0 .60474 m
.15252 .60874 L
s
0 0 0 r
6 Mabswid
.15252 .60874 Mdot
.001 .092 .901 r
.5 Mabswid
0 .44764 m
.15252 .44564 L
s
0 0 0 r
6 Mabswid
.15252 .44564 Mdot
.001 .092 .901 r
.5 Mabswid
0 .44764 m
.15252 .44564 L
s
0 0 0 r
6 Mabswid
.15252 .44564 Mdot
.001 .092 .901 r
.5 Mabswid
0 .5 m
.12356 .5 L
s
0 0 0 r
6 Mabswid
.12356 .5 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .55409 m
.14426 .55284 L
s
0 0 0 r
6 Mabswid
.14426 .55284 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .47295 m
.14426 .47358 L
s
0 0 0 r
6 Mabswid
.14426 .47358 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .47295 m
.14426 .47358 L
s
0 0 0 r
6 Mabswid
.14426 .47358 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .60874 m
.16429 .60724 L
s
0 0 0 r
6 Mabswid
.16429 .60724 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .44564 m
.16429 .44639 L
s
0 0 0 r
6 Mabswid
.16429 .44639 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .44564 m
.16429 .44639 L
s
0 0 0 r
6 Mabswid
.16429 .44639 Mdot
.001 .092 .901 r
.5 Mabswid
.12356 .5 m
.13606 .5 L
s
0 0 0 r
6 Mabswid
.13606 .5 Mdot
.001 .092 .901 r
.5 Mabswid
.14426 .55284 m
.3 .53651 L
s
0 0 0 r
6 Mabswid
.3 .53651 Mdot
.001 .092 .901 r
.5 Mabswid
.14426 .47358 m
.3 .48174 L
s
0 0 0 r
6 Mabswid
.3 .48174 Mdot
.001 .092 .901 r
.5 Mabswid
.14426 .47358 m
.3 .48174 L
s
0 0 0 r
6 Mabswid
.3 .48174 Mdot
.001 .092 .901 r
.5 Mabswid
.16429 .60724 m
.3 .58976 L
s
0 0 0 r
6 Mabswid
.3 .58976 Mdot
.001 .092 .901 r
.5 Mabswid
.16429 .44639 m
.3 .45513 L
s
0 0 0 r
6 Mabswid
.3 .45513 Mdot
.001 .092 .901 r
.5 Mabswid
.16429 .44639 m
.3 .45513 L
s
0 0 0 r
6 Mabswid
.3 .45513 Mdot
.001 .092 .901 r
.5 Mabswid
.13606 .5 m
.3 .49996 L
s
0 0 0 r
6 Mabswid
.3 .49996 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .53651 m
.425 .52267 L
s
0 0 0 r
6 Mabswid
.425 .52267 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .48174 m
.425 .48867 L
s
0 0 0 r
6 Mabswid
.425 .48867 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .48174 m
.425 .48867 L
s
0 0 0 r
6 Mabswid
.425 .48867 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .58976 m
.425 .57274 L
s
0 0 0 r
6 Mabswid
.425 .57274 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .45513 m
.425 .46364 L
s
0 0 0 r
6 Mabswid
.425 .46364 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .45513 m
.425 .46364 L
s
0 0 0 r
6 Mabswid
.425 .46364 Mdot
.001 .092 .901 r
.5 Mabswid
.3 .49996 m
.425 .49992 L
s
0 0 0 r
6 Mabswid
.425 .49992 Mdot
.001 .092 .901 r
.5 Mabswid
.425 .52267 m
0 0 rlineto s
.425 .52267 m
1 .42474 L
s
.425 .48867 m
0 0 rlineto s
.425 .48867 m
1 .53763 L
s
.425 .48867 m
0 0 rlineto s
.425 .48867 m
1 .53763 L
s
.425 .57274 m
0 0 rlineto s
.425 .57274 m
1 .45186 L
s
.425 .46364 m
0 0 rlineto s
.425 .46364 m
1 .52407 L
s
.425 .46364 m
0 0 rlineto s
.425 .46364 m
1 .52407 L
s
.425 .49992 m
0 0 rlineto s
.425 .49992 m
1 .49969 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 239.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000k`P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@002md0Q42M003
4GAd021d00<AM7@087@24JEd000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M0054GAdM140
8W@00a5dM00PM0034GAd0:Ad000_M0054GAdM1408W@00a5dM00PM0034GAd0:Ad000_M08A0W@00a5d
M00PM0034GAd021d0Q6UM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d
00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@24@9d00<AM7@0
87@00a5dM00PM08AYG@002md00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM003
4GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM003
4GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM003
4GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@002md00DAM7Ad4@0RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM003
4GAd021d00<AM7@0Y7@002md00<AM7@00Q4RM0034GAd021d00<AM7@0Y7@002id0Q42M08A8W@00a5d
M00PM0034GAd0:Ad000^M08A00Ad4A4A8W@00a5dM00PM0034GAd0:Ad000^M08A00Ad4A4A8W@00a5d
M00PM0034GAd0:Ad000]M0<A00Ad4A4A8W@00a5dM00PM0034GAd0:Ad000]M0<A00Ad4A4A8W@00a5d
M00PM0034GAd0:Ad000]M0034G@A008A00=d4G@08G@00a5dM00PM0034GAd0:Ad000]M0034G@A008A
00=d4G@08G@00a5dM00PM0034GAd0:Ad000/M08A00Id4A4AM14RM0034GAd021d00<AM7@0Y7@002ad
0Q401W@A4A5d4B9d00<AM7@087@00a5dM02TM000;7@00a5d4@024@03M14A029d00<AM7@087@00a5d
M02TM000:g@24@05M14A4G@00Q4RM0034GAd021d00<AM7@0Y7@002]d00<AM7@00Q42M08A8W@00a5d
M00PM0034GAd0:Ad000[M0034GAd008A0W@24B9d00<AM7@087@00a5dM02TM000:W@0115dM7@24@=d
00<AM7@087@00a5dM00PM0034GAd0:Ad000ZM0XA8W@00a5dM00PM08AYG@002Yd00@AM7Ad0Q42M08A
8W@00a5dM00PM0034GAd0:Ad000ZM0034GAd00<A00Ad4A4A8W@00a5dM00PM0034GAd0:1d00<C51<0
0G@002Ud00<AM7@01A400g@A4@0RM0034GAd021d00<AM7@0VW@01QPD61@H50Ad000YM0034GAd00PA
8W@00a5dM00PM0034GAd09Ad00HC51<D4a@:M000:G@0115d4G@34@04M14A4B9d00<AM7@087@00a5d
M02>M00661@H51PD47@002Ud2a4RM0034GAd021d00<AM7@0R7@01Q<D4a@C51Id000XM0`A8W@00a5d
M00PM0034GAd089d00HH51PD61@LM0005W@04a<D4a@C51<D4a@C51<D4a@C51<00Q400a@A4@064B9d
00<AM7@087@00a5dM01lM0064a@C51<D8W@0000F61@H51PD61@H51PD61@H51PD61@H519d00<AM140
11402Q@H51PD61@H51PKM0DA87@00a5dM01fM00661@H51PD:7@002Qd00<AM1402A45M00D51<D4a@C
51<D4a@C51<D4a@C51<7M0DA87@00a5dM01`M0064a@C51<D:W@00a<D4`01M0009g@24@05M14A4G@0
11400g@AM00HM00651PD61@H0a402APD61@H51PD600IM0DAJW@01A@H51PD02]d00DD61@H5004M000
9g@24@03M14A00HA00=d4G@07g@54@Id018D4a@C51<D4a@C51<D4a@C51<7M0DAI7@01Q@C51<D4bad
00@D4a@C2G@002Md2a400g@AM00OM0DA67@01Q@H51PD608A00DD61@H501MM00651PD61@H;G@01APD
61@H00ed000TM0TA00Md4A5d4G@A029d00<AM7@07g@54@0:M1<D4a@C51<D4did00HD4a@C51<^M005
51<D4a@04W@002Ad2Q401W@AM15d4B9d00<AM7@07g@54@Yd00TD61@H51PD61@0?g@01Q@H51PD631d
00@D61@H5g@0000S4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<00a402a<A4A@C51<D
4a@C00<A87@54B1d0Q4EM00:4a@C51<D4a@C52md00HD4a@C51<aM0054a@C51<06g@002Ad314047@D
61@H51PD61@H51PD61@DM0DA87@00a5dM00NM00961@H51PD61@H021d00HD61@H51PbM00551PD61@0
87@002Ad3A400g@A4@0<M00?4a@C51<D4a@C51<D4a@C00Ad1Q4OM0DA9W@02A@C51<D4a@C500AM006
51<D4a@C<g@01A<D4a@C02Ed000VM0/A00=d4A406g@01A@H51PD008A00TH51PD61@H51P06G@54Bmd
00TH51PD61@H51P00W@01Q@H51PD63Ed00@H51PD:W@002Id0Q4017@A4G@54@03M14A021d1A46M00B
51<D4a@C51<D4a@C51<D4a@C1W@64CAd00dD4a@C51<D4a@C51<D02md00DD4a@C500^M0008W@?4@03
M14A021d1A4HM00>51PD61@H514D61@H51P]M00561@H51P03G@02APD61@H51PD600QM00561@H51P0
<g@0029d2A400g@A4@034@03M14A021d1A4OM0DA0W@031@C51<D4a@C51<D4a]d00HC51<D4a@KM00:
51<D4a@C51<D4a=d00@C51<D>7@0025d2Q42M0LA7g@64Aid1Q4>M00<51PD61@H51PD61@H2G@01QPD
61@H52]d00TD61@H51PD61@01G@01A@H51PD03ad00009A<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@A51<00Q40;A@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C
50024@394a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C514D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C005d000RM0TA00=d4A400Q42M08A87@54Amd1A4GM006
61@H51PD2G@031@H51PD61@H51PD62Id00DD61@H5009M00951PD61@H51PD03Ad000TM0HA00=d4A40
0a42M08A8W@00a5dM00PM08A4g@01Q<D4a@C51]d00/D4a@C51<D4a@C500GM00451<D4aMd00TC51<D
4a@C51<0:g@002Ed00<AM7@00Q400g@A4@034@9d0Q4RM0034GAd021d00<AM7@037@01QPD61@H52ad
00`H51PD61@H51PD61@6M00561@H51P097@02A@H51PD61@H500RM0009G@00a5dM0024@9d1142M08A
8W@00a5dM00OM0DA1G@01Q<D4a@C53id00`C51<D4a@C51<D4a@/M00:4a@C51<D4a@C51Qd000TM08A
0W@24@9d1A400g@A4@0RM0034GAd01md11401QPD61@H545d00@D61@H2g@031PD61@H51PD61@H52Yd
00TH51PD61@H51P03g@002Ad0Q42M08A0W@44@04M14A4B9d00<AM7@077@021@C4A4D4a@A@G@01A<D
4a@C01]d00/C51<D4a@C51<D4`0XM00951<D4a@C51<D00Id000TM0044GAdM08A0W@0115d4A42M08A
8W@00a5dM00CM00961@H51PD61@H00=d1A4lM00551PD61@0:g@031@H51PD61@H51PD62Ed00DH51PD
6001M00097@0115dM7@24@9d00<AM1400Q400g@A4@0PM0DA2g@021<D4a@C51<D37@54CMd00DC51<D
4`0lM00<51<D4a@C51<D4a@C7g@002Ad0Q42M08A0W@0115d4A42M08A87@54@9d00TD61@H51PD61@0
5G@24CEd00@H51PDCG@031@H51PD61@H51PD61=d000UM0034GAd008A0W@0115d4A42M08A7W@02A<A
4A4C51<D4`0NM0034GAd02md00DD4a@C501MM00<51<D4a@C51<D4a@C1g@002Ed0Q401g@A4A5d4G@0
0Q42M08A5G@02A@H51PD61@H5002M0DA87@00a5dM00ZM00561@H51P0KW@01Q@H51PD605d000UM003
4G@A00<A00=d4G@00Q42M08A37@02A<D4a@C51<D4`0;M0DA87@00a5dM00VM0044a@C57Yd000TM0TA
00=d4A400W@24@=d00TD61@H51PD61@05W@00a5dM00PM0034GAd025d00DD61@H501nM00097@94@0:
M1<D4a@C51<D4amd00<AM7@087@00a5dM00LM0054a@C51<0Pg@0000S61@H51PD61@H51PD61@H51PD
61@H51PD61@H51PD61@H51P00a4021PA4A@H51PD0Q42M08A8W@00a5dM00PM0034GAd01Md00DD61@H
5028M00097@<4@9d0Q4RM0034GAd021d00<AM7@04g@011@C51>=M00097@94@03M14A009d0Q4RM003
4GAd021d00<AM7@03W@01APD61@H095d000VM0<A00Ad4A5d11400g@A4@0RM0034GAd01md1A48M005
51<D4a@0UW@002Md0Q42M0HA00=d4A408W@00a5dM00OM0DA17@011@H51RKM000:7@00a5dM0064@03
M14A029d00<AM7@07W@54@054a@C51<0Wg@002Qd00DAM7@AM0044@03M14A029d00<AM7@07G@01aPD
4A@H5140Xg@002Qd00DAM7@AM0074B9d00<AM7@05W@01a@C51<D4a@00W@54J=d000YM0034GAd00PA
87@54@md00LH51PD61@H00Yd0Q6UM000:G@00a5dM0024@04M14AM08A87@54@Qd00LD4a@C51<D015d
00<AM7@0Y7@002Ud0Q4017@A4G@24@03M14A01md1Q4027@H51PD61@H67@00a5dM02TM000:W@01A5d
M15d008A00=d4A407g@01a@A4A<D4a@07g@00a5dM02TM000:W@24@03M14A008A00=d4A405g@02A@H
51PD61@HM0054B1d00<AM7@0Y7@002Yd0Q400g@A4@054@md00PD4a@C51<D4`]d00<AM7@087@00a5d
M02TM000:W@:4@Md00PD61@H51PD61=d00<AM7@087@00a5dM02TM00001HC51<D4a@C51<D4a@C51<D
4a@C51<D57@94@0851<D4a@C51<KM0034GAd021d00<AM7@0Y7@001Id01<H51PD61@H51PD61@H51PD
61@H008A00TD614A51PD61408W@00a5dM00PM0034GAd0:Ad000ZM0XA8W@00a5dM00PM0034GAd0:Ad
000ZM0XA8W@00a5dM00PM0034GAd0:Ad000/M0PA8W@00a5dM00PM0034GAd0:Ad000/M0DA00=d4A40
8W@00a5dM00PM0034GAd0:Ad000]M0LA8W@00a5dM00PM0034GAd0:Ad000]M0074G@AM15d4@0RM003
4GAd021d00<AM7@0Y7@002ed00LAM15d4G@A029d00<AM7@087@00a5dM02TM000;G@54@03M15d025d
00<AM7@087@24JEd000^M08A00Ad4A4A8W@00a5dM00PM0034GAd0:Ad000^M08A00Ad4A4A8W@00a5d
M00PM0034GAd0:Ad000^M08A00Ad4A4A8W@00a5dM00PM0034GAd0:Ad000^M08A00Ad4G@A8W@00a5d
M00PM0034GAd0:Ad000^M08A00Ad4G@A8W@00a5dM00PM0034GAd0:Ad000^M08A00Ad4G@A8W@00a5d
M00PM0034GAd0:Ad000^M08A0W@24B9d00<AM7@087@00a5dM02TM000;W@24@9d0Q4RM0034GAd021d
00<AM7@0Y7@002id0Q42M08A8W@00a5dM00PM0034GAd0:Ad000^M08A0W@24B9d00<AM7@087@00a5d
M02TM000;W@24@9d0Q4RM0034GAd021d00<AM7@0Y7@002id0Q42M08A8W@00a5dM00PM0034GAd0:Ad
000^M08A0W@24B9d00<AM7@087@00a5dM02TM000;g@00a5dM0024B9d00<AM7@087@00a5dM02TM000
;g@00a5dM0024B9d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000
;g@01A5dM7@A029d00<AM7@087@00a5dM02TM000;g@24@9d00<AM7@087@00a5dM00PM08AYG@002md
00DAM7Ad4@0RM0034GAd021d00<AM7@0Y7@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00001\
\>"],
  ImageRangeCache->{{{0, 287}, {238.938, 0}} -> {0.239971, -0.025, \
0.000209258, 0.000209258}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[PressureLensTraced, PlotType -> TopView, 
\tShowLabels -> False, PlotRange -> {{0.24, 0.3}, {-0.025, 0.025}},
\tRayPointSize -> 6];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-4 16.6667 0.416667 16.6667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
.5 g
.16667 .08333 m
.19167 .08333 L
.19167 .19444 L
.16667 .19444 L
.16667 .08333 L
F
.16667 .19444 m
.19167 .19444 L
.19167 .30556 L
.16667 .30556 L
.16667 .19444 L
F
.16667 .30556 m
.19167 .30556 L
.19167 .41667 L
.16667 .41667 L
.16667 .30556 L
F
.16667 .41667 m
.19167 .41667 L
.19167 .52778 L
.16667 .52778 L
.16667 .41667 L
F
.16667 .52778 m
.19167 .52778 L
.19167 .63889 L
.16667 .63889 L
.16667 .52778 L
F
.16667 .63889 m
.19167 .63889 L
.19167 .75 L
.16667 .75 L
.16667 .63889 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .08333 m
.16667 .19444 L
.16667 .30556 L
.16667 .41667 L
.16667 .52778 L
.16667 .63889 L
.16667 .75 L
.19167 .75 L
.19167 .63889 L
.19167 .52778 L
.19167 .41667 L
.19167 .30556 L
.19167 .19444 L
.19167 .08333 L
.16667 .08333 L
s
.5 g
.16667 .41667 m
.19167 .41667 L
.19167 .41667 L
.16667 .41667 L
.16667 .41667 L
F
.16667 .41667 m
.19167 .41667 L
.19167 .41667 L
.16667 .41667 L
.16667 .41667 L
F
.16667 .41667 m
.19167 .41667 L
.19167 .41667 L
.16667 .41667 L
.16667 .41667 L
F
.16667 .41667 m
.19167 .41667 L
.174 .41667 L
.14914 .41667 L
.16667 .41667 L
F
.14914 .41667 m
.174 .41667 L
.174 .41667 L
.14914 .41667 L
.14914 .41667 L
F
.14914 .41667 m
.174 .41667 L
.19167 .41667 L
.16667 .41667 L
.14914 .41667 L
F
0 g
.16667 .41667 m
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
.14914 .41667 L
.14914 .41667 L
.16667 .41667 L
.19167 .41667 L
.174 .41667 L
.174 .41667 L
.19167 .41667 L
.19167 .41667 L
.19167 .41667 L
.19167 .41667 L
.16667 .41667 L
s
.19167 .08333 m
.3125 .08333 L
.3125 .19444 L
.19167 .19444 L
.19167 .08333 L
s
.19167 .19444 m
.3125 .19444 L
.3125 .30556 L
.19167 .30556 L
.19167 .19444 L
s
.19167 .30556 m
.3125 .30556 L
.3125 .41667 L
.19167 .41667 L
.19167 .30556 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .52778 L
.19167 .52778 L
.19167 .41667 L
s
.19167 .52778 m
.3125 .52778 L
.3125 .63889 L
.19167 .63889 L
.19167 .52778 L
s
.19167 .63889 m
.3125 .63889 L
.3125 .75 L
.19167 .75 L
.19167 .63889 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .41667 L
.174 .41667 L
.19167 .41667 L
s
.174 .41667 m
.3125 .41667 L
.3125 .41667 L
.174 .41667 L
.174 .41667 L
s
.174 .41667 m
.3125 .41667 L
.3125 .41667 L
.19167 .41667 L
.174 .41667 L
s
.5 g
.3125 .08333 m
.4375 .08333 L
.4375 .19444 L
.3125 .19444 L
.3125 .08333 L
F
.3125 .19444 m
.4375 .19444 L
.4375 .30556 L
.3125 .30556 L
.3125 .19444 L
F
.3125 .30556 m
.4375 .30556 L
.4375 .41667 L
.3125 .41667 L
.3125 .30556 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .52778 L
.3125 .52778 L
.3125 .41667 L
F
.3125 .52778 m
.4375 .52778 L
.4375 .63889 L
.3125 .63889 L
.3125 .52778 L
F
.3125 .63889 m
.4375 .63889 L
.4375 .75 L
.3125 .75 L
.3125 .63889 L
F
0 g
.3125 .08333 m
.3125 .19444 L
.3125 .30556 L
.3125 .41667 L
.3125 .52778 L
.3125 .63889 L
.3125 .75 L
.4375 .75 L
.4375 .63889 L
.4375 .52778 L
.4375 .41667 L
.4375 .30556 L
.4375 .19444 L
.4375 .08333 L
.3125 .08333 L
s
.5 g
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
.3125 .41667 m
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
.3125 .41667 L
F
0 g
.3125 .41667 m
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.4375 .41667 L
.3125 .41667 L
s
.16667 .41667 m
.16667 .52778 L
.16302 .52399 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16302 .52399 L
.15372 .51289 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.15372 .51289 L
.14439 .49523 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14439 .49523 L
.13957 .47222 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.13957 .47222 L
.14143 .44542 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14143 .44542 L
.14914 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.14914 .41667 L
.15912 .38791 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.15912 .38791 L
.16608 .36111 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16608 .36111 L
.16667 .3381 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .3381 L
.16667 .32044 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .32044 L
.16667 .30934 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30934 L
.16667 .30556 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30556 L
.16667 .30934 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .30934 L
.16667 .32044 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .32044 L
.16667 .3381 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .3381 L
.16667 .36111 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .36111 L
.16667 .38791 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .38791 L
.16667 .41667 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .44542 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .44542 L
.16667 .47222 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .47222 L
.16667 .49523 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .49523 L
.16667 .51289 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .51289 L
.16667 .52399 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .41667 m
.16667 .52399 L
.16667 .52778 L
.16667 .41667 L
.16667 .41667 L
s
.16667 .52778 m
.16667 .63889 L
.16667 .63132 L
.16302 .52399 L
.16667 .52778 L
s
.16302 .52399 m
.16667 .63132 L
.15762 .60912 L
.15372 .51289 L
.16302 .52399 L
s
.15372 .51289 m
.15762 .60912 L
.13908 .5738 L
.14439 .49523 L
.15372 .51289 L
s
.14439 .49523 m
.13908 .5738 L
.12793 .52778 L
.13957 .47222 L
.14439 .49523 L
s
.13957 .47222 m
.12793 .52778 L
.13232 .47418 L
.14143 .44542 L
.13957 .47222 L
s
.14143 .44542 m
.13232 .47418 L
.14914 .41667 L
.14914 .41667 L
.14143 .44542 L
s
.14914 .41667 m
.14914 .41667 L
.16499 .35915 L
.15912 .38791 L
.14914 .41667 L
s
.15912 .38791 m
.16499 .35915 L
.16667 .30556 L
.16608 .36111 L
.15912 .38791 L
s
.16608 .36111 m
.16667 .30556 L
.16667 .25953 L
.16667 .3381 L
.16608 .36111 L
s
.16667 .3381 m
.16667 .25953 L
.16667 .22422 L
.16667 .32044 L
.16667 .3381 L
s
.16667 .32044 m
.16667 .22422 L
.16667 .20202 L
.16667 .30934 L
.16667 .32044 L
s
.16667 .30934 m
.16667 .20202 L
.16667 .19444 L
.16667 .30556 L
.16667 .30934 L
s
.16667 .30556 m
.16667 .19444 L
.16667 .20202 L
.16667 .30934 L
.16667 .30556 L
s
.16667 .30934 m
.16667 .20202 L
.16667 .22422 L
.16667 .32044 L
.16667 .30934 L
s
.16667 .32044 m
.16667 .22422 L
.16667 .25953 L
.16667 .3381 L
.16667 .32044 L
s
.16667 .3381 m
.16667 .25953 L
.16667 .30556 L
.16667 .36111 L
.16667 .3381 L
s
.16667 .36111 m
.16667 .30556 L
.16667 .35915 L
.16667 .38791 L
.16667 .36111 L
s
.16667 .38791 m
.16667 .35915 L
.16667 .41667 L
.16667 .41667 L
.16667 .38791 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .47418 L
.16667 .44542 L
.16667 .41667 L
s
.16667 .44542 m
.16667 .47418 L
.16667 .52778 L
.16667 .47222 L
.16667 .44542 L
s
.16667 .47222 m
.16667 .52778 L
.16667 .5738 L
.16667 .49523 L
.16667 .47222 L
s
.16667 .49523 m
.16667 .5738 L
.16667 .60912 L
.16667 .51289 L
.16667 .49523 L
s
.16667 .51289 m
.16667 .60912 L
.16667 .63132 L
.16667 .52399 L
.16667 .51289 L
s
.16667 .52399 m
.16667 .63132 L
.16667 .63889 L
.16667 .52778 L
.16667 .52399 L
s
.16667 .63889 m
.16667 .75 L
.16667 .73864 L
.16667 .63132 L
.16667 .63889 L
s
.16667 .63132 m
.16667 .73864 L
.16667 .70534 L
.15762 .60912 L
.16667 .63132 L
s
.15762 .60912 m
.16667 .70534 L
.16667 .65237 L
.13908 .5738 L
.15762 .60912 L
s
.13908 .5738 m
.16667 .65237 L
.16479 .58333 L
.12793 .52778 L
.13908 .5738 L
s
.12793 .52778 m
.16479 .58333 L
.16603 .50294 L
.13232 .47418 L
.12793 .52778 L
s
.13232 .47418 m
.16603 .50294 L
.16667 .41667 L
.14914 .41667 L
.13232 .47418 L
s
.14914 .41667 m
.16667 .41667 L
.16667 .33039 L
.16499 .35915 L
.14914 .41667 L
s
.16499 .35915 m
.16667 .33039 L
.16667 .25 L
.16667 .30556 L
.16499 .35915 L
s
.16667 .30556 m
.16667 .25 L
.16667 .18096 L
.16667 .25953 L
.16667 .30556 L
s
.16667 .25953 m
.16667 .18096 L
.16667 .12799 L
.16667 .22422 L
.16667 .25953 L
s
.16667 .22422 m
.16667 .12799 L
.16667 .09469 L
.16667 .20202 L
.16667 .22422 L
s
.16667 .20202 m
.16667 .09469 L
.16667 .08333 L
.16667 .19444 L
.16667 .20202 L
s
.16667 .19444 m
.16667 .08333 L
.16667 .09469 L
.16667 .20202 L
.16667 .19444 L
s
.16667 .20202 m
.16667 .09469 L
.16667 .12799 L
.16667 .22422 L
.16667 .20202 L
s
.16667 .22422 m
.16667 .12799 L
.16667 .18096 L
.16667 .25953 L
.16667 .22422 L
s
.16667 .25953 m
.16667 .18096 L
.16667 .25 L
.16667 .30556 L
.16667 .25953 L
s
.16667 .30556 m
.16667 .25 L
.16667 .33039 L
.16667 .35915 L
.16667 .30556 L
s
.16667 .35915 m
.16667 .33039 L
.16667 .41667 L
.16667 .41667 L
.16667 .35915 L
s
.16667 .41667 m
.16667 .41667 L
.16667 .50294 L
.16667 .47418 L
.16667 .41667 L
s
.16667 .47418 m
.16667 .50294 L
.16667 .58333 L
.16667 .52778 L
.16667 .47418 L
s
.16667 .52778 m
.16667 .58333 L
.16667 .65237 L
.16667 .5738 L
.16667 .52778 L
s
.16667 .5738 m
.16667 .65237 L
.16667 .70534 L
.16667 .60912 L
.16667 .5738 L
s
.16667 .60912 m
.16667 .70534 L
.16667 .73864 L
.16667 .63132 L
.16667 .60912 L
s
.16667 .63132 m
.16667 .73864 L
.16667 .75 L
.16667 .63889 L
.16667 .63132 L
s
.19167 .41667 m
.19167 .52778 L
.18783 .52399 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.18783 .52399 L
.17857 .51289 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.17857 .51289 L
.16927 .49523 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16927 .49523 L
.16447 .47222 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16447 .47222 L
.16632 .44542 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16632 .44542 L
.174 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.174 .41667 L
.18394 .38791 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.18394 .38791 L
.19087 .36111 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19087 .36111 L
.19167 .3381 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .3381 L
.19167 .32044 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .32044 L
.19167 .30934 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30934 L
.19167 .30556 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30556 L
.19167 .30934 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30934 L
.19167 .32044 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .32044 L
.19167 .3381 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .3381 L
.19167 .36111 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .36111 L
.19167 .38791 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .38791 L
.19167 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .44542 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .44542 L
.19167 .47222 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .47222 L
.19167 .49523 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .49523 L
.19167 .51289 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .51289 L
.19167 .52399 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .52399 L
.19167 .52778 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .52778 m
.19167 .63889 L
.19167 .63132 L
.18783 .52399 L
.19167 .52778 L
s
.18783 .52399 m
.19167 .63132 L
.18245 .60912 L
.17857 .51289 L
.18783 .52399 L
s
.17857 .51289 m
.18245 .60912 L
.16398 .5738 L
.16927 .49523 L
.17857 .51289 L
s
.16927 .49523 m
.16398 .5738 L
.15288 .52778 L
.16447 .47222 L
.16927 .49523 L
s
.16447 .47222 m
.15288 .52778 L
.15725 .47418 L
.16632 .44542 L
.16447 .47222 L
s
.16632 .44542 m
.15725 .47418 L
.174 .41667 L
.174 .41667 L
.16632 .44542 L
s
.174 .41667 m
.174 .41667 L
.18979 .35915 L
.18394 .38791 L
.174 .41667 L
s
.18394 .38791 m
.18979 .35915 L
.19167 .30556 L
.19087 .36111 L
.18394 .38791 L
s
.19087 .36111 m
.19167 .30556 L
.19167 .25953 L
.19167 .3381 L
.19087 .36111 L
s
.19167 .3381 m
.19167 .25953 L
.19167 .22422 L
.19167 .32044 L
.19167 .3381 L
s
.19167 .32044 m
.19167 .22422 L
.19167 .20202 L
.19167 .30934 L
.19167 .32044 L
s
.19167 .30934 m
.19167 .20202 L
.19167 .19444 L
.19167 .30556 L
.19167 .30934 L
s
.19167 .30556 m
.19167 .19444 L
.19167 .20202 L
.19167 .30934 L
.19167 .30556 L
s
.19167 .30934 m
.19167 .20202 L
.19167 .22422 L
.19167 .32044 L
.19167 .30934 L
s
.19167 .32044 m
.19167 .22422 L
.19167 .25953 L
.19167 .3381 L
.19167 .32044 L
s
.19167 .3381 m
.19167 .25953 L
.19167 .30556 L
.19167 .36111 L
.19167 .3381 L
s
.19167 .36111 m
.19167 .30556 L
.19167 .35915 L
.19167 .38791 L
.19167 .36111 L
s
.19167 .38791 m
.19167 .35915 L
.19167 .41667 L
.19167 .41667 L
.19167 .38791 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .47418 L
.19167 .44542 L
.19167 .41667 L
s
.19167 .44542 m
.19167 .47418 L
.19167 .52778 L
.19167 .47222 L
.19167 .44542 L
s
.19167 .47222 m
.19167 .52778 L
.19167 .5738 L
.19167 .49523 L
.19167 .47222 L
s
.19167 .49523 m
.19167 .5738 L
.19167 .60912 L
.19167 .51289 L
.19167 .49523 L
s
.19167 .51289 m
.19167 .60912 L
.19167 .63132 L
.19167 .52399 L
.19167 .51289 L
s
.19167 .52399 m
.19167 .63132 L
.19167 .63889 L
.19167 .52778 L
.19167 .52399 L
s
.19167 .63889 m
.19167 .75 L
.19167 .73864 L
.19167 .63132 L
.19167 .63889 L
s
.19167 .63132 m
.19167 .73864 L
.19167 .70534 L
.18245 .60912 L
.19167 .63132 L
s
.18245 .60912 m
.19167 .70534 L
.19167 .65237 L
.16398 .5738 L
.18245 .60912 L
s
.16398 .5738 m
.19167 .65237 L
.18959 .58333 L
.15288 .52778 L
.16398 .5738 L
s
.15288 .52778 m
.18959 .58333 L
.19082 .50294 L
.15725 .47418 L
.15288 .52778 L
s
.15725 .47418 m
.19082 .50294 L
.19167 .41667 L
.174 .41667 L
.15725 .47418 L
s
.174 .41667 m
.19167 .41667 L
.19167 .33039 L
.18979 .35915 L
.174 .41667 L
s
.18979 .35915 m
.19167 .33039 L
.19167 .25 L
.19167 .30556 L
.18979 .35915 L
s
.19167 .30556 m
.19167 .25 L
.19167 .18096 L
.19167 .25953 L
.19167 .30556 L
s
.19167 .25953 m
.19167 .18096 L
.19167 .12799 L
.19167 .22422 L
.19167 .25953 L
s
.19167 .22422 m
.19167 .12799 L
.19167 .09469 L
.19167 .20202 L
.19167 .22422 L
s
.19167 .20202 m
.19167 .09469 L
.19167 .08333 L
.19167 .19444 L
.19167 .20202 L
s
.19167 .19444 m
.19167 .08333 L
.19167 .09469 L
.19167 .20202 L
.19167 .19444 L
s
.19167 .20202 m
.19167 .09469 L
.19167 .12799 L
.19167 .22422 L
.19167 .20202 L
s
.19167 .22422 m
.19167 .12799 L
.19167 .18096 L
.19167 .25953 L
.19167 .22422 L
s
.19167 .25953 m
.19167 .18096 L
.19167 .25 L
.19167 .30556 L
.19167 .25953 L
s
.19167 .30556 m
.19167 .25 L
.19167 .33039 L
.19167 .35915 L
.19167 .30556 L
s
.19167 .35915 m
.19167 .33039 L
.19167 .41667 L
.19167 .41667 L
.19167 .35915 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .50294 L
.19167 .47418 L
.19167 .41667 L
s
.19167 .47418 m
.19167 .50294 L
.19167 .58333 L
.19167 .52778 L
.19167 .47418 L
s
.19167 .52778 m
.19167 .58333 L
.19167 .65237 L
.19167 .5738 L
.19167 .52778 L
s
.19167 .5738 m
.19167 .65237 L
.19167 .70534 L
.19167 .60912 L
.19167 .5738 L
s
.19167 .60912 m
.19167 .70534 L
.19167 .73864 L
.19167 .63132 L
.19167 .60912 L
s
.19167 .63132 m
.19167 .73864 L
.19167 .75 L
.19167 .63889 L
.19167 .63132 L
s
.16667 .75 m
.19167 .75 L
.19167 .73864 L
.16667 .73864 L
.16667 .75 L
s
.16667 .73864 m
.19167 .73864 L
.19167 .70534 L
.16667 .70534 L
.16667 .73864 L
s
.16667 .70534 m
.19167 .70534 L
.19167 .65237 L
.16667 .65237 L
.16667 .70534 L
s
.16667 .65237 m
.19167 .65237 L
.18959 .58333 L
.16479 .58333 L
.16667 .65237 L
s
.16479 .58333 m
.18959 .58333 L
.19082 .50294 L
.16603 .50294 L
.16479 .58333 L
s
.16603 .50294 m
.19082 .50294 L
.19167 .41667 L
.16667 .41667 L
.16603 .50294 L
s
.16667 .41667 m
.19167 .41667 L
.19167 .33039 L
.16667 .33039 L
.16667 .41667 L
s
.16667 .33039 m
.19167 .33039 L
.19167 .25 L
.16667 .25 L
.16667 .33039 L
s
.16667 .25 m
.19167 .25 L
.19167 .18096 L
.16667 .18096 L
.16667 .25 L
s
.16667 .18096 m
.19167 .18096 L
.19167 .12799 L
.16667 .12799 L
.16667 .18096 L
s
.16667 .12799 m
.19167 .12799 L
.19167 .09469 L
.16667 .09469 L
.16667 .12799 L
s
.16667 .09469 m
.19167 .09469 L
.19167 .08333 L
.16667 .08333 L
.16667 .09469 L
s
.16667 .08333 m
.19167 .08333 L
.19167 .09469 L
.16667 .09469 L
.16667 .08333 L
s
.16667 .09469 m
.19167 .09469 L
.19167 .12799 L
.16667 .12799 L
.16667 .09469 L
s
.16667 .12799 m
.19167 .12799 L
.19167 .18096 L
.16667 .18096 L
.16667 .12799 L
s
.16667 .18096 m
.19167 .18096 L
.19167 .25 L
.16667 .25 L
.16667 .18096 L
s
.16667 .25 m
.19167 .25 L
.19167 .33039 L
.16667 .33039 L
.16667 .25 L
s
.16667 .33039 m
.19167 .33039 L
.19167 .41667 L
.16667 .41667 L
.16667 .33039 L
s
.16667 .41667 m
.19167 .41667 L
.19167 .50294 L
.16667 .50294 L
.16667 .41667 L
s
.16667 .50294 m
.19167 .50294 L
.19167 .58333 L
.16667 .58333 L
.16667 .50294 L
s
.16667 .58333 m
.19167 .58333 L
.19167 .65237 L
.16667 .65237 L
.16667 .58333 L
s
.16667 .65237 m
.19167 .65237 L
.19167 .70534 L
.16667 .70534 L
.16667 .65237 L
s
.16667 .70534 m
.19167 .70534 L
.19167 .73864 L
.16667 .73864 L
.16667 .70534 L
s
.16667 .73864 m
.19167 .73864 L
.19167 .75 L
.16667 .75 L
.16667 .73864 L
s
.19167 .41667 m
.19167 .52778 L
.18783 .52399 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.18783 .52399 L
.17857 .51289 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.17857 .51289 L
.16927 .49523 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16927 .49523 L
.16447 .47222 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16447 .47222 L
.16632 .44542 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.16632 .44542 L
.174 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.174 .41667 L
.18394 .38791 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.18394 .38791 L
.19087 .36111 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19087 .36111 L
.19167 .3381 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .3381 L
.19167 .32044 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .32044 L
.19167 .30934 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30934 L
.19167 .30556 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30556 L
.19167 .30934 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .30934 L
.19167 .32044 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .32044 L
.19167 .3381 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .3381 L
.19167 .36111 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .36111 L
.19167 .38791 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .38791 L
.19167 .41667 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .44542 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .44542 L
.19167 .47222 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .47222 L
.19167 .49523 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .49523 L
.19167 .51289 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .51289 L
.19167 .52399 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .41667 m
.19167 .52399 L
.19167 .52778 L
.19167 .41667 L
.19167 .41667 L
s
.19167 .52778 m
.19167 .63889 L
.19167 .63132 L
.18783 .52399 L
.19167 .52778 L
s
.18783 .52399 m
.19167 .63132 L
.18245 .60912 L
.17857 .51289 L
.18783 .52399 L
s
.17857 .51289 m
.18245 .60912 L
.16398 .5738 L
.16927 .49523 L
.17857 .51289 L
s
.16927 .49523 m
.16398 .5738 L
.15288 .52778 L
.16447 .47222 L
.16927 .49523 L
s
.16447 .47222 m
.15288 .52778 L
.15725 .47418 L
.16632 .44542 L
.16447 .47222 L
s
.16632 .44542 m
.15725 .47418 L
.174 .41667 L
.174 .41667 L
.16632 .44542 L
s
.174 .41667 m
.174 .41667 L
.18979 .35915 L
.18394 .38791 L
.174 .41667 L
s
.18394 .38791 m
.18979 .35915 L
.19167 .30556 L
.19087 .36111 L
.18394 .38791 L
s
.19087 .36111 m
.19167 .30556 L
.19167 .25953 L
.19167 .3381 L
.19087 .36111 L
s
.19167 .3381 m
.19167 .25953 L
.19167 .22422 L
.19167 .32044 L
.19167 .3381 L
s
.19167 .32044 m
.19167 .22422 L
.19167 .20202 L
.19167 .30934 L
.19167 .32044 L
s
.19167 .30934 m
.19167 .20202 L
.19167 .19444 L
.19167 .30556 L
.19167 .30934 L
s
.19167 .30556 m
.19167 .19444 L
.19167 .20202 L
.19167 .30934 L
.19167 .30556 L
s
.19167 .30934 m
.19167 .20202 L
.19167 .22422 L
.19167 .32044 L
.19167 .30934 L
s
.19167 .32044 m
.19167 .22422 L
.19167 .25953 L
.19167 .3381 L
.19167 .32044 L
s
.19167 .3381 m
.19167 .25953 L
.19167 .30556 L
.19167 .36111 L
.19167 .3381 L
s
.19167 .36111 m
.19167 .30556 L
.19167 .35915 L
.19167 .38791 L
.19167 .36111 L
s
.19167 .38791 m
.19167 .35915 L
.19167 .41667 L
.19167 .41667 L
.19167 .38791 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .47418 L
.19167 .44542 L
.19167 .41667 L
s
.19167 .44542 m
.19167 .47418 L
.19167 .52778 L
.19167 .47222 L
.19167 .44542 L
s
.19167 .47222 m
.19167 .52778 L
.19167 .5738 L
.19167 .49523 L
.19167 .47222 L
s
.19167 .49523 m
.19167 .5738 L
.19167 .60912 L
.19167 .51289 L
.19167 .49523 L
s
.19167 .51289 m
.19167 .60912 L
.19167 .63132 L
.19167 .52399 L
.19167 .51289 L
s
.19167 .52399 m
.19167 .63132 L
.19167 .63889 L
.19167 .52778 L
.19167 .52399 L
s
.19167 .63889 m
.19167 .75 L
.19167 .73864 L
.19167 .63132 L
.19167 .63889 L
s
.19167 .63132 m
.19167 .73864 L
.19167 .70534 L
.18245 .60912 L
.19167 .63132 L
s
.18245 .60912 m
.19167 .70534 L
.19167 .65237 L
.16398 .5738 L
.18245 .60912 L
s
.16398 .5738 m
.19167 .65237 L
.18959 .58333 L
.15288 .52778 L
.16398 .5738 L
s
.15288 .52778 m
.18959 .58333 L
.19082 .50294 L
.15725 .47418 L
.15288 .52778 L
s
.15725 .47418 m
.19082 .50294 L
.19167 .41667 L
.174 .41667 L
.15725 .47418 L
s
.174 .41667 m
.19167 .41667 L
.19167 .33039 L
.18979 .35915 L
.174 .41667 L
s
.18979 .35915 m
.19167 .33039 L
.19167 .25 L
.19167 .30556 L
.18979 .35915 L
s
.19167 .30556 m
.19167 .25 L
.19167 .18096 L
.19167 .25953 L
.19167 .30556 L
s
.19167 .25953 m
.19167 .18096 L
.19167 .12799 L
.19167 .22422 L
.19167 .25953 L
s
.19167 .22422 m
.19167 .12799 L
.19167 .09469 L
.19167 .20202 L
.19167 .22422 L
s
.19167 .20202 m
.19167 .09469 L
.19167 .08333 L
.19167 .19444 L
.19167 .20202 L
s
.19167 .19444 m
.19167 .08333 L
.19167 .09469 L
.19167 .20202 L
.19167 .19444 L
s
.19167 .20202 m
.19167 .09469 L
.19167 .12799 L
.19167 .22422 L
.19167 .20202 L
s
.19167 .22422 m
.19167 .12799 L
.19167 .18096 L
.19167 .25953 L
.19167 .22422 L
s
.19167 .25953 m
.19167 .18096 L
.19167 .25 L
.19167 .30556 L
.19167 .25953 L
s
.19167 .30556 m
.19167 .25 L
.19167 .33039 L
.19167 .35915 L
.19167 .30556 L
s
.19167 .35915 m
.19167 .33039 L
.19167 .41667 L
.19167 .41667 L
.19167 .35915 L
s
.19167 .41667 m
.19167 .41667 L
.19167 .50294 L
.19167 .47418 L
.19167 .41667 L
s
.19167 .47418 m
.19167 .50294 L
.19167 .58333 L
.19167 .52778 L
.19167 .47418 L
s
.19167 .52778 m
.19167 .58333 L
.19167 .65237 L
.19167 .5738 L
.19167 .52778 L
s
.19167 .5738 m
.19167 .65237 L
.19167 .70534 L
.19167 .60912 L
.19167 .5738 L
s
.19167 .60912 m
.19167 .70534 L
.19167 .73864 L
.19167 .63132 L
.19167 .60912 L
s
.19167 .63132 m
.19167 .73864 L
.19167 .75 L
.19167 .63889 L
.19167 .63132 L
s
.3125 .41667 m
.3125 .52778 L
.3125 .52399 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .52399 L
.3125 .51289 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .51289 L
.3125 .49523 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .49523 L
.3125 .47222 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .47222 L
.3125 .44542 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .44542 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .38791 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .38791 L
.3125 .36111 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .36111 L
.3125 .3381 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .3381 L
.3125 .32044 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .32044 L
.3125 .30934 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .30934 L
.3125 .30556 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .30556 L
.3125 .30934 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .30934 L
.3125 .32044 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .32044 L
.3125 .3381 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .3381 L
.3125 .36111 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .36111 L
.3125 .38791 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .38791 L
.3125 .41667 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .44542 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .44542 L
.3125 .47222 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .47222 L
.3125 .49523 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .49523 L
.3125 .51289 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .51289 L
.3125 .52399 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .41667 m
.3125 .52399 L
.3125 .52778 L
.3125 .41667 L
.3125 .41667 L
s
.3125 .52778 m
.3125 .63889 L
.3125 .63132 L
.3125 .52399 L
.3125 .52778 L
s
.3125 .52399 m
.3125 .63132 L
.3125 .60912 L
.3125 .51289 L
.3125 .52399 L
s
.3125 .51289 m
.3125 .60912 L
.3125 .5738 L
.3125 .49523 L
.3125 .51289 L
s
.3125 .49523 m
.3125 .5738 L
.3125 .52778 L
.3125 .47222 L
.3125 .49523 L
s
.3125 .47222 m
.3125 .52778 L
.3125 .47418 L
.3125 .44542 L
.3125 .47222 L
s
.3125 .44542 m
.3125 .47418 L
.3125 .41667 L
.3125 .41667 L
.3125 .44542 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .35915 L
.3125 .38791 L
.3125 .41667 L
s
.3125 .38791 m
.3125 .35915 L
.3125 .30556 L
.3125 .36111 L
.3125 .38791 L
s
.3125 .36111 m
.3125 .30556 L
.3125 .25953 L
.3125 .3381 L
.3125 .36111 L
s
.3125 .3381 m
.3125 .25953 L
.3125 .22422 L
.3125 .32044 L
.3125 .3381 L
s
.3125 .32044 m
.3125 .22422 L
.3125 .20202 L
.3125 .30934 L
.3125 .32044 L
s
.3125 .30934 m
.3125 .20202 L
.3125 .19444 L
.3125 .30556 L
.3125 .30934 L
s
.3125 .30556 m
.3125 .19444 L
.3125 .20202 L
.3125 .30934 L
.3125 .30556 L
s
.3125 .30934 m
.3125 .20202 L
.3125 .22422 L
.3125 .32044 L
.3125 .30934 L
s
.3125 .32044 m
.3125 .22422 L
.3125 .25953 L
.3125 .3381 L
.3125 .32044 L
s
.3125 .3381 m
.3125 .25953 L
.3125 .30556 L
.3125 .36111 L
.3125 .3381 L
s
.3125 .36111 m
.3125 .30556 L
.3125 .35915 L
.3125 .38791 L
.3125 .36111 L
s
.3125 .38791 m
.3125 .35915 L
.3125 .41667 L
.3125 .41667 L
.3125 .38791 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .47418 L
.3125 .44542 L
.3125 .41667 L
s
.3125 .44542 m
.3125 .47418 L
.3125 .52778 L
.3125 .47222 L
.3125 .44542 L
s
.3125 .47222 m
.3125 .52778 L
.3125 .5738 L
.3125 .49523 L
.3125 .47222 L
s
.3125 .49523 m
.3125 .5738 L
.3125 .60912 L
.3125 .51289 L
.3125 .49523 L
s
.3125 .51289 m
.3125 .60912 L
.3125 .63132 L
.3125 .52399 L
.3125 .51289 L
s
.3125 .52399 m
.3125 .63132 L
.3125 .63889 L
.3125 .52778 L
.3125 .52399 L
s
.3125 .63889 m
.3125 .75 L
.3125 .73864 L
.3125 .63132 L
.3125 .63889 L
s
.3125 .63132 m
.3125 .73864 L
.3125 .70534 L
.3125 .60912 L
.3125 .63132 L
s
.3125 .60912 m
.3125 .70534 L
.3125 .65237 L
.3125 .5738 L
.3125 .60912 L
s
.3125 .5738 m
.3125 .65237 L
.3125 .58333 L
.3125 .52778 L
.3125 .5738 L
s
.3125 .52778 m
.3125 .58333 L
.3125 .50294 L
.3125 .47418 L
.3125 .52778 L
s
.3125 .47418 m
.3125 .50294 L
.3125 .41667 L
.3125 .41667 L
.3125 .47418 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .33039 L
.3125 .35915 L
.3125 .41667 L
s
.3125 .35915 m
.3125 .33039 L
.3125 .25 L
.3125 .30556 L
.3125 .35915 L
s
.3125 .30556 m
.3125 .25 L
.3125 .18096 L
.3125 .25953 L
.3125 .30556 L
s
.3125 .25953 m
.3125 .18096 L
.3125 .12799 L
.3125 .22422 L
.3125 .25953 L
s
.3125 .22422 m
.3125 .12799 L
.3125 .09469 L
.3125 .20202 L
.3125 .22422 L
s
.3125 .20202 m
.3125 .09469 L
.3125 .08333 L
.3125 .19444 L
.3125 .20202 L
s
.3125 .19444 m
.3125 .08333 L
.3125 .09469 L
.3125 .20202 L
.3125 .19444 L
s
.3125 .20202 m
.3125 .09469 L
.3125 .12799 L
.3125 .22422 L
.3125 .20202 L
s
.3125 .22422 m
.3125 .12799 L
.3125 .18096 L
.3125 .25953 L
.3125 .22422 L
s
.3125 .25953 m
.3125 .18096 L
.3125 .25 L
.3125 .30556 L
.3125 .25953 L
s
.3125 .30556 m
.3125 .25 L
.3125 .33039 L
.3125 .35915 L
.3125 .30556 L
s
.3125 .35915 m
.3125 .33039 L
.3125 .41667 L
.3125 .41667 L
.3125 .35915 L
s
.3125 .41667 m
.3125 .41667 L
.3125 .50294 L
.3125 .47418 L
.3125 .41667 L
s
.3125 .47418 m
.3125 .50294 L
.3125 .58333 L
.3125 .52778 L
.3125 .47418 L
s
.3125 .52778 m
.3125 .58333 L
.3125 .65237 L
.3125 .5738 L
.3125 .52778 L
s
.3125 .5738 m
.3125 .65237 L
.3125 .70534 L
.3125 .60912 L
.3125 .5738 L
s
.3125 .60912 m
.3125 .70534 L
.3125 .73864 L
.3125 .63132 L
.3125 .60912 L
s
.3125 .63132 m
.3125 .73864 L
.3125 .75 L
.3125 .63889 L
.3125 .63132 L
s
.19167 .75 m
.3125 .75 L
.3125 .73864 L
.19167 .73864 L
.19167 .75 L
s
.19167 .73864 m
.3125 .73864 L
.3125 .70534 L
.19167 .70534 L
.19167 .73864 L
s
.19167 .70534 m
.3125 .70534 L
.3125 .65237 L
.19167 .65237 L
.19167 .70534 L
s
.19167 .65237 m
.3125 .65237 L
.3125 .58333 L
.18959 .58333 L
.19167 .65237 L
s
.18959 .58333 m
.3125 .58333 L
.3125 .50294 L
.19082 .50294 L
.18959 .58333 L
s
.19082 .50294 m
.3125 .50294 L
.3125 .41667 L
.19167 .41667 L
.19082 .50294 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .33039 L
.19167 .33039 L
.19167 .41667 L
s
.19167 .33039 m
.3125 .33039 L
.3125 .25 L
.19167 .25 L
.19167 .33039 L
s
.19167 .25 m
.3125 .25 L
.3125 .18096 L
.19167 .18096 L
.19167 .25 L
s
.19167 .18096 m
.3125 .18096 L
.3125 .12799 L
.19167 .12799 L
.19167 .18096 L
s
.19167 .12799 m
.3125 .12799 L
.3125 .09469 L
.19167 .09469 L
.19167 .12799 L
s
.19167 .09469 m
.3125 .09469 L
.3125 .08333 L
.19167 .08333 L
.19167 .09469 L
s
.19167 .08333 m
.3125 .08333 L
.3125 .09469 L
.19167 .09469 L
.19167 .08333 L
s
.19167 .09469 m
.3125 .09469 L
.3125 .12799 L
.19167 .12799 L
.19167 .09469 L
s
.19167 .12799 m
.3125 .12799 L
.3125 .18096 L
.19167 .18096 L
.19167 .12799 L
s
.19167 .18096 m
.3125 .18096 L
.3125 .25 L
.19167 .25 L
.19167 .18096 L
s
.19167 .25 m
.3125 .25 L
.3125 .33039 L
.19167 .33039 L
.19167 .25 L
s
.19167 .33039 m
.3125 .33039 L
.3125 .41667 L
.19167 .41667 L
.19167 .33039 L
s
.19167 .41667 m
.3125 .41667 L
.3125 .50294 L
.19167 .50294 L
.19167 .41667 L
s
.19167 .50294 m
.3125 .50294 L
.3125 .58333 L
.19167 .58333 L
.19167 .50294 L
s
.19167 .58333 m
.3125 .58333 L
.3125 .65237 L
.19167 .65237 L
.19167 .58333 L
s
.19167 .65237 m
.3125 .65237 L
.3125 .70534 L
.19167 .70534 L
.19167 .65237 L
s
.19167 .70534 m
.3125 .70534 L
.3125 .73864 L
.19167 .73864 L
.19167 .70534 L
s
.19167 .73864 m
.3125 .73864 L
.3125 .75 L
.19167 .75 L
.19167 .73864 L
s
.3125 .75 m
.4375 .75 L
.4375 .73864 L
.3125 .73864 L
.3125 .75 L
s
.3125 .73864 m
.4375 .73864 L
.4375 .70534 L
.3125 .70534 L
.3125 .73864 L
s
.3125 .70534 m
.4375 .70534 L
.4375 .65237 L
.3125 .65237 L
.3125 .70534 L
s
.3125 .65237 m
.4375 .65237 L
.4375 .58333 L
.3125 .58333 L
.3125 .65237 L
s
.3125 .58333 m
.4375 .58333 L
.4375 .50294 L
.3125 .50294 L
.3125 .58333 L
s
.3125 .50294 m
.4375 .50294 L
.4375 .41667 L
.3125 .41667 L
.3125 .50294 L
s
.3125 .41667 m
.4375 .41667 L
.4375 .33039 L
.3125 .33039 L
.3125 .41667 L
s
.3125 .33039 m
.4375 .33039 L
.4375 .25 L
.3125 .25 L
.3125 .33039 L
s
.3125 .25 m
.4375 .25 L
.4375 .18096 L
.3125 .18096 L
.3125 .25 L
s
.3125 .18096 m
.4375 .18096 L
.4375 .12799 L
.3125 .12799 L
.3125 .18096 L
s
.3125 .12799 m
.4375 .12799 L
.4375 .09469 L
.3125 .09469 L
.3125 .12799 L
s
.3125 .09469 m
.4375 .09469 L
.4375 .08333 L
.3125 .08333 L
.3125 .09469 L
s
.3125 .08333 m
.4375 .08333 L
.4375 .09469 L
.3125 .09469 L
.3125 .08333 L
s
.3125 .09469 m
.4375 .09469 L
.4375 .12799 L
.3125 .12799 L
.3125 .09469 L
s
.3125 .12799 m
.4375 .12799 L
.4375 .18096 L
.3125 .18096 L
.3125 .12799 L
s
.3125 .18096 m
.4375 .18096 L
.4375 .25 L
.3125 .25 L
.3125 .18096 L
s
.3125 .25 m
.4375 .25 L
.4375 .33039 L
.3125 .33039 L
.3125 .25 L
s
.3125 .33039 m
.4375 .33039 L
.4375 .41667 L
.3125 .41667 L
.3125 .33039 L
s
.3125 .41667 m
.4375 .41667 L
.4375 .50294 L
.3125 .50294 L
.3125 .41667 L
s
.3125 .50294 m
.4375 .50294 L
.4375 .58333 L
.3125 .58333 L
.3125 .50294 L
s
.3125 .58333 m
.4375 .58333 L
.4375 .65237 L
.3125 .65237 L
.3125 .58333 L
s
.3125 .65237 m
.4375 .65237 L
.4375 .70534 L
.3125 .70534 L
.3125 .65237 L
s
.3125 .70534 m
.4375 .70534 L
.4375 .73864 L
.3125 .73864 L
.3125 .70534 L
s
.3125 .73864 m
.4375 .73864 L
.4375 .75 L
.3125 .75 L
.3125 .73864 L
s
.001 .092 .901 r
0 .55236 m
.1322 .55409 L
s
0 0 0 r
6 Mabswid
.1322 .55409 Mdot
.001 .092 .901 r
.5 Mabswid
0 .47382 m
.1322 .47295 L
s
0 0 0 r
6 Mabswid
.1322 .47295 Mdot
.001 .092 .901 r
.5 Mabswid
0 .47382 m
.1322 .47295 L
s
0 0 0 r
6 Mabswid
.1322 .47295 Mdot
.001 .092 .901 r
.5 Mabswid
0 .60474 m
.15252 .60874 L
s
0 0 0 r
6 Mabswid
.15252 .60874 Mdot
.001 .092 .901 r
.5 Mabswid
0 .44764 m
.15252 .44564 L
s
0 0 0 r
6 Mabswid
.15252 .44564 Mdot
.001 .092 .901 r
.5 Mabswid
0 .44764 m
.15252 .44564 L
s
0 0 0 r
6 Mabswid
.15252 .44564 Mdot
.001 .092 .901 r
.5 Mabswid
0 .5 m
.12356 .5 L
s
0 0 0 r
6 Mabswid
.12356 .5 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .55409 m
.15639 .55159 L
s
0 0 0 r
6 Mabswid
.15639 .55159 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .47295 m
.15639 .47421 L
s
0 0 0 r
6 Mabswid
.15639 .47421 Mdot
.001 .092 .901 r
.5 Mabswid
.1322 .47295 m
.15639 .47421 L
s
0 0 0 r
6 Mabswid
.15639 .47421 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .60874 m
.1762 .60572 L
s
0 0 0 r
6 Mabswid
.1762 .60572 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .44564 m
.1762 .44715 L
s
0 0 0 r
6 Mabswid
.1762 .44715 Mdot
.001 .092 .901 r
.5 Mabswid
.15252 .44564 m
.1762 .44715 L
s
0 0 0 r
6 Mabswid
.1762 .44715 Mdot
.001 .092 .901 r
.5 Mabswid
.12356 .5 m
.14856 .49999 L
s
0 0 0 r
6 Mabswid
.14856 .49999 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .55159 m
.15639 .55159 L
s
0 0 0 r
6 Mabswid
.15639 .55159 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .47421 m
.15639 .47421 L
s
0 0 0 r
6 Mabswid
.15639 .47421 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .47421 m
.15639 .47421 L
s
0 0 0 r
6 Mabswid
.15639 .47421 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .60572 m
.1762 .60572 L
s
0 0 0 r
6 Mabswid
.1762 .60572 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .44715 m
.1762 .44715 L
s
0 0 0 r
6 Mabswid
.1762 .44715 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .44715 m
.1762 .44715 L
s
0 0 0 r
6 Mabswid
.1762 .44715 Mdot
.001 .092 .901 r
.5 Mabswid
.14856 .49999 m
.14856 .49999 L
s
0 0 0 r
6 Mabswid
.14856 .49999 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .55159 m
.3125 .53522 L
s
0 0 0 r
6 Mabswid
.3125 .53522 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .47421 m
.3125 .48239 L
s
0 0 0 r
6 Mabswid
.3125 .48239 Mdot
.001 .092 .901 r
.5 Mabswid
.15639 .47421 m
.3125 .48239 L
s
0 0 0 r
6 Mabswid
.3125 .48239 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .60572 m
.3125 .58816 L
s
0 0 0 r
6 Mabswid
.3125 .58816 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .44715 m
.3125 .45593 L
s
0 0 0 r
6 Mabswid
.3125 .45593 Mdot
.001 .092 .901 r
.5 Mabswid
.1762 .44715 m
.3125 .45593 L
s
0 0 0 r
6 Mabswid
.3125 .45593 Mdot
.001 .092 .901 r
.5 Mabswid
.14856 .49999 m
.3125 .49995 L
s
0 0 0 r
6 Mabswid
.3125 .49995 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .53522 m
.3125 .53522 L
s
0 0 0 r
6 Mabswid
.3125 .53522 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .48239 m
.3125 .48239 L
s
0 0 0 r
6 Mabswid
.3125 .48239 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .48239 m
.3125 .48239 L
s
0 0 0 r
6 Mabswid
.3125 .48239 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .58816 m
.3125 .58816 L
s
0 0 0 r
6 Mabswid
.3125 .58816 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .45593 m
.3125 .45593 L
s
0 0 0 r
6 Mabswid
.3125 .45593 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .45593 m
.3125 .45593 L
s
0 0 0 r
6 Mabswid
.3125 .45593 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .49995 m
.3125 .49995 L
s
0 0 0 r
6 Mabswid
.3125 .49995 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .53522 m
.4375 .52138 L
s
0 0 0 r
6 Mabswid
.4375 .52138 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .48239 m
.4375 .48931 L
s
0 0 0 r
6 Mabswid
.4375 .48931 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .48239 m
.4375 .48931 L
s
0 0 0 r
6 Mabswid
.4375 .48931 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .58816 m
.4375 .57115 L
s
0 0 0 r
6 Mabswid
.4375 .57115 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .45593 m
.4375 .46443 L
s
0 0 0 r
6 Mabswid
.4375 .46443 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .45593 m
.4375 .46443 L
s
0 0 0 r
6 Mabswid
.4375 .46443 Mdot
.001 .092 .901 r
.5 Mabswid
.3125 .49995 m
.4375 .49992 L
s
0 0 0 r
6 Mabswid
.4375 .49992 Mdot
.001 .092 .901 r
.5 Mabswid
.4375 .52138 m
0 0 rlineto s
.4375 .52138 m
1 .42562 L
s
.4375 .48931 m
0 0 rlineto s
.4375 .48931 m
1 .53719 L
s
.4375 .48931 m
0 0 rlineto s
.4375 .48931 m
1 .53719 L
s
.4375 .57115 m
0 0 rlineto s
.4375 .57115 m
1 .45288 L
s
.4375 .46443 m
0 0 rlineto s
.4375 .46443 m
1 .52356 L
s
.4375 .46443 m
0 0 rlineto s
.4375 .46443 m
1 .52356 L
s
.4375 .49992 m
0 0 rlineto s
.4375 .49992 m
1 .49969 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 239.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000k`P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@002mdCa6RM000
;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000
;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000
;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000
;gA?4J9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d8A0:9d000_M4lAXW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@a40XW@002mdCa6RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02152@d93@T=28a409493@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=24J9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A0:9d000_M4lAXW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q408G@09A52@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a408G@09A53@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00PA@T=2@d93@R<A02A2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@Q6RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM000;gA?4J9d000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000_M0074D93@T=2@`024B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000_M0074D93@T=2@`024B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000_M0074D93@T=2@`024B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000_M0074D93@T=2@`024B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000_M0074D=2@d93@P024B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000^M08A00I2@d93@T<24B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000^M08A00E3@T=2@`034B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000^M08A00E2@d93@P034B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000]M0<A00E3@T=2@`034B5d02DA@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000]M0<A00E2@d93@P034B5d02DA@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000]M0094G@A@d93@Q52008A8G@09A53@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002ed00TAM152@d934D<00Q4QM00U4D93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;7@24@0:M153@T=24D934B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000/M08A00Id4D93@T<24@03@Q5d021d
02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000/M00<4G@A4D=2@a534D<A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002]d0Q402g@A4D93@Q52
4D8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000[M0034GAd008A
00I3@T<A@d824B5d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000[M003
4GAd008A00I2@d8A@T<24B5d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d
000ZM0034GAd009d00TA@d8A@T=2@a408G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@a40XW@002YdE16RM000:W@0115dM7@24@06@d8A@T=20Q4QM00U4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@2RM000:W@00a5dM0034@05@Q52@d800a4QM00U4D93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000:G@01A5dM15d008A00I34D=24D824B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A09id00<H51P00G@002Ud00<AM7@011401D8A
@Q5200<A8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40V7@01Q<D4a@C50Ad
000YM0044G@AM0HA00=2@a400Q4QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
4@2BM00661@H51PD2W@002Ud3a4QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
4@2<M0064a@C51<D47@002Qd414QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
4@26M00661@H51PD5W@001Id01<C51<D4a@C51<D4a@C51<D4a@C008A00@D4a@C2A4QM00U4D93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@20M0064a@C51<D77@0000F61@H51PD61@H51PD
61@H51PD61@H519d00<AM14011403A@H4APD61@H51PD61@077@54@0Q@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A07Yd00HH51PD61@RM000:7@00a5d4@054@03@Q4A00DA17@051<D4a@C51<D
4a@C51<D4a@C51<D27@54@0Q@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A07Ad00HC51<D
4a@TM0034a@C005d000WM08A00Ed4G@AM0024@03@d8A00DA67@01aPD61@H51P00Q408a@H51PD6493
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=200DAJg@01QPD61@H52Ed00DD61@H5004M0009g@24@05
M15d4G@00Q401D8A@Q5200<A87@54@0O@d8D4a@C51<D4a@C51=3@T=2@d93@T=2@d93@T=2@`054FEd
00HC51<D4a@WM00451<D4`Ud000WM0<A0W@02A5d4A534D<A@`034B1d1A407T93@T=2@d93@T=2@d93
51PD61@H51PD61@H@T=2@`HAGg@01QPD61@H52Qd00DH51PD600=M00097@64@03M14A00@A00A3@Q52
0a4QM08A02M3@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=251<D4a@A51<D4a@0F7@01Q<D4a@C52Ud
00DD4a@C500BM00097@54@9d1Q40148A@T<34B5d02<A@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@P054@0;M1PD61@H51PD61@0B7@01QPD61@H52Yd00DH51PD600GM00002<C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4`034@044a@CM0HA00E2@a53@P034B1d1A4084=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=20Q4=M0094a@C51<D4a@C03Ud00HC51<D4a@/M0044a@C51ad
000TM0DA00lD614H51PD61@H51PD61@087@54@0Q@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T<A01Md00XD61@H51PD61@H:G@01QPD61@H52ed00DD61@H500PM00097@54@03M14A00@A00I2@a53
4D<24@0F4a@C51<D4a@C51<D4a@C51<D4a@C50Ud1Q407d=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T<01A4NM00951<D4a@C51<D01Yd00HC51<D4a@^M0054a@C51<09G@002Id0a4017@AM7@34@06
@a53@Q520Q4FM00^61@H51PD61@H514D61@H51PD61A3@T=2@d93@T=2@d93@T=2@d93@T=2@d93@PDA
9g@02QPD61@H51PD61@:M00661@H51PD<7@011PD61@ZM0009W@24@03M14A009d1A4014934D<24B1d
1A407T=2@d934a@C51<D4a@C51<D4a@C51<D@T=2@d93@PHA<G@02Q<D4a@C51<D4a@aM00551<D4a@0
;W@0029d1Q400g@A4@084@03@Q52008A87@54@0V@T=2@d93@T=2@d93@T=2@d93@T=2@d8H51PD61@H
514D61@H51P]M00661@H51PD1G@02Q@H51PD61@H51PSM00561@H51P0<g@0029d1Q400g@A4@064@05
@d8A4D<00Q4PM0DA01m3@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d9300DA0W@031@C51<D4a@C
51<D4a]d00HC51<D4a@EM00951<D4a@C51<D01Ed00DD4a@C500hM0008G@64@03M14A00LA00E2@d8A
@P024Amd1Q407T93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@`HA3W@02a@H51PD61@H51PD00Yd
00HH51PD61@TM00961@H51PD61@H00Qd00@D61@H?G@0003n4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C514D4a@C51<A4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C514D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C514D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D
4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@C51<D4a@24`0O51<D4a@C
51<D4a@C51<D4a@C51<D4a@C51<D4a@C5001M0008W@54@9dF14GM00661@H51PD27@02aPD61@H51PD
61@H02Ad00DD61@H5007M00951PD61@H51PD03Id000TM0<A0W@00a5d4@054@04@a4A@P<A8G@24@0R
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@P8A4g@01Q<D4a@C51Ud00`D4a@C51<D4a@C
51<CM0054a@C51<05G@02Q<D4a@C51<D4a@/M0009G@01Q5dM7@AM08A00Ed4A4A@P024@04@a4A4B5d
02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A00id00HH51PD61@[M00;51PD61@H
51PD61@017@011PD61@TM00961@H51PD61@H02=d000UM0054GAdM1400W@00a5d4@024@04@d8A@P<A
8G@08a52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d9300DA1G@01Q<D4a@C53]d00dD4a@C
51<D4a@C51<D02Ud00XD4a@C51<D4a@C6G@002Ad0Q43M0034G@A00DA00=2@a40114QM00S4D=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8011401QPD61@H53ad00DH51PD600=M00;61@H51PD
61@H51P0:7@02A@H51PD61@H500@M00097@24@=d00<AM1401A400d=24@044B5d028A@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@Q@C0Q4011@C514lM00551<D4a@07G@031@C51<D4a@C51<D4bEd
00XC51<D4a@C51<D1W@002Ad00<AM7@00W@01A5d4A5d00<A00A2@a530a4QM00S4D=2@d93@T=2@d93
@T=2@d93@T=2@d8H51PD61@H51Q2@d801A4hM00451PD62id00/D61@H51PD61@H500TM00561@H51P0
0G@002Ad00<AM7@00W@01A5d4A5d00<A00A3@Q52:1407d=2@d93@T=2@d8D4a@C51<D4aA2@d93@T=2
@d93@T<01A4cM0054a@C51<0?G@031<D4a@C51<D4a@C51id000TM08A0g@01A5d4A5d00<A00A2@a53
0a4PM0DA021261@H51PD61@H@T=2@d93@T=2@d93@T=2@d93@T=2@`8A<7@01A@H51PD04id00/H51PD
61@H51PD600CM0009G@01A5dM7@A009d00<AM1400Q4014=24D834Aed02TD4a4A51<D4aA2@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=24@0/M0054a@C51<0GW@031@C51<D4a@C51<D4`Md000UM08A
00=d4G@00W@44@05@d934D<00a4DM00961@H51PD61@H00=d1A408D93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d934@0XM00461@H56md00HD61@H51P1M0009G@0115d4A42M0DA00E2@d8A@P034@]d
00TD4a@C51<D4a@037@54@0Q@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A02=d00DD4a@C
501jM00097@54@9d1A401D=2@a5300<A0W@02APD61@H51PD600FM08A02=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d934@0NM00561@H51P0Og@002Ad1A400g@A4@044@0:@Q@C51<D4a@C51md
02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A01Yd00@C51<DQ7@0000S61@H51PD
61@H51PD61@H51PD61@H51PD61@H51PD61@H51P00a4041PD61@H4APD61@H@T<A@d824B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A01Ed00DD61@H5028M00097@64@03M14A00@A
00E3@Q52@`024B5d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A011d00DC51<D
4`2=M00097@54@03M15d00@A00I34D<A@d824B5d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T<A00]d00DD61@H502BM0009W@34@9d00<AM1400Q401T934D<A@`8A8G@08a52@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d9300DA17@011@C51>GM0009g@24@=d11400d=2@`024@03
@Q4A025d02<A@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@P044@0561@H51P0Vg@002Qd
00@AM7Ad11400d93@P024@03@a4A025d028A@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<C
0Q4011@C516OM000:7@00a5dM002M0<A00I3@T=24D824B5d02<A@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@a@H51PD61A3@P054Imd000XM0034GAd009d0a401493@T<44B5d02<A@T=2@d93@T=2@d93@T=2
@d8D4a@C51<D4d=2@d93@T=2@`054Imd000YM0044GAdM0@A00=2@d80114PM0DA0212@d93@T=261@H
51PD6493@T=2@d93@T=2@d93@T=2@`8AXG@002Ud00HAM7Ad4G@^4@0751<D4a@C500J4J9d000YM08A
0W@00a5d4@024@04@d8A@P8A7W@0:1PA4A@H51Q2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@a6RM000:W@0315dM15d4D8A@T<A@`8A5W@021<D4a@C51<D0W@54@0Q@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d8A0:9d000ZM08A00Ed4G@A@`024@03@Q52008A3W@021PD61@H51PD2W@54@0Q
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000ZM08A00Ed4G@A@P074@Id00PC51<D
4a@C51=d0Q408d=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000ZM0HA00=34A40
0a4021PD61@H51PD6g@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@0000F
4a@C51<D4a@C51<D4a@C51<D4a@C51Ad1A401a@A4A<D4a@00Q4QM00U4D93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T=24@2RM0005W@04aPD61@H51PD61@H51PD61@H51P00Q401Q@H51PA@`LA
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002Yd1Q400d8A4@054B5d
02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000ZM0HA00=3@T<01A4QM00U
4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;7@44@04@T=2@`@A8G@09A52
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002ad11401T=2@d8A@P8A8G@09A53
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002ed0a401493@T<44B5d02DA@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000]M00;4G@A@d93@T<A@a408G@09A53
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002ed00/AM152@d93@Q524@0QM00U
4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;G@34@08@d93@T<A@a4QM00U
4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;W@24@05@T=2@d809A409493
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24J9d000^M08A00E3@T=2@`034B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000^M08A00E2@d93@P034B5d02DA@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d000^M08A00Q3@T=2@a534B5d02DA@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d000^M50AXW@002id0Q4024=2@d934D<A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002id0Q401T93@T=2@`8A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002id0Q401T=2@d93@P8A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002id0Q401T93@T=2@`8A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002id0Q401T=2@d93@P8A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002id0Q401T93@T=2@`8A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002id0Q401T=2@d93@P8A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002id0Q401T93@T=2@`8A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00LA@d93@T=2008A
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00LA@T=2@d93008A
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a40
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q40
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002md00TA@d93@T=2@a40
8G@09A53@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a40XW@002md00TA@T=2@d93@Q40
8G@09A52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q40XW@002mdCa6RM000;g@02A52
@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53
@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52
@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53
@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52
@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53
@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;g@02A52
@d93@T=24@0QM00U4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24@2RM000;g@02A53
@T=2@d934@0QM00U4D=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d934@2RM000;gA?4J9d
000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d
000_M0094D93@T=2@d8A025d02DA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8A0:9d
000_M0094D=2@d93@T<A025d02DA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A0:9d
000_M4lAXW@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md8G@00?md
8G@00?md8G@00?md8G@00?md8G@00?md8G@00001\
\>"],
  ImageRangeCache->{{{0, 287}, {238.938, 0}} -> {0.239971, -0.025, \
0.000209258, 0.000209258}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Advanced Surfaces: a seashell", "Section"],

Cell["\<\
Surfaces of components in Optica may take arbitrary shapes. In this \
file, a mirror is defined with the shape of a seashell. The shape definition \
is taken from Alfred Gray, Modern Differential Geometry of Curves and \
Surfaces with Mathematica, CRC Press, 2nd ed. 1998 (pages 195, 196, 198, \
309).\
\>", "Text"],

Cell[CellGroupData[{

Cell["Definition", "Subsection"],

Cell[CellGroupData[{

Cell["Auxiliary Functions", "Subsubsection"],

Cell["First, we define some auxiliary functions.", "Text"],

Cell["\<\
Clear[cross3by3, surfacetangent, surfacenormal, binormal, helix, \
seashell];\
\>", "Input"],

Cell["\<\
cross3by3[u_List, v_List] :=
\tRotateLeft[u*RotateLeft[v] - \
RotateLeft[u]*v]/;Length[u]==Length[v]==3;\
\>", "Input"],

Cell["\<\
surfacetangent[alpha_][t_] := 
\tD[alpha[tt], tt] / 
\tSimplify[Factor[Dot[ D[alpha[tt], tt], D[alpha[tt], tt] ]]]^(1/2) /. tt->t;\
\
\>", "Input"],

Cell["\<\
binormal[alpha_][t_] :=
\tSimplify[cross3by3[D[alpha[tt], tt], D[alpha[tt], {tt, 2}]]] /
\tSimplify[Factor[Dot[
\t\tcross3by3[ D[alpha[tt], tt], D[alpha[tt], {tt, 2}] ],
\t\tcross3by3[ D[alpha[tt], tt], D[alpha[tt], {tt, 2}] ]
\t]]]^(1/2) /. tt-> t;\
\>", "Input"],

Cell["\<\
surfacenormal[alpha_][t_] := Cross[binormal[alpha][t], \
surfacetangent[alpha][t]];\
\>", "Input"],

Cell["The surface is constructed with a helix.", "Text"],

Cell["helix[a_, b_][t_] := {a*Cos[t], a*Sin[t], b*t};", "Input"],

Cell["\<\
seashell[curve_][r_][t_, theta_] :=
\tcurve[t] +
\tr*t*(-Cos[theta]*surfacenormal[curve][t] + Sin[theta]*binormal[curve][t])\
\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Shape", "Subsubsection"],

Cell["Here is the plot of the surface.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot3D[
\tEvaluate[
\t\tseashell[
\t\t\thelix[1, 0.6]
\t\t][0.1][t, theta]
\t],
\t{t, 1.75*Pi, 4.75*Pi},
\t{theta, 0, 2*Pi},
\tPlotPoints -> {48, 20},
\tBoxed -> False,
\tAxes -> None
];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.4833 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.230727 1.49617 -1.97108e-16 1.49617 [
[ 0 0 0 0 ]
[ 1 1.4833 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.4833 L
0 1.4833 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.52953 .67565 m .57538 .6539 L .55356 .62774 L p .694 .543 .677 r
F P
0 g
s
.55356 .62774 m .50942 .64619 L .52953 .67565 L p .694 .543 .677 r
F P
0 g
s
.59433 .60401 m .55356 .62774 L .57538 .6539 L p .658 .515 .678 r
F P
0 g
s
.50942 .64619 m .55356 .62774 L .53124 .60037 L p .731 .615 .728 r
F P
0 g
s
.55356 .62774 m .59433 .60401 L .56942 .58021 L p .703 .591 .727 r
F P
0 g
s
.56942 .58021 m .53124 .60037 L .55356 .62774 L p .703 .591 .727 r
F P
0 g
s
.48103 .69167 m .52953 .67565 L .50942 .64619 L p .729 .571 .677 r
F P
0 g
s
.50942 .64619 m .46344 .65908 L .48103 .69167 L p .729 .571 .677 r
F P
0 g
s
.46344 .65908 m .50942 .64619 L .49064 .61555 L p .758 .641 .732 r
F P
0 g
s
.53124 .60037 m .49064 .61555 L .50942 .64619 L p .731 .615 .728 r
F P
0 g
s
.49064 .61555 m .53124 .60037 L .51065 .57453 L p .763 .688 .779 r
F P
0 g
s
.53124 .60037 m .56942 .58021 L .54477 .5578 L p .742 .663 .772 r
F P
0 g
s
.54477 .5578 m .51065 .57453 L .53124 .60037 L p .742 .663 .772 r
F P
0 g
s
.60381 .55543 m .56942 .58021 L .59433 .60401 L p .673 .569 .729 r
F P
0 g
s
.56942 .58021 m .60381 .55543 L .57617 .53681 L p .721 .642 .769 r
F P
0 g
s
.57617 .53681 m .54477 .5578 L .56942 .58021 L p .721 .642 .769 r
F P
0 g
s
.50011 .72008 m .54899 .70098 L .52953 .67565 L p .69 .491 .613 r
F P
0 g
s
.52953 .67565 m .48103 .69167 L .50011 .72008 L p .69 .491 .613 r
F P
0 g
s
.57538 .6539 m .52953 .67565 L .54899 .70098 L p .646 .457 .613 r
F P
0 g
s
.49064 .61555 m .4491 .62557 L .46344 .65908 L p .758 .641 .732 r
F P
0 g
s
.4491 .62557 m .49064 .61555 L .4751 .58678 L p .783 .715 .788 r
F P
0 g
s
.51065 .57453 m .4751 .58678 L .49064 .61555 L p .763 .688 .779 r
F P
0 g
s
.57538 .6539 m .617 .6268 L .59433 .60401 L p .658 .515 .678 r
F P
0 g
s
.63029 .57546 m .59433 .60401 L .617 .6268 L p .618 .488 .682 r
F P
0 g
s
.59433 .60401 m .63029 .57546 L .60381 .55543 L p .673 .569 .729 r
F P
0 g
s
.43151 .70178 m .48103 .69167 L .46344 .65908 L p .762 .602 .679 r
F P
0 g
s
.46344 .65908 m .41724 .66631 L .43151 .70178 L p .762 .602 .679 r
F P
0 g
s
.41724 .66631 m .46344 .65908 L .4491 .62557 L p .785 .671 .738 r
F P
0 g
s
.54899 .70098 m .5945 .67622 L .57538 .6539 L p .646 .457 .613 r
F P
0 g
s
.617 .6268 m .57538 .6539 L .5945 .67622 L p .596 .42 .613 r
F P
0 g
s
.44951 .73328 m .50011 .72008 L .48103 .69167 L p .731 .525 .613 r
F P
0 g
s
.48103 .69167 m .43151 .70178 L .44951 .73328 L p .731 .525 .613 r
F P
0 g
s
.63313 .52652 m .60381 .55543 L .63029 .57546 L p .642 .549 .734 r
F P
0 g
s
.60381 .55543 m .63313 .52652 L .60366 .51194 L p .698 .623 .769 r
F P
0 g
s
.60366 .51194 m .57617 .53681 L .60381 .55543 L p .698 .623 .769 r
F P
0 g
s
.51065 .57453 m .54477 .5578 L .52286 .53902 L p .782 .747 .821 r
F P
0 g
s
.54477 .5578 m .57617 .53681 L .55017 .52146 L p .768 .721 .809 r
F P
0 g
s
.55017 .52146 m .52286 .53902 L .54477 .5578 L p .768 .721 .809 r
F P
0 g
s
.4491 .62557 m .40812 .63041 L .41724 .66631 L p .785 .671 .738 r
F P
0 g
s
.40812 .63041 m .4491 .62557 L .43946 .59448 L p .802 .746 .801 r
F P
0 g
s
.4751 .58678 m .43946 .59448 L .4491 .62557 L p .783 .715 .788 r
F P
0 g
s
.4751 .58678 m .51065 .57453 L .49388 .55285 L p .794 .775 .836 r
F P
0 g
s
.52286 .53902 m .49388 .55285 L .51065 .57453 L p .782 .747 .821 r
F P
0 g
s
.5945 .67622 m .63511 .64626 L .617 .6268 L p .596 .42 .613 r
F P
0 g
s
.65296 .59487 m .617 .6268 L .63511 .64626 L p .537 .378 .613 r
F P
0 g
s
.617 .6268 m .65296 .59487 L .63029 .57546 L p .618 .488 .682 r
F P
0 g
s
.57617 .53681 m .60366 .51194 L .57473 .50041 L p .751 .697 .8 r
F P
0 g
s
.57473 .50041 m .55017 .52146 L .57617 .53681 L p .751 .697 .8 r
F P
0 g
s
.66016 .5427 m .63029 .57546 L .65296 .59487 L p .572 .46 .688 r
F P
0 g
s
.63029 .57546 m .66016 .5427 L .63313 .52652 L p .642 .549 .734 r
F P
0 g
s
.38271 .70595 m .43151 .70178 L .41724 .66631 L p .796 .636 .683 r
F P
0 g
s
.41724 .66631 m .37249 .66793 L .38271 .70595 L p .796 .636 .683 r
F P
0 g
s
.37249 .66793 m .41724 .66631 L .40812 .63041 L p .812 .705 .747 r
F P
0 g
s
.3989 .74048 m .44951 .73328 L .43151 .70178 L p .771 .56 .613 r
F P
0 g
s
.43151 .70178 m .38271 .70595 L .3989 .74048 L p .771 .56 .613 r
F P
0 g
s
.51879 .74139 m .56579 .71955 L .54899 .70098 L p .628 .379 .522 r
F P
0 g
s
.54899 .70098 m .50011 .72008 L .51879 .74139 L p .628 .379 .522 r
F P
0 g
s
.5945 .67622 m .54899 .70098 L .56579 .71955 L p .566 .329 .516 r
F P
0 g
s
.43946 .59448 m .4751 .58678 L .4644 .56284 L p .802 .806 .854 r
F P
0 g
s
.49388 .55285 m .4644 .56284 L .4751 .58678 L p .794 .775 .836 r
F P
0 g
s
.46946 .7576 m .51879 .74139 L .50011 .72008 L p .681 .423 .525 r
F P
0 g
s
.50011 .72008 m .44951 .73328 L .46946 .7576 L p .681 .423 .525 r
F P
0 g
s
.6563 .49415 m .63313 .52652 L .66016 .5427 L p .608 .53 .741 r
F P
0 g
s
.63313 .52652 m .6563 .49415 L .62618 .48371 L p .674 .606 .771 r
F P
0 g
s
.62618 .48371 m .60366 .51194 L .63313 .52652 L p .674 .606 .771 r
F P
0 g
s
.56579 .71955 m .60893 .69237 L .5945 .67622 L p .566 .329 .516 r
F P
0 g
s
.63511 .64626 m .5945 .67622 L .60893 .69237 L p .489 .267 .503 r
F P
0 g
s
.60366 .51194 m .62618 .48371 L .59552 .47625 L p .734 .676 .794 r
F P
0 g
s
.59552 .47625 m .57473 .50041 L .60366 .51194 L p .734 .676 .794 r
F P
0 g
s
.40812 .63041 m .36925 .63024 L .37249 .66793 L p .812 .705 .747 r
F P
0 g
s
.36925 .63024 m .40812 .63041 L .40511 .59771 L p .818 .78 .817 r
F P
0 g
s
.43946 .59448 m .40511 .59771 L .40812 .63041 L p .802 .746 .801 r
F P
0 g
s
.41945 .76802 m .46946 .7576 L .44951 .73328 L p .73 .463 .524 r
F P
0 g
s
.44951 .73328 m .3989 .74048 L .41945 .76802 L p .73 .463 .524 r
F P
0 g
s
.49388 .55285 m .52286 .53902 L .50598 .52587 L p .821 .86 .877 r
F P
0 g
s
.52286 .53902 m .55017 .52146 L .52848 .511 L p .819 .823 .852 r
F P
0 g
s
.52848 .511 m .50598 .52587 L .52286 .53902 L p .819 .823 .852 r
F P
0 g
s
.55017 .52146 m .57473 .50041 L .54927 .49314 L p .81 .788 .832 r
F P
0 g
s
.54927 .49314 m .52848 .511 L .55017 .52146 L p .81 .788 .832 r
F P
0 g
s
.63511 .64626 m .66945 .61169 L .65296 .59487 L p .537 .378 .613 r
F P
0 g
s
.682 .55884 m .65296 .59487 L .66945 .61169 L p .463 .328 .612 r
F P
0 g
s
.65296 .59487 m .682 .55884 L .66016 .5427 L p .572 .46 .688 r
F P
0 g
s
.40511 .59771 m .43946 .59448 L .43559 .56903 L p .805 .839 .876 r
F P
0 g
s
.4644 .56284 m .43559 .56903 L .43946 .59448 L p .802 .806 .854 r
F P
0 g
s
.68284 .50652 m .66016 .5427 L .682 .55884 L p .518 .431 .696 r
F P
0 g
s
.66016 .5427 m .68284 .50652 L .6563 .49415 L p .608 .53 .741 r
F P
0 g
s
.57473 .50041 m .59552 .47625 L .56745 .47254 L p .797 .755 .815 r
F P
0 g
s
.56745 .47254 m .54927 .49314 L .57473 .50041 L p .797 .755 .815 r
F P
0 g
s
.4644 .56284 m .49388 .55285 L .48274 .53763 L p .811 .897 .903 r
F P
0 g
s
.50598 .52587 m .48274 .53763 L .49388 .55285 L p .821 .86 .877 r
F P
0 g
s
.60893 .69237 m .64674 .66035 L .63511 .64626 L p .489 .267 .503 r
F P
0 g
s
.66945 .61169 m .63511 .64626 L .64674 .66035 L p .385 .184 .48 r
F P
0 g
s
.6428 .4528 m .62618 .48371 L .6563 .49415 L p .65 .591 .775 r
F P
0 g
s
.62618 .48371 m .6428 .4528 L .61168 .4495 L p .715 .658 .791 r
F P
0 g
s
.61168 .4495 m .59552 .47625 L .62618 .48371 L p .715 .658 .791 r
F P
0 g
s
.35005 .74176 m .3989 .74048 L .38271 .70595 L p .812 .599 .614 r
F P
0 g
s
.38271 .70595 m .33639 .70433 L .35005 .74176 L p .812 .599 .614 r
F P
0 g
s
.33639 .70433 m .38271 .70595 L .37249 .66793 L p .831 .674 .689 r
F P
0 g
s
.37249 .66793 m .33086 .66418 L .33639 .70433 L p .831 .674 .689 r
F P
0 g
s
.33086 .66418 m .37249 .66793 L .36925 .63024 L p .838 .745 .76 r
F P
0 g
s
.67241 .45912 m .6563 .49415 L .68284 .50652 L p .57 .512 .751 r
F P
0 g
s
.6563 .49415 m .67241 .45912 L .6428 .4528 L p .65 .591 .775 r
F P
0 g
s
.59552 .47625 m .61168 .4495 L .58218 .44955 L p .781 .726 .802 r
F P
0 g
s
.58218 .44955 m .56745 .47254 L .59552 .47625 L p .781 .726 .802 r
F P
0 g
s
.48933 .77212 m .53512 .75329 L .51879 .74139 L p .583 .251 .372 r
F P
0 g
s
.51879 .74139 m .46946 .7576 L .48933 .77212 L p .583 .251 .372 r
F P
0 g
s
.56579 .71955 m .51879 .74139 L .53512 .75329 L p .5 .177 .351 r
F P
0 g
s
.53512 .75329 m .57817 .72931 L .56579 .71955 L p .5 .177 .351 r
F P
0 g
s
.60893 .69237 m .56579 .71955 L .57817 .72931 L p .39 .077 .31 r
F P
0 g
s
.43559 .56903 m .4644 .56284 L .45975 .54629 L p .785 .928 .929 r
F P
0 g
s
.48274 .53763 m .45975 .54629 L .4644 .56284 L p .811 .897 .903 r
F P
0 g
s
.37048 .77266 m .41945 .76802 L .3989 .74048 L p .778 .503 .52 r
F P
0 g
s
.3989 .74048 m .35005 .74176 L .37048 .77266 L p .778 .503 .52 r
F P
0 g
s
.40511 .59771 m .37341 .59671 L .36925 .63024 L p .818 .78 .817 r
F P
0 g
s
.37341 .59671 m .40511 .59771 L .40863 .5716 L p .799 .871 .901 r
F P
0 g
s
.43559 .56903 m .40863 .5716 L .40511 .59771 L p .805 .839 .876 r
F P
0 g
s
.44232 .78563 m .48933 .77212 L .46946 .7576 L p .65 .308 .38 r
F P
0 g
s
.46946 .7576 m .41945 .76802 L .44232 .78563 L p .65 .308 .38 r
F P
0 g
s
.66945 .61169 m .69631 .57327 L .682 .55884 L p .463 .328 .612 r
F P
0 g
s
.70304 .51956 m .682 .55884 L .69631 .57327 L p .362 .263 .606 r
F P
0 g
s
.682 .55884 m .70304 .51956 L .68284 .50652 L p .518 .431 .696 r
F P
0 g
s
.36925 .63024 m .33403 .62537 L .33086 .66418 L p .838 .745 .76 r
F P
0 g
s
.33403 .62537 m .36925 .63024 L .37341 .59671 L p .831 .819 .838 r
F P
0 g
s
.57817 .72931 m .61706 .70054 L .60893 .69237 L p .39 .077 .31 r
F P
0 g
s
.64674 .66035 m .60893 .69237 L .61706 .70054 L p .228 0 .236 r
F P
0 g
s
.65285 .42 m .6428 .4528 L .67241 .45912 L p .623 .578 .783 r
F P
0 g
s
.6428 .4528 m .65285 .42 L .62249 .42078 L p .696 .641 .791 r
F P
0 g
s
.62249 .42078 m .61168 .4495 L .6428 .4528 L p .696 .641 .791 r
F P
0 g
s
.61168 .4495 m .62249 .42078 L .59278 .42466 L p .763 .7 .792 r
F P
0 g
s
.59278 .42466 m .58218 .44955 L .61168 .4495 L p .763 .7 .792 r
F P
0 g
s
.52848 .511 m .54927 .49314 L .52997 .49095 L p .875 .914 .851 r
F P
0 g
s
.54927 .49314 m .56745 .47254 L .54486 .47299 L p .872 .86 .826 r
F P
0 g
s
.54486 .47299 m .52997 .49095 L .54927 .49314 L p .872 .86 .826 r
F P
0 g
s
.50598 .52587 m .52848 .511 L .51342 .50661 L p .853 .964 .874 r
F P
0 g
s
.52997 .49095 m .51342 .50661 L .52848 .511 L p .875 .914 .851 r
F P
0 g
s
.64674 .66035 m .67795 .62411 L .66945 .61169 L p .385 .184 .48 r
F P
0 g
s
.69631 .57327 m .66945 .61169 L .67795 .62411 L p .231 .063 .436 r
F P
0 g
s
.69746 .46783 m .68284 .50652 L .70304 .51956 L p .451 .397 .706 r
F P
0 g
s
.68284 .50652 m .69746 .46783 L .67241 .45912 L p .57 .512 .751 r
F P
0 g
s
.56745 .47254 m .58218 .44955 L .55735 .45297 L p .857 .809 .803 r
F P
0 g
s
.55735 .45297 m .54486 .47299 L .56745 .47254 L p .857 .809 .803 r
F P
0 g
s
.48274 .53763 m .50598 .52587 L .496 .51984 L p .786 .993 .88 r
F P
0 g
s
.51342 .50661 m .496 .51984 L .50598 .52587 L p .853 .964 .874 r
F P
0 g
s
.40863 .5716 m .43559 .56903 L .438 .55199 L p .735 .946 .95 r
F P
0 g
s
.45975 .54629 m .438 .55199 L .43559 .56903 L p .785 .928 .929 r
F P
0 g
s
.6808 .42238 m .67241 .45912 L .69746 .46783 L p .526 .496 .765 r
F P
0 g
s
.67241 .45912 m .6808 .42238 L .65285 .42 L p .623 .578 .783 r
F P
0 g
s
.58218 .44955 m .59278 .42466 L .56678 .43122 L p .836 .765 .784 r
F P
0 g
s
.56678 .43122 m .55735 .45297 L .58218 .44955 L p .836 .765 .784 r
F P
0 g
s
.61706 .70054 m .6505 .66745 L .64674 .66035 L p .228 0 .236 r
F P
0 g
s
.67795 .62411 m .64674 .66035 L .6505 .66745 L p 0 0 .1 r
F P
0 g
s
.45975 .54629 m .48274 .53763 L .47852 .53063 L p .651 .97 .849 r
F P
0 g
s
.47852 .53063 m .48274 .53763 L p .49389 .52266 L .786 .993 .88 r
F P
0 g
s
.46179 .53908 m .45975 .54629 L p .47566 .53302 L .651 .97 .849 r
F P
0 g
s
.47852 .53063 m .46179 .53908 L p .47566 .53302 L .651 .97 .849 r
F P
0 g
s
.438 .55199 m .45975 .54629 L .46179 .53908 L p .45 .875 .771 r
F P
0 g
s
.4466 .54538 m .438 .55199 L p .45831 .54097 L .45 .875 .771 r
F P
0 g
s
.46179 .53908 m .4466 .54538 L p .45831 .54097 L .45 .875 .771 r
F P
0 g
s
.41843 .55496 m .438 .55199 L .4466 .54538 L p 0 0 0 r
F P
0 g
s
.4466 .54538 m .46062 .55024 L p .43475 .54985 L .444 0 .07 r
F P
0 g
s
.43364 .54983 m .4466 .54538 L p .43475 .54985 L .444 0 .07 r
F P
0 g
s
.46179 .53908 m .4705 .54225 L p .44772 .54524 L .311 0 .012 r
F P
0 g
s
.4466 .54538 m .46179 .53908 L p .44772 .54524 L .311 0 .012 r
F P
0 g
s
.47852 .53063 m .48186 .53283 L p .46285 .53875 L .119 0 0 r
F P
0 g
s
.46179 .53908 m .47852 .53063 L p .46285 .53875 L .119 0 0 r
F P
0 g
s
.496 .51984 m .47852 .53063 L p .49389 .52266 L .786 .993 .88 r
F P
0 g
s
.39568 .79377 m .44232 .78563 L .41945 .76802 L p .709 .356 .376 r
F P
0 g
s
.41945 .76802 m .37048 .77266 L .39568 .79377 L p .709 .356 .376 r
F P
0 g
s
.30475 .73739 m .35005 .74176 L .33639 .70433 L p .855 .642 .613 r
F P
0 g
s
.33639 .70433 m .29431 .69727 L .30475 .73739 L p .855 .642 .613 r
F P
0 g
s
.29431 .69727 m .33639 .70433 L .33086 .66418 L p .866 .719 .697 r
F P
0 g
s
.62744 .39085 m .62249 .42078 L .65285 .42 L p .676 .627 .793 r
F P
0 g
s
.62249 .42078 m .62744 .39085 L .59871 .39844 L p .744 .676 .785 r
F P
0 g
s
.59871 .39844 m .59278 .42466 L .62249 .42078 L p .744 .676 .785 r
F P
0 g
s
.33086 .66418 m .29402 .65548 L .29431 .69727 L p .866 .719 .697 r
F P
0 g
s
.29402 .65548 m .33086 .66418 L .33403 .62537 L p .863 .79 .777 r
F P
0 g
s
.65588 .38619 m .65285 .42 L .6808 .42238 L p .595 .568 .794 r
F P
0 g
s
.65285 .42 m .65588 .38619 L .62744 .39085 L p .676 .627 .793 r
F P
0 g
s
.59278 .42466 m .59871 .39844 L .57262 .40818 L p .813 .726 .769 r
F P
0 g
s
.57262 .40818 m .56678 .43122 L .59278 .42466 L p .813 .726 .769 r
F P
0 g
s
.32429 .77173 m .37048 .77266 L .35005 .74176 L p .826 .544 .51 r
F P
0 g
s
.35005 .74176 m .30475 .73739 L .32429 .77173 L p .826 .544 .51 r
F P
0 g
s
.37341 .59671 m .34566 .59188 L .33403 .62537 L p .831 .819 .838 r
F P
0 g
s
.34566 .59188 m .37341 .59671 L .38464 .57087 L p .781 .899 .926 r
F P
0 g
s
.40863 .5716 m .38464 .57087 L .37341 .59671 L p .799 .871 .901 r
F P
0 g
s
.50704 .77511 m .54733 .75428 L .53512 .75329 L p .304 0 .007 r
F P
0 g
s
.53512 .75329 m .48933 .77212 L .50704 .77511 L p .304 0 .007 r
F P
0 g
s
.57817 .72931 m .53512 .75329 L .54733 .75428 L p .114 0 0 r
F P
0 g
s
.69631 .57327 m .7147 .53194 L .70304 .51956 L p .362 .263 .606 r
F P
0 g
s
.7153 .47806 m .70304 .51956 L .7147 .53194 L p .212 .169 .59 r
F P
0 g
s
.70304 .51956 m .7153 .47806 L .69746 .46783 L p .451 .397 .706 r
F P
0 g
s
.67795 .62411 m .70145 .58445 L .69631 .57327 L p .231 .063 .436 r
F P
0 g
s
.7147 .53194 m .69631 .57327 L .70145 .58445 L p 0 0 .344 r
F P
0 g
s
.54733 .75428 m .58468 .72901 L .57817 .72931 L p .114 0 0 r
F P
0 g
s
.61706 .70054 m .57817 .72931 L .58468 .72901 L p 0 0 0 r
F P
0 g
s
.38464 .57087 m .40863 .5716 L .41843 .55496 L p .657 .943 .961 r
F P
0 g
s
.438 .55199 m .41843 .55496 L .40863 .5716 L p .735 .946 .95 r
F P
0 g
s
.70342 .42771 m .69746 .46783 L .7153 .47806 L p .361 .355 .718 r
F P
0 g
s
.69746 .46783 m .70342 .42771 L .6808 .42238 L p .526 .496 .765 r
F P
0 g
s
.52997 .49095 m .54486 .47299 L .53022 .47764 L p .92 .977 .747 r
F P
0 g
s
.54486 .47299 m .55735 .45297 L .53981 .45946 L p .944 .917 .757 r
F P
0 g
s
.53981 .45946 m .53022 .47764 L .54486 .47299 L p .944 .917 .757 r
F P
0 g
s
.46516 .79127 m .50704 .77511 L .48933 .77212 L p .436 0 .07 r
F P
0 g
s
.48933 .77212 m .44232 .78563 L .46516 .79127 L p .436 0 .07 r
F P
0 g
s
.51342 .50661 m .52997 .49095 L .51899 .49416 L p .789 .97 .671 r
F P
0 g
s
.53022 .47764 m .51899 .49416 L .52997 .49095 L p .92 .977 .747 r
F P
0 g
s
.33403 .62537 m .30393 .61629 L .29402 .65548 L p .863 .79 .777 r
F P
0 g
s
.30393 .61629 m .33403 .62537 L .34566 .59188 L p .836 .86 .862 r
F P
0 g
s
.55735 .45297 m .56678 .43122 L .54718 .43984 L p .925 .846 .746 r
F P
0 g
s
.54718 .43984 m .53981 .45946 L .55735 .45297 L p .925 .846 .746 r
F P
0 g
s
.62627 .3605 m .62744 .39085 L .65588 .38619 L p .655 .615 .797 r
F P
0 g
s
.62744 .39085 m .62627 .3605 L .59963 .37155 L p .724 .655 .781 r
F P
0 g
s
.59963 .37155 m .59871 .39844 L .62744 .39085 L p .724 .655 .781 r
F P
0 g
s
.59871 .39844 m .59963 .37155 L .57449 .38436 L p .789 .692 .757 r
F P
0 g
s
.57449 .38436 m .57262 .40818 L .59871 .39844 L p .789 .692 .757 r
F P
0 g
s
.68111 .38495 m .6808 .42238 L .70342 .42771 L p .474 .48 .784 r
F P
0 g
s
.6808 .42238 m .68111 .38495 L .65588 .38619 L p .595 .568 .794 r
F P
0 g
s
.496 .51984 m .51342 .50661 L .50675 .50888 L p 0 0 0 r
F P
0 g
s
.51899 .49416 m .50675 .50888 L .51342 .50661 L p .789 .97 .671 r
F P
0 g
s
.6505 .66745 m .67735 .63071 L .67795 .62411 L p 0 0 .1 r
F P
0 g
s
.70145 .58445 m .67795 .62411 L .67735 .63071 L p 0 0 0 r
F P
0 g
s
.58468 .72901 m .61788 .69963 L .61706 .70054 L p 0 0 0 r
F P
0 g
s
.6505 .66745 m .61706 .70054 L .61788 .69963 L p .502 .821 .508 r
F P
0 g
s
.56678 .43122 m .57262 .40818 L .55185 .4191 L p .894 .783 .732 r
F P
0 g
s
.55185 .4191 m .54718 .43984 L .56678 .43122 L p .894 .783 .732 r
F P
0 g
s
.35102 .79668 m .39568 .79377 L .37048 .77266 L p .764 .397 .361 r
F P
0 g
s
.37048 .77266 m .32429 .77173 L .35102 .79668 L p .764 .397 .361 r
F P
0 g
s
.65171 .35235 m .65588 .38619 L .68111 .38495 L p .564 .561 .808 r
F P
0 g
s
.65588 .38619 m .65171 .35235 L .62627 .3605 L p .655 .615 .797 r
F P
0 g
s
.47852 .53063 m .496 .51984 L .49416 .52175 L p 0 0 0 r
F P
0 g
s
.50675 .50888 m .49416 .52175 L .496 .51984 L p 0 0 0 r
F P
0 g
s
.57262 .40818 m .57449 .38436 L .55344 .39764 L p .86 .73 .719 r
F P
0 g
s
.55344 .39764 m .55185 .4191 L .57262 .40818 L p .86 .73 .719 r
F P
0 g
s
.42308 .80271 m .46516 .79127 L .44232 .78563 L p .532 .068 .096 r
F P
0 g
s
.44232 .78563 m .39568 .79377 L .42308 .80271 L p .532 .068 .096 r
F P
0 g
s
.59539 .34472 m .59963 .37155 L .62627 .3605 L p .704 .637 .779 r
F P
0 g
s
.59963 .37155 m .59539 .34472 L .57219 .36035 L p .764 .662 .75 r
F P
0 g
s
.57219 .36035 m .57449 .38436 L .59963 .37155 L p .764 .662 .75 r
F P
0 g
s
.61896 .33062 m .62627 .3605 L .65171 .35235 L p .633 .605 .804 r
F P
0 g
s
.62627 .3605 m .61896 .33062 L .59539 .34472 L p .704 .637 .779 r
F P
0 g
s
.57449 .38436 m .57219 .36035 L .55172 .37592 L p .826 .686 .709 r
F P
0 g
s
.55172 .37592 m .55344 .39764 L .57449 .38436 L p .826 .686 .709 r
F P
0 g
s
.61788 .69963 m .6458 .66663 L .6505 .66745 L p .502 .821 .508 r
F P
0 g
s
.67735 .63071 m .6505 .66745 L .6458 .66663 L p .784 .974 .687 r
F P
0 g
s
.49416 .52175 m .48186 .53283 L .47852 .53063 L p 0 0 0 r
F P
0 g
s
.38464 .57087 m .36468 .56728 L .34566 .59188 L p .781 .899 .926 r
F P
0 g
s
.36468 .56728 m .38464 .57087 L .40192 .55559 L p .554 .914 .958 r
F P
0 g
s
.41843 .55496 m .40192 .55559 L .38464 .57087 L p .657 .943 .961 r
F P
0 g
s
.26479 .72781 m .30475 .73739 L .29431 .69727 L p .901 .692 .611 r
F P
0 g
s
.29431 .69727 m .25822 .68529 L .26479 .72781 L p .901 .692 .611 r
F P
0 g
s
.25822 .68529 m .29431 .69727 L .29402 .65548 L p .903 .773 .708 r
F P
0 g
s
.34566 .59188 m .3231 .58377 L .30393 .61629 L p .836 .86 .862 r
F P
0 g
s
.3231 .58377 m .34566 .59188 L .36468 .56728 L p .746 .92 .95 r
F P
0 g
s
.7147 .53194 m .72393 .48877 L .7153 .47806 L p .212 .169 .59 r
F P
0 g
s
.71828 .4355 m .7153 .47806 L .72393 .48877 L p 0 .024 .54 r
F P
0 g
s
.7153 .47806 m .71828 .4355 L .70342 .42771 L p .361 .355 .718 r
F P
0 g
s
.70145 .58445 m .7164 .54232 L .7147 .53194 L p 0 0 .344 r
F P
0 g
s
.72393 .48877 m .7147 .53194 L .7164 .54232 L p 0 0 .152 r
F P
0 g
s
.58611 .31869 m .59539 .34472 L .61896 .33062 L p .682 .621 .78 r
F P
0 g
s
.59539 .34472 m .58611 .31869 L .56569 .33676 L p .739 .636 .745 r
F P
0 g
s
.56569 .33676 m .57219 .36035 L .59539 .34472 L p .739 .636 .745 r
F P
0 g
s
.57219 .36035 m .56569 .33676 L .54661 .35442 L p .793 .648 .701 r
F P
0 g
s
.54661 .35442 m .55172 .37592 L .57219 .36035 L p .793 .648 .701 r
F P
0 g
s
.70048 .38732 m .70342 .42771 L .71828 .4355 L p .236 .301 .727 r
F P
0 g
s
.70342 .42771 m .70048 .38732 L .68111 .38495 L p .474 .48 .784 r
F P
0 g
s
.29402 .65548 m .26358 .64244 L .25822 .68529 L p .903 .773 .708 r
F P
0 g
s
.26358 .64244 m .29402 .65548 L .30393 .61629 L p .885 .843 .798 r
F P
0 g
s
.53022 .47764 m .53981 .45946 L .53156 .46838 L p .81 .844 .382 r
F P
0 g
s
.53981 .45946 m .54718 .43984 L .53614 .44964 L p .979 .897 .551 r
F P
0 g
s
.53614 .44964 m .53156 .46838 L .53981 .45946 L p .979 .897 .551 r
F P
0 g
s
.54718 .43984 m .55185 .4191 L .53862 .43008 L p .986 .841 .613 r
F P
0 g
s
.53862 .43008 m .53614 .44964 L .54718 .43984 L p .986 .841 .613 r
F P
0 g
s
.28263 .76558 m .32429 .77173 L .30475 .73739 L p .877 .588 .493 r
F P
0 g
s
.30475 .73739 m .26479 .72781 L .28263 .76558 L p .877 .588 .493 r
F P
0 g
s
.67331 .34797 m .68111 .38495 L .70048 .38732 L p .411 .465 .806 r
F P
0 g
s
.68111 .38495 m .67331 .34797 L .65171 .35235 L p .564 .561 .808 r
F P
0 g
s
.67735 .63071 m .69666 .5911 L .70145 .58445 L p 0 0 0 r
F P
0 g
s
.7164 .54232 m .70145 .58445 L .69666 .5911 L p .796 .857 .409 r
F P
0 g
s
.51899 .49416 m .53022 .47764 L .52526 .48608 L p 0 0 0 r
F P
0 g
s
.53156 .46838 m .52526 .48608 L .53022 .47764 L p .81 .844 .382 r
F P
0 g
s
.55185 .4191 m .55344 .39764 L .53867 .41002 L p .946 .77 .631 r
F P
0 g
s
.53867 .41002 m .53862 .43008 L .55185 .4191 L p .946 .77 .631 r
F P
0 g
s
.64049 .3195 m .65171 .35235 L .67331 .34797 L p .531 .556 .826 r
F P
0 g
s
.65171 .35235 m .64049 .3195 L .61896 .33062 L p .633 .605 .804 r
F P
0 g
s
.55519 .31421 m .56569 .33676 L .58611 .31869 L p .713 .612 .743 r
F P
0 g
s
.56569 .33676 m .55519 .31421 L .53821 .33368 L p .76 .614 .697 r
F P
0 g
s
.53821 .33368 m .54661 .35442 L .56569 .33676 L p .76 .614 .697 r
F P
0 g
s
.55344 .39764 m .55172 .37592 L .5361 .38982 L p .899 .707 .635 r
F P
0 g
s
.5361 .38982 m .53867 .41002 L .55344 .39764 L p .899 .707 .635 r
F P
0 g
s
.52064 .76594 m .55398 .74398 L .54733 .75428 L p .45 .871 .745 r
F P
0 g
s
.54733 .75428 m .50704 .77511 L .52064 .76594 L p .45 .871 .745 r
F P
0 g
s
.58468 .72901 m .54733 .75428 L .55398 .74398 L p .659 .972 .837 r
F P
0 g
s
.60579 .30207 m .61896 .33062 L .64049 .3195 L p .61 .598 .814 r
F P
0 g
s
.61896 .33062 m .60579 .30207 L .58611 .31869 L p .682 .621 .78 r
F P
0 g
s
.50675 .50888 m .51899 .49416 L .51771 .50256 L p 0 0 .123 r
F P
0 g
s
.52526 .48608 m .51771 .50256 L .51899 .49416 L p 0 0 0 r
F P
0 g
s
.43364 .54983 m .41843 .55496 L p .44265 .54673 L 0 0 0 r
F P
0 g
s
.4466 .54538 m .43364 .54983 L p .44265 .54673 L 0 0 0 r
F P
0 g
s
.43364 .54983 m .45272 .55709 L p .42457 .55296 L .541 .073 .091 r
F P
0 g
s
.40192 .55559 m .41843 .55496 L .43364 .54983 L p 0 0 0 r
F P
0 g
s
.42352 .55281 m .43364 .54983 L p .42457 .55296 L .541 .073 .091 r
F P
0 g
s
.38223 .80948 m .42308 .80271 L .39568 .79377 L p .606 .128 .092 r
F P
0 g
s
.39568 .79377 m .35102 .79668 L .38223 .80948 L p .606 .128 .092 r
F P
0 g
s
.57214 .29421 m .58611 .31869 L .60579 .30207 L p .66 .606 .784 r
F P
0 g
s
.58611 .31869 m .57214 .29421 L .55519 .31421 L p .713 .612 .743 r
F P
0 g
s
.55398 .74398 m .58446 .71839 L .58468 .72901 L p .659 .972 .837 r
F P
0 g
s
.61788 .69963 m .58468 .72901 L .58446 .71839 L p .795 .994 .874 r
F P
0 g
s
.55172 .37592 m .54661 .35442 L .53082 .36988 L p .853 .655 .634 r
F P
0 g
s
.53082 .36988 m .5361 .38982 L .55172 .37592 L p .853 .655 .634 r
F P
0 g
s
.48186 .53283 m .4705 .54225 L .46179 .53908 L p .119 0 0 r
F P
0 g
s
.5411 .29332 m .55519 .31421 L .57214 .29421 L p .686 .591 .744 r
F P
0 g
s
.55519 .31421 m .5411 .29332 L .52679 .31421 L p .728 .584 .694 r
F P
0 g
s
.52679 .31421 m .53821 .33368 L .55519 .31421 L p .728 .584 .694 r
F P
0 g
s
.50704 .77511 m .46516 .79127 L .48552 .78406 L p 0 0 0 r
F P
0 g
s
.48552 .78406 m .52064 .76594 L .50704 .77511 L p 0 0 0 r
F P
0 g
s
.54661 .35442 m .53821 .33368 L .52292 .35062 L p .81 .611 .633 r
F P
0 g
s
.52292 .35062 m .53082 .36988 L .54661 .35442 L p .81 .611 .633 r
F P
0 g
s
.30393 .61629 m .28034 .60368 L .26358 .64244 L p .885 .843 .798 r
F P
0 g
s
.28034 .60368 m .30393 .61629 L .3231 .58377 L p .83 .902 .89 r
F P
0 g
s
.57214 .29421 m .55406 .27195 L .5411 .29332 L p .686 .591 .744 r
F P
0 g
s
.53821 .33368 m .52679 .31421 L .5126 .33247 L p .769 .572 .631 r
F P
0 g
s
.5126 .33247 m .52292 .35062 L .53821 .33368 L p .769 .572 .631 r
F P
0 g
s
.49416 .52175 m .50675 .50888 L .50941 .51773 L p .226 0 .256 r
F P
0 g
s
.51771 .50256 m .50941 .51773 L .50675 .50888 L p 0 0 .123 r
F P
0 g
s
.6458 .66663 m .6675 .63064 L .67735 .63071 L p .784 .974 .687 r
F P
0 g
s
.69666 .5911 m .67735 .63071 L .6675 .63064 L p .913 .98 .761 r
F P
0 g
s
.60579 .30207 m .58731 .27571 L .57214 .29421 L p .66 .606 .784 r
F P
0 g
s
.55406 .27195 m .57214 .29421 L .58731 .27571 L p .636 .595 .791 r
F P
0 g
s
.30998 .79463 m .35102 .79668 L .32429 .77173 L p .816 .433 .329 r
F P
0 g
s
.32429 .77173 m .28263 .76558 L .30998 .79463 L p .816 .433 .329 r
F P
0 g
s
.58446 .71839 m .61107 .68951 L .61788 .69963 L p .795 .994 .874 r
F P
0 g
s
.6458 .66663 m .61788 .69963 L .61107 .68951 L p .858 .962 .87 r
F P
0 g
s
.64049 .3195 m .62269 .28862 L .60579 .30207 L p .61 .598 .814 r
F P
0 g
s
.58731 .27571 m .60579 .30207 L .62269 .28862 L p .586 .594 .827 r
F P
0 g
s
.4498 .79825 m .48552 .78406 L .46516 .79127 L p 0 0 0 r
F P
0 g
s
.46516 .79127 m .42308 .80271 L .4498 .79825 L p 0 0 0 r
F P
0 g
s
.58731 .27571 m .56434 .2523 L .55406 .27195 L p .636 .595 .791 r
F P
0 g
s
.48186 .53283 m .49416 .52175 L .50088 .5316 L p .391 .088 .327 r
F P
0 g
s
.50941 .51773 m .50088 .5316 L .49416 .52175 L p .226 0 .256 r
F P
0 g
s
.52292 .35062 m .5126 .33247 L .49999 .34622 L p .815 .544 .53 r
F P
0 g
s
.67331 .34797 m .65771 .31255 L .64049 .3195 L p .531 .556 .826 r
F P
0 g
s
.62269 .28862 m .64049 .3195 L .65771 .31255 L p .494 .556 .848 r
F P
0 g
s
.53082 .36988 m .52292 .35062 L .51091 .36327 L p .867 .591 .517 r
F P
0 g
s
.49999 .34622 m .51091 .36327 L .52292 .35062 L p .815 .544 .53 r
F P
0 g
s
.36468 .56728 m .34967 .56141 L .3231 .58377 L p .746 .92 .95 r
F P
0 g
s
.34967 .56141 m .36468 .56728 L .38921 .55434 L p .44 .862 .945 r
F P
0 g
s
.40192 .55559 m .38921 .55434 L .36468 .56728 L p .554 .914 .958 r
F P
0 g
s
.4705 .54225 m .46062 .55024 L .4466 .54538 L p .311 0 .012 r
F P
0 g
s
.70048 .38732 m .68876 .34786 L .67331 .34797 L p .411 .465 .806 r
F P
0 g
s
.65771 .31255 m .67331 .34797 L .68876 .34786 L p .332 .451 .831 r
F P
0 g
s
.5361 .38982 m .53082 .36988 L .52 .38151 L p .922 .642 .492 r
F P
0 g
s
.51091 .36327 m .52 .38151 L .53082 .36988 L p .867 .591 .517 r
F P
0 g
s
.72393 .48877 m .72363 .44494 L .71828 .4355 L p 0 .024 .54 r
F P
0 g
s
.71185 .39309 m .71828 .4355 L .72363 .44494 L p 0 0 .403 r
F P
0 g
s
.71828 .4355 m .71185 .39309 L .70048 .38732 L p .236 .301 .727 r
F P
0 g
s
.68876 .34786 m .70048 .38732 L .71185 .39309 L p .052 .222 .721 r
F P
0 g
s
.7164 .54232 m .72223 .4988 L .72393 .48877 L p 0 0 .152 r
F P
0 g
s
.72363 .44494 m .72393 .48877 L .72223 .4988 L p .818 .682 .14 r
F P
0 g
s
.53867 .41002 m .5361 .38982 L .52702 .4006 L p .973 .696 .442 r
F P
0 g
s
.52 .38151 m .52702 .4006 L .5361 .38982 L p .922 .642 .492 r
F P
0 g
s
.53862 .43008 m .53867 .41002 L .53184 .42019 L p .982 .729 .33 r
F P
0 g
s
.52702 .4006 m .53184 .42019 L .53867 .41002 L p .973 .696 .442 r
F P
0 g
s
.53614 .44964 m .53862 .43008 L .53447 .43996 L p .822 .652 .103 r
F P
0 g
s
.53184 .42019 m .53447 .43996 L .53862 .43008 L p .982 .729 .33 r
F P
0 g
s
.53156 .46838 m .53614 .44964 L .53502 .45959 L p 0 0 .185 r
F P
0 g
s
.53447 .43996 m .53502 .45959 L .53614 .44964 L p .822 .652 .103 r
F P
0 g
s
.69666 .5911 m .70773 .54953 L .7164 .54232 L p .796 .857 .409 r
F P
0 g
s
.72223 .4988 m .7164 .54232 L .70773 .54953 L p .971 .914 .577 r
F P
0 g
s
.62269 .28862 m .59911 .26066 L .58731 .27571 L p .586 .594 .827 r
F P
0 g
s
.56434 .2523 m .58731 .27571 L .59911 .26066 L p .561 .593 .843 r
F P
0 g
s
.61107 .68951 m .63293 .65777 L .6458 .66663 L p .858 .962 .87 r
F P
0 g
s
.6675 .63064 m .6458 .66663 L .63293 .65777 L p .876 .909 .849 r
F P
0 g
s
.43364 .54983 m .42352 .55281 L .40192 .55559 L p 0 0 0 r
F P
0 g
s
.38921 .55434 m .40192 .55559 L .42352 .55281 L p .126 0 0 r
F P
0 g
s
.52526 .48608 m .53156 .46838 L .53368 .47883 L p 0 0 .371 r
F P
0 g
s
.53502 .45959 m .53368 .47883 L .53156 .46838 L p 0 0 .185 r
F P
0 g
s
.3231 .58377 m .30683 .57307 L .28034 .60368 L p .83 .902 .89 r
F P
0 g
s
.30683 .57307 m .3231 .58377 L .34967 .56141 L p .691 .927 .969 r
F P
0 g
s
.4705 .54225 m .48186 .53283 L .49261 .54422 L p .503 .188 .365 r
F P
0 g
s
.50088 .5316 m .49261 .54422 L .48186 .53283 L p .391 .088 .327 r
F P
0 g
s
.51771 .50256 m .52526 .48608 L .53073 .49746 L p .224 .076 .459 r
F P
0 g
s
.53368 .47883 m .53073 .49746 L .52526 .48608 L p 0 0 .371 r
F P
0 g
s
.6675 .63064 m .68221 .59238 L .69666 .5911 L p .913 .98 .761 r
F P
0 g
s
.70773 .54953 m .69666 .5911 L .68221 .59238 L p .937 .919 .77 r
F P
0 g
s
.59911 .26066 m .57084 .23643 L .56434 .2523 L p .561 .593 .843 r
F P
0 g
s
.34407 .8118 m .38223 .80948 L .35102 .79668 L p .663 .166 .058 r
F P
0 g
s
.35102 .79668 m .30998 .79463 L .34407 .8118 L p .663 .166 .058 r
F P
0 g
s
.41467 .80854 m .4498 .79825 L .42308 .80271 L p .158 0 0 r
F P
0 g
s
.42308 .80271 m .38223 .80948 L .41467 .80854 L p .158 0 0 r
F P
0 g
s
.51091 .36327 m .49999 .34622 L .49029 .35397 L p .851 .458 .301 r
F P
0 g
s
.65771 .31255 m .63502 .27978 L .62269 .28862 L p .494 .556 .848 r
F P
0 g
s
.59911 .26066 m .62269 .28862 L .63502 .27978 L p .454 .56 .873 r
F P
0 g
s
.50941 .51773 m .51771 .50256 L .52649 .51533 L p .382 .195 .499 r
F P
0 g
s
.53073 .49746 m .52649 .51533 L .51771 .50256 L p .224 .076 .459 r
F P
0 g
s
.23192 .71365 m .26479 .72781 L .25822 .68529 L p .949 .752 .602 r
F P
0 g
s
.25822 .68529 m .22979 .66913 L .23192 .71365 L p .949 .752 .602 r
F P
0 g
s
.22979 .66913 m .25822 .68529 L .26358 .64244 L p .938 .838 .718 r
F P
0 g
s
.52849 .7453 m .55419 .72321 L .55398 .74398 L p .808 .944 .914 r
F P
0 g
s
.55398 .74398 m .52064 .76594 L .52849 .7453 L p .808 .944 .914 r
F P
0 g
s
.58446 .71839 m .55398 .74398 L .55419 .72321 L p .832 .904 .889 r
F P
0 g
s
.52 .38151 m .51091 .36327 L .50349 .37025 L p .894 .484 .214 r
F P
0 g
s
.49029 .35397 m .50349 .37025 L .51091 .36327 L p .851 .458 .301 r
F P
0 g
s
.26358 .64244 m .24103 .62586 L .22979 .66913 L p .938 .838 .718 r
F P
0 g
s
.24103 .62586 m .26358 .64244 L .28034 .60368 L p .896 .902 .822 r
F P
0 g
s
.46062 .55024 m .45272 .55709 L .43364 .54983 L p .444 0 .07 r
F P
0 g
s
.24723 .75476 m .28263 .76558 L .26479 .72781 L p .931 .636 .461 r
F P
0 g
s
.26479 .72781 m .23192 .71365 L .24723 .75476 L p .931 .636 .461 r
F P
0 g
s
.55419 .72321 m .57735 .69837 L .58446 .71839 L p .832 .904 .889 r
F P
0 g
s
.61107 .68951 m .58446 .71839 L .57735 .69837 L p .836 .86 .862 r
F P
0 g
s
.46062 .55024 m .4705 .54225 L .48506 .55572 L p .588 .262 .385 r
F P
0 g
s
.49261 .54422 m .48506 .55572 L .4705 .54225 L p .503 .188 .365 r
F P
0 g
s
.68876 .34786 m .66875 .31057 L .65771 .31255 L p .332 .451 .831 r
F P
0 g
s
.63502 .27978 m .65771 .31255 L .66875 .31057 L p .231 .435 .855 r
F P
0 g
s
.5011 .76445 m .52849 .7453 L .52064 .76594 L p .754 .968 .93 r
F P
0 g
s
.52064 .76594 m .48552 .78406 L .5011 .76445 L p .754 .968 .93 r
F P
0 g
s
.50088 .5316 m .50941 .51773 L .52133 .53235 L p .488 .278 .52 r
F P
0 g
s
.52649 .51533 m .52133 .53235 L .50941 .51773 L p .382 .195 .499 r
F P
0 g
s
.63293 .65777 m .64927 .62372 L .6675 .63064 L p .876 .909 .849 r
F P
0 g
s
.68221 .59238 m .6675 .63064 L .64927 .62372 L p .869 .853 .824 r
F P
0 g
s
.52702 .4006 m .52 .38151 L .51536 .38803 L p .886 .474 .054 r
F P
0 g
s
.50349 .37025 m .51536 .38803 L .52 .38151 L p .894 .484 .214 r
F P
0 g
s
.63502 .27978 m .60626 .25068 L .59911 .26066 L p .454 .56 .873 r
F P
0 g
s
.57084 .23643 m .59911 .26066 L .60626 .25068 L p .412 .57 .9 r
F P
0 g
s
.53184 .42019 m .52702 .4006 L .52555 .40705 L p .721 .367 0 r
F P
0 g
s
.51536 .38803 m .52555 .40705 L .52702 .4006 L p .886 .474 .054 r
F P
0 g
s
.71185 .39309 m .69629 .35213 L .68876 .34786 L p .052 .222 .721 r
F P
0 g
s
.66875 .31057 m .68876 .34786 L .69629 .35213 L p 0 .108 .662 r
F P
0 g
s
.57735 .69837 m .59723 .67107 L .61107 .68951 L p .836 .86 .862 r
F P
0 g
s
.63293 .65777 m .61107 .68951 L .59723 .67107 L p .829 .818 .839 r
F P
0 g
s
.53447 .43996 m .53184 .42019 L .53382 .42702 L p 0 0 .446 r
F P
0 g
s
.52555 .40705 m .53382 .42702 L .53184 .42019 L p .721 .367 0 r
F P
0 g
s
.28034 .60368 m .26449 .58836 L .24103 .62586 L p .896 .902 .822 r
F P
0 g
s
.26449 .58836 m .28034 .60368 L .30683 .57307 L p .805 .939 .916 r
F P
0 g
s
.72363 .44494 m .71382 .40172 L .71185 .39309 L p 0 0 .403 r
F P
0 g
s
.69629 .35213 m .71185 .39309 L .71382 .40172 L p .752 .422 0 r
F P
0 g
s
.4729 .78058 m .5011 .76445 L .48552 .78406 L p .658 .963 .928 r
F P
0 g
s
.48552 .78406 m .4498 .79825 L .4729 .78058 L p .658 .963 .928 r
F P
0 g
s
.27419 .78809 m .30998 .79463 L .28263 .76558 L p .865 .463 .27 r
F P
0 g
s
.28263 .76558 m .24723 .75476 L .27419 .78809 L p .865 .463 .27 r
F P
0 g
s
.49261 .54422 m .50088 .5316 L .51562 .54848 L p .566 .339 .531 r
F P
0 g
s
.52133 .53235 m .51562 .54848 L .50088 .5316 L p .488 .278 .52 r
F P
0 g
s
.53502 .45959 m .53447 .43996 L .54003 .44764 L p 0 .054 .571 r
F P
0 g
s
.53382 .42702 m .54003 .44764 L .53447 .43996 L p 0 0 .446 r
F P
0 g
s
.72223 .4988 m .7187 .45505 L .72363 .44494 L p .818 .682 .14 r
F P
0 g
s
.71382 .40172 m .72363 .44494 L .7187 .45505 L p .986 .761 .366 r
F P
0 g
s
.38921 .55434 m .38092 .55178 L .34967 .56141 L p .44 .862 .945 r
F P
0 g
s
.42352 .55281 m .41672 .55475 L .38921 .55434 L p .126 0 0 r
F P
0 g
s
.38092 .55178 m .38921 .55434 L .41672 .55475 L p .227 0 0 r
F P
0 g
s
.34967 .56141 m .34038 .55395 L .30683 .57307 L p .691 .927 .969 r
F P
0 g
s
.34038 .55395 m .34967 .56141 L .38092 .55178 L p .333 .799 .931 r
F P
0 g
s
.70773 .54953 m .71014 .50704 L .72223 .4988 L p .971 .914 .577 r
F P
0 g
s
.7187 .45505 m .72223 .4988 L .71014 .50704 L p .983 .856 .636 r
F P
0 g
s
.60626 .25068 m .5728 .22607 L .57084 .23643 L p .412 .57 .9 r
F P
0 g
s
.53368 .47883 m .53502 .45959 L .54414 .46862 L p .213 .19 .615 r
F P
0 g
s
.54003 .44764 m .54414 .46862 L .53502 .45959 L p 0 .054 .571 r
F P
0 g
s
.68221 .59238 m .68941 .5527 L .70773 .54953 L p .937 .919 .77 r
F P
0 g
s
.71014 .50704 m .70773 .54953 L .68941 .5527 L p .919 .849 .758 r
F P
0 g
s
.50349 .37025 m .49029 .35397 L .48459 .35479 L p .611 .079 0 r
F P
0 g
s
.45272 .55709 m .46062 .55024 L .47861 .56631 L p .656 .32 .391 r
F P
0 g
s
.48506 .55572 m .47861 .56631 L .46062 .55024 L p .588 .262 .385 r
F P
0 g
s
.38133 .81507 m .41467 .80854 L .38223 .80948 L p .269 0 0 r
F P
0 g
s
.38223 .80948 m .34407 .8118 L .38133 .81507 L p .269 0 0 r
F P
0 g
s
.53073 .49746 m .53368 .47883 L .54617 .48968 L p .361 .279 .627 r
F P
0 g
s
.54414 .46862 m .54617 .48968 L .53368 .47883 L p .213 .19 .615 r
F P
0 g
s
.59723 .67107 m .61315 .64167 L .63293 .65777 L p .829 .818 .839 r
F P
0 g
s
.64927 .62372 m .63293 .65777 L .61315 .64167 L p .815 .778 .818 r
F P
0 g
s
.66875 .31057 m .64138 .27658 L .63502 .27978 L p .231 .435 .855 r
F P
0 g
s
.60626 .25068 m .63502 .27978 L .64138 .27658 L p .108 .418 .865 r
F P
0 g
s
.41672 .55475 m .42352 .55281 L .44717 .56313 L p .616 .132 .08 r
F P
0 g
s
.45272 .55709 m .44717 .56313 L .42352 .55281 L p .541 .073 .091 r
F P
0 g
s
.52649 .51533 m .53073 .49746 L .54626 .51059 L p .462 .342 .63 r
F P
0 g
s
.54617 .48968 m .54626 .51059 L .53073 .49746 L p .361 .279 .627 r
F P
0 g
s
.48506 .55572 m .49261 .54422 L .50971 .56374 L p .629 .39 .536 r
F P
0 g
s
.51562 .54848 m .50971 .56374 L .49261 .54422 L p .566 .339 .531 r
F P
0 g
s
.64927 .62372 m .65954 .58802 L .68221 .59238 L p .869 .853 .824 r
F P
0 g
s
.68941 .5527 m .68221 .59238 L .65954 .58802 L p .852 .802 .802 r
F P
0 g
s
.51536 .38803 m .50349 .37025 L .50153 .3707 L p 0 .033 .568 r
F P
0 g
s
.50153 .3707 m .50349 .37025 L p .48723 .35695 L .611 .079 0 r
F P
0 g
s
.50153 .3707 m .50535 .36445 L p .515 .38363 L .263 .448 .855 r
F P
0 g
s
.51751 .38864 m .50153 .3707 L p .515 .38363 L .263 .448 .855 r
F P
0 g
s
.48459 .35479 m .50153 .3707 L p .48723 .35695 L .611 .079 0 r
F P
0 g
s
.44482 .79369 m .4729 .78058 L .4498 .79825 L p .522 .917 .9 r
F P
0 g
s
.4498 .79825 m .41467 .80854 L .44482 .79369 L p .522 .917 .9 r
F P
0 g
s
.30683 .57307 m .29776 .56063 L .26449 .58836 L p .805 .939 .916 r
F P
0 g
s
.29776 .56063 m .30683 .57307 L .34038 .55395 L p .617 .916 .979 r
F P
0 g
s
.52133 .53235 m .52649 .51533 L .54458 .53115 L p .537 .391 .63 r
F P
0 g
s
.54626 .51059 m .54458 .53115 L .52649 .51533 L p .462 .342 .63 r
F P
0 g
s
.31003 .81003 m .34407 .8118 L .30998 .79463 L p .702 .183 0 r
F P
0 g
s
.30998 .79463 m .27419 .78809 L .31003 .81003 L p .702 .183 0 r
F P
0 g
s
.69629 .35213 m .67229 .31387 L .66875 .31057 L p 0 .108 .662 r
F P
0 g
s
.64138 .27658 m .66875 .31057 L .67229 .31387 L p 0 0 .504 r
F P
0 g
s
.52555 .40705 m .51536 .38803 L .51751 .38864 L p 0 .16 .701 r
F P
0 g
s
.50153 .3707 m .51751 .38864 L .51536 .38803 L p 0 .033 .568 r
F P
0 g
s
.64138 .27658 m .6079 .24694 L .60626 .25068 L p .108 .418 .865 r
F P
0 g
s
.5728 .22607 m .60626 .25068 L .6079 .24694 L p 0 .396 .843 r
F P
0 g
s
.51562 .54848 m .52133 .53235 L .54135 .55118 L p .596 .431 .628 r
F P
0 g
s
.54458 .53115 m .54135 .55118 L .52133 .53235 L p .537 .391 .63 r
F P
0 g
s
.61315 .64167 m .62457 .61062 L .64927 .62372 L p .815 .778 .818 r
F P
0 g
s
.65954 .58802 m .64927 .62372 L .62457 .61062 L p .797 .743 .802 r
F P
0 g
s
.52958 .71524 m .54776 .69409 L .55419 .72321 L p .835 .823 .837 r
F P
0 g
s
.55419 .72321 m .52849 .7453 L .52958 .71524 L p .835 .823 .837 r
F P
0 g
s
.57735 .69837 m .55419 .72321 L .54776 .69409 L p .82 .782 .817 r
F P
0 g
s
.54776 .69409 m .56401 .67103 L .57735 .69837 L p .82 .782 .817 r
F P
0 g
s
.59723 .67107 m .57735 .69837 L .56401 .67103 L p .802 .746 .8 r
F P
0 g
s
.47861 .56631 m .48506 .55572 L .50395 .5782 L p .684 .434 .538 r
F P
0 g
s
.50971 .56374 m .50395 .5782 L .48506 .55572 L p .629 .39 .536 r
F P
0 g
s
.44717 .56313 m .45272 .55709 L .4736 .57621 L p .717 .368 .386 r
F P
0 g
s
.47861 .56631 m .4736 .57621 L .45272 .55709 L p .656 .32 .391 r
F P
0 g
s
.53382 .42702 m .52555 .40705 L .53201 .4084 L p .086 .26 .746 r
F P
0 g
s
.51751 .38864 m .53201 .4084 L .52555 .40705 L p 0 .16 .701 r
F P
0 g
s
.71382 .40172 m .69493 .3604 L .69629 .35213 L p .752 .422 0 r
F P
0 g
s
.67229 .31387 m .69629 .35213 L .69493 .3604 L p .911 .522 .11 r
F P
0 g
s
.51003 .73437 m .52958 .71524 L .52849 .7453 L p .842 .867 .861 r
F P
0 g
s
.52849 .7453 m .5011 .76445 L .51003 .73437 L p .842 .867 .861 r
F P
0 g
s
.54003 .44764 m .53382 .42702 L .54458 .4297 L p .255 .328 .747 r
F P
0 g
s
.53201 .4084 m .54458 .4297 L .53382 .42702 L p .086 .26 .746 r
F P
0 g
s
.56401 .67103 m .57778 .64627 L .59723 .67107 L p .802 .746 .8 r
F P
0 g
s
.61315 .64167 m .59723 .67107 L .57778 .64627 L p .782 .713 .787 r
F P
0 g
s
.6079 .24694 m .56993 .22245 L .5728 .22607 L p 0 .396 .843 r
F P
0 g
s
.7187 .45505 m .70599 .41232 L .71382 .40172 L p .986 .761 .366 r
F P
0 g
s
.69493 .3604 m .71382 .40172 L .70599 .41232 L p .979 .722 .473 r
F P
0 g
s
.38092 .55178 m .3775 .54852 L .34038 .55395 L p .333 .799 .931 r
F P
0 g
s
.41672 .55475 m .41356 .55617 L .38092 .55178 L p .227 0 0 r
F P
0 g
s
.3775 .54852 m .38092 .55178 L .41356 .55617 L p .279 0 0 r
F P
0 g
s
.50971 .56374 m .51562 .54848 L .53684 .57058 L p .646 .467 .628 r
F P
0 g
s
.54135 .55118 m .53684 .57058 L .51562 .54848 L p .596 .431 .628 r
F P
0 g
s
.71014 .50704 m .70382 .46473 L .7187 .45505 L p .983 .856 .636 r
F P
0 g
s
.70599 .41232 m .7187 .45505 L .70382 .46473 L p .945 .783 .651 r
F P
0 g
s
.54414 .46862 m .54003 .44764 L .5549 .45224 L p .373 .377 .735 r
F P
0 g
s
.54458 .4297 m .5549 .45224 L .54003 .44764 L p .255 .328 .747 r
F P
0 g
s
.68941 .5527 m .68882 .51253 L .71014 .50704 L p .919 .849 .758 r
F P
0 g
s
.70382 .46473 m .71014 .50704 L .68882 .51253 L p .888 .786 .742 r
F P
0 g
s
.50153 .3707 m .48459 .35479 L .48356 .34848 L p .147 .43 .868 r
F P
0 g
s
.54617 .48968 m .54414 .46862 L .5627 .4757 L p .458 .415 .721 r
F P
0 g
s
.5549 .45224 m .5627 .4757 L .54414 .46862 L p .373 .377 .735 r
F P
0 g
s
.41356 .55617 m .41672 .55475 L .44423 .56876 L p .673 .168 .035 r
F P
0 g
s
.44717 .56313 m .44423 .56876 L .41672 .55475 L p .616 .132 .08 r
F P
0 g
s
.65954 .58802 m .66334 .55138 L .68941 .5527 L p .852 .802 .802 r
F P
0 g
s
.68882 .51253 m .68941 .5527 L .66334 .55138 L p .829 .757 .783 r
F P
0 g
s
.48972 .75139 m .51003 .73437 L .5011 .76445 L p .837 .912 .888 r
F P
0 g
s
.5011 .76445 m .4729 .78058 L .48972 .75139 L p .837 .912 .888 r
F P
0 g
s
.41776 .80386 m .44482 .79369 L .41467 .80854 L p .365 .836 .853 r
F P
0 g
s
.41467 .80854 m .38133 .81507 L .41776 .80386 L p .365 .836 .853 r
F P
0 g
s
.57778 .64627 m .58862 .62007 L .61315 .64167 L p .782 .713 .787 r
F P
0 g
s
.62457 .61062 m .61315 .64167 L .58862 .62007 L p .76 .685 .778 r
F P
0 g
s
.54626 .51059 m .54617 .48968 L .56784 .49973 L p .524 .446 .71 r
F P
0 g
s
.5627 .4757 m .56784 .49973 L .54617 .48968 L p .458 .415 .721 r
F P
0 g
s
.34038 .55395 m .33738 .54568 L .29776 .56063 L p .617 .916 .979 r
F P
0 g
s
.33738 .54568 m .34038 .55395 L .3775 .54852 L p .249 .736 .924 r
F P
0 g
s
.20778 .69577 m .23192 .71365 L .22979 .66913 L p .991 .82 .577 r
F P
0 g
s
.22979 .66913 m .21054 .64971 L .20778 .69577 L p .991 .82 .577 r
F P
0 g
s
.21054 .64971 m .22979 .66913 L .24103 .62586 L p .96 .91 .723 r
F P
0 g
s
.67229 .31387 m .64095 .27948 L .64138 .27658 L p 0 0 .504 r
F P
0 g
s
.6079 .24694 m .64138 .27658 L .64095 .27948 L p .67 .143 0 r
F P
0 g
s
.54458 .53115 m .54626 .51059 L .57028 .52401 L p .577 .475 .701 r
F P
0 g
s
.56784 .49973 m .57028 .52401 L .54626 .51059 L p .524 .446 .71 r
F P
0 g
s
.4736 .57621 m .47861 .56631 L .4986 .59198 L p .734 .475 .537 r
F P
0 g
s
.50395 .5782 m .4986 .59198 L .47861 .56631 L p .684 .434 .538 r
F P
0 g
s
.62457 .61062 m .63107 .57842 L .65954 .58802 L p .797 .743 .802 r
F P
0 g
s
.66334 .55138 m .65954 .58802 L .63107 .57842 L p .778 .712 .79 r
F P
0 g
s
.35099 .81811 m .38133 .81507 L .34407 .8118 L p .337 0 0 r
F P
0 g
s
.34407 .8118 m .31003 .81003 L .35099 .81811 L p .337 0 0 r
F P
0 g
s
.24103 .62586 m .22769 .60672 L .21054 .64971 L p .96 .91 .723 r
F P
0 g
s
.22769 .60672 m .24103 .62586 L .26449 .58836 L p .884 .96 .843 r
F P
0 g
s
.50395 .5782 m .50971 .56374 L .53131 .58927 L p .691 .502 .627 r
F P
0 g
s
.53684 .57058 m .53131 .58927 L .50971 .56374 L p .646 .467 .628 r
F P
0 g
s
.21974 .74 m .24723 .75476 L .23192 .71365 L p .976 .683 .397 r
F P
0 g
s
.23192 .71365 m .20778 .69577 L .21974 .74 L p .976 .683 .397 r
F P
0 g
s
.54135 .55118 m .54458 .53115 L .57005 .54824 L p .621 .502 .695 r
F P
0 g
s
.57028 .52401 m .57005 .54824 L .54458 .53115 L p .577 .475 .701 r
F P
0 g
s
.48356 .34848 m .50535 .36445 L .50153 .3707 L p .147 .43 .868 r
F P
0 g
s
.44423 .56876 m .44717 .56313 L .47023 .5857 L p .774 .411 .368 r
F P
0 g
s
.4736 .57621 m .47023 .5857 L .44717 .56313 L p .717 .368 .386 r
F P
0 g
s
.53684 .57058 m .54135 .55118 L .56728 .57212 L p .661 .528 .692 r
F P
0 g
s
.57005 .54824 m .56728 .57212 L .54135 .55118 L p .621 .502 .695 r
F P
0 g
s
.58862 .62007 m .59614 .59273 L .62457 .61062 L p .76 .685 .778 r
F P
0 g
s
.63107 .57842 m .62457 .61062 L .59614 .59273 L p .738 .659 .772 r
F P
0 g
s
.26449 .58836 m .25741 .57136 L .22769 .60672 L p .884 .96 .843 r
F P
0 g
s
.25741 .57136 m .26449 .58836 L .29776 .56063 L p .751 .961 .936 r
F P
0 g
s
.46928 .76631 m .48972 .75139 L .4729 .78058 L p .81 .952 .912 r
F P
0 g
s
.4729 .78058 m .44482 .79369 L .46928 .76631 L p .81 .952 .912 r
F P
0 g
s
.24521 .77767 m .27419 .78809 L .24723 .75476 L p .895 .476 .163 r
F P
0 g
s
.24723 .75476 m .21974 .74 L .24521 .77767 L p .895 .476 .163 r
F P
0 g
s
.53533 .65983 m .54587 .63942 L .56401 .67103 L p .794 .692 .753 r
F P
0 g
s
.56401 .67103 m .54776 .69409 L .53533 .65983 L p .794 .692 .753 r
F P
0 g
s
.57778 .64627 m .56401 .67103 L .54587 .63942 L p .767 .66 .745 r
F P
0 g
s
.4986 .59198 m .50395 .5782 L .52504 .60721 L p .732 .536 .627 r
F P
0 g
s
.53131 .58927 m .52504 .60721 L .50395 .5782 L p .691 .502 .627 r
F P
0 g
s
.69493 .3604 m .66779 .32221 L .67229 .31387 L p .911 .522 .11 r
F P
0 g
s
.64095 .27948 m .67229 .31387 L .66779 .32221 L p .91 .522 .262 r
F P
0 g
s
.53201 .4084 m .51751 .38864 L .52636 .38315 L p .356 .463 .832 r
F P
0 g
s
.50535 .36445 m .52636 .38315 L .51751 .38864 L p .263 .448 .855 r
F P
0 g
s
.53131 .58927 m .53684 .57058 L .56216 .59541 L p .697 .555 .69 r
F P
0 g
s
.56728 .57212 m .56216 .59541 L .53684 .57058 L p .661 .528 .692 r
F P
0 g
s
.54587 .63942 m .55492 .6179 L .57778 .64627 L p .767 .66 .745 r
F P
0 g
s
.58862 .62007 m .57778 .64627 L .55492 .6179 L p .74 .632 .74 r
F P
0 g
s
.64095 .27948 m .60375 .24996 L .6079 .24694 L p .67 .143 0 r
F P
0 g
s
.56993 .22245 m .6079 .24694 L .60375 .24996 L p .72 .189 0 r
F P
0 g
s
.52364 .67906 m .53533 .65983 L .54776 .69409 L p .82 .729 .764 r
F P
0 g
s
.54776 .69409 m .52958 .71524 L .52364 .67906 L p .82 .729 .764 r
F P
0 g
s
.55492 .6179 m .56216 .59541 L .58862 .62007 L p .74 .632 .74 r
F P
0 g
s
.59614 .59273 m .58862 .62007 L .56216 .59541 L p .712 .607 .738 r
F P
0 g
s
.47023 .5857 m .4736 .57621 L .49391 .60523 L p .783 .516 .532 r
F P
0 g
s
.4986 .59198 m .49391 .60523 L .4736 .57621 L p .734 .475 .537 r
F P
0 g
s
.54458 .4297 m .53201 .4084 L .54584 .40438 L p .431 .478 .808 r
F P
0 g
s
.52636 .38315 m .54584 .40438 L .53201 .4084 L p .356 .463 .832 r
F P
0 g
s
.51115 .69705 m .52364 .67906 L .52958 .71524 L p .846 .771 .779 r
F P
0 g
s
.52958 .71524 m .51003 .73437 L .51115 .69705 L p .846 .771 .779 r
F P
0 g
s
.63107 .57842 m .6324 .54567 L .66334 .55138 L p .778 .712 .79 r
F P
0 g
s
.66054 .5146 m .66334 .55138 L .6324 .54567 L p .757 .684 .781 r
F P
0 g
s
.66334 .55138 m .66054 .5146 L .68882 .51253 L p .829 .757 .783 r
F P
0 g
s
.52504 .60721 m .53131 .58927 L .55492 .6179 L p .732 .584 .69 r
F P
0 g
s
.56216 .59541 m .55492 .6179 L .53131 .58927 L p .697 .555 .69 r
F P
0 g
s
.70599 .41232 m .68463 .37183 L .69493 .3604 L p .979 .722 .473 r
F P
0 g
s
.66779 .32221 m .69493 .3604 L .68463 .37183 L p .927 .663 .519 r
F P
0 g
s
.59614 .59273 m .60004 .56463 L .63107 .57842 L p .738 .659 .772 r
F P
0 g
s
.6324 .54567 m .63107 .57842 L .60004 .56463 L p .715 .637 .769 r
F P
0 g
s
.68048 .47286 m .68882 .51253 L .66054 .5146 L p .805 .718 .769 r
F P
0 g
s
.68882 .51253 m .68048 .47286 L .70382 .46473 L p .888 .786 .742 r
F P
0 g
s
.60375 .24996 m .56246 .22609 L .56993 .22245 L p .72 .189 0 r
F P
0 g
s
.56216 .59541 m .56728 .57212 L .59614 .59273 L p .712 .607 .738 r
F P
0 g
s
.56728 .57212 m .57005 .54824 L .60004 .56463 L p .683 .584 .738 r
F P
0 g
s
.60004 .56463 m .59614 .59273 L .56728 .57212 L p .683 .584 .738 r
F P
0 g
s
.57005 .54824 m .57028 .52401 L .60013 .53618 L p .652 .563 .742 r
F P
0 g
s
.60013 .53618 m .60004 .56463 L .57005 .54824 L p .652 .563 .742 r
F P
0 g
s
.68902 .42374 m .70382 .46473 L .68048 .47286 L p .854 .733 .728 r
F P
0 g
s
.70382 .46473 m .68902 .42374 L .70599 .41232 L p .945 .783 .651 r
F P
0 g
s
.5549 .45224 m .54458 .4297 L .56311 .42785 L p .49 .493 .787 r
F P
0 g
s
.54584 .40438 m .56311 .42785 L .54458 .4297 L p .431 .478 .808 r
F P
0 g
s
.68463 .37183 m .70599 .41232 L .68902 .42374 L p .897 .719 .652 r
F P
0 g
s
.29776 .56063 m .29655 .5474 L .25741 .57136 L p .751 .961 .936 r
F P
0 g
s
.29655 .5474 m .29776 .56063 L .33738 .54568 L p .531 .885 .981 r
F P
0 g
s
.41356 .55617 m .41421 .55759 L .3775 .54852 L p .279 0 0 r
F P
0 g
s
.41704 .55825 m .444 .57438 L p .41421 .55759 L .706 .178 0 r
F P
0 g
s
.444 .57438 m .44425 .57498 L p .41421 .55759 L .706 .178 0 r
F P
0 g
s
.44425 .57498 m .44645 .58039 L .4261 .566 L p .706 .178 0 r
F P
0 g
s
.4261 .566 m .41421 .55759 L p .44425 .57498 L .706 .178 0 r
F P
0 g
s
.41864 .55955 m .41421 .55759 L .4261 .566 L p .691 .151 0 r
F P
0 g
s
.4261 .566 m .44645 .58039 L p .41864 .55955 L .691 .151 0 r
F P
0 g
s
.41421 .55759 m .41864 .55955 L .41147 .55695 L p .276 0 0 r
F P
0 g
s
.37918 .54525 m .3775 .54852 L .41421 .55759 L p .276 0 0 r
F P
0 g
s
.41147 .55695 m .37918 .54525 L p .41421 .55759 L .276 0 0 r
F P
0 g
s
.41421 .55759 m .41356 .55617 L .41704 .55825 L p .706 .178 0 r
F P
0 g
s
.38596 .54266 m .38201 .54417 L p .41864 .55955 L 0 .338 .727 r
F P
0 g
s
.38201 .54417 m .37918 .54525 L .39786 .55202 L p 0 .338 .727 r
F P
0 g
s
.39786 .55202 m .41864 .55955 L p .38201 .54417 L 0 .338 .727 r
F P
0 g
s
.44423 .56876 m .444 .57438 L .41356 .55617 L p .673 .168 .035 r
F P
0 g
s
.57028 .52401 m .56784 .49973 L .59635 .50781 L p .619 .544 .748 r
F P
0 g
s
.59635 .50781 m .60013 .53618 L .57028 .52401 L p .619 .544 .748 r
F P
0 g
s
.56784 .49973 m .5627 .4757 L .58877 .47999 L p .582 .526 .757 r
F P
0 g
s
.58877 .47999 m .59635 .50781 L .56784 .49973 L p .582 .526 .757 r
F P
0 g
s
.5627 .4757 m .5549 .45224 L .57757 .45319 L p .54 .509 .77 r
F P
0 g
s
.56311 .42785 m .57757 .45319 L .5549 .45224 L p .49 .493 .787 r
F P
0 g
s
.55492 .6179 m .54587 .63942 L .52504 .60721 L p .732 .584 .69 r
F P
0 g
s
.57757 .45319 m .58877 .47999 L .5627 .4757 L p .54 .509 .77 r
F P
0 g
s
.50535 .36445 m .48356 .34848 L .48742 .33559 L p .456 .541 .855 r
F P
0 g
s
.3775 .54852 m .37918 .54525 L .33738 .54568 L p .249 .736 .924 r
F P
0 g
s
.49391 .60523 m .4986 .59198 L .51828 .62441 L p .773 .572 .627 r
F P
0 g
s
.52504 .60721 m .51828 .62441 L .4986 .59198 L p .732 .536 .627 r
F P
0 g
s
.28152 .80468 m .31003 .81003 L .27419 .78809 L p .706 .168 0 r
F P
0 g
s
.27419 .78809 m .24521 .77767 L .28152 .80468 L p .706 .168 0 r
F P
0 g
s
.39267 .81127 m .41776 .80386 L .38133 .81507 L p .215 .739 .804 r
F P
0 g
s
.38133 .81507 m .35099 .81811 L .39267 .81127 L p .215 .739 .804 r
F P
0 g
s
.51828 .62441 m .52504 .60721 L .54587 .63942 L p .765 .616 .693 r
F P
0 g
s
.54587 .63942 m .53533 .65983 L .51828 .62441 L p .765 .616 .693 r
F P
0 g
s
.60004 .56463 m .60013 .53618 L .6324 .54567 L p .715 .637 .769 r
F P
0 g
s
.49822 .71378 m .51115 .69705 L .51003 .73437 L p .869 .82 .798 r
F P
0 g
s
.51003 .73437 m .48972 .75139 L .49822 .71378 L p .869 .82 .798 r
F P
0 g
s
.49072 1.15314 m .55883 1.13352 L .51959 1.07843 L p .721 .562 .673 r
F P
0 g
s
.51959 1.07843 m .45614 1.09331 L .49072 1.15314 L p .721 .562 .673 r
F P
0 g
s
.5807 1.05701 m .51959 1.07843 L .55883 1.13352 L p .685 .532 .673 r
F P
0 g
s
.45614 1.09331 m .51959 1.07843 L .48169 1.02357 L p .757 .638 .729 r
F P
0 g
s
.51959 1.07843 m .5807 1.05701 L .53625 1.00726 L p .727 .61 .726 r
F P
0 g
s
.53625 1.00726 m .48169 1.02357 L .51959 1.07843 L p .727 .61 .726 r
F P
0 g
s
.444 .57438 m .44423 .56876 L .46862 .59506 L p .83 .449 .331 r
F P
0 g
s
.47023 .5857 m .46862 .59506 L .44423 .56876 L p .774 .411 .368 r
F P
0 g
s
.44933 .77917 m .46928 .76631 L .44482 .79369 L p .748 .974 .924 r
F P
0 g
s
.44482 .79369 m .41776 .80386 L .44933 .77917 L p .748 .974 .924 r
F P
0 g
s
.55883 1.13352 m .62321 1.10708 L .5807 1.05701 L p .685 .532 .673 r
F P
0 g
s
.63747 1.02928 m .5807 1.05701 L .62321 1.10708 L p .646 .504 .675 r
F P
0 g
s
.5807 1.05701 m .63747 1.02928 L .5881 .98515 L p .696 .584 .726 r
F P
0 g
s
.5881 .98515 m .53625 1.00726 L .5807 1.05701 L p .696 .584 .726 r
F P
0 g
s
.66779 .32221 m .63366 .28828 L .64095 .27948 L p .91 .522 .262 r
F P
0 g
s
.60375 .24996 m .64095 .27948 L .63366 .28828 L p .861 .489 .341 r
F P
0 g
s
.51127 .6409 m .51828 .62441 L .53533 .65983 L p .799 .651 .698 r
F P
0 g
s
.53533 .65983 m .52364 .67906 L .51127 .6409 L p .799 .651 .698 r
F P
0 g
s
.62849 .51297 m .6324 .54567 L .60013 .53618 L p .69 .617 .769 r
F P
0 g
s
.6324 .54567 m .62849 .51297 L .66054 .5146 L p .757 .684 .781 r
F P
0 g
s
.60013 .53618 m .59635 .50781 L .62849 .51297 L p .69 .617 .769 r
F P
0 g
s
.48169 1.02357 m .53625 1.00726 L .49397 .96243 L p .766 .69 .779 r
F P
0 g
s
.53625 1.00726 m .5881 .98515 L .53827 .94587 L p .742 .664 .773 r
F P
0 g
s
.53827 .94587 m .49397 .96243 L .53625 1.00726 L p .742 .664 .773 r
F P
0 g
s
.46862 .59506 m .47023 .5857 L .49003 .61812 L p .834 .559 .523 r
F P
0 g
s
.49391 .60523 m .49003 .61812 L .47023 .5857 L p .783 .516 .532 r
F P
0 g
s
.51828 .62441 m .51127 .6409 L .49391 .60523 L p .773 .572 .627 r
F P
0 g
s
.52636 .38315 m .50535 .36445 L .51464 .35207 L p .501 .544 .832 r
F P
0 g
s
.48742 .33559 m .51464 .35207 L .50535 .36445 L p .456 .541 .855 r
F P
0 g
s
.42104 1.16576 m .49072 1.15314 L .45614 1.09331 L p .757 .593 .674 r
F P
0 g
s
.45614 1.09331 m .39244 1.10157 L .42104 1.16576 L p .757 .593 .674 r
F P
0 g
s
.39244 1.10157 m .45614 1.09331 L .42629 1.03397 L p .786 .669 .735 r
F P
0 g
s
.48169 1.02357 m .42629 1.03397 L .45614 1.09331 L p .757 .638 .729 r
F P
0 g
s
.65125 .4785 m .66054 .5146 L .62849 .51297 L p .735 .659 .775 r
F P
0 g
s
.66054 .5146 m .65125 .4785 L .68048 .47286 L p .805 .718 .769 r
F P
0 g
s
.42629 1.03397 m .48169 1.02357 L .44867 .97401 L p .789 .721 .788 r
F P
0 g
s
.49397 .96243 m .44867 .97401 L .48169 1.02357 L p .766 .69 .779 r
F P
0 g
s
.49003 .61812 m .49391 .60523 L .51127 .6409 L p .815 .612 .628 r
F P
0 g
s
.4852 .72928 m .49822 .71378 L .48972 .75139 L p .885 .876 .821 r
F P
0 g
s
.48972 .75139 m .46928 .76631 L .4852 .72928 L p .885 .876 .821 r
F P
0 g
s
.33738 .54568 m .34099 .53745 L .29655 .5474 L p .531 .885 .981 r
F P
0 g
s
.34099 .53745 m .33738 .54568 L .37918 .54525 L p .198 .683 .927 r
F P
0 g
s
.63547 .95755 m .5881 .98515 L .63747 1.02928 L p .664 .561 .728 r
F P
0 g
s
.5881 .98515 m .63547 .95755 L .57998 .92448 L p .718 .64 .77 r
F P
0 g
s
.57998 .92448 m .53827 .94587 L .5881 .98515 L p .718 .64 .77 r
F P
0 g
s
.50423 .65673 m .51127 .6409 L .52364 .67906 L p .834 .691 .705 r
F P
0 g
s
.52364 .67906 m .51115 .69705 L .50423 .65673 L p .834 .691 .705 r
F P
0 g
s
.59635 .50781 m .58877 .47999 L .61945 .48097 L p .665 .599 .772 r
F P
0 g
s
.61945 .48097 m .62849 .51297 L .59635 .50781 L p .665 .599 .772 r
F P
0 g
s
.52685 1.20791 m .5958 1.18372 L .55883 1.13352 L p .679 .48 .61 r
F P
0 g
s
.55883 1.13352 m .49072 1.15314 L .52685 1.20791 L p .679 .48 .61 r
F P
0 g
s
.62321 1.10708 m .55883 1.13352 L .5958 1.18372 L p .633 .445 .61 r
F P
0 g
s
.66473 .43468 m .68048 .47286 L .65125 .4785 L p .78 .685 .759 r
F P
0 g
s
.68048 .47286 m .66473 .43468 L .68902 .42374 L p .854 .733 .728 r
F P
0 g
s
.68463 .37183 m .65558 .33474 L .66779 .32221 L p .927 .663 .519 r
F P
0 g
s
.63366 .28828 m .66779 .32221 L .65558 .33474 L p .871 .609 .54 r
F P
0 g
s
.32481 .81804 m .35099 .81811 L .31003 .81003 L p .36 0 0 r
F P
0 g
s
.31003 .81003 m .28152 .80468 L .32481 .81804 L p .36 0 0 r
F P
0 g
s
.54584 .40438 m .52636 .38315 L .54106 .37207 L p .541 .55 .813 r
F P
0 g
s
.51464 .35207 m .54106 .37207 L .52636 .38315 L p .501 .544 .832 r
F P
0 g
s
.45512 1.22513 m .52685 1.20791 L .49072 1.15314 L p .721 .514 .61 r
F P
0 g
s
.49072 1.15314 m .42104 1.16576 L .45512 1.22513 L p .721 .514 .61 r
F P
0 g
s
.63366 .28828 m .59415 .25955 L .60375 .24996 L p .861 .489 .341 r
F P
0 g
s
.56246 .22609 m .60375 .24996 L .59415 .25955 L p .803 .447 .383 r
F P
0 g
s
.62849 .51297 m .61945 .48097 L .65125 .4785 L p .735 .659 .775 r
F P
0 g
s
.58877 .47999 m .57757 .45319 L .6056 .45031 L p .638 .584 .777 r
F P
0 g
s
.6056 .45031 m .61945 .48097 L .58877 .47999 L p .638 .584 .777 r
F P
0 g
s
.62321 1.10708 m .6818 1.07417 L .63747 1.02928 L p .646 .504 .675 r
F P
0 g
s
.68801 .99567 m .63747 1.02928 L .6818 1.07417 L p .603 .475 .679 r
F P
0 g
s
.63747 1.02928 m .68801 .99567 L .63547 .95755 L p .664 .561 .728 r
F P
0 g
s
.51127 .6409 m .50423 .65673 L .49003 .61812 L p .815 .612 .628 r
F P
0 g
s
.6664 .38518 m .68902 .42374 L .66473 .43468 L p .82 .688 .718 r
F P
0 g
s
.68902 .42374 m .6664 .38518 L .68463 .37183 L p .897 .719 .652 r
F P
0 g
s
.65558 .33474 m .68463 .37183 L .6664 .38518 L p .852 .665 .649 r
F P
0 g
s
.57757 .45319 m .56311 .42785 L .58744 .42159 L p .608 .57 .786 r
F P
0 g
s
.58744 .42159 m .6056 .45031 L .57757 .45319 L p .608 .57 .786 r
F P
0 g
s
.49731 .67198 m .50423 .65673 L .51115 .69705 L p .87 .738 .715 r
F P
0 g
s
.51115 .69705 m .49822 .71378 L .49731 .67198 L p .87 .738 .715 r
F P
0 g
s
.56311 .42785 m .54584 .40438 L .56565 .39535 L p .576 .559 .797 r
F P
0 g
s
.54106 .37207 m .56565 .39535 L .54584 .40438 L p .541 .55 .813 r
F P
0 g
s
.59415 .25955 m .55114 .23671 L .56246 .22609 L p .803 .447 .383 r
F P
0 g
s
.44645 .58039 m .444 .57438 L .46876 .60459 L p .88 .479 .263 r
F P
0 g
s
.46862 .59506 m .46876 .60459 L .444 .57438 L p .83 .449 .331 r
F P
0 g
s
.56565 .39535 m .58744 .42159 L .56311 .42785 L p .576 .559 .797 r
F P
0 g
s
.4305 .7901 m .44933 .77917 L .41776 .80386 L p .641 .962 .915 r
F P
0 g
s
.41776 .80386 m .39267 .81127 L .4305 .7901 L p .641 .962 .915 r
F P
0 g
s
.51464 .35207 m .48742 .33559 L .49581 .31744 L p .575 .562 .802 r
F P
0 g
s
.49003 .61812 m .48704 .63082 L .46862 .59506 L p .834 .559 .523 r
F P
0 g
s
.48704 .63082 m .49003 .61812 L .50423 .65673 L p .859 .657 .629 r
F P
0 g
s
.46876 .60459 m .46862 .59506 L .48704 .63082 L p .887 .606 .505 r
F P
0 g
s
.42629 1.03397 m .37194 1.03848 L .39244 1.10157 L p .786 .669 .735 r
F P
0 g
s
.37194 1.03848 m .42629 1.03397 L .40399 .98063 L p .81 .756 .802 r
F P
0 g
s
.44867 .97401 m .40399 .98063 L .42629 1.03397 L p .789 .721 .788 r
F P
0 g
s
.5958 1.18372 m .65979 1.15281 L .62321 1.10708 L p .633 .445 .61 r
F P
0 g
s
.6818 1.07417 m .62321 1.10708 L .65979 1.15281 L p .581 .406 .61 r
F P
0 g
s
.47243 .7436 m .4852 .72928 L .46928 .76631 L p .886 .935 .844 r
F P
0 g
s
.46928 .76631 m .44933 .77917 L .47243 .7436 L p .886 .935 .844 r
F P
0 g
s
.6767 .92492 m .63547 .95755 L .68801 .99567 L p .629 .539 .733 r
F P
0 g
s
.63547 .95755 m .6767 .92492 L .61758 .89855 L p .692 .619 .77 r
F P
0 g
s
.61758 .89855 m .57998 .92448 L .63547 .95755 L p .692 .619 .77 r
F P
0 g
s
.63581 .4439 m .65125 .4785 L .61945 .48097 L p .712 .637 .773 r
F P
0 g
s
.65125 .4785 m .63581 .4439 L .66473 .43468 L p .78 .685 .759 r
F P
0 g
s
.61945 .48097 m .6056 .45031 L .63581 .4439 L p .712 .637 .773 r
F P
0 g
s
.35201 1.1714 m .42104 1.16576 L .39244 1.10157 L p .792 .628 .678 r
F P
0 g
s
.39244 1.10157 m .33059 1.10329 L .35201 1.1714 L p .792 .628 .678 r
F P
0 g
s
.33059 1.10329 m .39244 1.10157 L .37194 1.03848 L p .815 .705 .744 r
F P
0 g
s
.50423 .65673 m .49731 .67198 L .48704 .63082 L p .859 .657 .629 r
F P
0 g
s
.37918 .54525 m .38596 .54266 L .34099 .53745 L p .198 .683 .927 r
F P
0 g
s
.49397 .96243 m .53827 .94587 L .49265 .91518 L p .79 .757 .822 r
F P
0 g
s
.53827 .94587 m .57998 .92448 L .52669 .89958 L p .773 .727 .81 r
F P
0 g
s
.52669 .89958 m .49265 .91518 L .53827 .94587 L p .773 .727 .81 r
F P
0 g
s
.38283 1.23529 m .45512 1.22513 L .42104 1.16576 L p .762 .55 .61 r
F P
0 g
s
.42104 1.16576 m .35201 1.1714 L .38283 1.23529 L p .762 .55 .61 r
F P
0 g
s
.49066 .68673 m .49731 .67198 L .49822 .71378 L p .906 .795 .727 r
F P
0 g
s
.49822 .71378 m .4852 .72928 L .49066 .68673 L p .906 .795 .727 r
F P
0 g
s
.65558 .33474 m .62019 .3021 L .63366 .28828 L p .871 .609 .54 r
F P
0 g
s
.59415 .25955 m .63366 .28828 L .62019 .3021 L p .818 .561 .551 r
F P
0 g
s
.20179 .62818 m .21054 .64971 L .22769 .60672 L p .932 .969 .698 r
F P
0 g
s
.22769 .60672 m .22461 .5862 L .20179 .62818 L p .932 .969 .698 r
F P
0 g
s
.22461 .5862 m .22769 .60672 L .25741 .57136 L p .823 .997 .845 r
F P
0 g
s
.19384 .67522 m .20778 .69577 L .21054 .64971 L p .982 .871 .503 r
F P
0 g
s
.21054 .64971 m .20179 .62818 L .19384 .67522 L p .982 .871 .503 r
F P
0 g
s
.44867 .97401 m .49397 .96243 L .45788 .92684 L p .806 .79 .838 r
F P
0 g
s
.49265 .91518 m .45788 .92684 L .49397 .96243 L p .79 .757 .822 r
F P
0 g
s
.37043 .8162 m .39267 .81127 L .35099 .81811 L p .094 .651 .773 r
F P
0 g
s
.35099 .81811 m .32481 .81804 L .37043 .8162 L p .094 .651 .773 r
F P
0 g
s
.57998 .92448 m .61758 .89855 L .55871 .88015 L p .753 .7 .801 r
F P
0 g
s
.55871 .88015 m .52669 .89958 L .57998 .92448 L p .753 .7 .801 r
F P
0 g
s
.54106 .37207 m .51464 .35207 L .52845 .33484 L p .607 .573 .79 r
F P
0 g
s
.49581 .31744 m .52845 .33484 L .51464 .35207 L p .575 .562 .802 r
F P
0 g
s
.64223 .39896 m .66473 .43468 L .63581 .4439 L p .754 .655 .752 r
F P
0 g
s
.66473 .43468 m .64223 .39896 L .6664 .38518 L p .82 .688 .718 r
F P
0 g
s
.25741 .57136 m .25981 .5538 L .22461 .5862 L p .823 .997 .845 r
F P
0 g
s
.25981 .5538 m .25741 .57136 L .29655 .5474 L p .66 .957 .942 r
F P
0 g
s
.6056 .45031 m .58744 .42159 L .61486 .41158 L p .688 .618 .773 r
F P
0 g
s
.61486 .41158 m .63581 .4439 L .6056 .45031 L p .688 .618 .773 r
F P
0 g
s
.20166 .72226 m .21974 .74 L .20778 .69577 L p .962 .697 .26 r
F P
0 g
s
.20778 .69577 m .19384 .67522 L .20166 .72226 L p .962 .697 .26 r
F P
0 g
s
.48704 .63082 m .48496 .64351 L .46876 .60459 L p .887 .606 .505 r
F P
0 g
s
.48496 .64351 m .48704 .63082 L .49731 .67198 L p .906 .71 .627 r
F P
0 g
s
.6664 .38518 m .63695 .35011 L .65558 .33474 L p .852 .665 .649 r
F P
0 g
s
.62019 .3021 m .65558 .33474 L .63695 .35011 L p .809 .62 .647 r
F P
0 g
s
.63695 .35011 m .6664 .38518 L .64223 .39896 L p .787 .65 .71 r
F P
0 g
s
.49731 .67198 m .49066 .68673 L .48496 .64351 L p .906 .71 .627 r
F P
0 g
s
.63581 .4439 m .61486 .41158 L .64223 .39896 L p .754 .655 .752 r
F P
0 g
s
.6818 1.07417 m .73262 1.03532 L .68801 .99567 L p .603 .475 .679 r
F P
0 g
s
.73053 .9568 m .68801 .99567 L .73262 1.03532 L p .552 .444 .685 r
F P
0 g
s
.68801 .99567 m .73053 .9568 L .6767 .92492 L p .629 .539 .733 r
F P
0 g
s
.58744 .42159 m .56565 .39535 L .58924 .38227 L p .662 .601 .776 r
F P
0 g
s
.58924 .38227 m .61486 .41158 L .58744 .42159 L p .662 .601 .776 r
F P
0 g
s
.45604 .59398 m .44645 .58039 L p .46917 .60683 L .88 .479 .263 r
F P
0 g
s
.46917 .60683 m .47056 .61457 L .45604 .59398 L p .88 .479 .263 r
F P
0 g
s
.4514 .58718 m .44645 .58039 L .44909 .58413 L p .902 .487 .137 r
F P
0 g
s
.44909 .58413 m .47056 .61457 L p .4514 .58718 L .902 .487 .137 r
F P
0 g
s
.47056 .61457 m .47115 .61654 L p .4514 .58718 L .902 .487 .137 r
F P
0 g
s
.47115 .61654 m .47377 .62522 L .46004 .60187 L p .902 .487 .137 r
F P
0 g
s
.46004 .60187 m .4514 .58718 L p .47115 .61654 L .902 .487 .137 r
F P
0 g
s
.44645 .58039 m .45047 .5859 L p .44409 .57862 L .691 .151 0 r
F P
0 g
s
.45047 .5859 m .4514 .58718 L p .44409 .57862 L .691 .151 0 r
F P
0 g
s
.4514 .58718 m .41864 .55955 L p .44409 .57862 L .691 .151 0 r
F P
0 g
s
.46876 .60459 m .46917 .60683 L p .44645 .58039 L .88 .479 .263 r
F P
0 g
s
.43777 .5671 m .43189 .5647 L p .45852 .59508 L 0 .067 .617 r
F P
0 g
s
.45852 .59508 m .4514 .58718 L .47377 .62522 L p .817 .425 0 r
F P
0 g
s
.45356 .59003 m .45235 .58879 L p .4514 .58718 L .577 .067 0 r
F P
0 g
s
.42663 .56256 m .42224 .56091 L p .4514 .58718 L .577 .067 0 r
F P
0 g
s
.43466 .57306 m .4514 .58718 L p .42224 .56091 L .577 .067 0 r
F P
0 g
s
.45235 .58879 m .42663 .56256 L p .4514 .58718 L .577 .067 0 r
F P
0 g
s
.43189 .5647 m .42663 .56256 L .44261 .57886 L p 0 .067 .617 r
F P
0 g
s
.4514 .58718 m .45852 .59508 L .45356 .59003 L p .577 .067 0 r
F P
0 g
s
.44261 .57886 m .45852 .59508 L p .43189 .5647 L 0 .067 .617 r
F P
0 g
s
.42224 .56091 m .41864 .55955 L .43466 .57306 L p .577 .067 0 r
F P
0 g
s
.47056 .61457 m .46876 .60459 L .48496 .64351 L p .943 .658 .47 r
F P
0 g
s
.56565 .39535 m .54106 .37207 L .56003 .35654 L p .636 .586 .781 r
F P
0 g
s
.52845 .33484 m .56003 .35654 L .54106 .37207 L p .607 .573 .79 r
F P
0 g
s
.29655 .5474 m .30358 .53443 L .25981 .5538 L p .66 .957 .942 r
F P
0 g
s
.30358 .53443 m .29655 .5474 L .34099 .53745 L p .444 .841 .978 r
F P
0 g
s
.62019 .3021 m .5801 .27473 L .59415 .25955 L p .818 .561 .551 r
F P
0 g
s
.55114 .23671 m .59415 .25955 L .5801 .27473 L p .768 .517 .556 r
F P
0 g
s
.5801 .27473 m .53719 .25321 L .55114 .23671 L p .768 .517 .556 r
F P
0 g
s
.22447 .76418 m .24521 .77767 L .21974 .74 L p .852 .438 0 r
F P
0 g
s
.21974 .74 m .20166 .72226 L .22447 .76418 L p .852 .438 0 r
F P
0 g
s
.56003 .35654 m .58924 .38227 L .56565 .39535 L p .636 .586 .781 r
F P
0 g
s
.46023 .75682 m .47243 .7436 L .44933 .77917 L p .853 .985 .856 r
F P
0 g
s
.44933 .77917 m .4305 .7901 L .46023 .75682 L p .853 .985 .856 r
F P
0 g
s
.48436 .70106 m .49066 .68673 L .4852 .72928 L p .938 .862 .739 r
F P
0 g
s
.4852 .72928 m .47243 .7436 L .48436 .70106 L p .938 .862 .739 r
F P
0 g
s
.52845 .33484 m .49581 .31744 L .50785 .29602 L p .641 .564 .753 r
F P
0 g
s
.40399 .98063 m .44867 .97401 L .42374 .93458 L p .816 .827 .858 r
F P
0 g
s
.45788 .92684 m .42374 .93458 L .44867 .97401 L p .806 .79 .838 r
F P
0 g
s
.41864 .55955 m .42663 .56256 L .38596 .54266 L p 0 .338 .727 r
F P
0 g
s
.64968 .86854 m .61758 .89855 L .6767 .92492 L p .665 .6 .772 r
F P
0 g
s
.61758 .89855 m .64968 .86854 L .58746 .85714 L p .733 .676 .795 r
F P
0 g
s
.58746 .85714 m .55871 .88015 L .61758 .89855 L p .733 .676 .795 r
F P
0 g
s
.65979 1.15281 m .71678 1.11559 L .6818 1.07417 L p .581 .406 .61 r
F P
0 g
s
.73262 1.03532 m .6818 1.07417 L .71678 1.11559 L p .519 .362 .609 r
F P
0 g
s
.71025 .88791 m .6767 .92492 L .73053 .9568 L p .59 .518 .741 r
F P
0 g
s
.6767 .92492 m .71025 .88791 L .64968 .86854 L p .665 .6 .772 r
F P
0 g
s
.49155 1.27397 m .56114 1.25234 L .52685 1.20791 L p .67 .417 .529 r
F P
0 g
s
.52685 1.20791 m .45512 1.22513 L .49155 1.27397 L p .67 .417 .529 r
F P
0 g
s
.5958 1.18372 m .52685 1.20791 L .56114 1.25234 L p .618 .374 .525 r
F P
0 g
s
.34099 .53745 m .35122 .53016 L .30358 .53443 L p .444 .841 .978 r
F P
0 g
s
.35122 .53016 m .34099 .53745 L .38596 .54266 L p .183 .644 .939 r
F P
0 g
s
.37194 1.03848 m .32059 1.03733 L .33059 1.10329 L p .815 .705 .744 r
F P
0 g
s
.32059 1.03733 m .37194 1.03848 L .3616 .98246 L p .83 .795 .819 r
F P
0 g
s
.40399 .98063 m .3616 .98246 L .37194 1.03848 L p .81 .756 .802 r
F P
0 g
s
.41336 .79927 m .4305 .7901 L .39267 .81127 L p .492 .904 .876 r
F P
0 g
s
.39267 .81127 m .37043 .8162 L .41336 .79927 L p .492 .904 .876 r
F P
0 g
s
.61396 .36659 m .64223 .39896 L .61486 .41158 L p .727 .629 .748 r
F P
0 g
s
.64223 .39896 m .61396 .36659 L .63695 .35011 L p .787 .65 .71 r
F P
0 g
s
.61486 .41158 m .58924 .38227 L .61396 .36659 L p .727 .629 .748 r
F P
0 g
s
.25982 .7964 m .28152 .80468 L .24521 .77767 L p .636 .104 0 r
F P
0 g
s
.24521 .77767 m .22447 .76418 L .25982 .7964 L p .636 .104 0 r
F P
0 g
s
.48496 .64351 m .48371 .65636 L .47056 .61457 L p .943 .658 .47 r
F P
0 g
s
.48371 .65636 m .48496 .64351 L .49066 .68673 L p .955 .774 .62 r
F P
0 g
s
.63695 .35011 m .60201 .31942 L .62019 .3021 L p .809 .62 .647 r
F P
0 g
s
.5801 .27473 m .62019 .3021 L .60201 .31942 L p .768 .581 .645 r
F P
0 g
s
.49066 .68673 m .48436 .70106 L .48371 .65636 L p .955 .774 .62 r
F P
0 g
s
.56114 1.25234 m .62689 1.22413 L .5958 1.18372 L p .618 .374 .525 r
F P
0 g
s
.65979 1.15281 m .5958 1.18372 L .62689 1.22413 L p .556 .324 .518 r
F P
0 g
s
.56003 .35654 m .52845 .33484 L .54526 .31466 L p .671 .584 .748 r
F P
0 g
s
.50785 .29602 m .54526 .31466 L .52845 .33484 L p .641 .564 .753 r
F P
0 g
s
.60201 .31942 m .63695 .35011 L .61396 .36659 L p .754 .616 .705 r
F P
0 g
s
.42026 1.28886 m .49155 1.27397 L .45512 1.22513 L p .718 .456 .529 r
F P
0 g
s
.45512 1.22513 m .38283 1.23529 L .42026 1.28886 L p .718 .456 .529 r
F P
0 g
s
.56316 .29382 m .52219 .27376 L .53719 .25321 L p .728 .545 .644 r
F P
0 g
s
.53719 .25321 m .5801 .27473 L .56316 .29382 L p .728 .545 .644 r
F P
0 g
s
.58924 .38227 m .56003 .35654 L .58115 .33829 L p .7 .605 .747 r
F P
0 g
s
.58115 .33829 m .61396 .36659 L .58924 .38227 L p .7 .605 .747 r
F P
0 g
s
.47176 .61839 m .48371 .65636 L p .47377 .62522 L .985 .707 .396 r
F P
0 g
s
.48371 .65636 m .48348 .66183 L p .47377 .62522 L .985 .707 .396 r
F P
0 g
s
.48348 .66183 m .48317 .6695 L .47801 .64519 L p .985 .707 .396 r
F P
0 g
s
.47801 .64519 m .47377 .62522 L p .48348 .66183 L .985 .707 .396 r
F P
0 g
s
.4781 .63675 m .47377 .62522 L .48317 .6695 L p .942 .705 .234 r
F P
0 g
s
.47377 .62522 m .4781 .63675 L .4756 .63144 L p .817 .425 0 r
F P
0 g
s
.4756 .63144 m .45852 .59508 L p .47377 .62522 L .817 .425 0 r
F P
0 g
s
.47377 .62522 m .47056 .61457 L .47176 .61839 L p .985 .707 .396 r
F P
0 g
s
.46736 .60438 m .46311 .59991 L p .4781 .63675 L 0 0 .365 r
F P
0 g
s
.46311 .59991 m .45852 .59508 L .46853 .61638 L p 0 0 .365 r
F P
0 g
s
.46853 .61638 m .4781 .63675 L p .46311 .59991 L 0 0 .365 r
F P
0 g
s
.54526 .31466 m .50785 .29602 L .52219 .27376 L p .687 .558 .703 r
F P
0 g
s
.47848 .71507 m .48436 .70106 L .47243 .7436 L p .951 .934 .742 r
F P
0 g
s
.47243 .7436 m .46023 .75682 L .47848 .71507 L p .951 .934 .742 r
F P
0 g
s
.54526 .31466 m .58115 .33829 L .56003 .35654 L p .671 .584 .748 r
F P
0 g
s
.60201 .31942 m .56316 .29382 L .5801 .27473 L p .768 .581 .645 r
F P
0 g
s
.38596 .54266 m .39761 .54144 L .35122 .53016 L p .183 .644 .939 r
F P
0 g
s
.39761 .54144 m .38596 .54266 L .42663 .56256 L p 0 .374 .814 r
F P
0 g
s
.61396 .36659 m .58115 .33829 L .60201 .31942 L p .754 .616 .705 r
F P
0 g
s
.30388 .81538 m .32481 .81804 L .28152 .80468 L p .329 0 0 r
F P
0 g
s
.28152 .80468 m .25982 .7964 L .30388 .81538 L p .329 0 0 r
F P
0 g
s
.52219 .27376 m .56316 .29382 L .54526 .31466 L p .687 .558 .703 r
F P
0 g
s
.67504 .83506 m .64968 .86854 L .71025 .88791 L p .637 .584 .778 r
F P
0 g
s
.64968 .86854 m .67504 .83506 L .61182 .83094 L p .711 .655 .793 r
F P
0 g
s
.61182 .83094 m .58746 .85714 L .64968 .86854 L p .711 .655 .793 r
F P
0 g
s
.44888 .76904 m .46023 .75682 L .4305 .7901 L p .753 .995 .834 r
F P
0 g
s
.4305 .7901 m .41336 .79927 L .44888 .76904 L p .753 .995 .834 r
F P
0 g
s
.56316 .29382 m .60201 .31942 L .58115 .33829 L p .721 .586 .703 r
F P
0 g
s
.3616 .98246 m .40399 .98063 L .39158 .93857 L p .82 .867 .881 r
F P
0 g
s
.42374 .93458 m .39158 .93857 L .40399 .98063 L p .816 .827 .858 r
F P
0 g
s
.49265 .91518 m .52669 .89958 L .48075 .8854 L p .833 .837 .85 r
F P
0 g
s
.52669 .89958 m .55871 .88015 L .50568 .87159 L p .82 .796 .829 r
F P
0 g
s
.50568 .87159 m .48075 .8854 L .52669 .89958 L p .82 .796 .829 r
F P
0 g
s
.48317 .6695 m .48371 .65636 L .48436 .70106 L p .992 .845 .593 r
F P
0 g
s
.58115 .33829 m .54526 .31466 L .56316 .29382 L p .721 .586 .703 r
F P
0 g
s
.48436 .70106 m .47848 .71507 L .48317 .6695 L p .992 .845 .593 r
F P
0 g
s
.55871 .88015 m .58746 .85714 L .52948 .85485 L p .803 .759 .812 r
F P
0 g
s
.52948 .85485 m .50568 .87159 L .55871 .88015 L p .803 .759 .812 r
F P
0 g
s
.62689 1.22413 m .68673 1.18964 L .65979 1.15281 L p .556 .324 .518 r
F P
0 g
s
.71678 1.11559 m .65979 1.15281 L .68673 1.18964 L p .478 .261 .505 r
F P
0 g
s
.42663 .56256 m .43777 .5671 L .39761 .54144 L p 0 .374 .814 r
F P
0 g
s
.45788 .92684 m .49265 .91518 L .45573 .89626 L p .838 .882 .874 r
F P
0 g
s
.48075 .8854 m .45573 .89626 L .49265 .91518 L p .833 .837 .85 r
F P
0 g
s
.35185 .81901 m .37043 .8162 L .32481 .81804 L p .013 .584 .768 r
F P
0 g
s
.32481 .81804 m .30388 .81538 L .35185 .81901 L p .013 .584 .768 r
F P
0 g
s
.73262 1.03532 m .77386 .99126 L .73053 .9568 L p .552 .444 .685 r
F P
0 g
s
.76344 .91349 m .73053 .9568 L .77386 .99126 L p .491 .41 .692 r
F P
0 g
s
.73053 .9568 m .76344 .91349 L .71025 .88791 L p .59 .518 .741 r
F P
0 g
s
.58746 .85714 m .61182 .83094 L .55113 .83535 L p .783 .726 .799 r
F P
0 g
s
.55113 .83535 m .52948 .85485 L .58746 .85714 L p .783 .726 .799 r
F P
0 g
s
.47304 .72881 m .47848 .71507 L .47683 .71883 L p .901 .981 .707 r
F P
0 g
s
.47683 .71883 m .46103 .75498 L p .47304 .72881 L .901 .981 .707 r
F P
0 g
s
.46128 .75451 m .47304 .72881 L .46103 .75498 L .901 .981 .707 r
F
.46103 .75498 m .46023 .75682 L p .46128 .75451 L F P
0 g
s
.46023 .75682 m .44888 .76904 L .47304 .72881 L p .901 .981 .707 r
F P
0 g
s
.46804 .74237 m .47304 .72881 L .44888 .76904 L p .708 .92 .579 r
F P
0 g
s
.47304 .72881 m .46804 .74237 L .46931 .7386 L p .742 .789 .299 r
F P
0 g
s
.48314 .68303 m .48317 .6695 L .48288 .67231 L p .965 .889 .509 r
F P
0 g
s
.48288 .67231 m .47848 .71507 L p .48314 .68303 L .965 .889 .509 r
F P
0 g
s
.48314 .68303 m .48341 .69702 L .48339 .69305 L p 0 0 .049 r
F P
0 g
s
.48317 .6695 m .48314 .68303 L .4781 .63675 L p .942 .705 .234 r
F P
0 g
s
.48339 .69305 m .48316 .6493 L p .48314 .68303 L 0 0 .049 r
F P
0 g
s
.47848 .71507 m .47304 .72881 L .48314 .68303 L p .965 .889 .509 r
F P
0 g
s
.48341 .69702 m .48314 .68303 L .47304 .72881 L p .742 .789 .299 r
F P
0 g
s
.46931 .7386 m .48341 .69702 L p .47304 .72881 L .742 .789 .299 r
F P
0 g
s
.43867 .78038 m .44888 .76904 L .44806 .76974 L p .562 .923 .752 r
F P
0 g
s
.44806 .76974 m .41336 .79927 L p .43867 .78038 L .562 .923 .752 r
F P
0 g
s
.39848 .80691 m .41336 .79927 L .37043 .8162 L p .323 .81 .818 r
F P
0 g
s
.41336 .79927 m .39848 .80691 L .43867 .78038 L p .562 .923 .752 r
F P
0 g
s
.43867 .78038 m .39848 .80691 L p .4289 .79146 L 0 0 0 r
F P
0 g
s
.42983 .79099 m .43867 .78038 L p .4289 .79146 L 0 0 0 r
F P
0 g
s
.44888 .76904 m .43867 .78038 L .46727 .74336 L p .708 .92 .579 r
F P
0 g
s
.46727 .74336 m .46804 .74237 L p .46711 .74366 L .708 .92 .579 r
F P
0 g
s
.44888 .76904 m .46727 .74336 L .46711 .74366 L .708 .92 .579 r
F
.73483 .84735 m .71025 .88791 L .76344 .91349 L p .546 .497 .753 r
F P
0 g
s
.71025 .88791 m .73483 .84735 L .67504 .83506 L p .637 .584 .778 r
F P
0 g
s
.71678 1.11559 m .76481 1.0727 L .73262 1.03532 L p .519 .362 .609 r
F P
0 g
s
.77386 .99126 m .73262 1.03532 L .76481 1.0727 L p .437 .308 .606 r
F P
0 g
s
.45852 .59508 m .46736 .60438 L .43777 .5671 L p 0 .067 .617 r
F P
0 g
s
.37043 .8162 m .35185 .81901 L .39848 .80691 L p .323 .81 .818 r
F P
0 g
s
.42374 .93458 m .45788 .92684 L .4317 .90424 L p .828 .926 .899 r
F P
0 g
s
.45573 .89626 m .4317 .90424 L .45788 .92684 L p .838 .882 .874 r
F P
0 g
s
.3616 .98246 m .32314 .97982 L .32059 1.03733 L p .83 .795 .819 r
F P
0 g
s
.63078 .80205 m .61182 .83094 L .67504 .83506 L p .689 .637 .793 r
F P
0 g
s
.61182 .83094 m .63078 .80205 L .56973 .81337 L p .762 .697 .79 r
F P
0 g
s
.56973 .81337 m .55113 .83535 L .61182 .83094 L p .762 .697 .79 r
F P
0 g
s
.27208 .53694 m .25981 .5538 L .30358 .53443 L p .535 .918 .927 r
F P
0 g
s
.30358 .53443 m .31887 .52281 L .27208 .53694 L p .535 .918 .927 r
F P
0 g
s
.31887 .52281 m .30358 .53443 L .35122 .53016 L p .37 .791 .974 r
F P
0 g
s
.35122 .53016 m .3678 .52467 L .31887 .52281 L p .37 .791 .974 r
F P
0 g
s
.3678 .52467 m .35122 .53016 L .39761 .54144 L p .202 .615 .949 r
F P
0 g
s
.4781 .63675 m .48316 .6493 L .46736 .60438 L p 0 0 .365 r
F P
0 g
s
.48316 .6493 m .4781 .63675 L .48314 .68303 L p 0 0 .049 r
F P
0 g
s
.69262 .79888 m .67504 .83506 L .73483 .84735 L p .605 .569 .787 r
F P
0 g
s
.67504 .83506 m .69262 .79888 L .63078 .80205 L p .689 .637 .793 r
F P
0 g
s
.23251 .56563 m .22461 .5862 L .25981 .5538 L p .678 .973 .8 r
F P
0 g
s
.25981 .5538 m .27208 .53694 L .23251 .56563 L p .678 .973 .8 r
F P
0 g
s
.39761 .54144 m .41363 .54223 L .3678 .52467 L p .202 .615 .949 r
F P
0 g
s
.41363 .54223 m .39761 .54144 L .43777 .5671 L p .052 .409 .86 r
F P
0 g
s
.20453 .60585 m .20179 .62818 L .22461 .5862 L p .775 .94 .592 r
F P
0 g
s
.22461 .5862 m .23251 .56563 L .20453 .60585 L p .775 .94 .592 r
F P
0 g
s
.43777 .5671 m .45148 .57355 L .41363 .54223 L p .052 .409 .86 r
F P
0 g
s
.45148 .57355 m .43777 .5671 L .46736 .60438 L p 0 .197 .723 r
F P
0 g
s
.32314 .97982 m .3616 .98246 L .36271 .93912 L p .812 .906 .906 r
F P
0 g
s
.39158 .93857 m .36271 .93912 L .3616 .98246 L p .82 .867 .881 r
F P
0 g
s
.19128 .65325 m .19384 .67522 L .20179 .62818 L p .804 .805 .316 r
F P
0 g
s
.20179 .62818 m .20453 .60585 L .19128 .65325 L p .804 .805 .316 r
F P
0 g
s
.46736 .60438 m .47735 .61526 L .45148 .57355 L p 0 .197 .723 r
F P
0 g
s
.47735 .61526 m .46736 .60438 L .48316 .6493 L p 0 0 .545 r
F P
0 g
s
.68673 1.18964 m .73867 1.14936 L .71678 1.11559 L p .478 .261 .505 r
F P
0 g
s
.76481 1.0727 m .71678 1.11559 L .73867 1.14936 L p .372 .177 .482 r
F P
0 g
s
.19429 .70265 m .20166 .72226 L .19384 .67522 L p .753 .579 .005 r
F P
0 g
s
.19384 .67522 m .19128 .65325 L .19429 .70265 L p .753 .579 .005 r
F P
0 g
s
.39158 .93857 m .42374 .93458 L .40969 .90953 L p .793 .961 .918 r
F P
0 g
s
.4317 .90424 m .40969 .90953 L .42374 .93458 L p .828 .926 .899 r
F P
0 g
s
.48316 .6493 m .4885 .66293 L .47735 .61526 L p 0 0 .545 r
F P
0 g
s
.4885 .66293 m .48316 .6493 L .48341 .69702 L p 0 0 .308 r
F P
0 g
s
.64356 .77112 m .63078 .80205 L .69262 .79888 L p .665 .621 .796 r
F P
0 g
s
.63078 .80205 m .64356 .77112 L .58445 .78927 L p .74 .672 .784 r
F P
0 g
s
.58445 .78927 m .56973 .81337 L .63078 .80205 L p .74 .672 .784 r
F P
0 g
s
.52684 1.30718 m .59016 1.28169 L .56114 1.25234 L p .582 .267 .401 r
F P
0 g
s
.56114 1.25234 m .49155 1.27397 L .52684 1.30718 L p .582 .267 .401 r
F P
0 g
s
.62689 1.22413 m .56114 1.25234 L .59016 1.28169 L p .506 .199 .381 r
F P
0 g
s
.50568 .87159 m .52948 .85485 L .48139 .86206 L p .883 .864 .816 r
F P
0 g
s
.52948 .85485 m .55113 .83535 L .49881 .84799 L p .863 .809 .795 r
F P
0 g
s
.49881 .84799 m .48139 .86206 L .52948 .85485 L p .863 .809 .795 r
F P
0 g
s
.46084 1.32658 m .52684 1.30718 L .49155 1.27397 L p .645 .321 .409 r
F P
0 g
s
.49155 1.27397 m .42026 1.28886 L .46084 1.32658 L p .645 .321 .409 r
F P
0 g
s
.55113 .83535 m .56973 .81337 L .51524 .8318 L p .839 .762 .778 r
F P
0 g
s
.51524 .8318 m .49881 .84799 L .55113 .83535 L p .839 .762 .778 r
F P
0 g
s
.21326 .74859 m .22447 .76418 L .20166 .72226 L p 0 0 .297 r
F P
0 g
s
.20166 .72226 m .19429 .70265 L .21326 .74859 L p 0 0 .297 r
F P
0 g
s
.48341 .69702 m .48372 .7115 L .4885 .66293 L p 0 0 .308 r
F P
0 g
s
.48372 .7115 m .48341 .69702 L .46804 .74237 L p 0 0 0 r
F P
0 g
s
.48075 .8854 m .50568 .87159 L .46383 .87395 L p .89 .923 .838 r
F P
0 g
s
.48139 .86206 m .46383 .87395 L .50568 .87159 L p .883 .864 .816 r
F P
0 g
s
.56973 .81337 m .58445 .78927 L .52993 .81363 L p .812 .721 .764 r
F P
0 g
s
.52993 .81363 m .51524 .8318 L .56973 .81337 L p .812 .721 .764 r
F P
0 g
s
.2461 .78599 m .25982 .7964 L .22447 .76418 L p 0 .016 .547 r
F P
0 g
s
.22447 .76418 m .21326 .74859 L .2461 .78599 L p 0 .016 .547 r
F P
0 g
s
.46705 .58222 m .45148 .57355 L .47735 .61526 L p .159 .29 .75 r
F P
0 g
s
.47735 .61526 m .48789 .62784 L .46705 .58222 L p .159 .29 .75 r
F P
0 g
s
.48789 .62784 m .47735 .61526 L .4885 .66293 L p .147 .157 .613 r
F P
0 g
s
.46804 .74237 m .46347 .75578 L .48372 .7115 L p 0 0 0 r
F P
0 g
s
.46347 .75578 m .46804 .74237 L .43867 .78038 L p 0 0 0 r
F P
0 g
s
.43331 .54557 m .41363 .54223 L .45148 .57355 L p .189 .436 .866 r
F P
0 g
s
.45148 .57355 m .46705 .58222 L .43331 .54557 L p .189 .436 .866 r
F P
0 g
s
.77386 .99126 m .80393 .94294 L .76344 .91349 L p .491 .41 .692 r
F P
0 g
s
.7854 .86675 m .76344 .91349 L .80393 .94294 L p .411 .369 .702 r
F P
0 g
s
.76344 .91349 m .7854 .86675 L .73483 .84735 L p .546 .497 .753 r
F P
0 g
s
.74937 .80424 m .73483 .84735 L .7854 .86675 L p .493 .477 .768 r
F P
0 g
s
.73483 .84735 m .74937 .80424 L .69262 .79888 L p .605 .569 .787 r
F P
0 g
s
.59016 1.28169 m .64881 1.25033 L .62689 1.22413 L p .506 .199 .381 r
F P
0 g
s
.68673 1.18964 m .62689 1.22413 L .64881 1.25033 L p .404 .108 .345 r
F P
0 g
s
.4885 .66293 m .49369 .67764 L .48789 .62784 L p .147 .157 .613 r
F P
0 g
s
.49369 .67764 m .4885 .66293 L .48372 .7115 L p .114 .005 .44 r
F P
0 g
s
.28917 .81073 m .30388 .81538 L .25982 .7964 L p 0 .304 .717 r
F P
0 g
s
.25982 .7964 m .2461 .78599 L .28917 .81073 L p 0 .304 .717 r
F P
0 g
s
.43867 .78038 m .42983 .79099 L .46347 .75578 L p 0 0 0 r
F P
0 g
s
.39014 .52182 m .3678 .52467 L .41363 .54223 L p .244 .593 .949 r
F P
0 g
s
.41363 .54223 m .43331 .54557 L .39014 .52182 L p .244 .593 .949 r
F P
0 g
s
.70166 .76091 m .69262 .79888 L .74937 .80424 L p .571 .557 .8 r
F P
0 g
s
.69262 .79888 m .70166 .76091 L .64356 .77112 L p .665 .621 .796 r
F P
0 g
s
.3377 .82015 m .35185 .81901 L .30388 .81538 L p 0 .542 .793 r
F P
0 g
s
.30388 .81538 m .28917 .81073 L .3377 .82015 L p 0 .542 .793 r
F P
0 g
s
.39848 .80691 m .38635 .81329 L .42983 .79099 L p 0 0 0 r
F P
0 g
s
.38635 .81329 m .39848 .80691 L .35185 .81901 L p .167 .705 .762 r
F P
0 g
s
.45573 .89626 m .48075 .8854 L .44695 .88371 L p .867 .977 .851 r
F P
0 g
s
.46383 .87395 m .44695 .88371 L .48075 .8854 L p .89 .923 .838 r
F P
0 g
s
.35185 .81901 m .3377 .82015 L .38635 .81329 L p .167 .705 .762 r
F P
0 g
s
.76481 1.0727 m .80213 1.02497 L .77386 .99126 L p .437 .308 .606 r
F P
0 g
s
.80393 .94294 m .77386 .99126 L .80213 1.02497 L p .324 .234 .597 r
F P
0 g
s
.59466 .76356 m .58445 .78927 L .64356 .77112 L p .717 .649 .781 r
F P
0 g
s
.58445 .78927 m .59466 .76356 L .54218 .79373 L p .785 .685 .754 r
F P
0 g
s
.54218 .79373 m .52993 .81363 L .58445 .78927 L p .785 .685 .754 r
F P
0 g
s
.48372 .7115 m .48384 .72643 L .49369 .67764 L p .114 .005 .44 r
F P
0 g
s
.48384 .72643 m .48372 .7115 L .46347 .75578 L p .044 0 .193 r
F P
0 g
s
.64956 .73891 m .64356 .77112 L .70166 .76091 L p .639 .608 .802 r
F P
0 g
s
.64356 .77112 m .64956 .73891 L .59466 .76356 L p .717 .649 .781 r
F P
0 g
s
.34203 .51364 m .31887 .52281 L .3678 .52467 L p .318 .743 .973 r
F P
0 g
s
.3678 .52467 m .39014 .52182 L .34203 .51364 L p .318 .743 .973 r
F P
0 g
s
.48366 .59328 m .46705 .58222 L .48789 .62784 L p .31 .353 .745 r
F P
0 g
s
.48789 .62784 m .49831 .64212 L .48366 .59328 L p .31 .353 .745 r
F P
0 g
s
.49831 .64212 m .48789 .62784 L .49369 .67764 L p .323 .262 .633 r
F P
0 g
s
.49369 .67764 m .49826 .69336 L .49831 .64212 L p .323 .262 .633 r
F P
0 g
s
.49826 .69336 m .49369 .67764 L .48384 .72643 L p .316 .156 .499 r
F P
0 g
s
.36271 .93912 m .39158 .93857 L .3907 .91245 L p .72 .975 .924 r
F P
0 g
s
.40969 .90953 m .3907 .91245 L .39158 .93857 L p .793 .961 .918 r
F P
0 g
s
.46347 .75578 m .4593 .76907 L .48384 .72643 L p .044 0 .193 r
F P
0 g
s
.4593 .76907 m .46347 .75578 L .42983 .79099 L p 0 0 0 r
F P
0 g
s
.45574 .55189 m .43331 .54557 L .46705 .58222 L p .301 .457 .849 r
F P
0 g
s
.46705 .58222 m .48366 .59328 L .45574 .55189 L p .301 .457 .849 r
F P
0 g
s
.59986 .73679 m .59466 .76356 L .64956 .73891 L p .693 .629 .781 r
F P
0 g
s
.59466 .76356 m .59986 .73679 L .5514 .77243 L p .758 .654 .747 r
F P
0 g
s
.5514 .77243 m .54218 .79373 L .59466 .76356 L p .758 .654 .747 r
F P
0 g
s
.48384 .72643 m .48353 .74175 L .49826 .69336 L p .316 .156 .499 r
F P
0 g
s
.48353 .74175 m .48384 .72643 L .4593 .76907 L p .276 .002 .305 r
F P
0 g
s
.36271 .93912 m .33838 .93667 L .32314 .97982 L p .812 .906 .906 r
F P
0 g
s
.4317 .90424 m .43747 .90233 L p .43159 .89149 L .784 .998 .835 r
F P
0 g
s
.44055 .89326 m .43159 .89149 L p .43747 .90233 L .784 .998 .835 r
F P
0 g
s
.44695 .88371 m .43159 .89149 L .45573 .89626 L p .867 .977 .851 r
F P
0 g
s
.43159 .89149 m .41853 .89753 L .4317 .90424 L p .784 .998 .835 r
F P
0 g
s
.43159 .89149 m .4453 .88455 L p .43413 .89208 L 0 0 0 r
F P
0 g
s
.43294 .89288 m .43249 .89242 L .43413 .89208 L 0 0 0 r
F
.43249 .89242 m .43159 .89149 L .43413 .89208 L F
.43439 .90246 m .43123 .91112 L .4367 .89154 L p F P
0 g
s
.44499 .885 m .43294 .89288 L p .4453 .88455 L 0 0 0 r
F P
0 g
s
.43294 .89288 m .42933 .89524 L p .43011 .89396 L 0 0 0 r
F P
0 g
s
.43011 .89396 m .43159 .89149 L .43294 .89288 L 0 0 0 r
F
.43784 .88744 m .42933 .89524 L .4429 .88636 L p .771 .957 .641 r
F P
0 g
s
.4367 .89154 m .43784 .88744 L p .43691 .89149 L 0 0 0 r
F P
0 g
s
.43439 .90246 m .4367 .89154 L .43691 .89149 L 0 0 0 r
F
.4453 .88455 m .44695 .88371 L .44499 .885 L p F P
0 g
s
.4429 .88636 m .44695 .88371 L p .4433 .88521 L .771 .957 .641 r
F P
0 g
s
.43784 .88744 m .4429 .88636 L .4433 .88521 L .771 .957 .641 r
F
.44695 .88371 m .46359 .87409 L p .44559 .88342 L F P
0 g
s
.46341 .87417 m .44559 .88342 L p .46359 .87409 L .771 .957 .641 r
F P
0 g
s
.44531 .88439 m .44695 .88371 L .44559 .88342 L .771 .957 .641 r
F
.44559 .88342 m .43973 .88646 L p .44531 .88439 L F P
0 g
s
.43973 .88646 m .43784 .88744 L p .43871 .88708 L .771 .957 .641 r
F P
0 g
s
.43871 .88708 m .44531 .88439 L .43973 .88646 L .771 .957 .641 r
F
.44834 .87837 m .43784 .88744 L .46383 .87395 L p .919 .978 .734 r
F P
0 g
s
.43784 .88744 m .44834 .87837 L .43911 .89432 L p 0 0 0 r
F P
0 g
s
.43911 .89432 m .43784 .8965 L p .43784 .8881 L 0 0 0 r
F P
0 g
s
.43784 .8881 m .43784 .88744 L .43911 .89432 L 0 0 0 r
F
.43747 .90233 m .45573 .89626 L .44055 .89326 L p .784 .998 .835 r
F P
0 g
s
.44081 .91058 m .44041 .92139 L .43985 .89798 L p 0 0 .111 r
F P
0 g
s
.43494 .90008 m .43784 .88744 L .43784 .8965 L 0 0 0 r
F
.43974 .89312 m .43439 .90246 L .44213 .88909 L p .645 .804 .365 r
F P
0 g
s
.43985 .89798 m .43974 .89312 L p .44012 .89928 L 0 0 .111 r
F P
0 g
s
.44081 .91058 m .43985 .89798 L .44012 .89928 L 0 0 .111 r
F
.44213 .88909 m .44577 .88281 L p .44184 .88951 L .645 .804 .365 r
F P
0 g
s
.44184 .88951 m .44577 .88281 L .44579 .88274 L .645 .804 .365 r
F
.44184 .88951 m .44579 .88274 L .44302 .88906 L F
.44577 .88281 m .44834 .87837 L p .44579 .88274 L F P
0 g
s
.44579 .88274 m .44834 .87837 L .44633 .88241 L .645 .804 .365 r
F
.44579 .88274 m .44633 .88241 L .44302 .88906 L F
.43784 .8965 m .43439 .90246 L p .43494 .90008 L 0 0 0 r
F P
0 g
s
.46383 .87395 m .48139 .86206 L .45875 .87323 L p .919 .978 .734 r
F P
0 g
s
.48139 .86206 m .48228 .86135 L p .4602 .86784 L .947 .919 .752 r
F P
0 g
s
.48228 .86135 m .49881 .84799 L .47288 .86132 L p .947 .919 .752 r
F P
0 g
s
.47288 .86132 m .4602 .86784 L p .48228 .86135 L .947 .919 .752 r
F P
0 g
s
.47273 .8557 m .4602 .86784 L .49881 .84799 L p .927 .847 .743 r
F P
0 g
s
.4602 .86784 m .44834 .87837 L .48139 .86206 L p .947 .919 .752 r
F P
0 g
s
.4602 .86784 m .47273 .8557 L .45952 .86953 L p .938 .931 .574 r
F P
0 g
s
.45875 .87323 m .45057 .87727 L p .4634 .87408 L .919 .978 .734 r
F P
0 g
s
.44977 .87796 m .4634 .87408 L .45057 .87727 L .919 .978 .734 r
F
.45057 .87727 m .44834 .87837 L p .44977 .87796 L F P
0 g
s
.44834 .87837 m .44866 .87809 L p .44302 .88906 L .645 .804 .365 r
F P
0 g
s
.44678 .88442 m .44302 .88906 L p .44866 .87809 L .645 .804 .365 r
F P
0 g
s
.44866 .87809 m .4602 .86784 L .44678 .88442 L p .645 .804 .365 r
F P
0 g
s
.43974 .89312 m .44213 .88909 L .44184 .88951 L .645 .804 .365 r
F
.44302 .88906 m .43974 .89312 L p .44184 .88951 L F P
0 g
s
.44679 .88286 m .43974 .89312 L .45044 .87989 L p .938 .931 .574 r
F P
0 g
s
.43974 .89312 m .44679 .88286 L .44081 .91058 L p 0 0 .111 r
F P
0 g
s
.4429 .89944 m .44081 .91058 L .44415 .8951 L p .814 .722 .191 r
F P
0 g
s
.4429 .89944 m .44415 .8951 L .44406 .89469 L .814 .722 .191 r
F
.4429 .89944 m .44561 .88835 L .4451 .89007 L F
.44415 .8951 m .44561 .88835 L p .44406 .89469 L F P
0 g
s
.44561 .88835 m .44679 .88286 L p .4451 .89007 L .814 .722 .191 r
F P
0 g
s
.4488 .88062 m .45044 .87989 L .4562 .87277 L .938 .931 .574 r
F
.4562 .87277 m .4602 .86784 L p .45585 .87271 L F P
0 g
s
.4488 .88062 m .4562 .87277 L .45585 .87271 L .938 .931 .574 r
F
.44679 .88286 m .45044 .87989 L .4488 .88062 L F
.44837 .88121 m .45585 .87271 L .4577 .87111 L F
.45952 .86953 m .45588 .87335 L p .4577 .87111 L F P
0 g
s
.45588 .87335 m .44837 .88121 L p .4577 .87111 L .938 .931 .574 r
F P
0 g
s
.45236 .87768 m .4429 .89944 L p .44679 .88286 L .814 .722 .191 r
F P
0 g
s
.44632 .88779 m .4429 .89944 L .45236 .87768 L p .992 .787 .407 r
F P
0 g
s
.44815 .88134 m .45585 .87271 L .44837 .88121 L .938 .931 .574 r
F
.44837 .88121 m .44679 .88286 L p .44815 .88134 L F P
0 g
s
.45585 .87271 m .4602 .86784 L .45952 .86953 L .938 .931 .574 r
F
.45504 .87153 m .44679 .88286 L .46738 .8613 L p .985 .878 .641 r
F P
0 g
s
.44679 .88286 m .45504 .87153 L .45236 .87768 L p .814 .722 .191 r
F P
0 g
s
.45236 .87768 m .45504 .87153 L p .45053 .87993 L .992 .787 .407 r
F P
0 g
s
.44632 .88779 m .45236 .87768 L .45053 .87993 L .992 .787 .407 r
F
.45504 .87153 m .46738 .8613 L .46647 .8613 L .985 .878 .641 r
F
.47273 .8557 m .47387 .85445 L p .45504 .87153 L F P
0 g
s
.47387 .85445 m .48525 .84194 L .46582 .86097 L p .985 .878 .641 r
F P
0 g
s
.46582 .86097 m .45504 .87153 L p .47387 .85445 L .985 .878 .641 r
F P
0 g
s
.46392 .85903 m .45504 .87153 L .48525 .84194 L p .951 .796 .653 r
F P
0 g
s
.45504 .87153 m .46392 .85903 L .45147 .87938 L p .992 .787 .407 r
F P
0 g
s
.45147 .87938 m .44632 .88779 L p .45053 .87993 L .992 .787 .407 r
F P
0 g
s
.45053 .87993 m .45504 .87153 L .45147 .87938 L .992 .787 .407 r
F
.45073 .87552 m .44632 .88779 L .45969 .86593 L p .977 .731 .496 r
F P
0 g
s
.45969 .86593 m .46392 .85903 L p .456 .86892 L .977 .731 .496 r
F P
0 g
s
.45073 .87552 m .45969 .86593 L .456 .86892 L .977 .731 .496 r
F
.4429 .89944 m .44632 .88779 L .44672 .90649 L p 0 0 .243 r
F P
0 g
s
.44672 .90649 m .44678 .90972 L p .44643 .90878 L 0 0 .243 r
F P
0 g
s
.44643 .90878 m .4429 .89944 L .44672 .90649 L 0 0 .243 r
F
.44392 .89706 m .44678 .90972 L .44632 .88779 L p .881 .511 .033 r
F P
0 g
s
.44632 .88779 m .45073 .87552 L .44392 .89706 L p .881 .511 .033 r
F P
0 g
s
.44221 .88452 m .44392 .89706 L .45044 .87644 L p .926 .539 .22 r
F P
0 g
s
.45044 .87644 m .45073 .87552 L p .45052 .87573 L .926 .539 .22 r
F P
0 g
s
.44221 .88452 m .45044 .87644 L .45052 .87573 L .926 .539 .22 r
F
.44392 .89706 m .44297 .89008 L p .44282 .8936 L 0 0 .491 r
F P
0 g
s
.44297 .89008 m .44221 .88452 L .44243 .88778 L p 0 0 .491 r
F P
0 g
s
.44243 .88778 m .44282 .8936 L p .44297 .89008 L 0 0 .491 r
F P
0 g
s
.46738 .8613 m .47273 .8557 L p .46647 .8613 L .985 .878 .641 r
F P
0 g
s
.4634 .87408 m .46383 .87395 L .45875 .87323 L .919 .978 .734 r
F
.46359 .87409 m .46383 .87395 L .46341 .87417 L p .771 .957 .641 r
F P
0 g
s
.29413 .52208 m .27208 .53694 L .31887 .52281 L p .393 .848 .898 r
F P
0 g
s
.31887 .52281 m .34203 .51364 L .29413 .52208 L p .393 .848 .898 r
F P
0 g
s
.5004 .6068 m .48366 .59328 L .49831 .64212 L p .416 .398 .732 r
F P
0 g
s
.49831 .64212 m .50796 .65802 L .5004 .6068 L p .416 .398 .732 r
F P
0 g
s
.50796 .65802 m .49831 .64212 L .49826 .69336 L p .439 .333 .638 r
F P
0 g
s
.49826 .69336 m .50182 .70995 L .50796 .65802 L p .439 .333 .638 r
F P
0 g
s
.50182 .70995 m .49826 .69336 L .48353 .74175 L p .445 .254 .527 r
F P
0 g
s
.64881 1.25033 m .70088 1.21347 L .68673 1.18964 L p .404 .108 .345 r
F P
0 g
s
.73867 1.14936 m .68673 1.18964 L .70088 1.21347 L p .257 0 .281 r
F P
0 g
s
.73867 1.14936 m .7809 1.104 L .76481 1.0727 L p .372 .177 .482 r
F P
0 g
s
.80213 1.02497 m .76481 1.0727 L .7809 1.104 L p .215 .054 .436 r
F P
0 g
s
.42983 .79099 m .42256 .80102 L .4593 .76907 L p 0 0 0 r
F P
0 g
s
.42256 .80102 m .42983 .79099 L .38635 .81329 L p 0 0 0 r
F P
0 g
s
.51524 .8318 m .52993 .81363 L .48525 .84194 L p .894 .782 .73 r
F P
0 g
s
.52993 .81363 m .54218 .79373 L .4971 .82659 L p .858 .728 .718 r
F P
0 g
s
.4971 .82659 m .48525 .84194 L .52993 .81363 L p .858 .728 .718 r
F P
0 g
s
.54218 .79373 m .5514 .77243 L .50767 .80979 L p .823 .682 .708 r
F P
0 g
s
.50767 .80979 m .4971 .82659 L .54218 .79373 L p .823 .682 .708 r
F P
0 g
s
.41731 .52235 m .39014 .52182 L .43331 .54557 L p .299 .578 .938 r
F P
0 g
s
.43331 .54557 m .45574 .55189 L .41731 .52235 L p .299 .578 .938 r
F P
0 g
s
.5164 .62269 m .5004 .6068 L .50796 .65802 L p .493 .434 .72 r
F P
0 g
s
.50796 .65802 m .51624 .67535 L .5164 .62269 L p .493 .434 .72 r
F P
0 g
s
.51624 .67535 m .50796 .65802 L .50182 .70995 L p .521 .386 .638 r
F P
0 g
s
.55717 .75013 m .5514 .77243 L .59986 .73679 L p .73 .627 .744 r
F P
0 g
s
.5514 .77243 m .55717 .75013 L .51642 .79174 L p .788 .643 .701 r
F P
0 g
s
.51642 .79174 m .50767 .80979 L .5514 .77243 L p .788 .643 .701 r
F P
0 g
s
.49881 .84799 m .51524 .8318 L .47273 .8557 L p .927 .847 .743 r
F P
0 g
s
.48525 .84194 m .47273 .8557 L .51524 .8318 L p .894 .782 .73 r
F P
0 g
s
.50182 .70995 m .50401 .72721 L .51624 .67535 L p .521 .386 .638 r
F P
0 g
s
.50401 .72721 m .50182 .70995 L .48259 .75736 L p .535 .325 .541 r
F P
0 g
s
.48353 .74175 m .48259 .75736 L .50182 .70995 L p .445 .254 .527 r
F P
0 g
s
.64956 .73891 m .64848 .70624 L .59986 .73679 L p .693 .629 .781 r
F P
0 g
s
.59981 .7096 m .59986 .73679 L .64848 .70624 L p .667 .612 .783 r
F P
0 g
s
.59986 .73679 m .59981 .7096 L .55717 .75013 L p .73 .627 .744 r
F P
0 g
s
.47982 .56149 m .45574 .55189 L .48366 .59328 L p .39 .474 .826 r
F P
0 g
s
.48366 .59328 m .5004 .6068 L .47982 .56149 L p .39 .474 .826 r
F P
0 g
s
.25165 .54643 m .23251 .56563 L .27208 .53694 L p .443 .856 .692 r
F P
0 g
s
.27208 .53694 m .29413 .52208 L .25165 .54643 L p .443 .856 .692 r
F P
0 g
s
.48259 .75736 m .48353 .74175 L .45553 .78227 L p .424 .133 .364 r
F P
0 g
s
.4593 .76907 m .45553 .78227 L .48353 .74175 L p .276 .002 .305 r
F P
0 g
s
.70166 .76091 m .70169 .72217 L .64956 .73891 L p .639 .608 .802 r
F P
0 g
s
.64848 .70624 m .64956 .73891 L .70169 .72217 L p .612 .597 .811 r
F P
0 g
s
.45553 .78227 m .4593 .76907 L .42256 .80102 L p .215 0 .019 r
F P
0 g
s
.5592 .7273 m .55717 .75013 L .59981 .7096 L p .701 .602 .743 r
F P
0 g
s
.55717 .75013 m .5592 .7273 L .52294 .77271 L p .754 .608 .697 r
F P
0 g
s
.52294 .77271 m .51642 .79174 L .55717 .75013 L p .754 .608 .697 r
F P
0 g
s
.53079 .64075 m .5164 .62269 L .51624 .67535 L p .553 .465 .71 r
F P
0 g
s
.51624 .67535 m .52262 .69386 L .53079 .64075 L p .553 .465 .71 r
F P
0 g
s
.52262 .69386 m .51624 .67535 L .50401 .72721 L p .585 .43 .637 r
F P
0 g
s
.74937 .80424 m .75317 .75974 L .70166 .76091 L p .571 .557 .8 r
F P
0 g
s
.70169 .72217 m .70166 .76091 L .75317 .75974 L p .532 .547 .816 r
F P
0 g
s
.38635 .81329 m .3774 .81873 L .42256 .80102 L p 0 0 0 r
F P
0 g
s
.3774 .81873 m .38635 .81329 L .3377 .82015 L p .043 .612 .727 r
F P
0 g
s
.50401 .72721 m .50457 .7449 L .52262 .69386 L p .585 .43 .637 r
F P
0 g
s
.50457 .7449 m .50401 .72721 L .4809 .77312 L p .605 .38 .549 r
F P
0 g
s
.48259 .75736 m .4809 .77312 L .50401 .72721 L p .535 .325 .541 r
F P
0 g
s
.54281 .66068 m .53079 .64075 L .52262 .69386 L p .603 .494 .702 r
F P
0 g
s
.52262 .69386 m .52669 .71322 L .54281 .66068 L p .603 .494 .702 r
F P
0 g
s
.52669 .71322 m .52262 .69386 L .50457 .7449 L p .638 .468 .636 r
F P
0 g
s
.59981 .7096 m .59446 .68268 L .5592 .7273 L p .701 .602 .743 r
F P
0 g
s
.55739 .70444 m .5592 .7273 L .59446 .68268 L p .671 .58 .745 r
F P
0 g
s
.5592 .7273 m .55739 .70444 L .52691 .75304 L p .719 .577 .695 r
F P
0 g
s
.52691 .75304 m .52294 .77271 L .5592 .7273 L p .719 .577 .695 r
F P
0 g
s
.55183 .68206 m .54281 .66068 L .52669 .71322 L p .645 .521 .697 r
F P
0 g
s
.52669 .71322 m .52816 .73308 L .55183 .68206 L p .645 .521 .697 r
F P
0 g
s
.52816 .73308 m .52669 .71322 L .50334 .76277 L p .684 .504 .636 r
F P
0 g
s
.50457 .7449 m .50334 .76277 L .52669 .71322 L p .638 .468 .636 r
F P
0 g
s
.41457 .90836 m .4317 .90424 L .42334 .89998 L p .609 .943 .76 r
F P
0 g
s
.42933 .89524 m .42339 .90206 L .42975 .89386 L p 0 0 0 r
F P
0 g
s
.42975 .89386 m .43159 .89149 L p .43072 .89294 L 0 0 0 r
F P
0 g
s
.42933 .89524 m .42975 .89386 L .43072 .89294 L 0 0 0 r
F
.40969 .90953 m .41457 .90836 L p .41853 .89753 L .609 .943 .76 r
F P
0 g
s
.42334 .89998 m .41853 .89753 L p .41457 .90836 L .609 .943 .76 r
F P
0 g
s
.50438 .57446 m .47982 .56149 L .5004 .6068 L p .459 .49 .803 r
F P
0 g
s
.5004 .6068 m .5164 .62269 L .50438 .57446 L p .459 .49 .803 r
F P
0 g
s
.7854 .86675 m .79539 .81778 L .74937 .80424 L p .493 .477 .768 r
F P
0 g
s
.75317 .75974 m .74937 .80424 L .79539 .81778 L p .427 .455 .787 r
F P
0 g
s
.55739 .70444 m .55183 .68206 L .52816 .73308 L p .684 .549 .695 r
F P
0 g
s
.52816 .73308 m .52691 .75304 L .55739 .70444 L p .684 .549 .695 r
F P
0 g
s
.52691 .75304 m .52816 .73308 L .50029 .78052 L p .727 .54 .637 r
F P
0 g
s
.50334 .76277 m .50029 .78052 L .52816 .73308 L p .684 .504 .636 r
F P
0 g
s
.21936 .5842 m .20453 .60585 L .23251 .56563 L p 0 0 0 r
F P
0 g
s
.23251 .56563 m .25165 .54643 L .21936 .5842 L p 0 0 0 r
F P
0 g
s
.52294 .77271 m .52691 .75304 L .49547 .79789 L p .769 .577 .639 r
F P
0 g
s
.50029 .78052 m .49547 .79789 L .52691 .75304 L p .727 .54 .637 r
F P
0 g
s
.59446 .68268 m .58405 .6567 L .55739 .70444 L p .671 .58 .745 r
F P
0 g
s
.55183 .68206 m .55739 .70444 L .58405 .6567 L p .638 .56 .75 r
F P
0 g
s
.64848 .70624 m .64031 .674 L .59981 .7096 L p .667 .612 .783 r
F P
0 g
s
.59446 .68268 m .59981 .7096 L .64031 .674 L p .641 .596 .789 r
F P
0 g
s
.4809 .77312 m .48259 .75736 L .45212 .79539 L p .527 .224 .397 r
F P
0 g
s
.45553 .78227 m .45212 .79539 L .48259 .75736 L p .424 .133 .364 r
F P
0 g
s
.50334 .76277 m .50457 .7449 L .47836 .78889 L p .663 .427 .553 r
F P
0 g
s
.4809 .77312 m .47836 .78889 L .50457 .7449 L p .605 .38 .549 r
F P
0 g
s
.51642 .79174 m .52294 .77271 L .48909 .81462 L p .811 .619 .642 r
F P
0 g
s
.49547 .79789 m .48909 .81462 L .52294 .77271 L p .769 .577 .639 r
F P
0 g
s
.3723 .50795 m .34203 .51364 L .39014 .52182 L p .293 .701 .974 r
F P
0 g
s
.39014 .52182 m .41731 .52235 L .3723 .50795 L p .293 .701 .974 r
F P
0 g
s
.80393 .94294 m .8215 .89154 L .7854 .86675 L p .411 .369 .702 r
F P
0 g
s
.79539 .81778 m .7854 .86675 L .8215 .89154 L p .301 .317 .71 r
F P
0 g
s
.5282 .59077 m .50438 .57446 L .5164 .62269 L p .516 .506 .784 r
F P
0 g
s
.5164 .62269 m .53079 .64075 L .5282 .59077 L p .516 .506 .784 r
F P
0 g
s
.50767 .80979 m .51642 .79174 L .48143 .83049 L p .855 .667 .647 r
F P
0 g
s
.48909 .81462 m .48143 .83049 L .51642 .79174 L p .811 .619 .642 r
F P
0 g
s
.58405 .6567 m .56903 .63234 L .55183 .68206 L p .638 .56 .75 r
F P
0 g
s
.54281 .66068 m .55183 .68206 L .56903 .63234 L p .603 .541 .758 r
F P
0 g
s
.32861 .82013 m .3377 .82015 L .28917 .81073 L p 0 .523 .836 r
F P
0 g
s
.3377 .82015 m .32861 .82013 L .3774 .81873 L p .043 .612 .727 r
F P
0 g
s
.33838 .93667 m .36271 .93912 L .37563 .91339 L p .599 .949 .902 r
F P
0 g
s
.3907 .91245 m .37563 .91339 L .36271 .93912 L p .72 .975 .924 r
F P
0 g
s
.44814 .52682 m .41731 .52235 L .45574 .55189 L p .357 .567 .917 r
F P
0 g
s
.45574 .55189 m .47982 .56149 L .44814 .52682 L p .357 .567 .917 r
F P
0 g
s
.56903 .63234 m .55011 .61019 L .54281 .66068 L p .603 .541 .758 r
F P
0 g
s
.53079 .64075 m .54281 .66068 L .55011 .61019 L p .562 .523 .769 r
F P
0 g
s
.55011 .61019 m .5282 .59077 L .53079 .64075 L p .562 .523 .769 r
F P
0 g
s
.50029 .78052 m .50334 .76277 L .47499 .8045 L p .714 .471 .555 r
F P
0 g
s
.47836 .78889 m .47499 .8045 L .50334 .76277 L p .663 .427 .553 r
F P
0 g
s
.42256 .80102 m .41703 .81062 L .45553 .78227 L p .215 0 .019 r
F P
0 g
s
.41703 .81062 m .42256 .80102 L .3774 .81873 L p .134 0 0 r
F P
0 g
s
.45212 .79539 m .45553 .78227 L .41703 .81062 L p .378 0 .107 r
F P
0 g
s
.4971 .82659 m .50767 .80979 L .47289 .84533 L p .903 .724 .651 r
F P
0 g
s
.48143 .83049 m .47289 .84533 L .50767 .80979 L p .855 .667 .647 r
F P
0 g
s
.20095 .63129 m .19128 .65325 L .20453 .60585 L p 0 0 0 r
F P
0 g
s
.20453 .60585 m .21936 .5842 L .20095 .63129 L p 0 0 0 r
F P
0 g
s
.70169 .72217 m .6926 .68377 L .64848 .70624 L p .612 .597 .811 r
F P
0 g
s
.64031 .674 m .64848 .70624 L .6926 .68377 L p .583 .588 .823 r
F P
0 g
s
.47836 .78889 m .4809 .77312 L .4491 .80841 L p .605 .293 .414 r
F P
0 g
s
.45212 .79539 m .4491 .80841 L .4809 .77312 L p .527 .224 .397 r
F P
0 g
s
.80213 1.02497 m .8272 .97344 L .80393 .94294 L p .324 .234 .597 r
F P
0 g
s
.8215 .89154 m .80393 .94294 L .8272 .97344 L p .153 .126 .572 r
F P
0 g
s
.64031 .674 m .62535 .6431 L .59446 .68268 L p .641 .596 .789 r
F P
0 g
s
.58405 .6567 m .59446 .68268 L .62535 .6431 L p .612 .583 .798 r
F P
0 g
s
.37196 .8236 m .3774 .81873 L .32861 .82013 L p 0 .544 .724 r
F P
0 g
s
.28917 .81073 m .28361 .80646 L p .32861 .82013 L 0 .523 .836 r
F P
0 g
s
.29772 .81011 m .32861 .82013 L p .28361 .80646 L 0 .523 .836 r
F P
0 g
s
.28361 .80646 m .2815 .80484 L .29772 .81011 L p 0 .523 .836 r
F P
0 g
s
.32506 .81952 m .32861 .82013 L .2815 .80484 L p .037 .521 .882 r
F P
0 g
s
.32861 .82013 m .32506 .81952 L .37196 .8236 L p 0 .544 .724 r
F P
0 g
s
.37028 .82827 m .37196 .8236 L .33883 .82072 L p 0 .504 .753 r
F P
0 g
s
.33883 .82072 m .32506 .81952 L p .36152 .82658 L 0 .504 .753 r
F P
0 g
s
.36152 .82658 m .37028 .82827 L .33883 .82072 L 0 .504 .753 r
F
.2815 .80484 m .28917 .81073 L .2461 .78599 L p 0 .358 .813 r
F P
0 g
s
.70088 1.21347 m .74463 1.17166 L .73867 1.14936 L p .257 0 .281 r
F P
0 g
s
.7809 1.104 m .73867 1.14936 L .74463 1.17166 L p .027 0 .163 r
F P
0 g
s
.49547 .79789 m .50029 .78052 L .47085 .8198 L p .764 .513 .555 r
F P
0 g
s
.47499 .8045 m .47085 .8198 L .50029 .78052 L p .714 .471 .555 r
F P
0 g
s
.48525 .84194 m .4971 .82659 L .46392 .85903 L p .951 .796 .653 r
F P
0 g
s
.47289 .84533 m .46392 .85903 L .4971 .82659 L p .903 .724 .651 r
F P
0 g
s
.19858 .68249 m .19429 .70265 L .19128 .65325 L p 0 0 .271 r
F P
0 g
s
.19128 .65325 m .20095 .63129 L .19858 .68249 L p 0 0 .271 r
F P
0 g
s
.2461 .78599 m .2413 .77439 L .2815 .80484 L p 0 .358 .813 r
F P
0 g
s
.2413 .77439 m .2461 .78599 L .21326 .74859 L p 0 .157 .698 r
F P
0 g
s
.50056 1.34402 m .55735 1.32069 L .52684 1.30718 L p .483 .071 .182 r
F P
0 g
s
.52684 1.30718 m .46084 1.32658 L .50056 1.34402 L p .483 .071 .182 r
F P
0 g
s
.59016 1.28169 m .52684 1.30718 L .55735 1.32069 L p .374 0 .132 r
F P
0 g
s
.21256 .73204 m .21326 .74859 L .19429 .70265 L p 0 0 .515 r
F P
0 g
s
.19429 .70265 m .19858 .68249 L .21256 .73204 L p 0 0 .515 r
F P
0 g
s
.48119 .53564 m .44814 .52682 L .47982 .56149 L p .412 .56 .892 r
F P
0 g
s
.47982 .56149 m .50438 .57446 L .48119 .53564 L p .412 .56 .892 r
F P
0 g
s
.48909 .81462 m .49547 .79789 L .4661 .83465 L p .813 .558 .552 r
F P
0 g
s
.47085 .8198 m .4661 .83465 L .49547 .79789 L p .764 .513 .555 r
F P
0 g
s
.32542 .51053 m .29413 .52208 L .34203 .51364 L p .26 .765 .869 r
F P
0 g
s
.34203 .51364 m .3723 .50795 L .32542 .51053 L p .26 .765 .869 r
F P
0 g
s
.21326 .74859 m .21256 .73204 L .2413 .77439 L p 0 .157 .698 r
F P
0 g
s
.3907 .91245 m .40969 .90953 L .40847 .90216 L p .357 .793 .62 r
F P
0 g
s
.41853 .89753 m .40847 .90216 L .40969 .90953 L p .609 .943 .76 r
F P
0 g
s
.55735 1.32069 m .61067 1.29223 L .59016 1.28169 L p .374 0 .132 r
F P
0 g
s
.64881 1.25033 m .59016 1.28169 L .61067 1.29223 L p .219 0 .043 r
F P
0 g
s
.62535 .6431 m .60425 .61442 L .58405 .6567 L p .612 .583 .798 r
F P
0 g
s
.56903 .63234 m .58405 .6567 L .60425 .61442 L p .58 .573 .81 r
F P
0 g
s
.47499 .8045 m .47836 .78889 L .44649 .82134 L p .67 .348 .42 r
F P
0 g
s
.4491 .80841 m .44649 .82134 L .47836 .78889 L p .605 .293 .414 r
F P
0 g
s
.4491 .80841 m .45212 .79539 L .41338 .81999 L p .493 .064 .153 r
F P
0 g
s
.41703 .81062 m .41338 .81999 L .45212 .79539 L p .378 0 .107 r
F P
0 g
s
.75317 .75974 m .74591 .71514 L .70169 .72217 L p .532 .547 .816 r
F P
0 g
s
.6926 .68377 m .70169 .72217 L .74591 .71514 L p .488 .54 .836 r
F P
0 g
s
.3774 .81873 m .37196 .8236 L .41703 .81062 L p .134 0 0 r
F P
0 g
s
.7809 1.104 m .81181 1.05445 L .80213 1.02497 L p .215 .054 .436 r
F P
0 g
s
.8272 .97344 m .80213 1.02497 L .81181 1.05445 L p 0 0 .341 r
F P
0 g
s
.48143 .83049 m .48909 .81462 L .46097 .84894 L p .866 .607 .545 r
F P
0 g
s
.4661 .83465 m .46097 .84894 L .48909 .81462 L p .813 .558 .552 r
F P
0 g
s
.40847 .50666 m .3723 .50795 L .41731 .52235 L p .295 .666 .973 r
F P
0 g
s
.41731 .52235 m .44814 .52682 L .40847 .50666 L p .295 .666 .973 r
F P
0 g
s
.51492 .54898 m .48119 .53564 L .50438 .57446 L p .462 .558 .867 r
F P
0 g
s
.50438 .57446 m .5282 .59077 L .51492 .54898 L p .462 .558 .867 r
F P
0 g
s
.60425 .61442 m .57796 .58876 L .56903 .63234 L p .58 .573 .81 r
F P
0 g
s
.55011 .61019 m .56903 .63234 L .57796 .58876 L p .545 .565 .825 r
F P
0 g
s
.6926 .68377 m .67471 .64685 L .64031 .674 L p .583 .588 .823 r
F P
0 g
s
.62535 .6431 m .64031 .674 L .67471 .64685 L p .552 .583 .839 r
F P
0 g
s
.41338 .81999 m .41703 .81062 L .37196 .8236 L p .275 0 0 r
F P
0 g
s
.5477 .56678 m .51492 .54898 L .5282 .59077 L p .506 .56 .845 r
F P
0 g
s
.5282 .59077 m .55011 .61019 L .5477 .56678 L p .506 .56 .845 r
F P
0 g
s
.57796 .58876 m .5477 .56678 L .55011 .61019 L p .545 .565 .825 r
F P
0 g
s
.47085 .8198 m .47499 .8045 L .44433 .83416 L p .728 .395 .416 r
F P
0 g
s
.44649 .82134 m .44433 .83416 L .47499 .8045 L p .67 .348 .42 r
F P
0 g
s
.61067 1.29223 m .65879 1.2589 L .64881 1.25033 L p .219 0 .043 r
F P
0 g
s
.70088 1.21347 m .64881 1.25033 L .65879 1.2589 L p 0 0 0 r
F P
0 g
s
.79539 .81778 m .79279 .76799 L .75317 .75974 L p .427 .455 .787 r
F P
0 g
s
.74591 .71514 m .75317 .75974 L .79279 .76799 L p .343 .432 .809 r
F P
0 g
s
.47289 .84533 m .48143 .83049 L .45573 .86257 L p .922 .665 .53 r
F P
0 g
s
.46097 .84894 m .45573 .86257 L .48143 .83049 L p .866 .607 .545 r
F P
0 g
s
.28179 .53011 m .25165 .54643 L .29413 .52208 L p 0 0 0 r
F P
0 g
s
.29413 .52208 m .32542 .51053 L .28179 .53011 L p 0 0 0 r
F P
0 g
s
.37563 .91339 m .36525 .91288 L .33838 .93667 L p .599 .949 .902 r
F P
0 g
s
.44649 .82134 m .4491 .80841 L .4117 .82928 L p .579 .14 .17 r
F P
0 g
s
.41338 .81999 m .4117 .82928 L .4491 .80841 L p .493 .064 .153 r
F P
0 g
s
.4661 .83465 m .47085 .8198 L .44272 .84687 L p .783 .438 .402 r
F P
0 g
s
.44433 .83416 m .44272 .84687 L .47085 .8198 L p .728 .395 .416 r
F P
0 g
s
.37563 .91339 m .3907 .91245 L .40201 .90578 L p 0 0 0 r
F P
0 g
s
.40847 .90216 m .40201 .90578 L .3907 .91245 L p .357 .793 .62 r
F P
0 g
s
.67471 .64685 m .64874 .61256 L .62535 .6431 L p .552 .583 .839 r
F P
0 g
s
.60425 .61442 m .62535 .6431 L .64874 .61256 L p .517 .58 .858 r
F P
0 g
s
.46392 .85903 m .47289 .84533 L .45073 .87552 L p .977 .731 .496 r
F P
0 g
s
.45573 .86257 m .45073 .87552 L .47289 .84533 L p .922 .665 .53 r
F P
0 g
s
.8215 .89154 m .82566 .83843 L .79539 .81778 L p .301 .317 .71 r
F P
0 g
s
.79279 .76799 m .79539 .81778 L .82566 .83843 L p .141 .243 .709 r
F P
0 g
s
.44899 .51048 m .40847 .50666 L .44814 .52682 L p .318 .638 .965 r
F P
0 g
s
.44814 .52682 m .48119 .53564 L .44899 .51048 L p .318 .638 .965 r
F P
0 g
s
.41853 .89753 m .43159 .89149 L .42339 .90206 L p 0 0 0 r
F P
0 g
s
.74463 1.17166 m .77845 1.12564 L .7809 1.104 L p .027 0 .163 r
F P
0 g
s
.81181 1.05445 m .7809 1.104 L .77845 1.12564 L p 0 0 0 r
F P
0 g
s
.74591 .71514 m .72776 .67182 L .6926 .68377 L p .488 .54 .836 r
F P
0 g
s
.67471 .64685 m .6926 .68377 L .72776 .67182 L p .436 .536 .86 r
F P
0 g
s
.4117 .82928 m .41338 .81999 L .37028 .82827 L p .372 0 0 r
F P
0 g
s
.37196 .8236 m .37028 .82827 L .41338 .81999 L p .275 0 0 r
F P
0 g
s
.36488 .5035 m .32542 .51053 L .3723 .50795 L p .156 .688 .854 r
F P
0 g
s
.3723 .50795 m .40847 .50666 L .36488 .5035 L p .156 .688 .854 r
F P
0 g
s
.24633 .5648 m .21936 .5842 L .25165 .54643 L p 0 0 0 r
F P
0 g
s
.25165 .54643 m .28179 .53011 L .24633 .5648 L p 0 0 0 r
F P
0 g
s
.65879 1.2589 m .70012 1.22112 L .70088 1.21347 L p 0 0 0 r
F P
0 g
s
.74463 1.17166 m .70088 1.21347 L .70012 1.22112 L p 0 0 0 r
F P
0 g
s
.44433 .83416 m .44649 .82134 L .41205 .83869 L p .648 .195 .162 r
F P
0 g
s
.4117 .82928 m .41205 .83869 L .44649 .82134 L p .579 .14 .17 r
F P
0 g
s
.46097 .84894 m .4661 .83465 L .44174 .85948 L p .838 .479 .374 r
F P
0 g
s
.44272 .84687 m .44174 .85948 L .4661 .83465 L p .783 .438 .402 r
F P
0 g
s
.8272 .97344 m .83885 .91939 L .8215 .89154 L p .153 .126 .572 r
F P
0 g
s
.82566 .83843 m .8215 .89154 L .83885 .91939 L p 0 0 .501 r
F P
0 g
s
.2815 .80484 m .28145 .79853 L .32506 .81952 L p .037 .521 .882 r
F P
0 g
s
.28145 .79853 m .2815 .80484 L .2413 .77439 L p .072 .406 .859 r
F P
0 g
s
.64874 .61256 m .61583 .58194 L .60425 .61442 L p .517 .58 .858 r
F P
0 g
s
.57796 .58876 m .60425 .61442 L .61583 .58194 L p .479 .582 .88 r
F P
0 g
s
.49203 .51988 m .44899 .51048 L .48119 .53564 L p .354 .616 .949 r
F P
0 g
s
.48119 .53564 m .51492 .54898 L .49203 .51988 L p .354 .616 .949 r
F P
0 g
s
.22318 .61089 m .20095 .63129 L .21936 .5842 L p 0 0 .186 r
F P
0 g
s
.21936 .5842 m .24633 .5648 L .22318 .61089 L p 0 0 .186 r
F P
0 g
s
.61583 .58194 m .5775 .55587 L .57796 .58876 L p .479 .582 .88 r
F P
0 g
s
.5477 .56678 m .57796 .58876 L .5775 .55587 L p .439 .588 .904 r
F P
0 g
s
.45573 .86257 m .46097 .84894 L .44153 .87202 L p .891 .516 .321 r
F P
0 g
s
.44174 .85948 m .44153 .87202 L .46097 .84894 L p .838 .479 .374 r
F P
0 g
s
.53556 .53505 m .49203 .51988 L .51492 .54898 L p .396 .599 .928 r
F P
0 g
s
.51492 .54898 m .5477 .56678 L .53556 .53505 L p .396 .599 .928 r
F P
0 g
s
.40847 .90216 m .41853 .89753 L .42047 .90825 L p .152 0 0 r
F P
0 g
s
.42339 .90206 m .42047 .90825 L .41853 .89753 L p 0 0 0 r
F P
0 g
s
.2413 .77439 m .24607 .76267 L .28145 .79853 L p .072 .406 .859 r
F P
0 g
s
.24607 .76267 m .2413 .77439 L .21256 .73204 L p .079 .267 .754 r
F P
0 g
s
.79279 .76799 m .77751 .71887 L .74591 .71514 L p .343 .432 .809 r
F P
0 g
s
.72776 .67182 m .74591 .71514 L .77751 .71887 L p .231 .403 .828 r
F P
0 g
s
.5775 .55587 m .53556 .53505 L .5477 .56678 L p .439 .588 .904 r
F P
0 g
s
.81181 1.05445 m .83007 1.00182 L .8272 .97344 L p 0 0 .341 r
F P
0 g
s
.83885 .91939 m .8272 .97344 L .83007 1.00182 L p 0 0 .144 r
F P
0 g
s
.44272 .84687 m .44433 .83416 L .41442 .8484 L p .705 .233 .127 r
F P
0 g
s
.41205 .83869 m .41442 .8484 L .44433 .83416 L p .648 .195 .162 r
F P
0 g
s
.40201 .90578 m .39957 .90887 L .37563 .91339 L p 0 0 0 r
F P
0 g
s
.36525 .91288 m .37563 .91339 L .39957 .90887 L p .113 0 0 r
F P
0 g
s
.72776 .67182 m .69939 .63115 L .67471 .64685 L p .436 .536 .86 r
F P
0 g
s
.64874 .61256 m .67471 .64685 L .69939 .63115 L p .376 .535 .886 r
F P
0 g
s
.41205 .83869 m .4117 .82928 L .37248 .83315 L p .431 0 0 r
F P
0 g
s
.37028 .82827 m .37248 .83315 L .4117 .82928 L p .372 0 0 r
F P
0 g
s
.21509 .66322 m .19858 .68249 L .20095 .63129 L p .039 0 .428 r
F P
0 g
s
.20095 .63129 m .22318 .61089 L .21509 .66322 L p .039 0 .428 r
F P
0 g
s
.21256 .73204 m .22304 .71582 L .24607 .76267 L p .079 .267 .754 r
F P
0 g
s
.22304 .71582 m .21256 .73204 L .19858 .68249 L p .067 .121 .61 r
F P
0 g
s
.32209 .51812 m .28179 .53011 L .32542 .51053 L p .048 0 0 r
F P
0 g
s
.32542 .51053 m .36488 .5035 L .32209 .51812 L p .048 0 0 r
F P
0 g
s
.42933 .89524 m .43784 .88744 L .43123 .91112 L p .239 0 .099 r
F P
0 g
s
.41096 .50205 m .36488 .5035 L .40847 .50666 L p .093 .628 .861 r
F P
0 g
s
.40847 .50666 m .44899 .51048 L .41096 .50205 L p .093 .628 .861 r
F P
0 g
s
.19858 .68249 m .21509 .66322 L .22304 .71582 L p .067 .121 .61 r
F P
0 g
s
.32506 .81952 m .32736 .81897 L .36401 .82691 L p 0 .504 .753 r
F P
0 g
s
.32506 .81952 m .36401 .82691 L .36614 .82747 L 0 .504 .753 r
F
.36401 .82691 m .37028 .82827 L p .36614 .82747 L F P
0 g
s
.37248 .83315 m .37028 .82827 L .32736 .81897 L p 0 .49 .805 r
F P
0 g
s
.32736 .81897 m .33563 .81911 L .36695 .83104 L p 0 .49 .805 r
F P
0 g
s
.36695 .83104 m .37248 .83315 L p .36823 .83182 L 0 .49 .805 r
F P
0 g
s
.32736 .81897 m .36695 .83104 L .36823 .83182 L 0 .49 .805 r
F
.37858 .83865 m .37248 .83315 L .33869 .82028 L p 0 .493 .86 r
F P
0 g
s
.33752 .81997 m .37858 .83865 L .33869 .82028 L 0 .493 .86 r
F
.33869 .82028 m .33563 .81911 L p .33752 .81997 L F P
0 g
s
.33563 .81911 m .34975 .82063 L .37858 .83865 L p 0 .493 .86 r
F P
0 g
s
.38843 .84517 m .37858 .83865 L .35227 .8222 L p .082 .503 .9 r
F P
0 g
s
.35227 .8222 m .34975 .82063 L p .35155 .82177 L .082 .503 .9 r
F P
0 g
s
.35155 .82177 m .38843 .84517 L .35227 .8222 L .082 .503 .9 r
F
.32736 .81897 m .32506 .81952 L .28145 .79853 L p .117 .525 .913 r
F P
0 g
s
.45073 .87552 m .45573 .86257 L .44221 .88452 L p .926 .539 .22 r
F P
0 g
s
.44153 .87202 m .44221 .88452 L .45573 .86257 L p .891 .516 .321 r
F P
0 g
s
.70012 1.22112 m .7332 1.17949 L .74463 1.17166 L p 0 0 0 r
F P
0 g
s
.77845 1.12564 m .74463 1.17166 L .7332 1.17949 L p .681 .907 .567 r
F P
0 g
s
.53515 1.33835 m .57955 1.31206 L .55735 1.32069 L p .009 0 0 r
F P
0 g
s
.55735 1.32069 m .50056 1.34402 L .53515 1.33835 L p .009 0 0 r
F P
0 g
s
.61067 1.29223 m .55735 1.32069 L .57955 1.31206 L p 0 0 0 r
F P
0 g
s
.44174 .85948 m .44272 .84687 L .41879 .85857 L p .747 .252 .056 r
F P
0 g
s
.41442 .8484 m .41879 .85857 L .44272 .84687 L p .705 .233 .127 r
F P
0 g
s
.82566 .83843 m .81598 .78517 L .79279 .76799 L p .141 .243 .709 r
F P
0 g
s
.77751 .71887 m .79279 .76799 L .81598 .78517 L p 0 .131 .672 r
F P
0 g
s
.77845 1.12564 m .80101 1.07634 L .81181 1.05445 L p 0 0 0 r
F P
0 g
s
.83007 1.00182 m .81181 1.05445 L .80101 1.07634 L p .741 .808 .333 r
F P
0 g
s
.57955 1.31206 m .61998 1.28181 L .61067 1.29223 L p 0 0 0 r
F P
0 g
s
.65879 1.2589 m .61067 1.29223 L .61998 1.28181 L p .503 .883 .69 r
F P
0 g
s
.40201 .90578 m .40847 .90216 L .42092 .9142 L p .332 0 .052 r
F P
0 g
s
.42047 .90825 m .42092 .9142 L .40847 .90216 L p .152 0 0 r
F P
0 g
s
.69939 .63115 m .662 .59447 L .64874 .61256 L p .376 .535 .886 r
F P
0 g
s
.61583 .58194 m .64874 .61256 L .662 .59447 L p .307 .537 .91 r
F P
0 g
s
.41442 .8484 m .41205 .83869 L .37858 .83865 L p .45 0 0 r
F P
0 g
s
.37248 .83315 m .37858 .83865 L .41205 .83869 L p .431 0 0 r
F P
0 g
s
.42339 .90206 m .42933 .89524 L .43063 .91939 L p .523 .075 .128 r
F P
0 g
s
.43123 .91112 m .43063 .91939 L .42933 .89524 L p .239 0 .099 r
F P
0 g
s
.46166 .50697 m .41096 .50205 L .44899 .51048 L p .076 .589 .884 r
F P
0 g
s
.44899 .51048 m .49203 .51988 L .46166 .50697 L p .076 .589 .884 r
F P
0 g
s
.28492 .54927 m .24633 .5648 L .28179 .53011 L p .186 0 .016 r
F P
0 g
s
.28179 .53011 m .32209 .51812 L .28492 .54927 L p .186 0 .016 r
F P
0 g
s
.77751 .71887 m .75 .67203 L .72776 .67182 L p .231 .403 .828 r
F P
0 g
s
.69939 .63115 m .72776 .67182 L .75 .67203 L p .083 .365 .832 r
F P
0 g
s
.39957 .90887 m .40144 .91194 L .36525 .91288 L p .113 0 0 r
F P
0 g
s
.83885 .91939 m .83634 .86431 L .82566 .83843 L p 0 0 .501 r
F P
0 g
s
.81598 .78517 m .82566 .83843 L .83634 .86431 L p 0 0 .322 r
F P
0 g
s
.28145 .79853 m .28939 .79267 L .32736 .81897 L p .117 .525 .913 r
F P
0 g
s
.28939 .79267 m .28145 .79853 L .24607 .76267 L p .214 .44 .863 r
F P
0 g
s
.44153 .87202 m .44174 .85948 L .42507 .8694 L p .758 .242 0 r
F P
0 g
s
.41879 .85857 m .42507 .8694 L .44174 .85948 L p .747 .252 .056 r
F P
0 g
s
.43439 .90246 m .43974 .89312 L .44041 .92139 L p .101 0 .296 r
F P
0 g
s
.61998 1.28181 m .6551 1.24793 L .65879 1.2589 L p .503 .883 .69 r
F P
0 g
s
.70012 1.22112 m .65879 1.2589 L .6551 1.24793 L p .719 .986 .809 r
F P
0 g
s
.662 .59447 m .61729 .56294 L .61583 .58194 L p .307 .537 .91 r
F P
0 g
s
.5775 .55587 m .61583 .58194 L .61729 .56294 L p .232 .543 .927 r
F P
0 g
s
.51463 .51874 m .46166 .50697 L .49203 .51988 L p .101 .565 .911 r
F P
0 g
s
.49203 .51988 m .53556 .53505 L .51463 .51874 L p .101 .565 .911 r
F P
0 g
s
.37112 .5118 m .32209 .51812 L .36488 .5035 L p .217 0 0 r
F P
0 g
s
.36488 .5035 m .41096 .50205 L .37112 .5118 L p .217 0 0 r
F P
0 g
s
.61729 .56294 m .56736 .53749 L .5775 .55587 L p .232 .543 .927 r
F P
0 g
s
.53556 .53505 m .5775 .55587 L .56736 .53749 L p .158 .552 .928 r
F P
0 g
s
.7332 1.17949 m .75679 1.13474 L .77845 1.12564 L p .681 .907 .567 r
F P
0 g
s
.80101 1.07634 m .77845 1.12564 L .75679 1.13474 L p .887 .984 .712 r
F P
0 g
s
.39957 .90887 m .40201 .90578 L .4249 .92035 L p .458 .013 .103 r
F P
0 g
s
.42092 .9142 m .4249 .92035 L .40201 .90578 L p .332 0 .052 r
F P
0 g
s
.83007 1.00182 m .83474 .94744 L .83885 .91939 L p 0 0 .144 r
F P
0 g
s
.83634 .86431 m .83885 .91939 L .83474 .94744 L p .836 .687 .149 r
F P
0 g
s
.33563 .81911 m .32736 .81897 L .28939 .79267 L p .208 .53 .922 r
F P
0 g
s
.56736 .53749 m .51463 .51874 L .53556 .53505 L p .158 .552 .928 r
F P
0 g
s
.42047 .90825 m .42339 .90206 L .43288 .92759 L p .709 .196 0 r
F P
0 g
s
.43063 .91939 m .43288 .92759 L .42339 .90206 L p .523 .075 .128 r
F P
0 g
s
.41879 .85857 m .41442 .8484 L .38843 .84517 L p .413 0 0 r
F P
0 g
s
.37858 .83865 m .38843 .84517 L .41442 .8484 L p .45 0 0 r
F P
0 g
s
.25775 .59369 m .22318 .61089 L .24633 .5648 L p .247 0 .306 r
F P
0 g
s
.24633 .5648 m .28492 .54927 L .25775 .59369 L p .247 0 .306 r
F P
0 g
s
.44221 .88452 m .44153 .87202 L .43314 .88102 L p .695 .183 0 r
F P
0 g
s
.42507 .8694 m .43314 .88102 L .44153 .87202 L p .758 .242 0 r
F P
0 g
s
.24607 .76267 m .26075 .75196 L .28939 .79267 L p .214 .44 .863 r
F P
0 g
s
.26075 .75196 m .24607 .76267 L .22304 .71582 L p .257 .342 .76 r
F P
0 g
s
.43123 .91112 m .43439 .90246 L .44196 .93206 L p .381 .101 .358 r
F P
0 g
s
.44041 .92139 m .44196 .93206 L .43439 .90246 L p .101 0 .296 r
F P
0 g
s
.6551 1.24793 m .68371 1.21086 L .70012 1.22112 L p .719 .986 .809 r
F P
0 g
s
.7332 1.17949 m .70012 1.22112 L .68371 1.21086 L p .838 .992 .854 r
F P
0 g
s
.81598 .78517 m .79261 .73342 L .77751 .71887 L p 0 .131 .672 r
F P
0 g
s
.75 .67203 m .77751 .71887 L .79261 .73342 L p 0 0 .547 r
F P
0 g
s
.75 .67203 m .71137 .62901 L .69939 .63115 L p .083 .365 .832 r
F P
0 g
s
.662 .59447 m .69939 .63115 L .71137 .62901 L p 0 .312 .796 r
F P
0 g
s
.44081 .91058 m .4429 .89944 L .4509 .92261 L p 0 0 .465 r
F P
0 g
s
.44678 .90972 m .4509 .92261 L .4429 .89944 L p 0 0 .243 r
F P
0 g
s
.24385 .6464 m .21509 .66322 L .22318 .61089 L p .27 .128 .497 r
F P
0 g
s
.22318 .61089 m .25775 .59369 L .24385 .6464 L p .27 .128 .497 r
F P
0 g
s
.22304 .71582 m .24491 .70128 L .26075 .75196 L p .257 .342 .76 r
F P
0 g
s
.24491 .70128 m .22304 .71582 L .21509 .66322 L p .272 .241 .64 r
F P
0 g
s
.80101 1.07634 m .81128 1.02487 L .83007 1.00182 L p .741 .808 .333 r
F P
0 g
s
.83474 .94744 m .83007 1.00182 L .81128 1.02487 L p .961 .906 .538 r
F P
0 g
s
.21509 .66322 m .24385 .6464 L .24491 .70128 L p .272 .241 .64 r
F P
0 g
s
.43314 .88102 m .44282 .8936 L .44221 .88452 L p .695 .183 0 r
F P
0 g
s
.42687 .51225 m .37112 .5118 L .41096 .50205 L p .332 0 0 r
F P
0 g
s
.41096 .50205 m .46166 .50697 L .42687 .51225 L p .332 0 0 r
F P
0 g
s
.42507 .8694 m .41879 .85857 L .40177 .85307 L p 0 .233 .665 r
F P
0 g
s
.38843 .84517 m .40177 .85307 L .41879 .85857 L p .413 0 0 r
F P
0 g
s
.40144 .91194 m .39957 .90887 L .42283 .92182 L p .55 .091 .117 r
F P
0 g
s
.43001 .92331 m .43811 .93611 L p .42769 .92283 L .162 .115 .553 r
F P
0 g
s
.42769 .92283 m .42092 .9142 L .43001 .92331 L .162 .115 .553 r
F
.43288 .92759 m .43473 .9306 L p .42047 .90825 L .709 .196 0 r
F P
0 g
s
.43473 .9306 m .43731 .9348 L p .43449 .93038 L .709 .196 0 r
F P
0 g
s
.43721 .93468 m .43449 .93038 L p .43731 .9348 L .709 .196 0 r
F P
0 g
s
.43449 .93038 m .42047 .90825 L p .43473 .9306 L .709 .196 0 r
F P
0 g
s
.42822 .92315 m .42092 .9142 L p .42818 .92345 L .162 .115 .553 r
F P
0 g
s
.43566 .93299 m .42822 .92315 L .42818 .92345 L .162 .115 .553 r
F
.43594 .93326 m .42822 .92315 L .43566 .93299 L F
.43288 .92759 m .43063 .91939 L .45163 .95401 L p .739 .232 0 r
F P
0 g
s
.43811 .93611 m .43731 .9348 L p .45983 .96585 L .242 .231 .646 r
F P
0 g
s
.43731 .9348 m .43473 .9306 L p .4435 .94268 L .242 .231 .646 r
F P
0 g
s
.43485 .93039 m .4435 .94268 L p .43473 .9306 L .242 .231 .646 r
F P
0 g
s
.43867 .93594 m .42822 .92315 L p .43594 .93326 L .162 .115 .553 r
F P
0 g
s
.43311 .92913 m .43456 .9309 L p .43003 .92632 L .443 .244 .513 r
F P
0 g
s
.4435 .94268 m .45983 .96585 L p .43731 .9348 L .242 .231 .646 r
F P
0 g
s
.45163 .95401 m .45983 .96585 L .4435 .94268 L p .739 .232 0 r
F P
0 g
s
.4435 .94268 m .43288 .92759 L p .44411 .94343 L .739 .232 0 r
F P
0 g
s
.45163 .95401 m .4435 .94268 L .44411 .94343 L .739 .232 0 r
F
.42822 .92315 m .43311 .92913 L p .4281 .92407 L .443 .244 .513 r
F P
0 g
s
.4281 .92407 m .4249 .92035 L .42822 .92315 L .443 .244 .513 r
F
.44567 .94284 m .45163 .95401 L .43063 .91939 L p .599 .233 .32 r
F P
0 g
s
.44555 .94269 m .42657 .92194 L .44472 .94188 L .565 .315 .496 r
F
.42657 .92194 m .42616 .92149 L .42658 .92195 L F
.42657 .92194 m .42658 .92195 L .44472 .94188 L F
.43811 .93611 m .44632 .94531 L .43867 .93594 L p .162 .115 .553 r
F P
0 g
s
.43731 .9348 m .43811 .93611 L .43721 .93468 L p .709 .196 0 r
F P
0 g
s
.43811 .93611 m .43867 .93594 L .43594 .93326 L .162 .115 .553 r
F
.43456 .9309 m .44632 .94531 L p .43432 .93133 L .443 .244 .513 r
F P
0 g
s
.43432 .93133 m .43003 .92632 L .43456 .9309 L .443 .244 .513 r
F
.43473 .9306 m .43288 .92759 L .43485 .93039 L p .242 .231 .646 r
F P
0 g
s
.42828 .92402 m .43207 .92814 L p .42616 .92149 L .565 .315 .496 r
F P
0 g
s
.43207 .92814 m .44472 .94188 L p .43117 .927 L .565 .315 .496 r
F P
0 g
s
.43117 .927 m .42616 .92149 L .43207 .92814 L .565 .315 .496 r
F
.43063 .91939 m .43123 .91112 L .44567 .94284 L p .599 .233 .32 r
F P
0 g
s
.44196 .93206 m .44567 .94284 L .43123 .91112 L p .381 .101 .358 r
F P
0 g
s
.44567 .94284 m .44196 .93206 L .47118 .96404 L p .421 .298 .607 r
F P
0 g
s
.45163 .95401 m .44567 .94284 L .48044 .97927 L p .512 .359 .61 r
F P
0 g
s
.47118 .96404 m .48044 .97927 L .44567 .94284 L p .421 .298 .607 r
F P
0 g
s
.44472 .94188 m .45732 .95558 L p .44555 .94269 L .565 .315 .496 r
F P
0 g
s
.43243 .92716 m .42616 .92149 L p .44555 .94269 L .565 .315 .496 r
F P
0 g
s
.45732 .95558 m .44906 .94615 L .44555 .94269 L .565 .315 .496 r
F
.44906 .94615 m .43243 .92716 L .44555 .94269 L F
.43811 .93611 m .43594 .93326 L .43566 .93299 L .162 .115 .553 r
F
.42616 .92149 m .4249 .92035 L .42828 .92402 L p .565 .315 .496 r
F P
0 g
s
.43003 .92632 m .4281 .92407 L .43311 .92913 L .443 .244 .513 r
F
.4249 .92035 m .42092 .9142 L .42822 .92315 L p F P
0 g
s
.42283 .92182 m .42801 .9247 L p .42061 .92136 L .55 .091 .117 r
F P
0 g
s
.44632 .94531 m .45732 .95558 L .4249 .92035 L p .443 .244 .513 r
F P
0 g
s
.42801 .9247 m .43243 .92716 L p .42797 .92497 L .55 .091 .117 r
F P
0 g
s
.42797 .92497 m .42061 .92136 L .42801 .9247 L .55 .091 .117 r
F
.42061 .92136 m .40144 .91194 L .42283 .92182 L F
.42092 .9142 m .42047 .90825 L .43001 .92331 L p .162 .115 .553 r
F P
0 g
s
.4249 .92035 m .43243 .92716 L .39957 .90887 L p .458 .013 .103 r
F P
0 g
s
.33392 .53913 m .28492 .54927 L .32209 .51812 L p .365 0 .11 r
F P
0 g
s
.32209 .51812 m .37112 .5118 L .33392 .53913 L p .365 0 .11 r
F P
0 g
s
.83634 .86431 m .8195 .80983 L .81598 .78517 L p 0 0 .322 r
F P
0 g
s
.79261 .73342 m .81598 .78517 L .8195 .80983 L p .832 .484 0 r
F P
0 g
s
.44041 .92139 m .44081 .91058 L .45634 .93586 L p .087 .089 .563 r
F P
0 g
s
.4509 .92261 m .45634 .93586 L .44081 .91058 L p 0 0 .465 r
F P
0 g
s
.28939 .79267 m .30533 .78819 L .33563 .81911 L p .208 .53 .922 r
F P
0 g
s
.30533 .78819 m .28939 .79267 L .26075 .75196 L p .327 .466 .847 r
F P
0 g
s
.71137 .62901 m .66329 .59128 L .662 .59447 L p 0 .312 .796 r
F P
0 g
s
.61729 .56294 m .662 .59447 L .66329 .59128 L p 0 .25 .699 r
F P
0 g
s
.68371 1.21086 m .70478 1.1712 L .7332 1.17949 L p .838 .992 .854 r
F P
0 g
s
.75679 1.13474 m .7332 1.17949 L .70478 1.1712 L p .879 .946 .853 r
F P
0 g
s
.34975 .82063 m .33563 .81911 L .30533 .78819 L p .295 .534 .911 r
F P
0 g
s
.75679 1.13474 m .76993 1.08779 L .80101 1.07634 L p .887 .984 .712 r
F P
0 g
s
.81128 1.02487 m .80101 1.07634 L .76993 1.08779 L p .944 .942 .755 r
F P
0 g
s
.44678 .90972 m .44392 .89706 L .45388 .90727 L p 0 .102 .657 r
F P
0 g
s
.44282 .8936 m .45388 .90727 L .44392 .89706 L p 0 0 .491 r
F P
0 g
s
.57955 1.31206 m .53515 1.33835 L .56049 1.30909 L p .686 .978 .895 r
F P
0 g
s
.56049 1.30909 m .5905 1.2811 L .57955 1.31206 L p .686 .978 .895 r
F P
0 g
s
.61998 1.28181 m .57955 1.31206 L .5905 1.2811 L p .781 .977 .911 r
F P
0 g
s
.48685 .52025 m .42687 .51225 L .46166 .50697 L p .403 0 0 r
F P
0 g
s
.46166 .50697 m .51463 .51874 L .48685 .52025 L p .403 0 0 r
F P
0 g
s
.40177 .85307 m .4182 .8627 L .42507 .8694 L p 0 .233 .665 r
F P
0 g
s
.43314 .88102 m .42507 .8694 L .4182 .8627 L p 0 .304 .78 r
F P
0 g
s
.79261 .73342 m .75636 .68491 L .75 .67203 L p 0 0 .547 r
F P
0 g
s
.71137 .62901 m .75 .67203 L .75636 .68491 L p .657 .169 0 r
F P
0 g
s
.5905 1.2811 m .61644 1.25052 L .61998 1.28181 L p .781 .977 .911 r
F P
0 g
s
.6551 1.24793 m .61998 1.28181 L .61644 1.25052 L p .826 .943 .901 r
F P
0 g
s
.83474 .94744 m .82536 .8928 L .83634 .86431 L p .836 .687 .149 r
F P
0 g
s
.8195 .80983 m .83634 .86431 L .82536 .8928 L p .989 .755 .37 r
F P
0 g
s
.66329 .59128 m .60802 .56004 L .61729 .56294 L p 0 .25 .699 r
F P
0 g
s
.56736 .53749 m .61729 .56294 L .60802 .56004 L p .386 0 0 r
F P
0 g
s
.44196 .93206 m .44041 .92139 L .46311 .94962 L p .29 .215 .597 r
F P
0 g
s
.45634 .93586 m .46311 .94962 L .44041 .92139 L p .087 .089 .563 r
F P
0 g
s
.4433 .93507 m .43243 .92716 L .47078 .96726 L p .646 .368 .484 r
F P
0 g
s
.45732 .95558 m .47078 .96726 L .43243 .92716 L p .565 .315 .496 r
F P
0 g
s
.43243 .92716 m .4433 .93507 L .40144 .91194 L p .55 .091 .117 r
F P
0 g
s
.30375 .58129 m .25775 .59369 L .28492 .54927 L p .409 .126 .369 r
F P
0 g
s
.28492 .54927 m .33392 .53913 L .30375 .58129 L p .409 .126 .369 r
F P
0 g
s
.54823 .5362 m .48685 .52025 L .51463 .51874 L p .426 0 0 r
F P
0 g
s
.51463 .51874 m .56736 .53749 L .54823 .5362 L p .426 0 0 r
F P
0 g
s
.40177 .85307 m .38843 .84517 L .36935 .82414 L p .182 .513 .914 r
F P
0 g
s
.34975 .82063 m .36935 .82414 L .38843 .84517 L p .082 .503 .9 r
F P
0 g
s
.26075 .75196 m .28521 .74346 L .30533 .78819 L p .327 .466 .847 r
F P
0 g
s
.28521 .74346 m .26075 .75196 L .24491 .70128 L p .38 .394 .749 r
F P
0 g
s
.60802 .56004 m .54823 .5362 L .56736 .53749 L p .386 0 0 r
F P
0 g
s
.4509 .92261 m .44678 .90972 L .46608 .92212 L p .064 .228 .722 r
F P
0 g
s
.45388 .90727 m .46608 .92212 L .44678 .90972 L p 0 .102 .657 r
F P
0 g
s
.61644 1.25052 m .63745 1.21767 L .6551 1.24793 L p .826 .943 .901 r
F P
0 g
s
.68371 1.21086 m .6551 1.24793 L .63745 1.21767 L p .839 .896 .879 r
F P
0 g
s
.39147 .53572 m .33392 .53913 L .37112 .5118 L p .49 .064 .158 r
F P
0 g
s
.37112 .5118 m .42687 .51225 L .39147 .53572 L p .49 .064 .158 r
F P
0 g
s
.81128 1.02487 m .80865 .97253 L .83474 .94744 L p .961 .906 .538 r
F P
0 g
s
.82536 .8928 m .83474 .94744 L .80865 .97253 L p .988 .859 .619 r
F P
0 g
s
.44282 .8936 m .43314 .88102 L .4372 .87435 L p .043 .366 .836 r
F P
0 g
s
.4182 .8627 m .4372 .87435 L .43314 .88102 L p 0 .304 .78 r
F P
0 g
s
.70478 1.1712 m .7175 1.12964 L .75679 1.13474 L p .879 .946 .853 r
F P
0 g
s
.76993 1.08779 m .75679 1.13474 L .7175 1.12964 L p .879 .886 .834 r
F P
0 g
s
.28426 .63357 m .24385 .6464 L .25775 .59369 L p .415 .237 .528 r
F P
0 g
s
.25775 .59369 m .30375 .58129 L .28426 .63357 L p .415 .237 .528 r
F P
0 g
s
.46311 .94962 m .47118 .96404 L .44196 .93206 L p .29 .215 .597 r
F P
0 g
s
.24491 .70128 m .27784 .68985 L .28521 .74346 L p .38 .394 .749 r
F P
0 g
s
.27784 .68985 m .24491 .70128 L .24385 .6464 L p .406 .32 .646 r
F P
0 g
s
.8195 .80983 m .78879 .75769 L .79261 .73342 L p .832 .484 0 r
F P
0 g
s
.75636 .68491 m .79261 .73342 L .78879 .75769 L p .928 .543 .18 r
F P
0 g
s
.36935 .82414 m .34975 .82063 L .32897 .78602 L p .372 .539 .891 r
F P
0 g
s
.30533 .78819 m .32897 .78602 L .34975 .82063 L p .295 .534 .911 r
F P
0 g
s
.75636 .68491 m .70874 .64129 L .71137 .62901 L p .657 .169 0 r
F P
0 g
s
.66329 .59128 m .71137 .62901 L .70874 .64129 L p .76 .247 0 r
F P
0 g
s
.45634 .93586 m .4509 .92261 L .47908 .93825 L p .251 .313 .732 r
F P
0 g
s
.46608 .92212 m .47908 .93825 L .4509 .92261 L p .064 .228 .722 r
F P
0 g
s
.32897 .78602 m .30533 .78819 L .28521 .74346 L p .414 .487 .826 r
F P
0 g
s
.24385 .6464 m .28426 .63357 L .27784 .68985 L p .406 .32 .646 r
F P
0 g
s
.63745 1.21767 m .6528 1.183 L .68371 1.21086 L p .839 .896 .879 r
F P
0 g
s
.70478 1.1712 m .68371 1.21086 L .6528 1.183 L p .834 .847 .856 r
F P
0 g
s
.76993 1.08779 m .77197 1.03968 L .81128 1.02487 L p .944 .942 .755 r
F P
0 g
s
.80865 .97253 m .81128 1.02487 L .77197 1.03968 L p .932 .869 .754 r
F P
0 g
s
.4182 .8627 m .40177 .85307 L .39383 .83023 L p .277 .521 .907 r
F P
0 g
s
.36935 .82414 m .39383 .83023 L .40177 .85307 L p .182 .513 .914 r
F P
0 g
s
.45388 .90727 m .44282 .8936 L .45814 .88822 L p .2 .411 .844 r
F P
0 g
s
.4372 .87435 m .45814 .88822 L .44282 .8936 L p .043 .366 .836 r
F P
0 g
s
.45512 .54009 m .39147 .53572 L .42687 .51225 L p .583 .146 .175 r
F P
0 g
s
.42687 .51225 m .48685 .52025 L .45512 .54009 L p .583 .146 .175 r
F P
0 g
s
.45163 .95401 m .4907 .99546 L p .46131 .96728 L .583 .407 .609 r
F P
0 g
s
.45983 .96585 m .45665 .96126 L p .46131 .96728 L .583 .407 .609 r
F P
0 g
s
.45665 .96126 m .45163 .95401 L p .46131 .96728 L .583 .407 .609 r
F P
0 g
s
.48044 .97927 m .4907 .99546 L .45163 .95401 L p .512 .359 .61 r
F P
0 g
s
.47012 .97864 m .45983 .96585 L .5017 1.01274 L p .642 .449 .607 r
F P
0 g
s
.4907 .99546 m .5017 1.01274 L .46199 .96828 L p .583 .407 .609 r
F P
0 g
s
.46199 .96828 m .45983 .96585 L p .46131 .96728 L .583 .407 .609 r
F P
0 g
s
.4907 .99546 m .46199 .96828 L .46131 .96728 L .583 .407 .609 r
F
.44632 .94531 m .43811 .93611 L .45894 .96378 L p .485 .341 .61 r
F P
0 g
s
.45894 .96378 m .4699 .97835 L p .44764 .94716 L .485 .341 .61 r
F P
0 g
s
.44764 .94716 m .44632 .94531 L .45894 .96378 L .485 .341 .61 r
F
.4699 .97835 m .47012 .97864 L p .47004 .97853 L F P
0 g
s
.47004 .97853 m .44632 .94531 L .4699 .97835 L .485 .341 .61 r
F
.45983 .96585 m .47012 .97864 L .43811 .93611 L p .242 .231 .646 r
F P
0 g
s
.46311 .94962 m .45634 .93586 L .49257 .95572 L p .378 .371 .725 r
F P
0 g
s
.47908 .93825 m .49257 .95572 L .45634 .93586 L p .251 .313 .732 r
F P
0 g
s
.82536 .8928 m .80206 .83953 L .8195 .80983 L p .989 .755 .37 r
F P
0 g
s
.78879 .75769 m .8195 .80983 L .80206 .83953 L p .975 .714 .473 r
F P
0 g
s
.35959 .57517 m .30375 .58129 L .33392 .53913 L p .519 .222 .402 r
F P
0 g
s
.33392 .53913 m .39147 .53572 L .35959 .57517 L p .519 .222 .402 r
F P
0 g
s
.70874 .64129 m .65192 .60403 L .66329 .59128 L p .76 .247 0 r
F P
0 g
s
.60802 .56004 m .66329 .59128 L .65192 .60403 L p .76 .263 .04 r
F P
0 g
s
.6528 1.183 m .66196 1.14703 L .70478 1.1712 L p .834 .847 .856 r
F P
0 g
s
.7175 1.12964 m .70478 1.1712 L .66196 1.14703 L p .819 .802 .836 r
F P
0 g
s
.7175 1.12964 m .72133 1.08699 L .76993 1.08779 L p .879 .886 .834 r
F P
0 g
s
.77197 1.03968 m .76993 1.08779 L .72133 1.08699 L p .862 .828 .813 r
F P
0 g
s
.5905 1.2811 m .56049 1.30909 L .57319 1.25855 L p .844 .895 .874 r
F P
0 g
s
.46608 .92212 m .45388 .90727 L .48028 .90447 L p .321 .444 .83 r
F P
0 g
s
.45814 .88822 m .48028 .90447 L .45388 .90727 L p .2 .411 .844 r
F P
0 g
s
.28521 .74346 m .31889 .73832 L .32897 .78602 L p .414 .487 .826 r
F P
0 g
s
.31889 .73832 m .28521 .74346 L .27784 .68985 L p .468 .433 .736 r
F P
0 g
s
.57319 1.25855 m .58835 1.23043 L .5905 1.2811 L p .844 .895 .874 r
F P
0 g
s
.61644 1.25052 m .5905 1.2811 L .58835 1.23043 L p .837 .846 .852 r
F P
0 g
s
.4372 .87435 m .4182 .8627 L .42234 .8394 L p .36 .528 .887 r
F P
0 g
s
.39383 .83023 m .42234 .8394 L .4182 .8627 L p .277 .521 .907 r
F P
0 g
s
.5219 .55289 m .45512 .54009 L .48685 .52025 L p .657 .204 .164 r
F P
0 g
s
.48685 .52025 m .54823 .5362 L .5219 .55289 L p .657 .204 .164 r
F P
0 g
s
.39383 .83023 m .36935 .82414 L .35963 .78702 L p .437 .545 .868 r
F P
0 g
s
.32897 .78602 m .35963 .78702 L .36935 .82414 L p .372 .539 .891 r
F P
0 g
s
.80865 .97253 m .79301 .92073 L .82536 .8928 L p .988 .859 .619 r
F P
0 g
s
.80206 .83953 m .82536 .8928 L .79301 .92073 L p .95 .785 .642 r
F P
0 g
s
.78879 .75769 m .74538 .70962 L .75636 .68491 L p .928 .543 .18 r
F P
0 g
s
.70874 .64129 m .75636 .68491 L .74538 .70962 L p .904 .527 .304 r
F P
0 g
s
.47118 .96404 m .46311 .94962 L .50617 .97454 L p .468 .415 .715 r
F P
0 g
s
.49257 .95572 m .50617 .97454 L .46311 .94962 L p .378 .371 .725 r
F P
0 g
s
.65192 .60403 m .5886 .57431 L .60802 .56004 L p .76 .263 .04 r
F P
0 g
s
.54823 .5362 m .60802 .56004 L .5886 .57431 L p .718 .244 .123 r
F P
0 g
s
.58835 1.23043 m .59985 1.20111 L .61644 1.25052 L p .837 .846 .852 r
F P
0 g
s
.63745 1.21767 m .61644 1.25052 L .59985 1.20111 L p .822 .8 .831 r
F P
0 g
s
.5017 1.01274 m .51312 1.0312 L .47403 .98343 L p .642 .449 .607 r
F P
0 g
s
.47403 .98343 m .47012 .97864 L p .47311 .98188 L .642 .449 .607 r
F P
0 g
s
.5017 1.01274 m .47403 .98343 L .47311 .98188 L .642 .449 .607 r
F
.45732 .95558 m .44632 .94531 L .46973 .97618 L p .59 .4 .592 r
F P
0 g
s
.46973 .97618 m .48223 .99265 L p .45903 .95812 L .59 .4 .592 r
F P
0 g
s
.45903 .95812 m .45732 .95558 L .46973 .97618 L .59 .4 .592 r
F
.47012 .97864 m .48223 .99265 L .44632 .94531 L p .485 .341 .61 r
F P
0 g
s
.5886 .57431 m .5219 .55289 L .54823 .5362 L p .718 .244 .123 r
F P
0 g
s
.48044 .97927 m .47118 .96404 L .51809 .99383 L p .536 .451 .706 r
F P
0 g
s
.51809 .99383 m .51948 .99471 L p .51798 .99412 L .536 .451 .706 r
F P
0 g
s
.51798 .99412 m .48044 .97927 L .51809 .99383 L .536 .451 .706 r
F
.51312 1.0312 m .5017 1.01274 L .54144 1.05087 L p .679 .542 .692 r
F P
0 g
s
.54144 1.05087 m .55373 1.06266 L p .53853 1.05089 L .679 .542 .692 r
F P
0 g
s
.53853 1.05089 m .51312 1.0312 L .54144 1.05087 L .679 .542 .692 r
F
.48223 .99265 m .47012 .97864 L .51312 1.0312 L p .695 .488 .604 r
F P
0 g
s
.51312 1.0312 m .52456 1.05091 L .48223 .99265 L p .695 .488 .604 r
F P
0 g
s
.49575 1.00809 m .48223 .99265 L .52456 1.05091 L p .747 .528 .598 r
F P
0 g
s
.52456 1.05091 m .53558 1.07187 L .49575 1.00809 L p .747 .528 .598 r
F P
0 g
s
.52456 1.05091 m .51312 1.0312 L .56199 1.08741 L p .717 .573 .692 r
F P
0 g
s
.55373 1.06266 m .56199 1.08741 L .51312 1.0312 L p .679 .542 .692 r
F P
0 g
s
.51017 1.02514 m .49575 1.00809 L .53558 1.07187 L p .804 .571 .585 r
F P
0 g
s
.53558 1.07187 m .54571 1.09407 L .5235 1.05099 L p .804 .571 .585 r
F P
0 g
s
.5235 1.05099 m .51017 1.02514 L p .52422 1.05099 L .804 .571 .585 r
F P
0 g
s
.53558 1.07187 m .5235 1.05099 L .52422 1.05099 L .804 .571 .585 r
F
.54365 1.03887 m .55373 1.06266 L .5017 1.01274 L p .638 .513 .694 r
F P
0 g
s
.51017 1.02514 m .52485 1.04391 L .50921 1.01833 L p .719 .489 .575 r
F P
0 g
s
.4907 .99546 m .48044 .97927 L .5321 1.01618 L p .591 .483 .699 r
F P
0 g
s
.51948 .99471 m .5321 1.01618 L .48044 .97927 L p .536 .451 .706 r
F P
0 g
s
.5017 1.01274 m .4907 .99546 L .54365 1.03887 L p .638 .513 .694 r
F P
0 g
s
.5321 1.01618 m .54365 1.03887 L .4907 .99546 L p .591 .483 .699 r
F P
0 g
s
.50921 1.01833 m .48617 .98064 L p .50812 1.02135 L .719 .489 .575 r
F P
0 g
s
.51017 1.02514 m .50921 1.01833 L .50812 1.02135 L .719 .489 .575 r
F
.47078 .96726 m .48617 .98064 L .4433 .93507 L p .646 .368 .484 r
F P
0 g
s
.35963 .78702 m .32897 .78602 L .31889 .73832 L p .482 .506 .805 r
F P
0 g
s
.33507 .62623 m .28426 .63357 L .30375 .58129 L p .515 .313 .544 r
F P
0 g
s
.30375 .58129 m .35959 .57517 L .33507 .62623 L p .515 .313 .544 r
F P
0 g
s
.47908 .93825 m .46608 .92212 L .50286 .92315 L p .412 .469 .81 r
F P
0 g
s
.48028 .90447 m .50286 .92315 L .46608 .92212 L p .321 .444 .83 r
F P
0 g
s
.77197 1.03968 m .7627 .99159 L .80865 .97253 L p .932 .869 .754 r
F P
0 g
s
.79301 .92073 m .80865 .97253 L .7627 .99159 L p .899 .801 .743 r
F P
0 g
s
.59985 1.20111 m .60733 1.17091 L .63745 1.21767 L p .822 .8 .831 r
F P
0 g
s
.6528 1.183 m .63745 1.21767 L .60733 1.17091 L p .801 .759 .815 r
F P
0 g
s
.27784 .68985 m .32095 .68288 L .31889 .73832 L p .468 .433 .736 r
F P
0 g
s
.32095 .68288 m .27784 .68985 L .28426 .63357 L p .498 .378 .646 r
F P
0 g
s
.66196 1.14703 m .66456 1.11035 L .7175 1.12964 L p .819 .802 .836 r
F P
0 g
s
.72133 1.08699 m .7175 1.12964 L .66456 1.11035 L p .799 .762 .819 r
F P
0 g
s
.50617 .97454 m .51948 .99471 L .47118 .96404 L p .468 .415 .715 r
F P
0 g
s
.28426 .63357 m .33507 .62623 L .32095 .68288 L p .498 .378 .646 r
F P
0 g
s
.45814 .88822 m .4372 .87435 L .45383 .85203 L p .428 .536 .864 r
F P
0 g
s
.42234 .8394 m .45383 .85203 L .4372 .87435 L p .36 .528 .887 r
F P
0 g
s
.42301 .57654 m .35959 .57517 L .39147 .53572 L p .602 .294 .419 r
F P
0 g
s
.39147 .53572 m .45512 .54009 L .42301 .57654 L p .602 .294 .419 r
F P
0 g
s
.47078 .96726 m .45732 .95558 L .49575 1.00809 L p .661 .446 .582 r
F P
0 g
s
.48223 .99265 m .49575 1.00809 L .45732 .95558 L p .59 .4 .592 r
F P
0 g
s
.80206 .83953 m .76565 .7893 L .78879 .75769 L p .975 .714 .473 r
F P
0 g
s
.74538 .70962 m .78879 .75769 L .76565 .7893 L p .921 .655 .518 r
F P
0 g
s
.72133 1.08699 m .71605 1.04416 L .77197 1.03968 L p .862 .828 .813 r
F P
0 g
s
.7627 .99159 m .77197 1.03968 L .71605 1.04416 L p .837 .777 .794 r
F P
0 g
s
.60733 1.17091 m .61057 1.1402 L .6528 1.183 L p .801 .759 .815 r
F P
0 g
s
.66196 1.14703 m .6528 1.183 L .61057 1.1402 L p .778 .724 .802 r
F P
0 g
s
.49257 .95572 m .47908 .93825 L .52505 .94423 L p .482 .492 .791 r
F P
0 g
s
.50286 .92315 m .52505 .94423 L .47908 .93825 L p .412 .469 .81 r
F P
0 g
s
.42234 .8394 m .39383 .83023 L .39626 .79198 L p .492 .553 .846 r
F P
0 g
s
.35963 .78702 m .39626 .79198 L .39383 .83023 L p .437 .545 .868 r
F P
0 g
s
.74538 .70962 m .69115 .66725 L .70874 .64129 L p .904 .527 .304 r
F P
0 g
s
.65192 .60403 m .70874 .64129 L .69115 .66725 L p .85 .489 .368 r
F P
0 g
s
.48028 .90447 m .45814 .88822 L .48707 .86834 L p .486 .545 .843 r
F P
0 g
s
.45383 .85203 m .48707 .86834 L .45814 .88822 L p .428 .536 .864 r
F P
0 g
s
.50617 .97454 m .49257 .95572 L .54606 .96758 L p .539 .513 .775 r
F P
0 g
s
.52505 .94423 m .54606 .96758 L .49257 .95572 L p .482 .492 .791 r
F P
0 g
s
.48617 .98064 m .47078 .96726 L .51017 1.02514 L p .719 .489 .575 r
F P
0 g
s
.49575 1.00809 m .51017 1.02514 L .47078 .96726 L p .661 .446 .582 r
F P
0 g
s
.66456 1.11035 m .66049 1.0736 L .72133 1.08699 L p .799 .762 .819 r
F P
0 g
s
.71605 1.04416 m .72133 1.08699 L .66049 1.0736 L p .777 .727 .806 r
F P
0 g
s
.31889 .73832 m .36071 .73764 L .35963 .78702 L p .482 .506 .805 r
F P
0 g
s
.36071 .73764 m .31889 .73832 L .32095 .68288 L p .536 .466 .725 r
F P
0 g
s
.61057 1.1402 m .60948 1.10937 L .66196 1.14703 L p .778 .724 .802 r
F P
0 g
s
.66456 1.11035 m .66196 1.14703 L .60948 1.10937 L p .754 .693 .793 r
F P
0 g
s
.79301 .92073 m .76483 .87099 L .80206 .83953 L p .95 .785 .642 r
F P
0 g
s
.76565 .7893 m .80206 .83953 L .76483 .87099 L p .901 .719 .647 r
F P
0 g
s
.49118 .58627 m .42301 .57654 L .45512 .54009 L p .671 .351 .424 r
F P
0 g
s
.45512 .54009 m .5219 .55289 L .49118 .58627 L p .671 .351 .424 r
F P
0 g
s
.39626 .79198 m .35963 .78702 L .36071 .73764 L p .537 .524 .789 r
F P
0 g
s
.58835 1.23043 m .57319 1.25855 L .57122 1.19204 L p .845 .777 .785 r
F P
0 g
s
.39437 .62564 m .33507 .62623 L .35959 .57517 L p .591 .372 .552 r
F P
0 g
s
.35959 .57517 m .42301 .57654 L .39437 .62564 L p .591 .372 .552 r
F P
0 g
s
.57122 1.19204 m .57289 1.16548 L .58835 1.23043 L p .845 .777 .785 r
F P
0 g
s
.59985 1.20111 m .58835 1.23043 L .57289 1.16548 L p .817 .731 .77 r
F P
0 g
s
.69115 .66725 m .62863 .63195 L .65192 .60403 L p .85 .489 .368 r
F P
0 g
s
.5886 .57431 m .65192 .60403 L .62863 .63195 L p .792 .446 .402 r
F P
0 g
s
.51948 .99471 m .50617 .97454 L .56512 .99302 L p .586 .534 .763 r
F P
0 g
s
.54606 .96758 m .56512 .99302 L .50617 .97454 L p .539 .513 .775 r
F P
0 g
s
.7627 .99159 m .74235 .94476 L .79301 .92073 L p .899 .801 .743 r
F P
0 g
s
.76483 .87099 m .79301 .92073 L .74235 .94476 L p .861 .742 .73 r
F P
0 g
s
.57289 1.16548 m .5718 1.13904 L .59985 1.20111 L p .817 .731 .77 r
F P
0 g
s
.60733 1.17091 m .59985 1.20111 L .5718 1.13904 L p .787 .693 .76 r
F P
0 g
s
.50286 .92315 m .48028 .90447 L .52075 .88844 L p .534 .556 .824 r
F P
0 g
s
.48707 .86834 m .52075 .88844 L .48028 .90447 L p .486 .545 .843 r
F P
0 g
s
.45383 .85203 m .42234 .8394 L .43747 .80152 L p .538 .563 .828 r
F P
0 g
s
.39626 .79198 m .43747 .80152 L .42234 .8394 L p .492 .553 .846 r
F P
0 g
s
.60948 1.10937 m .60412 1.07883 L .66456 1.11035 L p .754 .693 .793 r
F P
0 g
s
.66049 1.0736 m .66456 1.11035 L .60412 1.07883 L p .729 .665 .788 r
F P
0 g
s
.56085 .60477 m .49118 .58627 L .5219 .55289 L p .733 .401 .419 r
F P
0 g
s
.5219 .55289 m .5886 .57431 L .56085 .60477 L p .733 .401 .419 r
F P
0 g
s
.5718 1.13904 m .5681 1.11294 L .60733 1.17091 L p .787 .693 .76 r
F P
0 g
s
.61057 1.1402 m .60733 1.17091 L .5681 1.11294 L p .758 .659 .753 r
F P
0 g
s
.62863 .63195 m .56085 .60477 L .5886 .57431 L p .792 .446 .402 r
F P
0 g
s
.71605 1.04416 m .70179 1.00212 L .7627 .99159 L p .837 .777 .794 r
F P
0 g
s
.74235 .94476 m .7627 .99159 L .70179 1.00212 L p .809 .733 .78 r
F P
0 g
s
.32095 .68288 m .37273 .68161 L .36071 .73764 L p .536 .466 .725 r
F P
0 g
s
.37273 .68161 m .32095 .68288 L .33507 .62623 L p .569 .424 .645 r
F P
0 g
s
.76565 .7893 m .7176 .74376 L .74538 .70962 L p .921 .655 .518 r
F P
0 g
s
.69115 .66725 m .74538 .70962 L .7176 .74376 L p .864 .601 .539 r
F P
0 g
s
.5321 1.01618 m .51948 .99471 L .58153 1.02027 L p .626 .555 .755 r
F P
0 g
s
.56512 .99302 m .58153 1.02027 L .51948 .99471 L p .586 .534 .763 r
F P
0 g
s
.33507 .62623 m .39437 .62564 L .37273 .68161 L p .569 .424 .645 r
F P
0 g
s
.5681 1.11294 m .56199 1.08741 L .61057 1.1402 L p .758 .659 .753 r
F P
0 g
s
.60948 1.10937 m .61057 1.1402 L .56199 1.08741 L p .727 .629 .749 r
F P
0 g
s
.66049 1.0736 m .64988 1.03747 L .71605 1.04416 L p .777 .727 .806 r
F P
0 g
s
.70179 1.00212 m .71605 1.04416 L .64988 1.03747 L p .753 .696 .797 r
F P
0 g
s
.52505 .94423 m .50286 .92315 L .55348 .91222 L p .575 .569 .809 r
F P
0 g
s
.52075 .88844 m .55348 .91222 L .50286 .92315 L p .534 .556 .824 r
F P
0 g
s
.54365 1.03887 m .5321 1.01618 L .59469 1.049 L p .662 .578 .75 r
F P
0 g
s
.58153 1.02027 m .59469 1.049 L .5321 1.01618 L p .626 .555 .755 r
F P
0 g
s
.56199 1.08741 m .55373 1.06266 L .60948 1.10937 L p .727 .629 .749 r
F P
0 g
s
.60412 1.07883 m .60948 1.10937 L .55373 1.06266 L p .696 .602 .748 r
F P
0 g
s
.60412 1.07883 m .59469 1.049 L .66049 1.0736 L p .729 .665 .788 r
F P
0 g
s
.64988 1.03747 m .66049 1.0736 L .59469 1.049 L p .702 .641 .785 r
F P
0 g
s
.55373 1.06266 m .54365 1.03887 L .60412 1.07883 L p .696 .602 .748 r
F P
0 g
s
.59469 1.049 m .60412 1.07883 L .54365 1.03887 L p .662 .578 .75 r
F P
0 g
s
.54606 .96758 m .52505 .94423 L .58392 .93946 L p .612 .584 .798 r
F P
0 g
s
.55348 .91222 m .58392 .93946 L .52505 .94423 L p .575 .569 .809 r
F P
0 g
s
.48707 .86834 m .45383 .85203 L .48158 .81604 L p .578 .575 .813 r
F P
0 g
s
.43747 .80152 m .48158 .81604 L .45383 .85203 L p .538 .563 .828 r
F P
0 g
s
.43747 .80152 m .39626 .79198 L .40912 .74233 L p .583 .543 .776 r
F P
0 g
s
.36071 .73764 m .40912 .74233 L .39626 .79198 L p .537 .524 .789 r
F P
0 g
s
.53558 1.07187 m .52456 1.05091 L .55892 1.09986 L p .754 .606 .694 r
F P
0 g
s
.55892 1.09986 m .5681 1.11294 L p .55391 1.09502 L .754 .606 .694 r
F P
0 g
s
.55391 1.09502 m .53558 1.07187 L .55892 1.09986 L .754 .606 .694 r
F
.56199 1.08741 m .5681 1.11294 L .52456 1.05091 L p .717 .573 .692 r
F P
0 g
s
.5718 1.13904 m .53558 1.07187 L p .55391 1.09502 L .754 .606 .694 r
F P
0 g
s
.5681 1.11294 m .56919 1.12067 L p .55391 1.09502 L .754 .606 .694 r
F P
0 g
s
.56919 1.12067 m .5718 1.13904 L p .55391 1.09502 L .754 .606 .694 r
F P
0 g
s
.54571 1.09407 m .53558 1.07187 L .5718 1.13904 L p .79 .642 .698 r
F P
0 g
s
.52485 1.04391 m .51017 1.02514 L .54571 1.09407 L p .882 .626 .547 r
F P
0 g
s
.54004 1.08161 m .52779 1.05119 L p .54086 1.0824 L .882 .626 .547 r
F P
0 g
s
.52779 1.05119 m .52485 1.04391 L p .5281 1.05171 L .882 .626 .547 r
F P
0 g
s
.54086 1.0824 m .52779 1.05119 L .5281 1.05171 L .882 .626 .547 r
F
.54571 1.09407 m .55446 1.11742 L .54004 1.08161 L p F P
0 g
s
.54571 1.09407 m .54004 1.08161 L .54086 1.0824 L .882 .626 .547 r
F
.45963 .6328 m .39437 .62564 L .42301 .57654 L p .652 .421 .555 r
F P
0 g
s
.42301 .57654 m .49118 .58627 L .45963 .6328 L p .652 .421 .555 r
F P
0 g
s
.76483 .87099 m .72519 .82479 L .76565 .7893 L p .901 .719 .647 r
F P
0 g
s
.7176 .74376 m .76565 .7893 L .72519 .82479 L p .852 .663 .646 r
F P
0 g
s
.40912 .74233 m .36071 .73764 L .37273 .68161 L p .59 .496 .716 r
F P
0 g
s
.59469 1.049 m .58153 1.02027 L .64988 1.03747 L p .702 .641 .785 r
F P
0 g
s
.56512 .99302 m .54606 .96758 L .61083 .96977 L p .644 .601 .791 r
F P
0 g
s
.58392 .93946 m .61083 .96977 L .54606 .96758 L p .612 .584 .798 r
F P
0 g
s
.57289 1.16548 m .57122 1.19204 L .55446 1.11742 L p .827 .683 .704 r
F P
0 g
s
.5718 1.13904 m .57289 1.16548 L .54571 1.09407 L p .79 .642 .698 r
F P
0 g
s
.55446 1.11742 m .54571 1.09407 L .57289 1.16548 L p .827 .683 .704 r
F P
0 g
s
.58153 1.02027 m .56512 .99302 L .63311 1.00264 L p .674 .62 .786 r
F P
0 g
s
.63311 1.00264 m .64988 1.03747 L .58153 1.02027 L p .674 .62 .786 r
F P
0 g
s
.61083 .96977 m .63311 1.00264 L .56512 .99302 L p .644 .601 .791 r
F P
0 g
s
.7176 .74376 m .66006 .70435 L .69115 .66725 L p .864 .601 .539 r
F P
0 g
s
.62863 .63195 m .69115 .66725 L .66006 .70435 L p .81 .552 .549 r
F P
0 g
s
.64988 1.03747 m .63311 1.00264 L .70179 1.00212 L p .753 .696 .797 r
F P
0 g
s
.74235 .94476 m .71166 .90046 L .76483 .87099 L p .861 .742 .73 r
F P
0 g
s
.72519 .82479 m .76483 .87099 L .71166 .90046 L p .824 .694 .72 r
F P
0 g
s
.67907 .96184 m .70179 1.00212 L .63311 1.00264 L p .729 .669 .792 r
F P
0 g
s
.70179 1.00212 m .67907 .96184 L .74235 .94476 L p .809 .733 .78 r
F P
0 g
s
.71166 .90046 m .74235 .94476 L .67907 .96184 L p .781 .695 .769 r
F P
0 g
s
.52075 .88844 m .48707 .86834 L .52672 .83576 L p .614 .589 .802 r
F P
0 g
s
.48158 .81604 m .52672 .83576 L .48707 .86834 L p .578 .575 .813 r
F P
0 g
s
.43111 .68703 m .37273 .68161 L .39437 .62564 L p .625 .464 .643 r
F P
0 g
s
.39437 .62564 m .45963 .6328 L .43111 .68703 L p .625 .464 .643 r
F P
0 g
s
.37273 .68161 m .43111 .68703 L .40912 .74233 L p .59 .496 .716 r
F P
0 g
s
.63311 1.00264 m .61083 .96977 L .67907 .96184 L p .729 .669 .792 r
F P
0 g
s
.52786 .6483 m .45963 .6328 L .49118 .58627 L p .707 .465 .556 r
F P
0 g
s
.49118 .58627 m .56085 .60477 L .52786 .6483 L p .707 .465 .556 r
F P
0 g
s
.66006 .70435 m .59577 .67227 L .62863 .63195 L p .81 .552 .549 r
F P
0 g
s
.56085 .60477 m .62863 .63195 L .59577 .67227 L p .758 .508 .554 r
F P
0 g
s
.48158 .81604 m .43747 .80152 L .46214 .7531 L p .623 .563 .766 r
F P
0 g
s
.40912 .74233 m .46214 .7531 L .43747 .80152 L p .583 .543 .776 r
F P
0 g
s
.55348 .91222 m .52075 .88844 L .57091 .86062 L p .646 .606 .795 r
F P
0 g
s
.52672 .83576 m .57091 .86062 L .52075 .88844 L p .614 .589 .802 r
F P
0 g
s
.59577 .67227 m .52786 .6483 L .56085 .60477 L p .758 .508 .554 r
F P
0 g
s
.61083 .96977 m .58392 .93946 L .64878 .92428 L p .703 .645 .789 r
F P
0 g
s
.64878 .92428 m .67907 .96184 L .61083 .96977 L p .703 .645 .789 r
F P
0 g
s
.72519 .82479 m .67579 .78354 L .7176 .74376 L p .852 .663 .646 r
F P
0 g
s
.66006 .70435 m .7176 .74376 L .67579 .78354 L p .807 .616 .644 r
F P
0 g
s
.67907 .96184 m .64878 .92428 L .71166 .90046 L p .781 .695 .769 r
F P
0 g
s
.58392 .93946 m .55348 .91222 L .6122 .8903 L p .675 .624 .79 r
F P
0 g
s
.57091 .86062 m .6122 .8903 L .55348 .91222 L p .646 .606 .795 r
F P
0 g
s
.6122 .8903 m .64878 .92428 L .58392 .93946 L p .675 .624 .79 r
F P
0 g
s
.46214 .7531 m .40912 .74233 L .43111 .68703 L p .636 .525 .711 r
F P
0 g
s
.6719 .85991 m .71166 .90046 L .64878 .92428 L p .752 .662 .762 r
F P
0 g
s
.71166 .90046 m .6719 .85991 L .72519 .82479 L p .824 .694 .72 r
F P
0 g
s
.67579 .78354 m .72519 .82479 L .6719 .85991 L p .787 .652 .713 r
F P
0 g
s
.52672 .83576 m .48158 .81604 L .51744 .77033 L p .659 .585 .761 r
F P
0 g
s
.46214 .7531 m .51744 .77033 L .48158 .81604 L p .623 .563 .766 r
F P
0 g
s
.49354 .69985 m .43111 .68703 L .45963 .6328 L p .675 .501 .642 r
F P
0 g
s
.45963 .6328 m .52786 .6483 L .49354 .69985 L p .675 .501 .642 r
F P
0 g
s
.64878 .92428 m .6122 .8903 L .6719 .85991 L p .752 .662 .762 r
F P
0 g
s
.43111 .68703 m .49354 .69985 L .46214 .7531 L p .636 .525 .711 r
F P
0 g
s
.67579 .78354 m .61887 .74842 L .66006 .70435 L p .807 .616 .644 r
F P
0 g
s
.59577 .67227 m .66006 .70435 L .61887 .74842 L p .763 .575 .643 r
F P
0 g
s
.57091 .86062 m .52672 .83576 L .57251 .79411 L p .692 .608 .758 r
F P
0 g
s
.51744 .77033 m .57251 .79411 L .52672 .83576 L p .659 .585 .761 r
F P
0 g
s
.51744 .77033 m .46214 .7531 L .49354 .69985 L p .677 .554 .707 r
F P
0 g
s
.6122 .8903 m .57091 .86062 L .62481 .82417 L p .722 .634 .758 r
F P
0 g
s
.62481 .82417 m .6719 .85991 L .6122 .8903 L p .722 .634 .758 r
F P
0 g
s
.55714 .72035 m .49354 .69985 L .52786 .6483 L p .72 .537 .642 r
F P
0 g
s
.52786 .6483 m .59577 .67227 L .55714 .72035 L p .72 .537 .642 r
F P
0 g
s
.6719 .85991 m .62481 .82417 L .67579 .78354 L p .787 .652 .713 r
F P
0 g
s
.57251 .79411 m .62481 .82417 L .57091 .86062 L p .692 .608 .758 r
F P
0 g
s
.61887 .74842 m .55714 .72035 L .59577 .67227 L p .763 .575 .643 r
F P
0 g
s
.61887 .74842 m .67579 .78354 L .62481 .82417 L p .751 .616 .709 r
F P
0 g
s
.49354 .69985 m .55714 .72035 L .51744 .77033 L p .677 .554 .707 r
F P
0 g
s
.57251 .79411 m .51744 .77033 L .55714 .72035 L p .715 .584 .707 r
F P
0 g
s
.62481 .82417 m .57251 .79411 L .61887 .74842 L p .751 .616 .709 r
F P
0 g
s
.55714 .72035 m .61887 .74842 L .57251 .79411 L p .715 .584 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{194.125, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400032000180P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000<9d0032M000`W@00<9d0032M000`W@00<9d
0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00<9d
0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00<9d
0032M000`W@00<9d0032M000`W@00<9d0032M000K7@34E=d001[M0064FXA4E4ADG@006Yd00LAEU9F
DQ5=008ACg@006Ud00LAJa4AEVYF008A00=A4A40CG@006Ud00TAEUMF4E9FDUH00Q400ddAM01;M000
J7@01Q5GJeM[E`8A00MZEVYF4DdA04]d001WM08A00MGEUMFEeIG008A00IB4EHA>A5:M000IW@00a5G
F`024@0>Ef]GJeM[Ea5FJUHACA59M000IW@00a5GE`02E`8A00IGEUMF4EH24@03JUHA008AB7@006Ed
00PAFeMKEe]GF`8A00YGJa5_EflAJUIZ0Q57M000I7@00a5GE`08E`8A00EGEUMFE`024@04EVXA4DId
001TM0<A00YGFeMKEe]GFa5_0Q401EM_EfmG008A00=Z4A40AG@006=d00@A@eM30Q45E`034EMG009G
00TAEUMFEeIG4FX00Q54M000Hg@01Q5LEeaGG08A019GFa5_EfmGKeLAEfmGKa5_4FX24D=d001RM009
4EM3Ed=G@eM3008A25L24@08Ea5_EVlAJQ53M000HG@0315L4A5GG5MLEe`AG08A015GKeM_EfmGKa5_
EfmGKa5Z4@12M000HG@01153Ed<24@05Ed=G@a400eL24@EG00/AFa5_EVmF4EEZ4@11M000H7@01a53
G4=L@e`00Q4025LAEeaGG5ML0Q4035M_4FmGKa5_EfmG4@9Z00<AM7@0?W@005md0Q402EM3Ed=G@eM3
4@09E`8A00EKEe]GF`024@05EVmF4ED00Q4oM000Gg@02a5L4A53G4=L@a5G008A01MLEeaGG5ML4E`A
KeM_EfmG4EM_Ea5YJP0oM000Gg@01153A4<24@07Ed<A@eM3E`024@AG018AFeMK4E]GFeMKEa5F4EHA
EA4nM000GW@01a53G4=L@e`00Q401eMLEeaGG5L00Q401e`AG5MLEe`00Q402eM_EfmG4Fi_KQ5Y03id
001NM00U4DA3A4=4@a534D=G@eM3Ed=G4E]GFeMKEe]G4EMKEa5G4EI_EP024Ced001NM0<A02E3G4=L
4Ea34EMLEeaGG15L4EaGG5MLEeaG4ELAFflAKfi_4FXA03ad001MM0044Bm4;`8A00I44EQ3F4<24@0I
Ed=G4E]3Fa5KEe]GFeMKEa5GKeM_4FmFK`024Cad001MM08A02I4B4A84Ea3G4=L@e`AG15LEeaGG15L
EeaGG5LAFa5KKe]_4Fm^K`8A>g@005id0a405d@AA15H@eQ3F4=H4E]3Fd=K@e/AFeMK008A00eGFa5_
EfmGKa5_EVlA03]d001OM0064C0AB4=80Q400d=L@`024@0LG15LEeaGG5ML4E`AL5]`Fg0AKe]_Fa5^
Ka5_4CYd001PM00X4C0AA4=4@a534D=H@ePAFd=K@e]3Fa5KEe]GFeMK4FmGKeLAEQ5^4CYd001QM00C
4C0AB4=8@a53G4=L@e`AG5MLE`024@0=G15`Fg1KL5]`4FmKK`024@03KVlA03Yd001QM0054B/`4D@0
0Q402T<A@eQ3F4=H4E/24@0=Ee]GFa5KEe]GFeLAE`024@04Ke/AKP8A>G@0069d00PA<14AG4=L@`8A
00AL@ea30Q403eaGG5MLEe`AL5]`Fg1K4@04K`044Fm^4CUd001SM00;4B]44DA3A4=44EP00Q403T=L
4E]GFeMKEe/AFeMK0Q4025LAFfmKKa5_0Q4hM000I7@0214_A15L@ea30Q4055aGG5ML4EaGG5MLEe`A
L15`Fg0A16l0115^Ka4hM000I7@01Q54:d@AA08A00m3A15L@ea3G15KEe]GFeL00Q403E]GFeMK4FmK
Ke/AKQ40>7@006Ed00<AA2l00Q403Ua3G4=L4EaGG5ML4EaG0a4025]L4G1KL5/A16l00a5_4@0hM000
IG@34@0=;d@AA4=4@a53G4=L@`034@0BEe]GFeLAEe]GFeLAFfmKKa5^>7@006Id0Q402dA34D=L@ea3
4EML008A011GG15LFeaKG5/AFg1KL5/A0Vl24@03KQ5d03Id001VM08A00L_A2lA@dA300@A01QL@ea3
4EMKEe]GFa5KEe]GFa5_4FlAKQ4gM000IW@34@03@d@A00<A01E3G15LEeaGG5LAFeaKG5]L4G1KL5/0
0Q400g=_L`024CMd001VM0DA01M4@a53F4=H4Ea3G4=L@a5GFeMKEa5GF`024@03Fa5_009_0Q4gM000
Ig@05Q4`4DA3A15L@ea34EMLEeaGG15LFe`54@0:L5]`4G=_La5^4CId001WM08A010[4DA3A15H@eQ3
4D=L@ea311402U]GFa5_FfmKKa42K`034FhA03Id001WM0@A00]3A4<A@ea3G15LE`034@0AEa5KL5]`
Fg0AL5]`Fa5_Lfl00Q4fM000Ig@24@03@a4A00XA015GG5MLEa5GFeMKEa5KKe]_4@03K`8A=W@006Md
0Q408B]44EQ3F15L@ea34EMLEeaGG15`Fg1KL5/AFg1K4FmcK`024CId001VM08A01lB4B/A@dA3A15H
@eQ34EMLEeaGG15KEe]GFa5_FfmK00DA=W@006Id11406d@[4D=H@a53G4=L4EaGG5MLEa5KL5]`Fg0A
L0034@04LflA4CId001VM08A00<B4A400Q404dA3A4<A@eQ3F15LEeaGG5LAEe/01A401FmK4Fmc008A
=W@006Id0Q4012/AA4<84@06G4<AEeaG1Q402W1KL15dKg@ALfl24CId001UM0034A8A008A00<[@a40
14<00a53G0064@04EeaG4@EK00TAFfmKKa5cKa40=W@006Ed02LA4Q4o4DA34D=H@eQ34EMLEe`AG5]L
FeaK4E]`Fg1K4FmdKa5_La40=W@006Ad0a400cl[4@024@03:a5300=300dAG4=L@e`AG5MLEe`A00EK
00PAKe]_4G=_4CId001SM08A00LV4B/o4DA300<A01e3F4<AEeaGG5LAFeaKG5/AFg1KL5/AKgA_4Fmc
4@0fM000@W@B4@id0Q400a8V4@034@05?d<o4D<00a403D<A@ea3G15LEeaGG1401E/01A5_FfmK00<A
=W@003ed21449@@A00LU>BDi9CTU00PA1G@00a4B4@024@0<@cm34DA3A15L@ea311404EaGG15LFeaK
G15`Fg1KL15d00<A00=c4G@0=G@003]d7A4012Di9CT74@06?bHA:cl[0a402Sm34EM3Ed<A@e/A4@05
Le/AKQ40=W@003Ud2Q403BDj4A4i?STn>Chi?ST00Q401U8iDSUB>@lA00Do@a5H@`034@0M@ea3G15L
EeaGG15LFeaKG15`Fg1KL15dKg@ALa40=W@003Md1a4042Di9CTU>A4j>CXi>STj>CX24@0<>Chi?STn
>Chi?STn0Q400cUB4@034@039A4A00<A14<24@0I@eM34D=K@e]34EMLEeaG4E]`Fg1K4E]cF`024CMd
000eM0<A12D0414U>RDj9CXA?STn>Chi?ST24@0<DSUB>E8iDSUB>E8i0Q40259ADU5BDE9A1Q401UQ3
F4<AE`8A01ML4EaGG5ML4EaKG5]L4G1KL5]`4GA_M0024CMd000cM0@A00<U4BD00Q401BDi9CTU008A
00<j>CX02a401chi?STn>Ch00Q403SUB>E8iDSUB>E8iDSUB1142@`044EM3E`<A01IK@e]3Fa5LEeaG
G15`Fg1K4E]c4G<A=g@0035d11449@054CXU>RD021402cln?chA?U<nDciC00TA015BDE9ADU5BDE9A
DU5BDA5ADP044@06EeaGG15L11404ULAFeaKG5/AFg1KL15dKa5c4CMd000`M0DA00DU4BDA>@044@0L
9Q4j?SXn>Shj?SXn4E8nDSiB?U8nDSiB4E8nDP@A00PiDSUB>E8iDP8A1E444@08Ed<AEe]GFeL44@0;
G5ML4G1KL5/AFg<00a4gM000;g@44@<U114093hV?RHn4Cln?cho?Sln?a5C?U<nDciC?U<nDa5GDUMB
Ee9GDP@A00eBDE8ADU5BDE9ADU5B00DA00ULEeaGG5LAFg001Q4015]`4G@24@03FQ5d03Id000^M0TA
02/n9ShV?RHn4Chj?SXn>Shj?Q5B?U8nDSiB?U8nDQ5B?U8nDSiB?U8nDSiB00@A35444@0=Ee]GFa5L
FeaKG15`F`044@03M15N03Qd000]M0HA0bH0<14V?RHn9ShA?cho?Sln?cho4E<nDciC?U<nDciC?Q5B
Ee9GDUMBEe9GDUMBEa5GDP<A00]ADU5BDE9ADU5BD@044@0@G5LAFg1KL5/AFgAKM15dL`8A>7@002ad
1A40>2HU9RDA9ShV?RHn4Chj?SXn>Shj?SXA?U8nDSiB?U8nDShA?U8nDSiB?U8nDSiB?U8AEU9FDUIB
1146D@8A01EA4A4G4E]LFeaKG15`Fg0AM5/AFQ40>7@002]d1A449P0i4BHn9ShV?RHA?Sln?cho?Sln
4CiC?U<nDciC?U<n4E9GDUMBEe9GDUMBEe9G4EMBEe9GDUMBEe9G00<A00=BDA401E424@0=L5]`Fg0A
M5]dFa5cM0024CUd000[M0@A014V9BHU4BHn9ShV?RHA>Shj?P0E4@0KDSiB?U8nDSiB?U8AEU9FDUIB
EU9FDUIBEU9F00<A1e424@0;FeaK4E]`Fg0AM5/00Q4iM000:W@24@034Q4A00@V00DA?RHn9P084@0B
@cm3?d<AEcmG?eLoEcmG?eLA0eL64@0HDUMBEa5GDUMBEe9GDUMBEe9GDUMB4EI[0Q47D@8A00Y`4GAK
M5/ALg@A>W@002Yd00XA4Q4A9BHU9Q4n11408bXo4Cln?cho?Sln?a5G?ULnEciG?ULnEa5G?ULnEciG
?ULn00DA01EBEU9FDUIBEU9FDUIBEU8ADUIBEU800Q47D@<A00E`Fa5KM0024CYd000YM0<A00<B4BH0
0RH34@0M?cho?SlA@cm3?d<o@cm3?a4oEcmG?eLoEcmG?a4035L00a5GE`044@0CEe9GDUMBEe9GDULA
JeI[EV]FJ`034@IA1a4kM000:7@34@044Q4V9@<A038Z?bXo:SlZ4Cho?Sln?cho?Q4nEciG?ULnEciG
?Q4nEciG?ULnEciG?ULn4E9GDUMBE`<A01=FDUIBEU9F4EIBEU9FDUIBEU9F008A0U424@07DA5K4Emc
4@0kM000:7@24@0V4Q4A9Q4V:a4o?Sln?chA?d<o@cm3?d<o@a5G?eLoEcmG?eLoEa4<E`034EMG00QG
11404E9G4F]FJeI[EV]FJeI[EV]F008A15424@03M15d03]d000WM08A00<B4A400Q40?BH[4ClZ?bXo
:SlA?cho?Sln?cho4ELnEciG?ULnEciG4ELnEciG?ULnEciG?Q5BEe9GDUMBEe9GDUMBEe800a40459F
DUIBEU9FDUIBEU9F4FX24@AA0Q4lM0009g@34@0U4Q4[9R/V4Cho?Sln?chA?d<o@cm3?d<o4CmG?eLo
EcmG?eLo4@0<E`034EMG00eG00<AEeL00Q404F]FJeI[EV]FJeI[EQ5FJUHA00AA00<AM7@0>W@002Id
0a40Aa8A4BH[9R/A?bXo:SlZ4Cho?Sln?cho?Q4nEciG?ULnEciG?Q4nEciG?ULnEciG?ULAEe9GDUMB
Ee9GDUMBEe9G4EMFEeIG00<A00mFDUIBEU9FDQ5FJUIZEQ4015424CYd000VM0@A02@C4B/V:bHA?Sln
?cho4D<o@cm3?d<o@a5G?eLoEcmG?eLoEa4;E`034EMG00eG00<AEeL01eL34@0<JeI[EQ5FJUIZEVYF
0Q44D@034GAd03Md000VM08A0Q804A4[9R/V:a4o:SlZ?a4o?Sln01LA02@nEciG?ULn4E9GDUMBEe9G
DUMBEe9GDQ5FEeIGEUMFEeIGEUL24@0=DUHAJUIZEVYFJUIZ4@04D@034GAd03Id000UM08A00hB4a8A
9R/V:bHA?Sln?`HA01Lo@cm3?a53Ed=G@eM3Ed=G@a53Ed=G@`094@eG00<AEeL03EL24@0<JUIZEVYF
JUIZEVXA0e424CMd000UM08A0a802A4[9R/V4BXo:P024@0V?a53?d<o@cm3?a4o@cm3?d<o@cm3?a4o
EcmG?eLoEcmG?eLAEd<44@0KEe9GDUMBEe8AEUMFEeIGEUMFEeIGEUMFEa5G008A00YFJUIZEVYFJUIZ
0a400e4i4@0fM0009G@24@0:4Q<B4BH[9R/A?`8A02D[@b/A?d<o@cm3?d<AEd=G@eM3Ed=G@eLAEd=G
@eM3Ed=G@eLA00MG1143E`034EMG00mG00@AEfmG0Q403VYFJUIZEVYFJUHACE5==W@002Ad0a434P04
4B/V:`<A038o:cl[?a53?d<o@cm3?a4o@cm3?d<o@cm34ELoEcmG?eLoEcmG?a53Ed=G@eM3Ed=G@`@A
02IGEUMFEeIGEUMFEeIGEUMF4EIGEUMFEa5ZEVYFJUIZEQ5E4CUA>CEd000TM0084A8A4Q<A:bH24@0Y
:a53:d<[@b/A?d<o@cm3?d<AEd=G@eM3Ed=G@a53Ed=G@eM3Ed=G@a403EL00a5GF`034@aG00TAEfmG
KeM_Efl00Q401eIZEVYFJQ400VX24@03DDed03=d000TM0034A8A008B0a43:`0f4B/o:cl[?a53?d<o
@cm34D<o@cm3?d<o@clA?eLoEcmG?eLoEcmG4EM3Ed=G@eM3Ed=G@eLA1EL24@0EEUMFEeIGEUMF4EIG
EUMFEeIGEUMF008A00aZEVXAJUEZEFXADA4cM00097@01Q4B4A8C4@D[02LA@b]3:d<A@cm3?d<o@clA
@eM3Ed=G@eM3Ea5G@eM3Ed=G@eM3Ea403EL02A5KEe]GFeMKE`034@IG00hAKeM_EfmGKeM_EfmGK`8A
00=F4FX01FX00a5AM00bM00097@0114B4A824@D[03DA:cl[?b/A?d<o@cm3?d<A@cm3?d<o@cm34ELo
EcmG?eLoEcmG?a53Ed=G@eM3Ed=G@eM34@0;E`<A01iFEa5GEUMFEeIGEUMFEeIGEUMF4EEZEFYEJUEZ
4E4bM00097@0114B4A824@D[02HA@b]3:d<A@cm3?d<o@clA@eM3Ed=G@eM34D=G@eM3Ed=G@eM34@eG
010AEe]GFeMKEe]GFeMKEe]G0Q404fmGKeM_EfmGKeM_EfmGKeLAEa4026X24C5d000UM0<A00<B5a40
12/04a4[?b/o:a4o@cm3?d<o4Cm3?d<02a405ELoEcmG?eLAEd=G@eM3Ed=G@eM34@0@E`0E4ELA4EIG
EUMFEeIGEUMFEeHAEVmF008A00UZEFYEJUEZEA40<7@002Ed0Q4011<[4a44:`0:4D<[@b]34D<o@`TA
00]H@eQ3F15H@eQ3F0084@aG01DAFeMKEe]GFeMKEe]GFeMK4E]GFeL00Q404VmGKeM_EfmGKeLAEfmG
KeM_4@QZ00<AM7@0;G@002Ed0Q4011LB5a44:`054B/o:cl01A4074<[@b/A?d<o@cm3?d<o4D=G@eM3
Ed=G@eM34D<44@08Ed=G@eM3Ea4?E`034EMG00EG0Q406UIGEUMFEeIG4FmFKeI_EVlAJUEZEFYE4EDA
;W@002Ed00HA4a4[4a44:`034D<A008A02E44DA3A4=4@d@AF4=H@eQ3F4<A@eQ3F4=H@eQ3F4<A@eQ3
F4=H00@A0eL06Q5GFeMKEe]GFeMKEe]GFa5KEe]GFeMKEe]G0Q4046mGKeM_4FmGKeM_EfmGKa45JP04
4FiY4Bed000UM0064A8A4QLA12/24@0/@b]3:a4[@b]3:d<[4Cm3?d<o@cm34EM3Ed=G@eM3Ed=G4EM3
Ed=G@eM3Ed<44@iG00<AEeL02UL24@0>EULAKeI_EVmFKeI_EVl24@07EFXAJUEZ4@0]M0009G@0214C
4B/C:a4[0a40<D@[A2]4:a53A4=4@d@AF4=H@eQ3F4<A@eQ3F4=H@eQ3F4<A@eQ3F4=H@eQ3F4<AEe`0
0a406U]GFeMKEe]GFeLAEe]GFeMKEe]GFeMKEe]G0Q405VmGKeM_EfmGKeM_EfmG4FXAJFiYKQ4/M000
9G@24@044a4G4P8A0b/0=153:d<[@a53:d<[@b/A?d<o@cm3?d<AEd=G@eM3Ed=G@a53Ed=G@eM3Ed=G
@eLAEd=G@eL34@IG00<AEeL03UL06A5K4A5FKeI_EVmFKeI_EVmF4EEZEFYEJQ40:g@002Id044A4Q4C
:a4`:c0[4B]4:d@[4D=4@dA3A15H@eQ3F4=H@a53F4=H@eQ3F4=H4EQ3F4=H@eQ3F4=H4EaGG5MLEeaG
G0034@0^FeLAEe]GFeMKEe]GFeMKEe]GFa5_EfmG4EM_EfmGKeM_EfmG4FhAJFiYKVU^4BYd000VM0<A
00<G4A4012/0>Q53:d<[@a53:d<[@b/A?d<o@cm3?d<AEd=G@eM3Ed=G4EM3Ed=G@eM3Ed=G@a53Ed=G
@eM3Ed=G@eL34@mG00LAFeMKEe]G008A01=_EVmFKeI_EQ5FKeHAEFYEJUDA02Yd000WM0164A<A4ALA
:c0[4B]4:d@[4D=4@dA3A15H@eQ3F4=H4EQ3F4=H@eQ3F4<A@eQ3F4=H@eQ3F4<AEeaGG5MLEeaGG5ML
Ea5GG08A01IGFeMKEe]GFeMKEe/AKeM_EfmGKeM_0Q404UM_EfmGKa5_KVm^4FU^JFiY4BUd000WM0<A
0QL00a4[:`02:`0i4B]3:d<[4B]3:d<[4Cm3?d<o@clA@eM3Ed=G@eM3Ea5G@eM3Ed=G@eM34D=G@eM3
Ed=G@eM3Ed<A00EG0Q49E`0P4E]GFeMKEe]GFeMKEa5FKeI_4FmFKeI_EQ5EJUEZEA4XM000:7@24@0@
;1L/4C0[<154:d@[A154@a0A02MH@eQ3F15H@eQ3F4=H@eQ3F15LEeaGG5MLEeaGG5ML4EaGG5MLEe`0
0a4055]GFeMK4FmGKeM_EfmGKeM_EfmG0Q4046lAKfi_KVm^KfhAJFiYKQ4XM000:7@34@8G00TA:b/[
4B]3:d<0114042m4;a53A4=4@dA34D=4@d@84@0G@eM3Ed=G@eLAEd=G@eM3Ed=G@eM3Ea402eL24@9G
024AFeMKEe]GFeMKEe]GFeMKEe/AKeI_EVmFKeI_EQ5EJUD00Q4WM000:G@02a4H4B`G4B/`:a4[008A
01a44DA3A4=44DA3A4=4@d@AF4=H@eQ3F4=H4Ea31A407d=H@a5GG5MLEeaGG5MLEe`AG5MLEeaGG5ML
EeaGG5L00Q408fmGKeM_EfmGKeM_EfmGKeM_4FlAKfi_KVm^Kfi_KQ5Y4EDA02Md000ZM0054a4G5a40
0b/24@0S:c0[<154;d@_A154@dA3A4<A@dA3A4=4@d@AA4=4@dA3A4<0114035M3Ed=G@eM3Ed=G4@mG
024AFa4AEe]GFeMKEe]GFeMKEe/AKeM_4FmFKeI_EVmFKeH00Q400fUE4@0VM000:W@01A4C4AL/00<A
02T`4D@`A30A@dA3A4<A@dA3A4=44EQ3F4=H@eQ34D=L@ea3G4=L@e`AG0024@0oEeaGG5MLEe`AG5ML
EeaGG5MLEeaGG5ML4EaGG5LAEfmGKeM_EfmGKeM_4FmKKe]_4Fm^Kfi_KVm^KfhAEFTA02Id000[M00b
4A<A5a4G<1LA:c0[<154;d@_A154@dA3A4<A@dA3A4=4@d@AA4=4@dA3A4=44EM3Ed<34@06@eM3Ed<A
3UL01a5KEe]GFeL00Q407e]GFeMKEe]GFa5_EfmGKeM_4FmFKeI_EVmF4FhAEA409W@002ad0Q400b`A
4@03<00/4C14<4@AA4=4@a53A4=4@d@AF4=H@eQ3F4<A@ea3G4=L@ea34D=L@ea3G4<24@0KG5LAEeaG
G5MLEeaGG5MLEe`AG5MLEeaGG5ML008A01iGKeM_EflAKe]_FfmKKe]_4Fm^Kfi_KQ5^Ka5YEA4UM000
;G@24@0c71LA5c0A<2/`:a4_A2m44DA3A4=4@a53A4=4@dA34D=4@dA3A4=4@a53Ed=G@eM3Ed=G00<A
3EL0:a5KEe]GFeMKEe]GFeLAEe]GFa5_EfmGKeM_EfmGKa5_EVmFKa5_KVlAJA409G@002ed0a400c0H
4@02<00`4D@`A154@dA3A154@dA3A15H@eQ3F4=H4Ea3G4=L@ea3G15L@ea3G4=L@ea34EML0a4065aG
G5MLEeaGG15LEeaGG5MLEeaGG5MLE`8A01a_4FmKKe]_FfmKKe]_FflAKfi_4Fm^KfhAEFTA97@002id
1140=QLA5c0A<2/`4D@_A2lA@dA3A4<A@dA3A4=4@a53A4=4@dA3A15G@eM3Ed=G@eM3Ea5G@eM3E`8A
1UL0;Q5KEe]GFeMKEe]GFeMKEe]GFa5_EfmGKeM_EfmGKeM_EflAKa5_KVm^KfhAEA4TM000;g@02Q4L
5a4H4C0A<4@@4@0Q@eQ34D=L@ea3G4=L@a53G4=L@ea3G4=L4EaGG5MLEeaG00<A02mGG15LEeaGG5ML
EeaGG5MLEeaGG15`4FmKKe]_FfmKKe]_FfmKKa5_KVm^Kfi_KP024BAd000`M08A00DG4ALA5`024@0@
<1/A;c0_<154;d@_4Bm4;`DA01m3A4=4@dA34D=G@eM3Ed=G@eLAEd=G@eM3Ed=G@eM3008A011KEe]G
FeMKEe]GFeMKEe]G0Q400e]GF`024@0FEfmGKeM_EfmGKeM_4FlAKfi_KVm^K`8A97@0039d1A405a`A
<3@`4C18<14`B318<154B4A8A15300@A01eL@e`AG4=L@ea3G4=L4EaGG5MLEeaGG5MLEe`AG0024@0Q
EeaGG5MLEeaGG5MLEa5KL5]`Fg1K4E]_FfmKKe]_FflA009_00TAKVm^Kfi_KVl00Q4SM000=7@54@0I
714`6a4_<2lA;d@_A154;d@_A154@dA3A0054@0JEd=G@eM3Ed<A@eM3Ed=G@eM3Ed=G4E]3Fd<24@0Z
FeMKEe]GFeMKEa5GFeMKEe]GFeLAEfmGKeM_EflAKe]_Fa5^Kfi_KVm^0Q4SM000=W@74@0J<14`B30A
<4P`4DA8A4Q44D=8@dQ3B4<A@e`44@0e@ea34EMLEeaGG5MLEeaGG15LEeaGG5ML4EaGG5MLEeaG4E]`
Fg1KL5]`Fg1K4E]_FfmKKa401Vl02A5^Kfi_KVm^4@0SM000>G@74@0K;c0AA2m44D@_A2m44DA3A4=4
@a53A4=4@dA300<A00]3Ed=G@eM3Ed=G@`024@09Fd=K@e]3Fd=K008A00AGFeMK0Q403EMKEe]GFeMK
Ee]GFeL00Q4056mGKa5_FfmKKe]_4Fm^Kfi_KQ5^8g@003ad2A406C184DQ4B4@A@dQ3B4=84Ea3G4=L
@ea34D<00Q405UaGG5MLEeaG4EMLEeaGG5MLEeaGG5L24@0FG15`Fg1KL5]`Fg1KL5]`Fg1KL15_4@U_
00TAKfi_KVlAKQ408W@0045d0Q400a`K4@044@0F;d@AA4=4@d@AA4=4@dA3A4<A@dA3A08A03]3Ed=G
@a53Fd=K@e]3Fd=K@e]3Fd=K4E]GFeMKEe]GFeMKEe]GFeMKEe/AKe]_FfmKKe]_FflAKfi_4@02KP03
4GAd021d0014M08A00@`730`114054Q3B4<A@ea3G4=L@a53G4=L@ea30Q404UaG4EMLEeaGG5MLEeaG
G5MLE`8A019L4G1KL5]`Fg1KL5]`Fg1KL5/24@03L15_00Y_00<AKa400fh00a5dM00PM000AW@24@06
6c0K<14`0Q4054<A@dA3A4=4@d@AA4=4@dA3A4=40Q4054=K@e]3Fd=K@e]3Fd=K@a5GFeMK0Q4085MK
Ee]GFeMKEe]GFeLAEfmGKa5_FfmKKe]_FfmK4FhA0fh00a5dM00PM000B7@24@8`00@A<30`0a404d=L
@ea3G15L@ea3G4=L@ea34D<00Q402eaGG5MLEeaGG5ML008A019GG5MLEeaG4E]`Fg1KL5]`Fg024@06
Fg1KL5/A2fl00a5^KP03KP034GAd01md001:M0094C0K4Bl`;a4_00<A0193A154@dA3A4=4@dA34D=L
@e`24@0K@e]3Fd=K@e/AFeMKEe]GFeMKEa5GFeMKEe]G008A019_EfmGKeM_Ea5KKe]_FfmKKe/24@E^
00<AM7@07g@004ad00<`4C000S001A54<4@`00<A00Q3G4=L@ea3G08A00M3G4=L@ea3008A019LEeaG
G15LEeaGG5MLEeaGG5L24@0AL5]`Fa5KL5]`Fg1KL5]`Fa401fl0115_La44KP034GAd01md001=M08A
00X`4D@_A2m44D@_0Q404DA3A4=44Ea3G4=L@ea3G4=L008A01A34A5KEe]GFeMKEe]GFeMKEe/AF`8A
019GKeM_EfmGKeM_EfmG4E]_Ffl24@=_00<AKVh00Vh00a5dM00OM000Cg@24@0:<4@`A30AA4Q4B08A
0113G15L@ea3G4=L@ea3G4=L0Q408eMLEeaGG5MLEeaGG5MLEeaGG15`Fg1KL5]`Fg1KL5]`Fg0A00=_
00PALfmcKg=_4@A^00<AM7@07W@0055d00`A;d@_4Bm4;d@_A2l24@0<G4=L@ea3G4=L@ea30Q404Ua3
4EMKEe]GFeMKEe]GFeMKE`8A01AK4FmGKeM_EfmGKeM_EfmGKa5_4@M_00<AKVh00Vh00a5dM00NM000
DW@24@08A158A4Q4B4@24@0;B14A@ea3G4=L@e`00Q401D=L@ea3008A00]LEeaGG5MLEeaGG0024@0O
FeaKG15`Fg1KL5]`Fg1KL5]`Fg0ALfmcKg=_Lfmc4@03KP034GAd01id001BM00E4APAA2m4;d@_4D=4
@dA34D=L@ea3008A019L@ea3G4=L@e`AFeMKEe]GFeL24@0DFeMKEe]GFa5_EfmGKeM_EfmGKeL24@03
Ka5_00M_00<AKVh00Q4PM000Dg@01Q4L4A54B08A00M3B4=8@dQ3008A01EL4A53G4=L@ea3G4=L@e`A
G5MLEe`00Q4055]LFeaKG5]LFe`AL5]`Fg1KL5]`0Q403e]`Fa5_LfmcKg=_LflAKP024B1d001DM003
4A`G008A00Y4@dA3A4=4@dA30Q403ea3G4=L@ea3G4=L@ea3G0024@0PEa4AFeMKEe]GFeMKEe]GFa5_
EfmGKeM_4FmKKe]_Fa48K`8A00=E4G@07g@0059d1A402B/`4DQ3B4=8@`034@0B@e`AG4=L@ea3G4=L
@ea3G4=L0Q405E]LFeaKG5]LFeaKG5]LFe`AL5]`F`024@0DL5]`Fg1KL15cKg=_LfmcKg<AKQ4PM000
Cg@44@079A4A4C0G<0024@0F@d@A4D=4@dA3A15L@ea3G4=L@ea3G0<A01EL@a5GFeMKEe]GFeMKEe]G
FeMK4Fl00Q402e]_FfmKKe]_FflA00M_0Q400eE]4@0OM000CW@94@03:c0[00@A00UL@ea3G4=L@e`0
0Q401T=L@ea3G0<A01ILEeaGG5LAFeaKG5]LFeaKG5]LFeaK0Q406G1KL5]`Fg1KL5]`Fg0ALfmcKg<A
La5^FA407g@004]d0a400bDA4@094@0B:c0[4D=4@dA3A4=4@dA34D=L0a402Ua3G4=L@ea3G4<24@0:
FeMKEe]GFeMKE`<A011GFa5_FfmKKe]_FfmKKe/A16l01a5cKg<AKA407g@004Id2Q400cTA4@064@05
;d@_A2l00Q4025a3G4=L@ea311405UaGG5MLEeaGG5MLEeaGG15LFeaKG5/34@0NFg1KL5/AFg1KL5]`
Fg1KL5]`Fa5_La5cKg=_4ETA7g@004Ed00@ABf0A0V000a5OH00<4@0::c0[<2/`4DA3A0@A01M3A4<A
@ea3G4=L@ea3G4=L@ea3G15KE`034@0QEe]GFeMKEe]G4E]_FfmKKe]_FfmKKa5_4G=_Lfmc4FdA01md
0014M0044DaP4@=P00DAM61dH0084@03;1LA00TA01ML@ea3G4=L@a5GG5MLEeaGG5MLEeaGG0044@0I
Fg1KL5]`Fg1KL5]`Fa5KL5]`Fg1KL5]`F`024@09LfmcKg=_4ETA01md0013M0054D]PBa400f001Q5O
H5mPG`TA01<C4B]4:d@[A154@dA3A4=4@dA3008A00QL@ea3G4=L@`@A01]L@e`AFeMKEe]GFeMKEe]G
FeLAFfmKKe]_Ffl00Q402e/AKg=_Lfmc4FdA01md0012M0054DaPC14016000a5dH0084@04:a4A:`8A
01M4@dA3A4=44Ea3G4=L@ea3G4=L4EaGG0044@0LEeaGG5MLEa5KL5]`Fg1KL5]`Fg1KL15`Fg1KL0<A
00edKgA_4FmcKg=_4ETA01md0011M0dA00IKH5]P4E`64@8[1A402T@[A154@dA3A4<84@0NG4=L@ea3
G4=L@ea34EMKEe]GFeMKEe]GFeMK4FmK0Q403fmKKe]_FflALfmcKg=_4@0PM000@G@0515dH7AP4Ead
G7@AM5adG7AL4E]d114022/A4C0AA4=42Q408d=L@ea3G15LEeaGG5MLEeaGG5MLEa5KL5]`Fg1KL5]`
Fg1K00<A015_M6mdKgA_M6lAKg=_Lfmc4@0PM000@7@05a5PFf1KH15PFf1KH15PFf1KH5/AFa4n00<A
00<[@a400Q40;4A3A4=4@d@AF4=H@eQ3F4=H@ePAG4=L@ea3G4=L@ea3G4<AEe]GFeMKEe]G0a4055/A
FfmKKe]_FfmKKa5cKg=_LflA87@0041d01HAH7APM60AG7ALM5`AG7ALM5ad4GAK1Q400d@[A0024@0W
@dA3A4=44Ea3G4=L@ea3G4<AEeaGG5MLEeaGG5MLEe`AL5]`Fg1K00<A01EKL5]`Fa5_M6mdKgA_M6md
4G=_Lfl00Q4PM000@7@05a5PFf1KH15PFf1KH15PFf1KH5]P4EaK00@A00I34D<[4D<34@0Q@dA34D=H
@eQ3F4=H@eQ34D=L@ea3G4=L@ea3G4=L4E]G00<A01YKG5]LFeaKG15_FfmKKe]_FfmK4FmcKa5^4B1d
000oM00I4GAPM61d4GALM5adG7@AM5adG7ALM15dF`034@09@d@A4B/A@eQ300DA01=3G4=L@ea3G4=L
@a5GG5MLEeaG00TA01eKL5]`Fg1KL5]`Fg0AM6mdKgA_M6md4G=_4G9c4@0PM000?g@06a5KH5]PFa5K
H5]PFf1K4E]PFf1KH5/AFe`A?`034@0;@b/A4DA3A4=4@d@0514085MLEeaGG5ML4EaKG5]LFeaKG5]L
Fa5KKe]_FfmKKe]_0Q4016icKQ4PM000?W@0515PM61dH7@AM5adG7ALM5`AG7AL21400d<A4@024@0l
@d@A4D=H@eQ3F4<A@ea3G4=L@ea3G4<AFeaKG5]LFeaKG5]LFa5KL5]`Fg1KL5]`Fg1K4FmdKgA_M6md
0Q401G9cLW<A021d000nM0@A00QKH5/AFf1KH0PA00QKG5]LFa5GG08A00IF4ClA:d<44@0b@dA3A4<A
@ea3G4=L@ea3G4<AEeaGG5MLEeaGG5MLEa5KG5]LFeaKG5]LFe`AKe]_Ffl34@06La5cKW<A8G@003id
00@AFgAK21404G1KL5/AFg1KL5]`Fg1K4E]`008A00=G4D<00a400d=L@`034@0/@ePAG4=L@ea3G4=L
@e`AG5]LFeaKG5]LFeaKG15`Fg1KL5]`Fg1KL5]`4G@34@09M6mdKa5bLg8A025d000nM00N4G1KL5]`
Fa5KG5]LFeaKG5/AFeaKG5]LFe`AG5ML0Q4015HA?d<24@E311408ea3G4=L@ea3G4=L4EaGG5MLEeaG
G5MLEe`AG5]LFeaKG5]L00DA00acFg=KLe]c4G=^La4QM000?W@07a5KM5]dFg@AL5]`Fg1KL5]`4G1K
L5]`Fg1KL15`Fg0011400d=H@`024@06G4=L@ea321405Ua3G4=L4EaKG5]LFeaKG5]LFa5KL5/64@0A
M5]d4GA_M6mdKgA_4G9cLQ408G@003id028AL5]`Fg1KL15LFeaKG5]LFe`AG5]LFeaKG5]L4EaGG15G
0a400d<AE`024@I300HAG4=L@e`F4@0GFg1KL5]`Fg1K4E]cFg=KLe]c4G=^La408G@003id020AFgAK
M5]dFa5KL5]`Fg1KL5/AFg1KL5]`Fg1KL15`F`@A00IH4EPAG4<24@0eG4=L@a5GG5MLEeaGG5MLEa5K
G5]LFeaKG5]LFe`AM5]dFgAKM5]dFgAK4FmdKgA_M6lALW<00Q4QM000?G@08Q5KL5]`Fg1KL15LFeaK
G5]LFe`AG5]LFeaKG5]LFa5GG5L44@07Ea4A@eM3E`034@93034A@ea3G4=L@ea3G4<AEeaGG5MLEeaG
G5ML4G1KL5]`Fg1KL5]`4G=KLe]cFg<ALa5J029d000mM00R4GAKM5]dFgAK4E]`Fg1KL5]`Fg0AL5]`
Fg1KL5]`Fa5KL0DA00UH@a53G4=L@e`00a40;UaGG5MLEeaGG5ML4EaKG5]LFeaKG5]LFa5KM5]dFgAK
M5]dFa5_M6mdKgA_4G824B9d000mM00N4E]`Fg1KL5]`4EaKG5]LFeaKG5/AFeaKG5]LFeaK114015]G
4EH24@0;Ea4A4EM3Ed=G@eL00a40:Ea3G4=L@ea3G15LEeaGG5MLEeaGG15`Fg1KL5]`Fg1KL15cFg=K
Le]c008A00=JM7@08G@003ed01PAM5]dFgAKM5]d4G1KL5]`Fg1KL5/AFg064@06EeaG4EML0a401EPA
4A5L008A00Q3G4=L@a5GG0@A02AGG5MLEa5KG5]LFeaKG5]LFe`AM5]dFgAKM5]dFa5_M6mdKg@24@03
FQ5d029d000mM00@4E]`Fg1KL5]`Fa5KG5]LF`PA00eKEe]GFeMKEe/AFeMK00<A00IG@a53Ed<24@0:
Ed=G@a53G4=L@`@A01iL@a5GG5MLEeaGG5MLEa5KL5]`Fg1KL5]`Fa5KLe/24@04La5J4B=d000mM10A
01IKL5]`Fa5GG5MLEeaGG5MLEe`AG5ML0a401eQ34EMLEe`00Q4034=L4EaGG5MLEeaGG0TA01=LFeaK
G5/AFgAKM5]dFgAKM15d008A00EcM7<AFP0TM000?G@09Q5GFeMKEe]GFeLAEe]GFeMKEe]GFeLAEe]G
FeMKEe]GFeMK4E]G114025LA4A5G@eM30Q404eLAG4=L@ea3G4=L@a5KG5]LFe`04a44L`034EXA02Ad
000mM00W4G1KL5]`Fg1KL5/AFg1KL5]`Fg1KL15LEeaGG5MLEeaGG5LAEeaG008A00aK4EPAG15LEeaG
G5L24@0YG5MLEeaGG5MLEa5KL5]`Fg1KL5]`Fa5KM5]dFgAKM5]d4GAcM7=d4Eh09G@003ed02PAEe]G
FeMKEe]GFa5KEe]GFeMKEe]GFa5KEe]GFeMKEe]GFeLAEe]G0Q401ELA4D=K008A00I3Ed=G4E`24@0P
@ea3G4=L@e`AG5]LFeaKG5]LFe`AM5]dFgAKM5]dFa45L`8A9G@003id02/AFg1KL5]`Fg1K4E]`Fg1K
L5]`Fg1K4EMLEeaGG5MLEeaGG15LEe`AKa5K008A00]GG5LAEeaGG15LF`034@0REeaGG5LAFg1KL5]`
Fg1KL5/AFgAKM5]dFgAKM15dLgAcM08A9G@003id034AFeMKEe]GFeMKEa5GFeMKEe]GFeMKEa5GFeMK
Ee]GFeMKEe/AFeMK4ELAEa5K@e]3008A00QG@a5GG5MLE`<A01Y3G15LFeaKG5]LFeaKG15dFgAKM5]d
FgAK4@Ec00<AM7@097@003id02PAFg1KL5]`Fg1KL15`Fg1KL5]`Fg1KL15LEeaGG5MLEeaGG5ML4EaG
0Q4055/A4A5LEeaGG15L4EaKG5]LFeaK0Q4075`AL5]`Fg1KL5]`Fg0AM5]dFgAKM5/ALgAcM7<24BId
000nM00X4E]GFeMKEe]GFeLAEe]GFeMKEe]GFeMK4E]GFeMKEe]GFeMKEa5GF`<A00=G4A400Q4014=K
@e/34@09G5MLEeaGG5ML00<A01ALFeaKG5]LFeaK4E]dFgAKM5]d4@Ec00<AM7@09G@003id02@AFg1K
L5]`Fg1KL15`Fg1KL5]`Fg1KL5/AEeaGG5MLEeaGG5L44@04Fa4AE`8A01ELEa5GG5MLEa5KG5]LFeaK
G5]L4G00114055]`Fg1KL15dFgAKM5]dFa5cM7=d0Q4WM000?W@0815KEe]GFeMKEe]GFa5KEe]GFeMK
Ee]GFeLAEe]GFeMK1143E`034D=G008A00YG4A5KEa53Fd=K0a403UaGG5MLEeaG4E]LFeaK11403EaK
4E]dFgAKM5]d4G<00a400g<AM00VM000?g@06a5`Fg1KL5]`Fg1K4E]`Fg1KL5]`Fg1KL15LE`044@0:
FeMKEe]GFa5KE`<A00aG4EMLEa5GG5LAFe`24@0@FeaKG5]L4G1KL5]`Fg1KL0dA00AdLg@A:7@003md
01HAEe]GFeMKEe]GFa5KEe]GFeMKEe]G1A4<E`034EM3008A00iG4A5GFeLA@e/AG5MLE`8A01mLEeaG
G15LFeaKG5]LFeaK4E]dFgAKM5]d4G=OLelA02Qd000oM00@4G1KL5]`Fg1KL5]`4G1KL0HA01AGFeMK
4E]GFeMKEe]GFeMKEe/AF`@A00EK4EMLE`024@07G15LFeaKG0024@0LFeaK4E]`Fg1KL5]`Fg0AM5md
GgAOM5lALgAc4BUd000oM10A00]KEe]GFeMKEe]G4@0=E`054D=G4E/00Q401ULAEe]GF`8A00MGG5ML
EeaG008A01YL4EaKG5]LFeaKG5/AFgAKM5]dFa5OLemc4BUd000oM00[4FmGKeM_EfmGKeM_4E]GFeMK
Ee]GFeMKEe]G4EMKEe]GFeMKEe]GFeLAE`024@0CG15LFa5GG5ML4EaKG5]LFeaKG0034@0FL5]`Fg1K
L5]`4GAOM5mdGg@AM7=d4BYd0010M00K4E]GFeMKEe]GFeMK4E]GFeMKEe]GFeMKEe/A00eG00dAEa4A
Ea5GFa5KEe]G00<A00YGG5MLEeaGG15L0Q4055]LFeaKG15dFgAKM5]dFa5OLelA:W@0041d02/AEfmG
KeM_EfmGKeLAEe]GFeMKEe]GFeMKEe/AFeMKEe]GFeMKEe]GFa5K00@A01EKG15LEe`AL5/AFeaKG5]L
Fa5KM5/00a4045]`Fa5OM5mdGgAOM15dLa4[M000@7@0715KEe]GFeMKEe]GFeLAEe]GFeMKEe]GFeMK
Ea4>E`8A01]G4A5KEe/AFeLAFeaK4EMLEeaGG15LFeaKG5/00Q4035`AM5]dFgAKM15cG`8A:g@0045d
02TAKeM_EfmGKeM_EflAFeMKEe]GFeMKEe]GFeLAEe]GFeMKEe]GFeMKE`024@0>L14A4EaKG15L4G1K
L5/24@0=G5]L4GAKM5]dFgAKM0054@04M5mdG`<A00=OM7@0:W@0045d01`AEe]GFeMKEe]GFeMK4E]G
FeMKEe]GFeMKEe/A35L44@07Fa5K4E]GF`024@0HFeaKG5]L4EaG4E]LFeaKG5]LFe`AM5md1A400em6
M00/M000@G@0915_EfmGKeM_EfmGKeLAEe]GFeMKEe]GFeMKEe/AFeMKEe]GF`@A0eL04A5G4E]`4EaK
G15`Fg1KL5]`00<A019dFgAKM5]dFgAK4F1dH7APM142G`034GAd02]d0011M00M4EMKEe]GFeMKEe]G
FeLAEe]GFeMKEe]GFeMKEa400eL44@07Ed9G@UM2E`034@06FeLAEe]G0Q407EaKG5]LFeaK4E]LFeaK
G5]LFa5OM5mdGgAO4DHA02id0012M00J4EM_EfmGKeM_EfmGKa5KEe]GFeMKEe]GFeL54@]G11403g1K
4E]L4G0AL5]`Fg1KL0034@0AM5]dFgAKM15dH7APM60AGa40;g@0049d01HAFeMKEe]GFeMKEe]GFa5K
Ee]GFeMK114045IGEQ52Ed9G@UM2Ed9G@UL44@0BEe]G4ELAFe`AG5]LFeaK4E]d0Q403U]LFeaK4Emd
GgAOM15O<7@0049d018AEfmGKeM_EfmGKeM_Ea5GFeL44@MG00<AEeL02eL24@05Fa5KL5/00Q400g1K
L0024@09Fg1KL15dG7AL008A00adFg@AM61dH7@AGa4`M000@g@01a5GFeMKEe/02Q406EIGEUMFEeIG
EUMFEa5G@UM2Ed9G@UM2Ed800Q401E`AFeMK008A011KG5]LFa5KG15dFgAKM5]d0a401WAOM5mdG`8A
<G@004=d1a402E]GFeMKEe]G4@0>E`034EMG00UG0Q406E/AFg1KL15`Fg1KL5/AFa5LM5adG7ALM5`0
0Q4017APM6024C9d0013M00Z4EIGEUMFEeIGEUMFEeIG4EMFEeIGEUMFEeIGEUMF4D9G@UM2Ed9G@UM2
0Q401UaK4EMKE`8A00ILFeaKG5/24@0;M5]dFgAKM5]d4G@00Q400emd4@0cM000A7@0415GFeMKEe]G
FeMKEe]GFa4>E`034EMG00UG0Q40770AL5/AFa5KL5]`Fg1K4EadG7ALM5ad4GAPM6024CAd0014M00Z
4EMFEeIGEUMFEeIGEUMF4EIGEUMFEeIGEUMFEeIG4EM2Ed9G@UM2Ed9G0Q403U]L4E/AG5/AFeaKG5]L
0Q403E]dFgAKM5/AGgAOM140=G@004Ed010AFeMKEe]GFeMKEe]GFeLA3UL00a5GE`06E`@A01e`Fa5K
4E]dFa5KL5]`4GAP4EadG7AL4F1dH7AP4@0eM000AG@09A5FEeIGEUMFEeIGEUMFEa5GEUMFEeIGEUMF
EeIGEULAEd9G@UL00Q4083iG4A5KG5/AFeaKG15LFeaK4E]dFa5KM5]d4GAOM5lA=W@004Id010AEe]G
FeMKEe]GFeMKEe/A3UL00a5GE`034@0QEciG?Q5K4E]`4GAKM5]d4G1K4F1dH7AP4Ead4GAPM60A03Md
0016M00M4EMFEeIGEUMFEeIGEUMF4EIGEUMFEeIGEUMFEeH011408eLnEciG?ULAL15LFa5KG5]LFe`A
G15dFgAKM5/AFa5OM5lA03Qd0017M00@4E]GFeMKEe]GFeMKEe]G4@MG1A405eIGEQ4nEciG?ULn4E/A
Fa5L4E]dFgAK008A00idH7APM61dH15PM61d4CQd0017M00C4EIGEUMFEeIGEUMFEeIG4EMFE`044@0W
?ULnEciG?ULn4CiG?ULnEa5`4E`AM15LFeaKG5/AFgAKM5]dFa5O008A00=d4G@0>7@004Qd00`AEe]G
FeMKEe]GFeL64@0PEeIGEUMFEeIGEUMFEa5G?ULnEchAFg@AM5ad4GAKM5/24@0<M61dH7AP4EmPGf0A
>W@004Qd00DAEeIGEP074@0cDUMBEa5G?ULnEciG?ULnEciG?ULAEciG?ULAL5/AFgAK4E]LFe`AM15d
FgAK4EmPGf0A03]d0019M0@A03UFEeIGEUMFEeIGEQ5FEeIGEUMFEeIGEUMFEeIG4ELnEchAFg@AM5ad
G15KM15dH15PM61d4F1OH140?7@004Yd02HAEe9GDUMBEe9GDUMBEe8A?ULnEciG?ULnEciG?ULnEa5G
?ULAL08A015KM5]d4E`AM5mdGa5KM15PG`024Ced001:M00V4EIGEUMFEeIGEUMFEeIGEQ5FEeIGEUMF
EeIGEUMFEeHA?ULn4E/24@05M5adG7@00Q402V1dH7@AM15PGa4oM000Bg@08a5BEe9GDUMBEe9GDUMB
Ea5G?ULnEciG?ULnEciG?ULn4CiG008A019K4E]dFgAK4EmdGgAOM15PGa50M000C7@07a5FEeIGEUMF
EeIGEUMFEa5GEUMFEeIGEUMFEeIGEUL01A401W@AM5adG08A00EdH7APM0024@03Ga5d041d001=M00J
4E9GDUMBEe9GDUMBEe9G4ELnEciG?ULnEch44@8n0Q404GAKM15dFa5O4EmdGg@ABdLA049d001=M00G
4EMFEeIGEUMFEeIGEUMFEa5GEUMFEeH00a404ciC?U<nDchAH7AP4Ead4G@AM6000Q400d/A4@13M000
CW@04Q5GDUMBEe9GDUMBEe9GDQ4nE`@A2Sh03A5dFg@AM15PGa5O4DL00Q55M000Cg@03A5GEUMFEeIG
EUMFEeH011404U<nDciC?U<nDciC?U<AM61dH08A00=dH7@00Q400d/AM016M000D7@0215GDUMBEe9G
114013iB?Q4=?P0:4E]dFg@AH5mPG`<AB7@0051d00@AEUMF11406ELnEciG?ULn4CiC?U<nDciC?U<n
Da5dH7@00Q400f1d4@024DYd001AM0<A00dnDSiB?U8nDSiB?U8n008A23h34@06Fg@A4EmP0Q5<M000
DW@05a4nEciG?ULnEciG?ULnEciG4E<nDciC008A00PU>Q5d4F0AM08ACG@005=d018A?U8nDSiB?U8n
DSiB?U8nDQ42?P8A00Li9CTAM15P00<ACg@005Ad010A?ULnEciG?ULnEciG?ULn0a401BDj9CXU008A
0V000a5dM01?M000EG@24@0:DSiB?U8nDSiB?P<A00`i>Q4A9CTU>A5PBa5BM000Eg@01a5G?ULnEch0
0a401cTn>Chi?ST00Q400cXAH0024E=d001HM0034E8n00<A00`i>STj>CXi>STj>CX34EEd001IM08A
00`i?STn>Chi?STn>Ch44EMd001KM08A00Pj>CXi>STj>@DAF7@005ed0Q400cTn>@064EYd001OM0DA
GW@00<9d0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00<9d0032M000
`W@00<9d0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00<9d0032M000`W@00001\
\>"],
  ImageRangeCache->{{{0, 193.125}, {287, 0}} -> {0.154208, -0.000935389, \
0.00346087, 0.00346087}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mirror Definition", "Subsubsection"],

Cell["The shape function is brought into the format Optica uses.", "Text"],

Cell[CellGroupData[{

Cell["\<\
mirrorfunction = With[{body = 
\tChop[
\t\tseashell[
\t\t\thelix[1, 0.6]
\t\t][0.1][t, theta]
\t]},
\tWith[{
\t\tf1 = body[[1]],
\t\tf2 = body[[2]],
\t\tf3 = body[[3]]
\t},
\t\t{Function[{t, theta}, f1], Function[{t, theta}, f2], Function[{t, theta}, \
f3]}
\t]
]/.{t$ -> t, theta$ -> theta}\
\>", "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Function", "[", 
          RowBox[{\({t, theta}\), ",", 
            RowBox[{\(Cos[t]\), "+", 
              RowBox[{
                StyleBox["0.1`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], " ", "t", 
                " ", \((1.`\ Cos[t]\ Cos[theta] + 
                    0.514495755427526457`\ Sin[t]\ Sin[theta])\)}]}]}], "]"}],
         ",", 
        RowBox[{"Function", "[", 
          RowBox[{\({t, theta}\), ",", 
            RowBox[{\(Sin[t]\), "+", 
              RowBox[{
                StyleBox["0.1`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], " ", "t", 
                " ", \((1.`\ Cos[theta]\ Sin[t] - 
                    0.514495755427526457`\ Cos[t]\ Sin[theta])\)}]}]}], "]"}],
         ",", 
        RowBox[{"Function", "[", 
          RowBox[{\({t, theta}\), ",", 
            RowBox[{
              RowBox[{
                StyleBox["0.6`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], " ", "t"}], 
              "+", \(0.0857492925712544185`\ t\ Sin[theta]\)}]}], "]"}]}], 
      "}"}]], "Output"]
}, Open  ]],

Cell["\<\
With this function, we define a mirror. The option SurfacePoints \
creates a triangle net on the surface. In total 2*9*24 == 432 triangles are \
used. The preparation of the triangles needs some initialization time. \
SurfaceApproximation -> Open creates an approximation that is inscribed in \
the parameter range of the surface, the threedimensional position of the \
triangles may inscribe or circumscribe the surface. Closed make a \
circumscribed net.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Timing[seashellmirror = Mirror[
\tmirrorfunction, 
\t4.75*Pi-1.75*Pi,
\tGraphicDesign -> Solid,
\tSurfacePoints -> {10, 25},
\tSurfaceApproximation -> Open,
\tSurfaceRayIntersections -> Numeric,
\tOffAxis -> {(1.75*Pi+4.75*Pi)/2, 0}]]\
\>", "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(8.59000000000000341`\ Second\), ",", 
        TagBox[
          RowBox[{"CustomMirror", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"Function", "[", 
                    RowBox[{\({t, theta}\), ",", 
                      RowBox[{\(Cos[t]\), "+", 
                        RowBox[{
                          StyleBox["0.1`",
                            StyleBoxAutoDelete->True,
                            PrintPrecision->1], " ", "t", 
                          " ", \((1.`\ Cos[t]\ Cos[theta] + 
                              0.514495755427526457`\ Sin[t]\ Sin[
                                  theta])\)}]}]}], "]"}], ",", 
                  RowBox[{"Function", "[", 
                    RowBox[{\({t, theta}\), ",", 
                      RowBox[{\(Sin[t]\), "+", 
                        RowBox[{
                          StyleBox["0.1`",
                            StyleBoxAutoDelete->True,
                            PrintPrecision->1], " ", "t", 
                          " ", \((1.`\ Cos[theta]\ Sin[t] - 
                              0.514495755427526457`\ Cos[t]\ Sin[
                                  theta])\)}]}]}], "]"}], ",", 
                  RowBox[{"Function", "[", 
                    RowBox[{\({t, theta}\), ",", 
                      RowBox[{
                        RowBox[{
                          StyleBox["0.6`",
                            StyleBoxAutoDelete->True,
                            PrintPrecision->1], " ", "t"}], 
                        "+", \(0.0857492925712544185`\ t\ Sin[theta]\)}]}], 
                    "]"}]}], "}"}], ",", "9.42477796076937934`", 
              ",", \({GraphicDesign \[Rule] Solid, 
                OffAxis \[Rule] {10.2101761241668276`, 0}, 
                SurfaceApproximation \[Rule] Open, 
                SurfacePoints \[Rule] {10, 25}, 
                SurfaceRayIntersections \[Rule] Numeric}\)}], "]"}],
          HoldForm]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The size of the component in memory is rather large, because all \
the triangles data is stored in the component.\
\>", "Text"],

Cell[CellGroupData[{

Cell["ByteCount[seashellmirror]", "Input"],

Cell[BoxData[
    \(852508\)], "Output"]
}, Open  ]],

Cell["\<\
This shows the approximation without the surface itself \
(GraphicDesign -> Off).\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[seashellmirror, SurfacePoints -> Fill, ShowLabels -> \
False, GraphicDesign -> Off];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.4645 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.222336 1.48012 7.46473e-17 1.48012 [
[ 0 0 0 0 ]
[ 1 1.4645 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.4645 L
0 1.4645 L
closepath
clip
newpath
.49834 .65882 m .42853 .61735 L .60004 .59409 L .733 .648 .765 r
F
.65877 .62221 m .60004 .59409 L .49834 .65882 L .607 .4 .574 r
F
.54813 .69811 m .49834 .65882 L .65877 .62221 L .641 .506 .684 r
F
.49834 .65882 m .42853 .61735 L .33994 .64602 L .786 .614 .668 r
F
.38186 .6932 m .33994 .64602 L .49834 .65882 L .779 .675 .748 r
F
.54813 .69811 m .49834 .65882 L .38186 .6932 L .719 .481 .564 r
F
.60004 .59409 m .50566 .57207 L .66754 .50633 L .701 .639 .784 r
F
.72184 .5176 m .66754 .50633 L .60004 .59409 L .448 .293 .576 r
F
.65877 .62221 m .60004 .59409 L .72184 .5176 L .538 .459 .714 r
F
.60004 .59409 m .50566 .57207 L .42853 .61735 L .727 .587 .699 r
F
.50566 .57207 m .42972 .55208 L .5602 .51634 L .804 .802 .849 r
F
.66754 .50633 m .5602 .51634 L .50566 .57207 L .684 .581 .735 r
F
.50566 .57207 m .42972 .55208 L .3737 .57668 L .777 .818 .885 r
F
.42853 .61735 m .3737 .57668 L .50566 .57207 L .796 .782 .84 r
F
.65755 .659 m .65877 .62221 L .54813 .69811 L .376 .082 .332 r
F
.55833 .7337 m .54813 .69811 L .65755 .659 L .448 .222 .478 r
F
.41517 .73533 m .38186 .6932 L .54813 .69811 L .728 .563 .667 r
F
.55833 .7337 m .54813 .69811 L .41517 .73533 L .635 .331 .438 r
F
.42853 .61735 m .3737 .57668 L .30829 .59827 L .82 .778 .813 r
F
.33994 .64602 m .30829 .59827 L .42853 .61735 L .817 .783 .821 r
F
.5602 .51634 m .48287 .52695 L .54912 .48323 L .837 .818 .831 r
F
.58662 .46031 m .54912 .48323 L .58787 .45766 L F
.5602 .51634 m .54912 .48323 L .58662 .46031 L F
.48398 .52304 m .48591 .52186 L .48465 .52238 L 0 0 0 r
F
.48465 .52238 m .4871 .51915 L .48591 .52186 L .183 .006 .391 r
F
.4871 .51915 m .48914 .51646 L .4879 .51854 L F
.4871 .51915 m .4879 .51854 L .48591 .52186 L F
.58787 .45766 m .50381 .50635 L .4879 .51854 L .537 .911 .745 r
F
.48287 .52695 m .4879 .51854 L .58787 .45766 L .837 .818 .831 r
F
.58787 .45766 m .50818 .50382 L .59023 .40264 L .871 .798 .776 r
F
.50818 .50382 m .50381 .50635 L .51097 .49776 L F
.50818 .50382 m .51097 .49776 L .59023 .40264 L F
.50381 .50635 m .50597 .50184 L .59023 .40264 L F
.53079 .47262 m .52289 .48773 L .50597 .50184 L 0 0 0 r
F
.59023 .40264 m .53807 .46855 L .53079 .47262 L F
.53807 .46855 m .52289 .48773 L .53079 .47262 L F
.59023 .40264 m .52289 .48773 L .57228 .35571 L .874 .731 .7 r
F
.51723 .4956 m .52366 .48093 L .51984 .49634 L .183 .006 .391 r
F
.52366 .48093 m .53217 .4615 L .52252 .48877 L F
.52366 .48093 m .52252 .48877 L .51984 .49634 L F
.51013 .51181 m .51723 .4956 L .5151 .50974 L F
.51723 .4956 m .51984 .49634 L .5151 .50974 L F
.43534 .55054 m .47152 .52851 L .42972 .55208 L .735 .925 .954 r
F
.5602 .51634 m .47604 .52789 L .43534 .55054 L F
.47604 .52789 m .47152 .52851 L .43534 .55054 L F
.48287 .52695 m .47604 .52789 L .48591 .52186 L .837 .818 .831 r
F
.49288 .56936 m .51614 .5505 L .49661 .54429 L .602 .275 .388 r
F
.51976 .50781 m .52208 .54568 L .51614 .5505 L .752 .501 .553 r
F
.49661 .54429 m .50942 .52862 L .51614 .5505 L .575 .401 .609 r
F
.51976 .50781 m .51614 .5505 L .5144 .54483 L .752 .501 .553 r
F
.52175 .50653 m .52457 .57797 L .51976 .50781 L F
.52457 .57797 m .52393 .57589 L .51976 .50781 L F
.50847 .52551 m .50942 .52862 L .49661 .54429 L .575 .401 .609 r
F
.49434 .54788 m .48994 .57609 L .50847 .52551 L .108 0 .251 r
F
.52289 .48773 m .53493 .45371 L .57228 .35571 L .874 .731 .7 r
F
.49334 .56899 m .50895 .58243 L .49143 .57389 L .752 .501 .553 r
F
.49905 .51775 m .49434 .54788 L .49676 .5433 L .108 0 .251 r
F
.50066 .5171 m .49676 .5433 L .51328 .51199 L F
.49905 .51775 m .49676 .5433 L .50066 .5171 L F
.49434 .54788 m .50847 .52551 L .51328 .51199 L F
.5058 .51681 m .51976 .50781 L .50396 .51437 L 0 0 0 r
F
.49727 .51898 m .50396 .51437 L .48591 .52186 L F
.49905 .51775 m .49434 .54788 L .49665 .5194 L .73 .396 .414 r
F
.5058 .51681 m .50396 .51437 L .49727 .51898 L 0 0 0 r
F
.49665 .5194 m .49434 .54788 L .48886 .54182 L .73 .396 .414 r
F
.47429 .53296 m .48471 .52762 L .49392 .51983 L 0 0 0 r
F
.49245 .52229 m .48886 .54182 L .47934 .53132 L .73 .396 .414 r
F
.48471 .52762 m .49727 .51898 L .49392 .51983 L 0 0 0 r
F
.48564 .52318 m .49392 .51983 L .48769 .52141 L F
.47429 .53296 m .49392 .51983 L .48564 .52318 L F
.48591 .52186 m .51535 .48231 L .49897 .51644 L .183 .006 .391 r
F
.48914 .51646 m .53409 .45713 L .48591 .52186 L F
.50381 .50635 m .50053 .50825 L .4879 .51854 L .537 .911 .745 r
F
.50053 .50825 m .49665 .5194 L .49367 .51566 L .73 .396 .414 r
F
.49665 .5194 m .48886 .54182 L .49245 .52229 L F
.49665 .5194 m .49245 .52229 L .49367 .51566 L F
.47861 .53172 m .47934 .53132 L .47429 .53296 L 0 0 0 r
F
.47934 .53132 m .5058 .51681 L .48471 .52762 L F
.47934 .53132 m .48471 .52762 L .47429 .53296 L F
.48471 .52762 m .5058 .51681 L .49727 .51898 L F
.49367 .51566 m .49245 .52229 L .47926 .53122 L .73 .396 .414 r
F
.49245 .52229 m .47934 .53132 L .47926 .53122 L F
.49897 .51644 m .53187 .46087 L .51013 .51181 L .183 .006 .391 r
F
.51535 .48231 m .53409 .45713 L .49897 .51644 L F
.50053 .50825 m .49905 .51775 L .49665 .5194 L .73 .396 .414 r
F
.48547 .56022 m .48886 .54182 L .4723 .53655 L .602 .275 .388 r
F
.4722 .53356 m .46712 .54053 L .47176 .53697 L 0 0 0 r
F
.47229 .53632 m .47176 .53697 L .4723 .53655 L F
.4722 .53356 m .47176 .53697 L .47229 .53632 L F
.45568 .55668 m .48471 .5757 L .45402 .55847 L .73 .396 .414 r
F
.42756 .76968 m .41517 .73533 L .55833 .7337 L .656 .407 .531 r
F
.53288 .76061 m .55833 .7337 L .42756 .76968 L .449 .021 .134 r
F
.41806 .79423 m .42756 .76968 L .53288 .76061 L .489 .103 .234 r
F
.51386 .65286 m .55818 .6307 L .52869 .67757 L .8 .699 .754 r
F
.49647 .60596 m .52128 .61591 L .48866 .5759 L .772 .532 .573 r
F
.52128 .61591 m .55818 .6307 L .52647 .60571 L F
.52128 .61591 m .52647 .60571 L .48866 .5759 L F
.50468 .63756 m .51065 .63679 L .50933 .64531 L .8 .699 .754 r
F
.52001 .61841 m .50753 .6569 L .51065 .63679 L .985 .886 .642 r
F
.52001 .61841 m .50753 .6569 L .51396 .65256 L .744 .572 .661 r
F
.52433 .62069 m .51396 .65256 L .545 .63162 L F
.52001 .61841 m .51396 .65256 L .52433 .62069 L F
.49941 .71348 m .52869 .67757 L .51386 .65286 L .866 .712 .688 r
F
.49918 .71376 m .51386 .65286 L .50348 .68476 L F
.49332 .65834 m .50468 .63756 L .50256 .66624 L .965 .803 .632 r
F
.50357 .63331 m .51151 .61392 L .49647 .60596 L .772 .532 .573 r
F
.50468 .63756 m .51151 .61392 L .50357 .63331 L F
.54617 .63224 m .55818 .6307 L .49647 .60596 L F
.55818 .6307 m .55886 .62993 L .48866 .5759 L F
.52314 .60068 m .55412 .60444 L .55934 .62919 L .712 .562 .682 r
F
.49083 .77556 m .53288 .76061 L .51755 .7651 L 0 0 0 r
F
.46859 .78127 m .51755 .7651 L .41806 .79423 L F
.49083 .77556 m .51755 .7651 L .46859 .78127 L F
.39441 .80863 m .41806 .79423 L .49083 .77556 L .026 0 0 r
F
.39441 .80863 m .41806 .79423 L .29567 .78154 L .656 .181 .113 r
F
.28539 .79375 m .29567 .78154 L .39441 .80863 L .642 .151 .07 r
F
.36619 .81535 m .39441 .80863 L .28539 .79375 L .517 0 0 r
F
.36619 .81535 m .39441 .80863 L .41783 .79803 L .394 .849 .793 r
F
.37139 .81336 m .41783 .79803 L .45094 .78303 L F
.36619 .81535 m .41783 .79803 L .37139 .81336 L F
.45094 .78303 m .46651 .78012 L .46756 .7779 L .895 .92 .831 r
F
.41806 .79423 m .42756 .76968 L .29786 .7608 L .741 .362 .334 r
F
.29567 .78154 m .29786 .7608 L .41806 .79423 L .746 .383 .366 r
F
.2707 .79791 m .28539 .79375 L .36619 .81535 L .44 0 0 r
F
.33956 .81792 m .36619 .81535 L .2707 .79791 L .415 0 0 r
F
.29681 .80605 m .2707 .79791 L .33956 .81792 L .228 0 0 r
F
.25571 .79464 m .27045 .79785 L .29681 .80605 L F
.27045 .79785 m .2707 .79791 L .29681 .80605 L F
.3174 .81737 m .33956 .81792 L .25571 .79464 L .378 0 0 r
F
.45107 .78285 m .35953 .80649 L .36946 .80734 L .363 0 0 r
F
.46244 .77944 m .45357 .78176 L .45107 .78285 L F
.45357 .78176 m .3174 .81737 L .45107 .78285 L F
.451 .78288 m .45106 .78285 L .45094 .78303 L .894 .986 .792 r
F
.45094 .78303 m .46756 .7779 L .45107 .78285 L .895 .92 .831 r
F
.45106 .78285 m .45107 .78285 L .45094 .78303 L .894 .986 .792 r
F
.45094 .78303 m .46675 .78007 L .39441 .80863 L .446 .881 .863 r
F
.46675 .78007 m .49083 .77556 L .47916 .77956 L F
.46675 .78007 m .47916 .77956 L .39441 .80863 L F
.52314 .60068 m .55934 .62919 L .55887 .62991 L .712 .562 .682 r
F
.50651 .66005 m .48331 .73165 L .49216 .71954 L .744 .572 .661 r
F
.50052 .69387 m .49216 .71954 L .49711 .71277 L F
.50651 .66005 m .49216 .71954 L .50052 .69387 L F
.50779 .70703 m .49336 .73373 L .49659 .71693 L .91 .982 .731 r
F
.51313 .70231 m .49659 .71693 L .50094 .7116 L F
.49891 .71555 m .50348 .68476 L .50052 .69387 L .866 .712 .688 r
F
.49908 .71388 m .49659 .71693 L .49737 .71531 L .91 .982 .731 r
F
.49646 .71606 m .49861 .71427 L .49762 .7102 L .96 .802 .642 r
F
.49266 .72103 m .49387 .72265 L .48784 .73113 L .894 .986 .792 r
F
.49402 .71949 m .49387 .72265 L .49266 .72103 L F
.4852 .73143 m .48784 .73113 L .45107 .78285 L F
.49782 .70907 m .50052 .69387 L .49903 .71394 L .965 .803 .632 r
F
.49762 .7102 m .49903 .71394 L .49861 .71427 L F
.50052 .69387 m .49711 .71277 L .49762 .7102 L .744 .572 .661 r
F
.49819 .67973 m .48312 .73167 L .48247 .72833 L .985 .886 .642 r
F
.50468 .63756 m .48866 .5759 L .48832 .57589 L .772 .532 .573 r
F
.50468 .63756 m .48824 .57558 L .48611 .57565 L F
.45107 .78285 m .46756 .7779 L .49387 .72265 L .895 .92 .831 r
F
.55972 .62895 m .46683 .77829 L .53583 .66506 L .91 .982 .731 r
F
.55886 .62993 m .53583 .66506 L .55347 .63611 L F
.55972 .62895 m .53583 .66506 L .55886 .62993 L F
.4723 .53655 m .47999 .53202 L .48886 .54182 L .575 .401 .609 r
F
.47861 .53172 m .5058 .51681 L .4723 .53655 L F
.49434 .54788 m .48994 .57609 L .48577 .55858 L .73 .396 .414 r
F
.48994 .57609 m .48885 .57576 L .48549 .56014 L F
.48577 .55858 m .48549 .56014 L .47926 .53122 L F
.48994 .57609 m .48549 .56014 L .48577 .55858 L F
.48381 .56928 m .48472 .5643 L .4714 .53743 L .602 .275 .388 r
F
.48381 .56928 m .4714 .53743 L .4713 .53753 L F
.46712 .54053 m .46433 .54435 L .4723 .53655 L 0 0 0 r
F
.48472 .5643 m .48547 .56022 L .47071 .53605 L .602 .275 .388 r
F
.45568 .55668 m .4713 .53753 L .48381 .56928 L .729 .339 .311 r
F
.48547 .56022 m .4723 .53655 L .4715 .53734 L .602 .275 .388 r
F
.4723 .53655 m .45402 .55847 L .47257 .53635 L 0 0 0 r
F
.46433 .54435 m .45402 .55847 L .4723 .53655 L F
.4713 .53753 m .4714 .53743 L .47071 .53605 L .602 .275 .388 r
F
.47926 .53122 m .48784 .57109 L .45568 .55668 L .73 .396 .414 r
F
.48832 .57589 m .48866 .5759 L .48824 .57558 L .772 .532 .573 r
F
.48798 .57175 m .48666 .5745 L .45568 .55668 L .73 .396 .414 r
F
.49794 .63014 m .48968 .59211 L .50468 .63756 L .883 .59 .487 r
F
.48968 .59211 m .48614 .57582 L .49021 .58936 L F
.48968 .59211 m .49021 .58936 L .50468 .63756 L F
.48614 .57582 m .48615 .5758 L .50468 .63756 L F
.48514 .61603 m .48744 .67258 L .47987 .64376 L .989 .738 .453 r
F
.48899 .60256 m .48744 .67258 L .48514 .61603 L F
.49794 .63014 m .48744 .67258 L .50055 .64061 L .745 .509 .573 r
F
.48916 .59488 m .48899 .60256 L .49794 .63014 L F
.48899 .60256 m .48744 .67258 L .49794 .63014 L F
.50101 .63957 m .50468 .63756 L .49794 .63014 L .89 .581 .455 r
F
.48496 .57804 m .48611 .57565 L .49794 .63014 L .883 .59 .487 r
F
.48961 .57664 m .48994 .57609 L .55887 .62991 L .712 .562 .682 r
F
.48994 .57609 m .49485 .57754 L .55887 .62991 L F
.48961 .57664 m .55887 .62991 L .55886 .62993 L F
.48916 .59488 m .50055 .64061 L .51842 .59704 L .745 .509 .573 r
F
.48744 .67258 m .48815 .67098 L .51842 .59704 L F
.48295 .64947 m .50101 .63957 L .48514 .61603 L .89 .581 .455 r
F
.50101 .63957 m .49794 .63014 L .48514 .61603 L F
.47236 .60788 m .48514 .61603 L .47086 .60029 L F
.47877 .63831 m .48314 .62302 L .47344 .61338 L F
.4869 .6738 m .48744 .67258 L .48647 .67115 L .96 .802 .642 r
F
.48331 .73165 m .49662 .71584 L .49718 .71268 L .744 .572 .661 r
F
.48916 .6877 m .4875 .67245 L .4869 .6738 L .96 .802 .642 r
F
.48959 .68692 m .4875 .67245 L .48916 .6877 L F
.49819 .67973 m .48247 .72833 L .48597 .69339 L .985 .886 .642 r
F
.48959 .68692 m .49016 .6859 L .4875 .67245 L .96 .802 .642 r
F
.48295 .64947 m .49147 .68361 L .49127 .68392 L .965 .803 .632 r
F
.48295 .64947 m .50256 .66624 L .49147 .68361 L F
.49819 .67973 m .48597 .69339 L .49263 .6815 L .985 .886 .642 r
F
.41492 .79494 m .45094 .78303 L .36619 .81535 L .329 .805 .735 r
F
.39711 .80037 m .36619 .81535 L .41492 .79494 L .408 .86 .845 r
F
.33956 .81792 m .36584 .81538 L .39711 .80037 L F
.36584 .81538 m .36619 .81535 L .39711 .80037 L F
.45107 .78285 m .40787 .79581 L .4142 .79511 L .363 0 0 r
F
.40787 .79581 m .39535 .79957 L .407 .79681 L F
.40787 .79581 m .407 .79681 L .4142 .79511 L F
.33956 .81792 m .41492 .79494 L .407 .79681 L .408 .86 .845 r
F
.3959 .80959 m .407 .79681 L .33956 .81792 L .135 0 0 r
F
.4142 .79511 m .3452 .81462 L .35989 .81316 L .363 0 0 r
F
.39535 .79957 m .3452 .81462 L .4142 .79511 L F
.45107 .78285 m .35989 .81316 L .4493 .78355 L F
.407 .79681 m .41492 .79494 L .42062 .79255 L .408 .86 .845 r
F
.44935 .78353 m .45094 .78303 L .41492 .79494 L .329 .805 .735 r
F
.45107 .78285 m .37916 .81125 L .451 .78288 L .363 0 0 r
F
.42062 .79255 m .44935 .78353 L .42006 .79324 L .329 .805 .735 r
F
.42062 .79255 m .42006 .79324 L .41492 .79494 L F
.42062 .79255 m .44935 .78353 L .45669 .76659 L .891 .98 .815 r
F
.46038 .74425 m .45669 .76659 L .47302 .7289 L F
.42062 .79255 m .44201 .77715 L .46038 .74425 L F
.44201 .77715 m .45669 .76659 L .46038 .74425 L F
.44935 .78353 m .451 .78288 L .47302 .7289 L F
.4852 .73143 m .45107 .78285 L .45106 .78285 L .894 .986 .792 r
F
.4852 .73143 m .45107 .78285 L .4852 .73143 L F
.45727 .76759 m .45952 .77011 L .45106 .78285 L F
.47302 .7289 m .45952 .77011 L .45727 .76759 L F
.50256 .66624 m .50933 .64531 L .50468 .63756 L .866 .712 .688 r
F
.50753 .6569 m .48331 .73165 L .50312 .66276 L .985 .886 .642 r
F
.48331 .73165 m .48312 .73167 L .50312 .66276 L F
.48331 .73165 m .49402 .71949 L .49662 .71584 L .744 .572 .661 r
F
.48312 .73167 m .48212 .73178 L .48247 .72833 L .985 .886 .642 r
F
.47302 .7289 m .47767 .7265 L .45952 .77011 L .894 .986 .792 r
F
.47767 .7265 m .48371 .73367 L .45952 .77011 L F
.47302 .7289 m .45106 .78285 L .451 .78288 L F
.48161 .73689 m .4621 .75344 L .46683 .77829 L .91 .978 .78 r
F
.4621 .75344 m .45216 .76187 L .45626 .76645 L F
.4621 .75344 m .45626 .76645 L .46683 .77829 L F
.48534 .69968 m .48295 .70544 L .48212 .73178 L .979 .88 .513 r
F
.47302 .7289 m .47767 .7265 L .48427 .70018 L .96 .802 .642 r
F
.48597 .69339 m .48916 .6877 L .48846 .68343 L F
.48744 .67258 m .48493 .66888 L .47987 .64376 L .989 .738 .453 r
F
.47344 .61338 m .48314 .62302 L .47236 .60788 L .89 .581 .455 r
F
.48314 .62302 m .48514 .61603 L .47236 .60788 L F
.47309 .60274 m .48496 .57804 L .48916 .59488 L .883 .59 .487 r
F
.48916 .59488 m .48899 .60256 L .48514 .61603 L .989 .738 .453 r
F
.48514 .61603 m .48916 .59488 L .49794 .63014 L .883 .59 .487 r
F
.47309 .60274 m .48916 .59488 L .48514 .61603 L F
.45481 .56212 m .46942 .60375 L .46142 .59252 L .897 .477 .142 r
F
.45488 .561 m .46942 .60375 L .45481 .56212 L F
.3834 .54908 m .4751 .5249 L .47502 .52536 L .255 0 0 r
F
.38304 .54909 m .48023 .52354 L .3834 .54908 L F
.4722 .53356 m .4723 .53655 L .47256 .5363 L 0 0 0 r
F
.47152 .52851 m .46784 .53482 L .4722 .53356 L F
.46784 .53482 m .45402 .55847 L .4722 .53356 L F
.4774 .52493 m .47488 .52616 L .47152 .52851 L .537 .911 .745 r
F
.48234 .52351 m .47152 .52851 L .4774 .52493 L .837 .818 .831 r
F
.47821 .52453 m .48465 .52238 L .48398 .52304 L .255 0 0 r
F
.42972 .55208 m .41567 .54805 L .39684 .54865 L .112 .66 .815 r
F
.39322 .54931 m .39684 .54865 L .38821 .54893 L F
.42972 .55208 m .39684 .54865 L .39322 .54931 L F
.3737 .57668 m .36427 .55533 L .42972 .55208 L .742 .932 .951 r
F
.3623 .55454 m .48398 .52304 L .47013 .52702 L .255 0 0 r
F
.3623 .55454 m .47013 .52702 L .37641 .55208 L F
.36427 .55533 m .37586 .55223 L .42972 .55208 L .742 .932 .951 r
F
.37586 .55223 m .38821 .54893 L .39322 .54931 L F
.37586 .55223 m .39322 .54931 L .42972 .55208 L F
.36728 .55367 m .368 .55355 L .3623 .55454 L .125 .672 .704 r
F
.37586 .55223 m .39276 .54926 L .39197 .54948 L .255 0 0 r
F
.3623 .55454 m .3763 .55211 L .37586 .55223 L F
.3763 .55211 m .39276 .54926 L .37586 .55223 L F
.47604 .52789 m .47152 .52851 L .48234 .52351 L .837 .818 .831 r
F
.48398 .52304 m .48234 .52351 L .48591 .52186 L F
.47604 .52789 m .48234 .52351 L .48398 .52304 L F
.4739 .53307 m .48769 .52141 L .48448 .52319 L 0 0 0 r
F
.4722 .53356 m .47282 .53818 L .47368 .53314 L F
.47429 .53296 m .48769 .52141 L .4739 .53307 L F
.47498 .52563 m .48398 .52304 L .47368 .53314 L .255 0 0 r
F
.47502 .52536 m .48023 .52354 L .47821 .52453 L F
.4751 .5249 m .48023 .52354 L .47502 .52536 L F
.4879 .51854 m .50053 .50825 L .47488 .52616 L .537 .911 .745 r
F
.4879 .51854 m .47488 .52616 L .4774 .52493 L F
.48023 .52354 m .48465 .52238 L .47821 .52453 L .255 0 0 r
F
.48591 .52186 m .48234 .52351 L .4879 .51854 L .837 .818 .831 r
F
.48234 .52351 m .4774 .52493 L .4879 .51854 L F
.48448 .52319 m .48769 .52141 L .48591 .52186 L 0 0 0 r
F
.47368 .53314 m .48591 .52186 L .48398 .52304 L F
.47488 .52616 m .47368 .53314 L .50053 .50825 L F
.47368 .53314 m .47282 .53818 L .47886 .53165 L F
.4739 .53307 m .48591 .52186 L .47368 .53314 L F
.47368 .53314 m .47886 .53165 L .50053 .50825 L F
.47071 .53605 m .4739 .53307 L .47368 .53314 L F
.47071 .53605 m .47429 .53296 L .4739 .53307 L F
.47152 .52851 m .4722 .53356 L .47488 .52616 L F
.4722 .53356 m .47368 .53314 L .47488 .52616 L F
.45229 .53936 m .43019 .54297 L .47152 .52851 L .583 .945 .856 r
F
.39197 .54948 m .45986 .53052 L .42895 .54317 L .255 0 0 r
F
.45986 .53052 m .47467 .52638 L .45373 .53407 L F
.45986 .53052 m .45373 .53407 L .42895 .54317 L F
.47152 .52851 m .46667 .53681 L .44732 .54006 L .599 .105 .051 r
F
.41981 .54467 m .42895 .54317 L .41971 .54475 L .125 .672 .704 r
F
.41981 .54467 m .41971 .54475 L .39684 .54865 L F
.39197 .54948 m .47498 .52563 L .47467 .52638 L .255 0 0 r
F
.37641 .55208 m .47013 .52702 L .39296 .5492 L F
.41567 .54805 m .41218 .54705 L .41981 .54467 L .583 .945 .856 r
F
.41567 .54805 m .41981 .54467 L .42895 .54317 L F
.42895 .54317 m .41981 .54467 L .45373 .53407 L F
.41567 .54805 m .45373 .53407 L .47152 .52851 L F
.42972 .55208 m .41567 .54805 L .43019 .54297 L F
.42972 .55208 m .43019 .54297 L .45229 .53936 L F
.47152 .52851 m .4252 .55061 L .45373 .53407 L .599 .105 .051 r
F
.42895 .54317 m .47467 .52638 L .47071 .53605 L .255 0 0 r
F
.42171 .54435 m .44181 .54098 L .42895 .54317 L .125 .672 .704 r
F
.45373 .53407 m .44181 .54098 L .41981 .54467 L .599 .105 .051 r
F
.36051 .54682 m .36307 .54596 L .41018 .54626 L .249 .741 .916 r
F
.39862 .54169 m .36275 .54592 L .39877 .54182 L .347 .743 .984 r
F
.36389 .52434 m .36275 .54592 L .39862 .54169 L F
.36275 .54592 m .36307 .54596 L .39877 .54182 L F
.36307 .54596 m .38324 .54362 L .39832 .5451 L .249 .741 .916 r
F
.39817 .54618 m .39832 .5451 L .41018 .54626 L F
.36307 .54596 m .39832 .5451 L .39817 .54618 L F
.40047 .52971 m .39877 .54182 L .36452 .51251 L 0 .474 .853 r
F
.373 .54262 m .38804 .53755 L .40654 .54483 L .249 .741 .916 r
F
.373 .54262 m .40654 .54483 L .41018 .54626 L F
.36051 .54682 m .41018 .54626 L .40583 .54702 L F
.38821 .54893 m .39263 .54858 L .36051 .54682 L .112 .66 .815 r
F
.40583 .54702 m .41981 .54467 L .39684 .54865 L .125 .672 .704 r
F
.39263 .54858 m .41218 .54705 L .39805 .54699 L .112 .66 .815 r
F
.39263 .54858 m .39805 .54699 L .36051 .54682 L F
.39888 .54184 m .40311 .5455 L .39877 .54182 L 0 .474 .853 r
F
.40311 .5455 m .40495 .54711 L .40309 .54551 L F
.40311 .5455 m .40309 .54551 L .39877 .54182 L F
.41018 .54626 m .41116 .54613 L .40583 .54702 L .125 .672 .704 r
F
.40583 .54702 m .40906 .54646 L .40997 .54704 L .249 .741 .916 r
F
.40912 .54645 m .41018 .54626 L .41218 .54705 L F
.40966 .54633 m .41169 .546 L .41018 .54626 L .125 .672 .704 r
F
.40955 .54635 m .41018 .54626 L .40583 .54702 L F
.41018 .54626 m .40901 .54642 L .40654 .54483 L .494 0 0 r
F
.40966 .54633 m .41018 .54626 L .40955 .54635 L .125 .672 .704 r
F
.41567 .54805 m .41218 .54705 L .38821 .54893 L .112 .66 .815 r
F
.41077 .54613 m .39684 .54865 L .39257 .54931 L .125 .672 .704 r
F
.40495 .54711 m .40901 .54642 L .40913 .5465 L .729 .339 .311 r
F
.3623 .55454 m .38304 .54909 L .3834 .54908 L .255 0 0 r
F
.37586 .55223 m .36051 .54682 L .38821 .54893 L .742 .932 .951 r
F
.36728 .55367 m .36051 .54682 L .37586 .55223 L F
.36656 .55306 m .3623 .55454 L .36728 .55367 L .347 .743 .984 r
F
.3613 .5486 m .36051 .54682 L .36728 .55367 L .742 .932 .951 r
F
.36275 .546 m .36256 .54949 L .39877 .54182 L .347 .743 .984 r
F
.36256 .54949 m .3623 .55454 L .36729 .5528 L F
.36256 .54949 m .36729 .5528 L .39877 .54182 L F
.368 .55355 m .37586 .55223 L .3623 .55454 L .125 .672 .704 r
F
.3737 .57668 m .3613 .5486 L .30183 .5568 L .668 .896 .979 r
F
.3613 .5486 m .36051 .54682 L .3591 .54706 L F
.3613 .5486 m .3591 .54706 L .30183 .5568 L F
.3638 .55426 m .3613 .5486 L .36728 .55367 L .742 .932 .951 r
F
.39877 .54182 m .36656 .55306 L .40495 .54711 L .347 .743 .984 r
F
.36656 .55306 m .36728 .55367 L .40495 .54711 L F
.41077 .54613 m .37586 .55223 L .368 .55355 L .125 .672 .704 r
F
.40654 .54483 m .40901 .54642 L .39886 .54181 L .494 0 0 r
F
.40495 .54711 m .40901 .54642 L .40214 .54763 L .125 .672 .704 r
F
.40901 .54642 m .40929 .54639 L .40214 .54763 L F
.41695 .55084 m .42113 .55417 L .42038 .55376 L .494 0 0 r
F
.45366 .5814 m .45397 .57617 L .41822 .55497 L .695 .233 .151 r
F
.41218 .54705 m .42157 .55453 L .44872 .55702 L .52 0 0 r
F
.42157 .55453 m .42249 .55526 L .4318 .55589 L F
.42157 .55453 m .4318 .55589 L .44872 .55702 L F
.45402 .55847 m .46142 .59252 L .45368 .55879 L .897 .477 .142 r
F
.4318 .55589 m .45393 .55882 L .45116 .56222 L .729 .339 .311 r
F
.45397 .57617 m .45474 .56339 L .4318 .55589 L .695 .233 .151 r
F
.41695 .55084 m .42038 .55376 L .41533 .5505 L .494 0 0 r
F
.45397 .57617 m .41533 .5505 L .40495 .54711 L .695 .233 .151 r
F
.40495 .54711 m .40913 .5465 L .41533 .5505 L .729 .339 .311 r
F
.42113 .55417 m .43446 .56479 L .41116 .54864 L .494 0 0 r
F
.45397 .57617 m .4318 .55589 L .42249 .55526 L .695 .233 .151 r
F
.45116 .56222 m .45374 .55905 L .45474 .56339 L .729 .339 .311 r
F
.45368 .55879 m .46065 .58919 L .45224 .57852 L .897 .477 .142 r
F
.44596 .57283 m .42522 .55982 L .45363 .58137 L 0 .327 .811 r
F
.46065 .58919 m .45291 .58057 L .44397 .56802 L .897 .477 .142 r
F
.45366 .5814 m .41822 .55497 L .4159 .55481 L .695 .233 .151 r
F
.45385 .58154 m .45474 .56339 L .45366 .5814 L F
.42522 .55982 m .4159 .55481 L .45366 .5814 L 0 .327 .811 r
F
.45363 .58137 m .45366 .5814 L .45385 .58154 L F
.42522 .55982 m .45366 .5814 L .45363 .58137 L F
.47851 .61495 m .47922 .63003 L .47529 .62102 L .989 .738 .453 r
F
.47922 .63003 m .47987 .64376 L .47529 .62102 L F
.4837 .62359 m .47987 .64376 L .47851 .61495 L F
.48916 .59488 m .4837 .62359 L .47851 .61495 L F
.47877 .63831 m .47937 .64113 L .48024 .64561 L 0 0 .181 r
F
.47937 .64113 m .47877 .63831 L .47853 .63915 L .89 .581 .455 r
F
.47853 .63915 m .47877 .63831 L .47344 .61338 L F
.47853 .63915 m .47086 .60029 L .46643 .61091 L F
.46916 .61184 m .46682 .61183 L .47937 .64113 L 0 .108 .634 r
F
.48295 .64947 m .48514 .61603 L .47877 .63831 L .89 .581 .455 r
F
.48295 .64947 m .47877 .63831 L .47937 .64113 L F
.47879 .63814 m .47937 .64113 L .48295 .64947 L 0 .108 .634 r
F
.47529 .62102 m .47767 .63232 L .47877 .63831 L 0 0 .181 r
F
.47744 .62967 m .47879 .63814 L .48295 .64947 L 0 .108 .634 r
F
.47529 .62102 m .47728 .63032 L .4818 .61187 L 0 0 .408 r
F
.4765 .62631 m .47728 .63032 L .47744 .62967 L 0 .108 .634 r
F
.47728 .63032 m .47879 .63814 L .47744 .62967 L F
.48015 .63349 m .4765 .62631 L .48295 .64947 L F
.48261 .63834 m .48015 .63349 L .48295 .64947 L F
.46065 .58919 m .46142 .59252 L .45291 .58057 L .897 .477 .142 r
F
.45955 .57473 m .46916 .603 L .48115 .5756 L .733 .386 .392 r
F
.46916 .603 m .46942 .60375 L .47086 .60029 L F
.46916 .603 m .47086 .60029 L .48115 .5756 L F
.47086 .60029 m .48564 .57662 L .47309 .60274 L .883 .59 .487 r
F
.48115 .5756 m .47529 .62102 L .48407 .57572 L .733 .386 .392 r
F
.46942 .60375 m .47529 .62102 L .48115 .5756 L F
.48407 .57572 m .48311 .58067 L .48564 .57662 L F
.48885 .57576 m .48951 .57884 L .48576 .57638 L .73 .396 .414 r
F
.4864 .57504 m .48576 .57638 L .48148 .57358 L F
.48614 .57582 m .48611 .57565 L .48615 .5758 L .883 .59 .487 r
F
.48885 .57576 m .48576 .57638 L .4864 .57504 L .73 .396 .414 r
F
.48471 .5757 m .48951 .57884 L .48407 .57572 L F
.45385 .58154 m .48611 .57565 L .48564 .57662 L .883 .59 .487 r
F
.45385 .58154 m .48564 .57662 L .47086 .60029 L F
.45422 .58241 m .47086 .60029 L .45385 .58154 L .89 .581 .455 r
F
.46643 .61091 m .46942 .60375 L .45422 .58241 L F
.46942 .60375 m .47086 .60029 L .45422 .58241 L F
.46916 .61184 m .45422 .58241 L .46682 .61183 L 0 .108 .634 r
F
.46942 .60375 m .47529 .62102 L .44847 .57562 L .897 .477 .142 r
F
.44872 .55702 m .44326 .56711 L .45402 .55847 L .52 0 0 r
F
.44326 .56711 m .44225 .56897 L .44378 .5676 L F
.44326 .56711 m .44378 .5676 L .45402 .55847 L F
.45368 .55879 m .45224 .57852 L .44596 .56613 L .897 .477 .142 r
F
.44225 .56897 m .44271 .56922 L .4441 .5679 L .52 0 0 r
F
.44378 .5676 m .4441 .5679 L .45402 .55847 L F
.44225 .56897 m .4441 .5679 L .44378 .5676 L F
.48885 .57576 m .48148 .57358 L .45568 .55668 L .73 .396 .414 r
F
.45402 .55847 m .45955 .57473 L .48407 .57572 L .733 .386 .392 r
F
.48471 .5757 m .48407 .57572 L .45402 .55847 L .73 .396 .414 r
F
.45385 .58154 m .48544 .57343 L .45474 .56339 L .695 .233 .151 r
F
.45385 .58154 m .48544 .57343 L .48611 .57565 L .883 .59 .487 r
F
.46703 .59584 m .45385 .58154 L .4513 .5746 L 0 .019 .579 r
F
.45805 .58088 m .4513 .5746 L .44663 .56188 L F
.46703 .59584 m .4513 .5746 L .45805 .58088 L F
.42249 .55526 m .43446 .56479 L .44872 .55702 L .52 0 0 r
F
.41695 .55084 m .41533 .5505 L .41437 .54987 L .494 0 0 r
F
.44397 .56802 m .44847 .57562 L .44271 .56922 L .897 .477 .142 r
F
.45291 .58057 m .44847 .57562 L .44397 .56802 L F
.44596 .56613 m .45224 .57852 L .44397 .56802 L F
.4159 .55481 m .41822 .55497 L .40495 .54711 L .695 .233 .151 r
F
.40831 .54706 m .40495 .54711 L .451 .576 L 0 .327 .811 r
F
.40831 .54706 m .40495 .54711 L .40753 .54663 L 0 .474 .853 r
F
.41695 .55084 m .40631 .5468 L .4083 .54652 L .494 0 0 r
F
.41218 .54705 m .41695 .55084 L .41213 .54844 L F
.44163 .54108 m .4252 .55061 L .41843 .5451 L .599 .105 .051 r
F
.41843 .5451 m .4252 .55061 L .41218 .54705 L F
.41533 .5505 m .42374 .54855 L .42663 .55294 L .729 .339 .311 r
F
.44732 .54006 m .45402 .55847 L .4252 .55061 L .599 .105 .051 r
F
.46667 .53681 m .45402 .55847 L .44732 .54006 L F
.42374 .54855 m .4713 .53753 L .42663 .55294 L .729 .339 .311 r
F
.43446 .56479 m .44225 .56897 L .44872 .55702 L .52 0 0 r
F
.45402 .55847 m .45488 .561 L .45481 .56212 L .897 .477 .142 r
F
.47257 .53635 m .45402 .55847 L .47282 .53818 L 0 0 0 r
F
.42663 .55294 m .4713 .53753 L .45393 .55882 L .729 .339 .311 r
F
.43446 .56479 m .42016 .5551 L .41116 .54864 L .494 0 0 r
F
.42249 .55526 m .4318 .55589 L .41533 .5505 L .695 .233 .151 r
F
.41533 .5505 m .45393 .55882 L .4318 .55589 L .729 .339 .311 r
F
.41437 .54987 m .41533 .5505 L .4143 .54984 L .494 0 0 r
F
.41218 .54705 m .41213 .54844 L .40901 .54642 L F
.41218 .54705 m .40901 .54642 L .41018 .54626 L F
.40913 .5465 m .4713 .53753 L .41533 .5505 L .729 .339 .311 r
F
.4143 .54984 m .42038 .55376 L .41116 .54864 L .494 0 0 r
F
.40901 .54642 m .41213 .54844 L .4083 .54652 L F
.40753 .54663 m .40495 .54711 L .39888 .54184 L 0 .474 .853 r
F
.41116 .54864 m .44149 .57038 L .40631 .5468 L .494 0 0 r
F
.42263 .54687 m .40831 .54706 L .43446 .56479 L 0 .327 .811 r
F
.44271 .56922 m .43446 .56479 L .44537 .57218 L F
.42263 .54687 m .43446 .56479 L .44271 .56922 L F
.43446 .56479 m .44149 .57038 L .44225 .56897 L .52 0 0 r
F
.44663 .56188 m .4513 .5746 L .43595 .5467 L 0 .019 .579 r
F
.4513 .5746 m .45385 .58154 L .44935 .57279 L F
.4513 .5746 m .44935 .57279 L .43595 .5467 L F
.44271 .56922 m .47529 .62102 L .44149 .57038 L .897 .477 .142 r
F
.44847 .57562 m .47529 .62102 L .44271 .56922 L F
.43595 .5467 m .42263 .54687 L .451 .576 L 0 .327 .811 r
F
.42263 .54687 m .44537 .57218 L .451 .576 L F
.46916 .61184 m .47128 .61184 L .47529 .62102 L 0 .217 .735 r
F
.46942 .60375 m .44847 .57562 L .45291 .58057 L .897 .477 .142 r
F
.48951 .57884 m .48916 .59488 L .47663 .61849 L .989 .738 .453 r
F
.47633 .61793 m .47663 .61849 L .47529 .62102 L F
.48951 .57884 m .47663 .61849 L .47633 .61793 L F
.48564 .57662 m .47529 .62102 L .48951 .57884 L .733 .386 .392 r
F
.48311 .58067 m .47529 .62102 L .48564 .57662 L F
.4818 .61187 m .45422 .58241 L .46916 .61184 L 0 .108 .634 r
F
.4818 .61187 m .45385 .58154 L .45422 .58241 L F
.451 .576 m .44596 .57283 L .45385 .58154 L 0 .327 .811 r
F
.44596 .57283 m .45363 .58137 L .45385 .58154 L F
.44225 .56897 m .44149 .57038 L .44271 .56922 L .52 0 0 r
F
.44149 .57038 m .46271 .59222 L .43595 .5467 L 0 .166 .705 r
F
.4818 .61187 m .46703 .59584 L .44663 .56188 L 0 .019 .579 r
F
.46271 .59222 m .4818 .61187 L .44663 .56188 L 0 .166 .705 r
F
.46271 .59222 m .44663 .56188 L .43595 .5467 L F
.47128 .61184 m .4818 .61187 L .47529 .62102 L 0 .217 .735 r
F
.48647 .67477 m .48846 .68343 L .4869 .6738 L .96 .802 .642 r
F
.48806 .68504 m .48846 .68343 L .48647 .67477 L F
.48619 .6754 m .48647 .67477 L .48392 .66368 L F
.48806 .68504 m .48647 .67477 L .48619 .6754 L F
.49039 .7236 m .48784 .73113 L .4852 .73143 L .894 .986 .792 r
F
.49266 .72103 m .48784 .73113 L .49039 .7236 L F
.49646 .71606 m .46683 .77829 L .48161 .73689 L .91 .982 .731 r
F
.49734 .71533 m .46683 .77829 L .49646 .71606 L F
.4963 .7169 m .49762 .7102 L .49127 .68392 L .96 .802 .642 r
F
.49016 .6859 m .49127 .68392 L .48295 .64947 L F
.4963 .7169 m .49127 .68392 L .49016 .6859 L F
.50173 .66754 m .49286 .68142 L .49263 .6815 L .985 .886 .642 r
F
.48024 .64561 m .48132 .65022 L .48225 .65504 L 0 0 .181 r
F
.48114 .65004 m .48225 .65504 L .48493 .66888 L F
.48024 .64561 m .48225 .65504 L .48114 .65004 L F
.48597 .69339 m .48806 .68504 L .48392 .66368 L .96 .802 .642 r
F
.48759 .68264 m .48768 .68307 L .48698 .68329 L .985 .886 .642 r
F
.49852 .67097 m .48768 .68307 L .48759 .68264 L F
.49852 .67097 m .49263 .6815 L .48768 .68307 L F
.50101 .63957 m .50468 .63756 L .49332 .65834 L .965 .803 .632 r
F
.48744 .67272 m .48726 .68046 L .50533 .6321 L .745 .509 .573 r
F
.55962 .63052 m .63541 .60654 L .59088 .58349 L .74 .58 .675 r
F
.55934 .62919 m .57399 .60797 L .55329 .60052 L F
.525 .59057 m .55412 .60444 L .52314 .60068 L .712 .562 .682 r
F
.4913 .57382 m .55412 .60444 L .49097 .57437 L F
.51324 .55285 m .50895 .58243 L .49334 .56899 L .752 .501 .553 r
F
.52326 .54472 m .52457 .57797 L .52666 .55385 L .161 .053 .474 r
F
.53094 .50387 m .53395 .49933 L .53956 .50585 L .547 .521 .778 r
F
.53302 .5003 m .53395 .49933 L .53094 .50387 L F
.53883 .48186 m .54101 .49213 L .53395 .49933 L .751 .554 .629 r
F
.54101 .49213 m .54538 .51262 L .53956 .50585 L F
.54101 .49213 m .53956 .50585 L .53395 .49933 L F
.53695 .53046 m .53956 .50585 L .53094 .50387 L .594 .413 .606 r
F
.52136 .49676 m .52326 .54472 L .53117 .50064 L .161 .053 .474 r
F
.53695 .53046 m .53094 .50387 L .53073 .50695 L .594 .413 .606 r
F
.53302 .5003 m .57625 .45511 L .53025 .49925 L .192 .012 .394 r
F
.52326 .54472 m .52666 .55385 L .53137 .49957 L .161 .053 .474 r
F
.53073 .50695 m .53094 .50387 L .52985 .50362 L .594 .413 .606 r
F
.53124 .49964 m .53117 .50064 L .53135 .49967 L .161 .053 .474 r
F
.52136 .49676 m .53117 .50064 L .53124 .49964 L F
.53395 .49933 m .56749 .61645 L .53362 .50053 L .751 .554 .629 r
F
.54538 .51262 m .56749 .61645 L .53395 .49933 L F
.52885 .55973 m .55772 .60212 L .55329 .60052 L F
.52885 .55973 m .55329 .60052 L .52744 .57726 L F
.54812 .55016 m .56749 .61645 L .53446 .56796 L F
.53522 .55657 m .53446 .56796 L .52885 .55973 L F
.54812 .55016 m .53446 .56796 L .53522 .55657 L F
.52666 .55385 m .53073 .50695 L .53695 .53046 L .575 .401 .609 r
F
.52666 .55385 m .53695 .53046 L .53522 .55657 L F
.53007 .56298 m .54465 .55957 L .53522 .55657 L .602 .275 .388 r
F
.52885 .55973 m .53522 .55657 L .52666 .55385 L F
.53007 .56298 m .53522 .55657 L .52885 .55973 L F
.53362 .50053 m .53795 .51535 L .52885 .55973 L .751 .554 .629 r
F
.53795 .51535 m .54812 .55016 L .53522 .55657 L F
.53795 .51535 m .53522 .55657 L .52885 .55973 L F
.53522 .55657 m .53695 .53046 L .54465 .55957 L .575 .401 .609 r
F
.68899 .40789 m .58787 .45766 L .5602 .51634 L .662 .597 .772 r
F
.66754 .50633 m .5602 .51634 L .68899 .40789 L .684 .639 .799 r
F
.54465 .55957 m .61725 .52367 L .53956 .50585 L .594 .413 .606 r
F
.54465 .55957 m .53956 .50585 L .53695 .53046 L F
.53316 .50007 m .53313 .50034 L .53364 .50021 L .161 .053 .474 r
F
.53313 .50034 m .52505 .59027 L .53361 .50053 L F
.53313 .50034 m .53361 .50053 L .53364 .50021 L F
.53137 .49957 m .53108 .50363 L .53316 .50007 L F
.53108 .50363 m .52505 .59027 L .53316 .50007 L F
.52457 .57797 m .52505 .59027 L .53137 .49957 L F
.52985 .50362 m .53302 .5003 L .53094 .50387 L .547 .521 .778 r
F
.53956 .50585 m .57625 .45511 L .61725 .52367 L F
.53395 .49933 m .57625 .45511 L .53956 .50585 L F
.52505 .59027 m .52744 .57726 L .53364 .50021 L .161 .053 .474 r
F
.49097 .57437 m .525 .59057 L .52314 .60068 L .712 .562 .682 r
F
.52457 .57797 m .52549 .60148 L .52393 .57589 L .752 .501 .553 r
F
.52208 .54568 m .5248 .59015 L .51324 .55285 L F
.5248 .59015 m .52549 .60148 L .52233 .58895 L F
.5248 .59015 m .52233 .58895 L .51324 .55285 L F
.48994 .57609 m .4913 .57382 L .50847 .52551 L .108 0 .251 r
F
.51324 .55285 m .52233 .58895 L .50895 .58243 L .752 .501 .553 r
F
.48994 .57609 m .49097 .57437 L .49485 .57754 L .712 .562 .682 r
F
.52136 .49676 m .53135 .49967 L .53025 .49925 L .161 .053 .474 r
F
.52136 .49676 m .52175 .50653 L .51976 .50781 L .752 .501 .553 r
F
.51976 .50781 m .52311 .48754 L .52985 .50362 L .183 .006 .391 r
F
.5151 .50974 m .52242 .48945 L .51976 .50781 L F
.52242 .48945 m .52311 .48754 L .51976 .50781 L F
.53217 .4615 m .53409 .45713 L .5151 .50974 L F
.5211 .48999 m .52136 .49676 L .49334 .56899 L .752 .501 .553 r
F
.49288 .56936 m .49334 .56899 L .48951 .57884 L F
.5211 .48999 m .49334 .56899 L .49288 .56936 L F
.49434 .54788 m .48577 .55858 L .48886 .54182 L .73 .396 .414 r
F
.49229 .56984 m .49661 .54429 L .48886 .54182 L .602 .275 .388 r
F
.49253 .57177 m .49288 .56936 L .49229 .56984 L F
.49288 .56936 m .49661 .54429 L .49229 .56984 L F
.48885 .57263 m .51539 .56641 L .55412 .60444 L .712 .562 .682 r
F
.51539 .56641 m .54465 .55957 L .55329 .60052 L F
.51539 .56641 m .55329 .60052 L .55412 .60444 L F
.52744 .57726 m .55329 .60052 L .52635 .59083 L .751 .554 .629 r
F
.52635 .59083 m .56749 .61645 L .52549 .60148 L F
.55772 .60212 m .56749 .61645 L .52635 .59083 L F
.55329 .60052 m .59088 .58349 L .54465 .55957 L .74 .58 .675 r
F
.57399 .60797 m .59088 .58349 L .55329 .60052 L F
.56159 .62594 m .55972 .62895 L .55934 .62919 L .91 .982 .731 r
F
.55962 .63052 m .59088 .58349 L .55934 .62919 L .74 .58 .675 r
F
.55934 .62919 m .55972 .62895 L .55886 .62993 L .91 .982 .731 r
F
.56366 .6226 m .56159 .62594 L .55934 .62919 L F
.545 .63162 m .56463 .62047 L .56749 .61645 L .744 .572 .661 r
F
.50753 .6569 m .54617 .63224 L .545 .63162 L F
.54617 .63224 m .56463 .62047 L .545 .63162 L F
.50468 .63756 m .54617 .63224 L .51151 .61392 L .772 .532 .573 r
F
.5203 .59822 m .48726 .68046 L .52549 .60148 L .745 .509 .573 r
F
.50533 .6321 m .48726 .68046 L .5203 .59822 L F
.48392 .66368 m .48647 .67477 L .48295 .64947 L .96 .802 .642 r
F
.48647 .67477 m .4869 .6738 L .48295 .64947 L F
.48225 .65504 m .48392 .66368 L .48295 .64947 L F
.49263 .6815 m .49127 .68392 L .48698 .68329 L .985 .886 .642 r
F
.49127 .68392 m .48597 .69339 L .48611 .692 L F
.49127 .68392 m .48611 .692 L .48698 .68329 L F
.49408 .71804 m .49016 .6859 L .48959 .68692 L .96 .802 .642 r
F
.49408 .71804 m .48959 .68692 L .48916 .6877 L F
.51065 .63679 m .50312 .66276 L .48698 .68329 L .985 .886 .642 r
F
.50312 .66276 m .49852 .67097 L .48698 .68329 L F
.48744 .67258 m .48739 .67467 L .48688 .67175 L .989 .738 .453 r
F
.48739 .67467 m .48726 .68046 L .48688 .67175 L F
.48688 .67175 m .48726 .68046 L .48493 .66888 L F
.48647 .67115 m .4875 .67245 L .48295 .64947 L .96 .802 .642 r
F
.48744 .67258 m .4875 .67245 L .48647 .67115 L F
.52549 .60148 m .52001 .61841 L .48726 .68046 L .985 .886 .642 r
F
.52001 .61841 m .48757 .68214 L .48726 .68046 L F
.48757 .68214 m .48698 .68329 L .48726 .68046 L F
.48493 .66888 m .48594 .67319 L .48726 .68046 L 0 0 .181 r
F
.48594 .67319 m .4893 .68757 L .48726 .68046 L F
.49025 .6909 m .48295 .64947 L .48225 .65504 L .038 0 .439 r
F
.47996 .64319 m .49025 .6909 L .4893 .68757 L 0 0 .181 r
F
.47767 .63232 m .4893 .68757 L .47937 .64113 L F
.48132 .65022 m .4893 .68757 L .48493 .66888 L F
.47501 .71296 m .48597 .69339 L .48392 .66368 L .96 .802 .642 r
F
.47501 .71296 m .48392 .66368 L .48225 .65504 L F
.48597 .69339 m .48295 .70544 L .48534 .69968 L .979 .88 .513 r
F
.47302 .7289 m .48427 .70018 L .47501 .71296 L .96 .802 .642 r
F
.48427 .70018 m .48916 .6877 L .48597 .69339 L F
.48427 .70018 m .48597 .69339 L .47501 .71296 L F
.48726 .68046 m .47535 .72375 L .48295 .70544 L .979 .88 .513 r
F
.48726 .68046 m .48295 .70544 L .48597 .69339 L F
.48427 .70018 m .49408 .71804 L .48916 .6877 L .96 .802 .642 r
F
.47532 .72384 m .47682 .70892 L .47302 .7289 L .038 0 .439 r
F
.47682 .70892 m .47526 .71102 L .47302 .7289 L F
.48494 .66709 m .48225 .65504 L .47532 .72384 L F
.48726 .68046 m .4733 .72132 L .47535 .72375 L .979 .88 .513 r
F
.48726 .68046 m .47815 .70714 L .49023 .69081 L 0 0 .038 r
F
.47815 .70714 m .48995 .6913 L .49023 .69081 L F
.48161 .73689 m .4621 .75344 L .459 .76318 L 0 0 0 r
F
.45216 .76187 m .44181 .77066 L .43606 .78099 L .91 .978 .78 r
F
.45216 .76187 m .43606 .78099 L .44563 .77417 L F
.45216 .76187 m .4423 .78045 L .46683 .77829 L F
.4621 .75344 m .44181 .77066 L .459 .76318 L 0 0 0 r
F
.43119 .78446 m .44148 .7708 L .42062 .79255 L .017 0 .085 r
F
.44148 .7708 m .43688 .7728 L .42062 .79255 L F
.44181 .77066 m .4337 .7812 L .43606 .78099 L .91 .978 .78 r
F
.47201 .73138 m .47302 .7289 L .43119 .78446 L .017 0 .085 r
F
.42172 .7912 m .42062 .79255 L .43119 .78446 L .459 .838 .606 r
F
.4493 .78355 m .35989 .81316 L .37916 .81125 L .363 0 0 r
F
.451 .78288 m .37916 .81125 L .3881 .81037 L F
.44935 .78353 m .45094 .78303 L .451 .78288 L .891 .98 .815 r
F
.45107 .78285 m .3881 .81037 L .3959 .80959 L .363 0 0 r
F
.3959 .80959 m .42062 .79255 L .407 .79681 L .135 0 0 r
F
.3959 .80959 m .42062 .79255 L .42172 .7912 L .459 .838 .606 r
F
.46244 .77944 m .45107 .78285 L .40437 .80549 L .363 0 0 r
F
.40479 .80556 m .40437 .80549 L .3959 .80959 L F
.46244 .77944 m .40437 .80549 L .40479 .80556 L F
.46683 .77829 m .46244 .77944 L .3959 .80959 L F
.43555 .78135 m .3959 .80959 L .46238 .78025 L .91 .978 .78 r
F
.42887 .78162 m .46238 .78025 L .46683 .77829 L F
.49336 .73373 m .47377 .76486 L .49387 .72265 L .91 .982 .731 r
F
.51313 .70231 m .46935 .77416 L .47377 .76486 L F
.51249 .70332 m .49336 .73373 L .50779 .70703 L F
.49336 .73373 m .49387 .72265 L .49659 .71693 L F
.49387 .72265 m .49083 .77556 L .49891 .71555 L .895 .92 .831 r
F
.46651 .78012 m .49083 .77556 L .49387 .72265 L F
.46935 .77416 m .46683 .77829 L .4981 .71376 L .91 .982 .731 r
F
.49891 .71555 m .54752 .70892 L .49083 .77556 L .839 .875 .869 r
F
.48527 .77239 m .48612 .75856 L .459 .76318 L .514 .332 .572 r
F
.4694 .78615 m .459 .76318 L .48527 .77239 L .548 .227 .376 r
F
.459 .76318 m .4581 .77725 L .46345 .77301 L .465 .19 .411 r
F
.48527 .77239 m .48612 .75856 L .49574 .75213 L .597 .402 .587 r
F
.49083 .77556 m .53288 .76061 L .54752 .70892 L .861 .97 .863 r
F
.50179 .74263 m .48965 .78998 L .49536 .75449 L .778 .572 .62 r
F
.49612 .75154 m .49536 .75449 L .49574 .75213 L F
.50179 .74263 m .49536 .75449 L .49612 .75154 L F
.47288 .83829 m .47622 .82929 L .48527 .77239 L .532 .326 .546 r
F
.49782 .70907 m .49903 .71394 L .49762 .7102 L .965 .803 .632 r
F
.49941 .71348 m .51386 .65286 L .49918 .71376 L .866 .712 .688 r
F
.54617 .63224 m .55818 .6307 L .51386 .65286 L .8 .699 .754 r
F
.49718 .71268 m .49662 .71584 L .56463 .62047 L .744 .572 .661 r
F
.50651 .66005 m .49718 .71268 L .56463 .62047 L F
.55347 .63611 m .52676 .67995 L .4981 .71376 L .91 .982 .731 r
F
.51313 .70231 m .51249 .70332 L .50779 .70703 L F
.52676 .67995 m .51313 .70231 L .50094 .7116 L F
.49891 .71555 m .54752 .70892 L .52869 .67757 L .866 .712 .688 r
F
.52869 .67757 m .55962 .63052 L .54752 .70892 L .8 .699 .754 r
F
.55818 .6307 m .55962 .63052 L .52869 .67757 L F
.49127 .68392 m .49782 .70907 L .49762 .7102 L .965 .803 .632 r
F
.49147 .68361 m .49782 .70907 L .49127 .68392 L F
.49408 .71804 m .49618 .7163 L .49016 .6859 L .96 .802 .642 r
F
.49147 .68361 m .50052 .69387 L .49782 .70907 L .965 .803 .632 r
F
.52676 .67995 m .50094 .7116 L .4981 .71376 L .91 .982 .731 r
F
.49891 .71555 m .52869 .67757 L .49941 .71348 L .866 .712 .688 r
F
.51 .72853 m .49025 .6909 L .52039 .71011 L .597 .402 .587 r
F
.50359 .73222 m .50635 .73063 L .50179 .74263 L .657 .519 .684 r
F
.48295 .70544 m .47767 .7265 L .48212 .73178 L .979 .88 .513 r
F
.47767 .7265 m .49408 .71804 L .48427 .70018 L .96 .802 .642 r
F
.47767 .7265 m .49408 .71804 L .48371 .73367 L .894 .986 .792 r
F
.49408 .71804 m .4852 .73143 L .4852 .73143 L F
.49408 .71804 m .49266 .72103 L .49039 .7236 L F
.4981 .71376 m .49734 .71533 L .49646 .71606 L .91 .982 .731 r
F
.49408 .71804 m .4963 .7169 L .49618 .7163 L .96 .802 .642 r
F
.4963 .7169 m .49891 .71555 L .49861 .71427 L F
.4963 .7169 m .49861 .71427 L .49646 .71606 L F
.50094 .7116 m .49908 .71388 L .4981 .71376 L .91 .982 .731 r
F
.49908 .71388 m .49737 .71531 L .4981 .71376 L F
.49762 .7102 m .49711 .71277 L .49718 .71268 L .744 .572 .661 r
F
.48331 .73165 m .48161 .73689 L .49402 .71949 L F
.49408 .71804 m .49402 .71949 L .49266 .72103 L .894 .986 .792 r
F
.49861 .71427 m .49903 .71394 L .49891 .71555 L .965 .803 .632 r
F
.49408 .71804 m .49891 .71555 L .49387 .72265 L .894 .986 .792 r
F
.49891 .71555 m .49941 .71348 L .49918 .71376 L .866 .712 .688 r
F
.459 .76318 m .47201 .73138 L .47428 .72633 L 0 0 0 r
F
.47201 .73138 m .47302 .7289 L .47532 .72384 L F
.47535 .72375 m .47333 .73004 L .47581 .7243 L .979 .88 .513 r
F
.47332 .72864 m .47333 .73004 L .47535 .72375 L F
.48295 .70544 m .47535 .72375 L .47767 .7265 L F
.47439 .72608 m .47532 .72384 L .48323 .70639 L 0 0 0 r
F
.47201 .73138 m .47532 .72384 L .47439 .72608 L F
.47428 .72633 m .48323 .70639 L .49025 .6909 L F
.47201 .73138 m .47439 .72608 L .47428 .72633 L F
.47439 .72608 m .48323 .70639 L .47428 .72633 L F
.47267 .73023 m .459 .76318 L .47153 .74616 L .979 .88 .513 r
F
.459 .76318 m .47201 .73138 L .46815 .7364 L .017 0 .085 r
F
.42887 .78162 m .3959 .80959 L .43555 .78135 L .91 .978 .78 r
F
.459 .76318 m .46815 .7364 L .43119 .78446 L .017 0 .085 r
F
.44148 .7708 m .47302 .7289 L .43688 .7728 L F
.4733 .72132 m .459 .76318 L .47267 .73023 L .979 .88 .513 r
F
.4733 .72132 m .47332 .72864 L .47535 .72375 L F
.47333 .73004 m .47337 .74366 L .47581 .7243 L F
.47581 .7243 m .47337 .74366 L .47767 .7265 L F
.47335 .73547 m .47153 .74616 L .47337 .74366 L F
.4733 .72132 m .47153 .74616 L .47335 .73547 L F
.47767 .7265 m .47337 .74366 L .48212 .73178 L F
.48212 .73178 m .459 .76318 L .48161 .73689 L F
.48331 .73165 m .48161 .73689 L .48312 .73167 L .985 .886 .642 r
F
.48312 .73167 m .48161 .73689 L .48212 .73178 L F
.49025 .6909 m .50179 .74263 L .459 .76318 L .579 .403 .607 r
F
.50359 .73222 m .49025 .6909 L .51 .72853 L .597 .402 .587 r
F
.49025 .6909 m .50179 .74263 L .50359 .73222 L .425 .303 .61 r
F
.4956 .73682 m .49025 .6909 L .50359 .73222 L .597 .402 .587 r
F
.50797 .65409 m .50312 .66276 L .51065 .63679 L .985 .886 .642 r
F
.50753 .6569 m .50312 .66276 L .50797 .65409 L F
.50753 .6569 m .50651 .66005 L .56463 .62047 L .744 .572 .661 r
F
.50052 .69387 m .50933 .64531 L .50256 .66624 L .866 .712 .688 r
F
.50348 .68476 m .50933 .64531 L .50052 .69387 L F
.50173 .66754 m .49819 .67973 L .49286 .68142 L .985 .886 .642 r
F
.49147 .68361 m .50256 .66624 L .50052 .69387 L .965 .803 .632 r
F
.50348 .68476 m .51386 .65286 L .50933 .64531 L .866 .712 .688 r
F
.50933 .64531 m .54617 .63224 L .51386 .65286 L .8 .699 .754 r
F
.52039 .71011 m .50538 .6719 L .52414 .65791 L .566 .456 .688 r
F
.52039 .71011 m .52414 .65791 L .52914 .68677 L F
.51423 .75964 m .51484 .75735 L .52039 .71011 L .41 .291 .606 r
F
.51425 .76 m .51979 .76773 L .52483 .71281 L .682 .555 .703 r
F
.51484 .75735 m .52162 .73222 L .52139 .72813 L .41 .291 .606 r
F
.51484 .75735 m .52139 .72813 L .52039 .71011 L F
.52483 .71281 m .51979 .76773 L .53376 .73156 L .682 .555 .703 r
F
.52483 .71281 m .53376 .73156 L .54382 .68823 L F
.54597 .66491 m .55025 .66723 L .5483 .67071 L .657 .519 .684 r
F
.55025 .66723 m .54382 .68823 L .52483 .71281 L F
.56749 .61645 m .56366 .6226 L .55347 .63611 L .91 .982 .731 r
F
.56366 .6226 m .55886 .62993 L .55347 .63611 L F
.52549 .60148 m .52001 .61841 L .56749 .61645 L .744 .572 .661 r
F
.52001 .61841 m .545 .63162 L .56749 .61645 L F
.54037 .65247 m .54597 .66491 L .54579 .65315 L .574 .555 .795 r
F
.53675 .65572 m .54597 .66491 L .54037 .65247 L F
.52321 .65256 m .53384 .65833 L .53251 .65149 L F
.53384 .65833 m .54597 .66491 L .53675 .65572 L F
.53384 .65833 m .53675 .65572 L .53251 .65149 L F
.54443 .64884 m .54609 .64154 L .54402 .64921 L .41 .291 .606 r
F
.54402 .64921 m .54609 .64154 L .54281 .65029 L F
.54281 .65029 m .5328 .65145 L .54609 .64154 L .566 .456 .688 r
F
.51065 .63679 m .54617 .63224 L .50933 .64531 L .8 .699 .754 r
F
.5328 .65145 m .5223 .63056 L .54609 .64154 L .566 .456 .688 r
F
.52321 .65256 m .5223 .63056 L .5328 .65145 L F
.5128 .65377 m .52026 .63553 L .52321 .65256 L F
.52026 .63553 m .5223 .63056 L .52321 .65256 L F
.52321 .65256 m .53384 .65833 L .52722 .67573 L .657 .519 .684 r
F
.53251 .65149 m .54579 .65315 L .54481 .65006 L .574 .555 .795 r
F
.53251 .65149 m .53675 .65572 L .54037 .65247 L F
.51173 .66717 m .5128 .65377 L .5328 .65145 L .566 .456 .688 r
F
.50538 .6719 m .50922 .66252 L .51173 .66717 L F
.50922 .66252 m .5128 .65377 L .51173 .66717 L F
.50173 .66754 m .49263 .6815 L .49852 .67097 L .985 .886 .642 r
F
.48815 .67098 m .50533 .6321 L .51842 .59704 L .745 .509 .573 r
F
.48744 .67272 m .50533 .6321 L .48815 .67098 L F
.50312 .66276 m .50173 .66754 L .49852 .67097 L .985 .886 .642 r
F
.48744 .67258 m .48744 .67272 L .48815 .67098 L .745 .509 .573 r
F
.48295 .64947 m .50101 .63957 L .49332 .65834 L .965 .803 .632 r
F
.4818 .61187 m .50922 .66252 L .49025 .6909 L .536 .443 .697 r
F
.52039 .71011 m .50538 .6719 L .49025 .6909 L .52 .432 .696 r
F
.49025 .6909 m .4935 .70095 L .50538 .6719 L .425 .303 .61 r
F
.49025 .6909 m .50538 .6719 L .50922 .66252 L F
.50538 .6719 m .4818 .61187 L .49025 .6909 L .52 .432 .696 r
F
.51842 .59704 m .50533 .6321 L .5203 .59822 L .745 .509 .573 r
F
.50538 .6719 m .4818 .61187 L .5223 .63056 L .566 .456 .688 r
F
.4818 .61187 m .51783 .64964 L .50922 .66252 L .536 .443 .697 r
F
.51783 .64964 m .52321 .65256 L .50635 .73063 L .657 .519 .684 r
F
.52321 .65256 m .52722 .67573 L .50635 .73063 L F
.45474 .56339 m .45568 .55668 L .48544 .57343 L .729 .339 .311 r
F
.45374 .55905 m .45568 .55668 L .45474 .56339 L F
.48951 .57884 m .48916 .59488 L .51842 .59704 L .745 .509 .573 r
F
.54609 .64154 m .43595 .5467 L .4818 .61187 L .459 .506 .82 r
F
.48784 .57109 m .48798 .57175 L .45568 .55668 L .73 .396 .414 r
F
.48798 .57175 m .48885 .57576 L .48666 .5745 L F
.48544 .57343 m .49097 .57437 L .48994 .57609 L .712 .562 .682 r
F
.48824 .57558 m .48994 .57609 L .48961 .57664 L F
.48544 .57343 m .48994 .57609 L .48824 .57558 L F
.48544 .57343 m .48885 .57263 L .48472 .5643 L .602 .275 .388 r
F
.48544 .57343 m .48472 .5643 L .48381 .56928 L F
.48885 .57263 m .49166 .57035 L .48547 .56022 L F
.48885 .57263 m .48547 .56022 L .48472 .5643 L F
.48994 .57609 m .48951 .57884 L .48885 .57576 L .73 .396 .414 r
F
.48611 .57565 m .48824 .57558 L .48544 .57343 L .772 .532 .573 r
F
.45568 .55668 m .48381 .56928 L .48544 .57343 L .729 .339 .311 r
F
.49253 .57177 m .48886 .54182 L .48547 .56022 L .602 .275 .388 r
F
.50924 .52801 m .51324 .55285 L .49334 .56899 L .752 .501 .553 r
F
.48885 .57263 m .49253 .57177 L .49166 .57035 L .602 .275 .388 r
F
.49253 .57177 m .51539 .56641 L .51614 .5505 L F
.52505 .59027 m .52549 .60148 L .52744 .57726 L .161 .053 .474 r
F
.48885 .57263 m .4913 .57382 L .49097 .57437 L .712 .562 .682 r
F
.49143 .57389 m .5078 .59035 L .48951 .57884 L .752 .501 .553 r
F
.50895 .58243 m .5078 .59035 L .49143 .57389 L F
.48994 .57609 m .48951 .57884 L .4913 .57382 L .108 0 .251 r
F
.48544 .57343 m .48885 .57263 L .49097 .57437 L .712 .562 .682 r
F
.50895 .58243 m .52549 .60148 L .5078 .59035 L .752 .501 .553 r
F
.52233 .58895 m .52549 .60148 L .50895 .58243 L F
.49253 .57177 m .51614 .5505 L .49288 .56936 L .602 .275 .388 r
F
.54609 .64154 m .48466 .58864 L .56801 .58237 L .531 .517 .786 r
F
.48466 .58864 m .43595 .5467 L .47412 .55701 L F
.48466 .58864 m .47412 .55701 L .56801 .58237 L F
.48483 .58915 m .51783 .64964 L .48841 .56222 L .348 .4 .774 r
F
.4818 .61187 m .49808 .62894 L .48483 .58915 L F
.49808 .62894 m .51783 .64964 L .48483 .58915 L F
.51783 .64964 m .53251 .65149 L .53208 .60982 L .574 .555 .795 r
F
.53251 .65149 m .54481 .65006 L .53208 .60982 L F
.53384 .65833 m .54597 .66491 L .52483 .71281 L .657 .519 .684 r
F
.54597 .66491 m .5483 .67071 L .52483 .71281 L F
.51425 .76 m .51979 .76773 L .51494 .77131 L .778 .572 .62 r
F
.60964 .69186 m .65755 .659 L .55833 .7337 L .507 .875 .657 r
F
.53288 .76061 m .55833 .7337 L .60964 .69186 L 0 0 0 r
F
.54752 .70892 m .60964 .69186 L .53288 .76061 L .804 .918 .915 r
F
.54752 .70892 m .60964 .69186 L .55962 .63052 L .844 .742 .751 r
F
.55731 .76729 m .56181 .71493 L .5488 .67195 L .411 .386 .721 r
F
.55715 .67097 m .56557 .72812 L .55263 .68268 L .683 .556 .704 r
F
.56181 .71493 m .56183 .71466 L .56036 .70984 L .411 .386 .721 r
F
.56181 .71493 m .56036 .70984 L .5488 .67195 L F
.60964 .69186 m .65755 .659 L .63541 .60654 L .917 .898 .793 r
F
.55962 .63052 m .63541 .60654 L .60964 .69186 L .774 .735 .817 r
F
.55715 .67097 m .61815 .68262 L .56557 .72812 L .683 .556 .704 r
F
.56183 .71466 m .5514 .67841 L .5488 .67195 L .411 .386 .721 r
F
.55934 .77262 m .5627 .77303 L .56021 .77492 L .796 .591 .624 r
F
.55934 .77262 m .56257 .70616 L .55731 .76729 L .411 .386 .721 r
F
.55934 .77262 m .5627 .77303 L .56557 .72812 L .771 .721 .806 r
F
.55961 .77334 m .55978 .76944 L .55934 .77262 L .411 .386 .721 r
F
.55978 .76944 m .56257 .70616 L .55934 .77262 L F
.56557 .72812 m .5627 .77303 L .61815 .68262 L .771 .721 .806 r
F
.55836 .77898 m .55957 .77433 L .55731 .76729 L .411 .386 .721 r
F
.55947 .77654 m .55957 .77433 L .55836 .77898 L F
.50816 .80841 m .51528 .77705 L .55903 .78654 L .819 .694 .727 r
F
.51979 .76773 m .54265 .77056 L .5268 .76167 L .771 .721 .806 r
F
.51528 .77705 m .51754 .77616 L .55903 .78654 L .819 .694 .727 r
F
.51754 .77616 m .54131 .77085 L .55903 .78654 L F
.53808 .76799 m .55671 .76059 L .55839 .77938 L F
.51979 .76773 m .54265 .77056 L .51917 .77579 L .796 .591 .624 r
F
.53808 .76799 m .55839 .77938 L .55903 .78654 L .819 .694 .727 r
F
.55957 .77433 m .55961 .77334 L .55874 .77104 L .411 .386 .721 r
F
.55957 .77433 m .55874 .77104 L .55731 .76729 L F
.53422 .7992 m .5713 .82092 L .48692 .84265 L .777 .619 .684 r
F
.53805 .79797 m .55903 .78654 L .54196 .79388 L .648 .316 .396 r
F
.55173 .79359 m .55903 .78654 L .53805 .79797 L F
.49428 .82665 m .54196 .79388 L .50816 .80841 L F
.56347 .78983 m .5713 .82092 L .53422 .7992 L .777 .619 .684 r
F
.49428 .82665 m .48692 .84265 L .53422 .7992 L .885 .968 .839 r
F
.47052 .84299 m .47077 .84456 L .47909 .83822 L F
.47435 .84035 m .47909 .83822 L .49428 .82665 L F
.47052 .84299 m .47909 .83822 L .47435 .84035 L F
.47077 .84456 m .48692 .84265 L .49428 .82665 L F
.45498 .88948 m .48965 1.00684 L .4094 .90261 L .98 .844 .635 r
F
.54877 .86085 m .63927 .96839 L .45498 .88948 L .816 .672 .704 r
F
.45498 .88948 m .48965 1.00684 L .62792 .97131 L .718 .741 .869 r
F
.45498 .88948 m .62792 .97131 L .60854 .95524 L F
.44809 .94888 m .4094 .90261 L .42259 .89881 L .638 .113 0 r
F
.48965 1.00684 m .57184 1.19984 L .73395 1.11094 L .639 .517 .698 r
F
.63927 .96839 m .73395 1.11094 L .48965 1.00684 L .669 .479 .618 r
F
.5644 1.10767 m .45459 .9467 L .45131 .94218 L .602 .163 0 r
F
.45459 .9467 m .44468 .93217 L .44923 .93904 L F
.45459 .9467 m .44923 .93904 L .45131 .94218 L F
.44927 .93873 m .42259 .89881 L .45498 .88948 L .638 .113 0 r
F
.44923 .93904 m .44878 .93836 L .44927 .93873 L F
.44878 .93836 m .42259 .89881 L .44927 .93873 L F
.43815 .89508 m .45387 .88984 L .44927 .93873 L .878 .47 .03 r
F
.45387 .88984 m .45498 .88948 L .45484 .89066 L F
.45387 .88984 m .45484 .89066 L .44927 .93873 L F
.44654 .89248 m .45498 .88948 L .53707 .86442 L 0 0 0 r
F
.44654 .89248 m .53707 .86442 L .52143 .86931 L F
.44028 .89442 m .45387 .88984 L .44654 .89248 L F
.43815 .89508 m .43928 .8947 L .44028 .89442 L F
.43928 .8947 m .45387 .88984 L .44028 .89442 L F
.43815 .89508 m .44927 .93873 L .44907 .93839 L .878 .47 .03 r
F
.449 .94107 m .42259 .89881 L .44923 .93904 L .638 .113 0 r
F
.44809 .94888 m .44254 .93798 L .449 .94107 L F
.44254 .93798 m .42259 .89881 L .449 .94107 L F
.59149 1.08852 m .45814 .94546 L .5644 1.10767 L .648 .425 .566 r
F
.44522 .93331 m .44923 .93904 L .44809 .94888 L .878 .47 .03 r
F
.44446 .93215 m .4302 .91094 L .44092 .92698 L .602 .163 0 r
F
.45131 .94218 m .44163 .92786 L .44446 .93215 L F
.44163 .92786 m .4302 .91094 L .44446 .93215 L F
.43815 .89508 m .44907 .93839 L .4488 .93795 L .878 .47 .03 r
F
.44203 .91605 m .4488 .93795 L .44483 .93121 L F
.43815 .89508 m .4488 .93795 L .44203 .91605 L F
.44639 .90966 m .44695 .91878 L .44268 .9101 L .154 0 .282 r
F
.44695 .91878 m .44737 .92565 L .44681 .92381 L F
.44695 .91878 m .44681 .92381 L .44268 .9101 L F
.44701 .91625 m .45212 .90724 L .4461 .90665 L .506 .148 .294 r
F
.45212 .90724 m .4536 .90463 L .4503 .90552 L F
.45212 .90724 m .4503 .90552 L .4461 .90665 L F
.45387 .88984 m .45498 .88948 L .44654 .89248 L 0 0 0 r
F
.48079 .84924 m .50945 .87302 L .43815 .89508 L .911 .673 .566 r
F
.48692 .84265 m .50945 .87302 L .48079 .84924 L F
.464 .87113 m .44098 .89246 L .47321 .85752 L 0 0 0 r
F
.44098 .89246 m .44042 .89264 L .48692 .84265 L F
.52143 .86931 m .53707 .86442 L .54877 .86085 L F
.48692 .84265 m .54877 .86085 L .50945 .87302 L .911 .673 .566 r
F
.48692 .84265 m .54877 .86085 L .6493 .80083 L .776 .863 .914 r
F
.44239 .89816 m .55173 .79359 L .53805 .79797 L .648 .316 .396 r
F
.44289 .89868 m .55173 .79359 L .44239 .89816 L F
.43971 .8955 m .43815 .89508 L .44384 .89965 L 0 .06 .599 r
F
.43971 .8955 m .44384 .89965 L .441 .89672 L F
.45191 .88336 m .43815 .89508 L .464 .87113 L 0 0 0 r
F
.44869 .88661 m .44369 .89063 L .45191 .88336 L F
.44369 .89063 m .43815 .89508 L .45191 .88336 L F
.46943 .86438 m .47321 .85752 L .48692 .84265 L F
.464 .87113 m .47321 .85752 L .46943 .86438 L F
.47077 .84456 m .48692 .84265 L .464 .87113 L .923 .598 .408 r
F
.44384 .89965 m .44268 .9101 L .43815 .89508 L .154 0 .282 r
F
.45814 .94546 m .44487 .93122 L .45131 .94218 L .648 .425 .566 r
F
.44487 .93122 m .44486 .93126 L .45131 .94218 L F
.44468 .93217 m .4302 .91094 L .45131 .94218 L .602 .163 0 r
F
.44483 .93121 m .44923 .93904 L .44644 .93506 L .878 .47 .03 r
F
.44477 .93111 m .44092 .92698 L .44446 .93215 L .648 .425 .566 r
F
.44484 .93129 m .44446 .93215 L .44644 .93506 L F
.44477 .93111 m .44446 .93215 L .44484 .93129 L F
.44484 .93129 m .44644 .93506 L .44522 .93331 L .878 .47 .03 r
F
.44483 .93121 m .44644 .93506 L .44484 .93129 L F
.44907 .93839 m .44923 .93904 L .44483 .93121 L F
.44648 .92764 m .44487 .93122 L .44203 .91605 L .154 0 .282 r
F
.44487 .93122 m .44484 .93129 L .44483 .93121 L F
.44487 .93122 m .44483 .93121 L .44203 .91605 L F
.45814 .94546 m .44487 .93122 L .48542 .96613 L .05 .273 .766 r
F
.44487 .93122 m .44477 .93111 L .44491 .93123 L F
.44487 .93122 m .44491 .93123 L .48542 .96613 L F
.44907 .93839 m .44927 .93873 L .44923 .93904 L .878 .47 .03 r
F
.44477 .93111 m .44644 .93506 L .45131 .94218 L .648 .425 .566 r
F
.45344 .94581 m .44522 .93331 L .44484 .93129 L .154 0 .282 r
F
.45814 .94546 m .45131 .94218 L .5644 1.10767 L .648 .425 .566 r
F
.44806 .93177 m .44487 .93122 L .44648 .92764 L .154 0 .282 r
F
.44477 .93111 m .44385 .92956 L .44595 .93141 L .05 .273 .766 r
F
.44491 .93123 m .44595 .93141 L .48542 .96613 L F
.44477 .93111 m .44595 .93141 L .44491 .93123 L F
.45344 .94581 m .44484 .93129 L .44487 .93122 L .154 0 .282 r
F
.44927 .93198 m .44203 .91605 L .44268 .9101 L F
.44806 .93177 m .44203 .91605 L .44927 .93198 L F
.48542 .96613 m .44595 .93141 L .45696 .9333 L .05 .273 .766 r
F
.45434 .92651 m .45344 .94581 L .44737 .92565 L .154 0 .282 r
F
.4536 .90463 m .46513 .8843 L .45729 .89174 L .506 .148 .294 r
F
.46513 .8843 m .48319 .85245 L .45729 .89174 L F
.45729 .89174 m .48319 .85245 L .46272 .87271 L F
.46452 .86748 m .46455 .86723 L .44464 .89233 L .648 .316 .396 r
F
.46452 .86748 m .44464 .89233 L .44463 .89239 L F
.44123 .89696 m .46452 .86748 L .4411 .89682 L F
.44869 .88661 m .46426 .86734 L .46481 .86541 L F
.44971 .88558 m .4646 .86693 L .44869 .88661 L F
.44469 .89187 m .44971 .88558 L .44869 .88661 L F
.47077 .84456 m .464 .87113 L .46481 .86541 L .923 .598 .408 r
F
.44464 .89233 m .46455 .86723 L .44469 .89187 L .648 .316 .396 r
F
.46455 .86723 m .4997 .82293 L .4646 .86693 L F
.46455 .86723 m .4646 .86693 L .44469 .89187 L F
.46272 .87271 m .4628 .87235 L .464 .87113 L 0 0 0 r
F
.46481 .86541 m .464 .87113 L .46272 .87271 L .923 .598 .408 r
F
.46481 .86541 m .4997 .82293 L .49428 .82665 L .648 .316 .396 r
F
.4646 .86693 m .4997 .82293 L .46481 .86541 L F
.50049 .82193 m .50816 .80841 L .49428 .82665 L .506 .148 .294 r
F
.46772 .84492 m .53422 .7992 L .53734 .79633 L .885 .968 .839 r
F
.49647 .82472 m .50816 .80841 L .47153 .84204 L .602 .252 .349 r
F
.46772 .84492 m .53734 .79633 L .47166 .84195 L .885 .968 .839 r
F
.50049 .82193 m .49428 .82665 L .44869 .88661 L .506 .148 .294 r
F
.45068 .88464 m .44869 .88661 L .45072 .88456 L 0 0 0 r
F
.46452 .86748 m .4997 .82293 L .46455 .86723 L .648 .316 .396 r
F
.50049 .82193 m .44869 .88661 L .45197 .88336 L .506 .148 .294 r
F
.44268 .9101 m .44203 .91605 L .43815 .89508 L .154 0 .282 r
F
.44463 .89239 m .44464 .89233 L .43748 .90135 L .648 .316 .396 r
F
.441 .89672 m .44384 .89965 L .44556 .90104 L 0 .06 .599 r
F
.4302 .91094 m .44289 .89868 L .44239 .89816 L .648 .316 .396 r
F
.4536 .90463 m .46405 .86807 L .44475 .8925 L .506 .148 .294 r
F
.44556 .90104 m .44268 .9101 L .44384 .89965 L .154 0 .282 r
F
.44639 .90966 m .44268 .9101 L .44556 .90104 L F
.4461 .90665 m .44475 .8925 L .4302 .91094 L .506 .148 .294 r
F
.4536 .90463 m .44475 .8925 L .4461 .90665 L F
.44912 .90424 m .47739 .85834 L .45886 .87721 L .602 .252 .349 r
F
.46272 .87271 m .50049 .82193 L .46405 .86807 L .506 .148 .294 r
F
.48319 .85245 m .50049 .82193 L .46272 .87271 L F
.44993 .90505 m .49967 .8225 L .44912 .90424 L .602 .252 .349 r
F
.49967 .8225 m .50816 .80841 L .49933 .82273 L F
.49967 .8225 m .49933 .82273 L .44912 .90424 L F
.46748 .84494 m .46772 .84492 L .47166 .84195 L .885 .968 .839 r
F
.46296 .87148 m .46272 .87271 L .46251 .87299 L .923 .598 .408 r
F
.46296 .87148 m .46251 .87299 L .46023 .87581 L F
.46658 .85292 m .46296 .87148 L .46023 .87581 L F
.46658 .85292 m .46023 .87581 L .46176 .86916 L F
.46596 .85417 m .46176 .86916 L .46457 .85692 L F
.46658 .85292 m .46176 .86916 L .46596 .85417 L F
.46481 .86541 m .46272 .87271 L .46658 .85292 L F
.47739 .85834 m .49933 .82273 L .4604 .87505 L .602 .252 .349 r
F
.49933 .82273 m .50816 .80841 L .49647 .82472 L F
.49933 .82273 m .49647 .82472 L .4604 .87505 L F
.47153 .84204 m .50816 .80841 L .47288 .83829 L F
.44701 .91625 m .45212 .90724 L .44719 .9096 L F
.49746 .82727 m .50816 .80841 L .49643 .82787 L F
.47237 .84125 m .47288 .83829 L .47153 .84204 L .322 0 .233 r
F
.47078 .84112 m .47238 .84124 L .46899 .84381 L .796 .591 .624 r
F
.47238 .84124 m .47239 .84124 L .47237 .84125 L F
.47238 .84124 m .47237 .84125 L .46899 .84381 L F
.47238 .84124 m .47238 .84124 L .47237 .84125 L .322 0 .233 r
F
.47238 .84124 m .47288 .83829 L .47237 .84125 L F
.47238 .84124 m .47288 .83829 L .46946 .84093 L .736 .35 .32 r
F
.46557 .84011 m .46748 .84494 L .46918 .84244 L .765 .548 .603 r
F
.46946 .84093 m .46918 .84244 L .47011 .84107 L F
.46557 .84011 m .46918 .84244 L .46946 .84093 L F
.47191 .83904 m .48527 .77239 L .47288 .83829 L .948 .743 .592 r
F
.47451 .81902 m .48527 .77239 L .47191 .83904 L F
.47979 .78445 m .48527 .77239 L .46946 .84093 L F
.47622 .82929 m .48549 .79306 L .48527 .77239 L .532 .326 .546 r
F
.48549 .79306 m .49536 .75449 L .49174 .76091 L F
.48549 .79306 m .49174 .76091 L .48527 .77239 L F
.46946 .84093 m .47451 .81902 L .47191 .83904 L .948 .743 .592 r
F
.51528 .77705 m .51538 .77664 L .51514 .77313 L .41 .291 .606 r
F
.51528 .77705 m .51514 .77313 L .51494 .77131 L F
.51494 .77131 m .51522 .77383 L .51979 .76773 L .765 .548 .603 r
F
.51514 .77313 m .5146 .75828 L .51423 .75964 L .41 .291 .606 r
F
.51538 .77664 m .51528 .77438 L .51514 .77313 L F
.51522 .77383 m .51528 .77438 L .51979 .76773 L .765 .548 .603 r
F
.51528 .77438 m .5146 .75828 L .51514 .77313 L .41 .291 .606 r
F
.48527 .77239 m .49574 .75213 L .49536 .75449 L .597 .402 .587 r
F
.49574 .75213 m .48965 .78998 L .47708 .79927 L .778 .572 .62 r
F
.51494 .77131 m .51514 .77313 L .51423 .75964 L .41 .291 .606 r
F
.51979 .76773 m .51917 .77579 L .51528 .77438 L .796 .591 .624 r
F
.51917 .77579 m .51538 .77664 L .51528 .77438 L F
.53376 .73156 m .5268 .76167 L .51979 .76773 L .683 .556 .704 r
F
.52399 .77359 m .54382 .68823 L .55671 .76059 L .819 .694 .727 r
F
.54382 .68823 m .5488 .67195 L .55671 .76059 L F
.55263 .68268 m .56557 .72812 L .5268 .76167 L .683 .556 .704 r
F
.55263 .68268 m .5268 .76167 L .53376 .73156 L F
.51754 .77616 m .54809 .66954 L .52399 .77359 L .819 .694 .727 r
F
.54809 .66954 m .54847 .66822 L .53376 .73156 L F
.54809 .66954 m .53376 .73156 L .52399 .77359 L F
.51528 .77705 m .51541 .77663 L .51754 .77616 L F
.51541 .77663 m .54847 .66822 L .51754 .77616 L F
.50816 .80841 m .51528 .77705 L .51423 .75964 L .41 .291 .606 r
F
.50179 .74263 m .51412 .75983 L .51515 .72649 L .682 .555 .703 r
F
.50179 .74263 m .51412 .75983 L .49771 .78404 L .778 .572 .62 r
F
.51412 .75983 m .51423 .75964 L .5141 .76068 L .894 .733 .676 r
F
.51412 .75983 m .51318 .76156 L .49771 .78404 L .778 .572 .62 r
F
.50568 .73239 m .51518 .72529 L .50179 .74263 L .657 .519 .684 r
F
.51423 .72476 m .52039 .71011 L .51 .72853 L .532 .326 .546 r
F
.51532 .72378 m .51518 .72529 L .50568 .73239 L .657 .519 .684 r
F
.51518 .72529 m .52039 .71011 L .51423 .75964 L .894 .733 .676 r
F
.51518 .72529 m .51423 .75964 L .51412 .75983 L F
.51532 .72378 m .52039 .71011 L .51423 .72476 L .532 .326 .546 r
F
.51738 .70163 m .51532 .72378 L .50568 .73239 L .657 .519 .684 r
F
.50944 .72953 m .4956 .73682 L .51 .72853 L .597 .402 .587 r
F
.50179 .74263 m .51704 .7242 L .51483 .72575 L .682 .555 .703 r
F
.50179 .74263 m .49771 .78404 L .49044 .78693 L .778 .572 .62 r
F
.459 .76318 m .48048 .75952 L .50179 .74263 L .465 .19 .411 r
F
.4581 .77725 m .49569 .75217 L .50179 .74263 L F
.45571 .81469 m .4559 .81473 L .46731 .79681 L F
.45569 .81507 m .46557 .84011 L .47137 .83237 L .765 .548 .603 r
F
.47288 .83829 m .4809 .81664 L .50816 .80841 L .894 .733 .676 r
F
.47622 .82929 m .4809 .81664 L .48549 .79306 L .532 .326 .546 r
F
.47865 .82036 m .47137 .83237 L .48012 .82069 L .765 .548 .603 r
F
.45569 .81507 m .47137 .83237 L .47865 .82036 L F
.52162 .73222 m .52914 .68677 L .52039 .71011 L .41 .291 .606 r
F
.51483 .72575 m .52422 .71553 L .51865 .72081 L .682 .555 .703 r
F
.51704 .7242 m .52422 .71553 L .51483 .72575 L F
.48355 .81584 m .51172 .7658 L .50816 .80841 L .894 .733 .676 r
F
.4809 .81664 m .50307 .78007 L .48355 .81584 L F
.50307 .78007 m .51172 .7658 L .48355 .81584 L F
.51318 .76156 m .50307 .78007 L .49771 .78404 L .778 .572 .62 r
F
.51522 .72405 m .5141 .76068 L .51391 .7622 L .894 .733 .676 r
F
.51172 .7658 m .51391 .7622 L .50816 .80841 L F
.51522 .72405 m .51391 .7622 L .51172 .7658 L F
.50147 .78273 m .48012 .82069 L .51522 .77383 L .765 .548 .603 r
F
.48549 .79306 m .4809 .81664 L .50147 .78273 L F
.4809 .81664 m .48012 .82069 L .50147 .78273 L F
.48549 .79306 m .51522 .77383 L .51494 .77131 L F
.49044 .78693 m .49771 .78404 L .48965 .78998 L .778 .572 .62 r
F
.4809 .81664 m .51522 .72405 L .51172 .7658 L .894 .733 .676 r
F
.51425 .76 m .51494 .77131 L .50307 .78007 L .778 .572 .62 r
F
.51425 .76 m .50307 .78007 L .51318 .76156 L F
.45569 .81507 m .48012 .82069 L .48549 .79306 L .765 .548 .603 r
F
.46731 .79681 m .48527 .77239 L .4694 .78615 L .627 .337 .458 r
F
.46731 .79681 m .47708 .79927 L .45569 .81507 L .778 .572 .62 r
F
.4787 .78687 m .47708 .79927 L .46731 .79681 L F
.46205 .82355 m .4787 .78687 L .46731 .79681 L .627 .337 .458 r
F
.4787 .78687 m .48527 .77239 L .46731 .79681 L F
.48 .77687 m .4787 .78687 L .46731 .79681 L .778 .572 .62 r
F
.46738 .79644 m .46731 .79681 L .50179 .74263 L .465 .19 .411 r
F
.45571 .81469 m .46731 .79681 L .46738 .79644 L F
.3959 .80959 m .39944 .82258 L .43887 .81731 L .456 0 .038 r
F
.3959 .80959 m .43887 .81731 L .44154 .81377 L F
.42616 .83605 m .43879 .84635 L .40922 .84781 L .878 .593 .501 r
F
.40449 .85109 m .40688 .84837 L .40059 .84819 L .606 .171 .188 r
F
.3174 .81737 m .33956 .81792 L .3959 .80959 L .171 .708 .791 r
F
.35797 .81335 m .39108 .84056 L .3174 .81737 L .502 .011 .023 r
F
.40557 .84512 m .40082 .84605 L .3174 .81737 L F
.3959 .80959 m .40557 .84512 L .39108 .84056 L F
.3959 .80959 m .39108 .84056 L .35797 .81335 L F
.40688 .84837 m .4106 .84413 L .40513 .84539 L .606 .171 .188 r
F
.4106 .84413 m .40557 .84512 L .40513 .84539 L F
.40688 .84837 m .40681 .84825 L .40059 .84819 L F
.40681 .84825 m .40513 .84539 L .40285 .8468 L F
.40681 .84825 m .40285 .8468 L .40059 .84819 L F
.39556 .84425 m .39534 .84404 L .40082 .84605 L 0 .405 .757 r
F
.39944 .82258 m .40557 .84512 L .42864 .83088 L .456 0 .038 r
F
.39944 .82258 m .42864 .83088 L .4373 .81939 L F
.45384 .81531 m .45091 .81825 L .45569 .81507 L F
.39944 .82258 m .4488 .81843 L .45384 .81531 L F
.4488 .81843 m .45091 .81825 L .45384 .81531 L F
.43756 .90161 m .44123 .89696 L .43748 .90135 L .648 .316 .396 r
F
.44123 .89696 m .4411 .89682 L .43748 .90135 L F
.441 .89672 m .44464 .89233 L .44469 .89187 L F
.43748 .90135 m .44109 .89681 L .441 .89672 L F
.44109 .89681 m .44464 .89233 L .441 .89672 L F
.4302 .91094 m .43756 .90161 L .43748 .90135 L F
.45197 .88336 m .44869 .88661 L .4302 .91094 L .506 .148 .294 r
F
.45027 .88546 m .43986 .89554 L .44869 .88661 L 0 0 0 r
F
.45212 .90724 m .49746 .82727 L .44993 .90505 L .602 .252 .349 r
F
.49746 .82727 m .49643 .82787 L .44993 .90505 L F
.45212 .90724 m .44993 .90505 L .44719 .9096 L F
.44719 .9096 m .44993 .90505 L .44912 .90424 L F
.4543 .89581 m .45935 .87678 L .44725 .90975 L .322 0 .233 r
F
.45972 .87645 m .45935 .87678 L .4543 .89581 L F
.47077 .84456 m .46481 .86541 L .46658 .85292 L .923 .598 .408 r
F
.44063 .89576 m .43986 .89554 L .46023 .87581 L 0 0 0 r
F
.46687 .85091 m .47077 .84456 L .46658 .85292 L .923 .598 .408 r
F
.46772 .84492 m .46857 .84482 L .46687 .85091 L F
.46857 .84482 m .47077 .84456 L .46687 .85091 L F
.46857 .84482 m .47077 .84456 L .47052 .84299 L .885 .968 .839 r
F
.45886 .87721 m .49647 .82472 L .47153 .84204 L .602 .252 .349 r
F
.46899 .84381 m .55989 .77562 L .56021 .77492 L .885 .968 .839 r
F
.46912 .84372 m .55989 .77562 L .46899 .84381 L F
.46912 .84372 m .47166 .84195 L .55989 .77562 L F
.47166 .84195 m .53734 .79633 L .55989 .77562 L F
.47238 .84124 m .47153 .84204 L .46176 .86916 L .322 0 .233 r
F
.46139 .87048 m .46176 .86916 L .45886 .87721 L F
.46176 .86916 m .46023 .87581 L .45972 .87645 L .923 .598 .408 r
F
.47238 .84124 m .46176 .86916 L .46139 .87048 L .322 0 .233 r
F
.44781 .92466 m .44737 .92565 L .44639 .90966 L .154 0 .282 r
F
.44092 .92698 m .44701 .91625 L .4302 .91094 L .506 .148 .294 r
F
.44701 .91625 m .4461 .90665 L .4302 .91094 L F
.44717 .90956 m .44781 .92466 L .44639 .90966 L .154 0 .282 r
F
.45935 .87678 m .45886 .87721 L .44719 .9096 L .322 0 .233 r
F
.45935 .87678 m .44719 .9096 L .44725 .90975 L F
.46763 .86945 m .44725 .90975 L .44805 .91164 L F
.45697 .93274 m .46763 .86945 L .44805 .91164 L F
.455 .90862 m .45077 .91807 L .44912 .90933 L .154 0 .282 r
F
.44912 .90933 m .45077 .91807 L .44717 .90956 L F
.45077 .91807 m .44781 .92466 L .44717 .90956 L F
.44092 .92698 m .44701 .91625 L .44718 .90994 L .602 .252 .349 r
F
.44725 .90975 m .44719 .9096 L .44092 .92698 L .322 0 .233 r
F
.46023 .87581 m .4604 .87505 L .45886 .87721 L .602 .252 .349 r
F
.47238 .84124 m .45886 .87721 L .45935 .87678 L .322 0 .233 r
F
.44665 .89268 m .4523 .88388 L .45886 .87721 L 0 0 0 r
F
.45972 .87645 m .45886 .87721 L .46023 .87581 L F
.44665 .89268 m .45886 .87721 L .45972 .87645 L F
.44353 .89655 m .4523 .88388 L .44665 .89268 L F
.44353 .89655 m .44114 .89524 L .4523 .88388 L F
.43986 .89554 m .43971 .8955 L .44869 .88661 L F
.43971 .8955 m .43815 .89508 L .44869 .88661 L F
.44098 .89246 m .43815 .89508 L .44042 .89264 L F
.41313 .85649 m .44353 .89655 L .41657 .85859 L .834 .47 .366 r
F
.41657 .85859 m .44353 .89655 L .44664 .88986 L F
.40762 .84962 m .44353 .89655 L .40777 .84944 L F
.39465 .84379 m .43631 .81484 L .37377 .82832 L .606 .171 .188 r
F
.3174 .81737 m .33286 .82116 L .39556 .84425 L 0 .405 .757 r
F
.33286 .82116 m .35498 .82658 L .39465 .84379 L F
.32603 .81514 m .3174 .81737 L .32939 .81618 L .363 0 0 r
F
.37377 .82832 m .3959 .80959 L .3174 .81737 L .399 0 0 r
F
.30469 .81002 m .3174 .81737 L .37377 .82832 L 0 .509 .79 r
F
.37195 .83255 m .37377 .82832 L .31774 .81348 L .333 0 0 r
F
.35498 .82658 m .36471 .82896 L .37195 .83255 L 0 .405 .757 r
F
.35498 .82658 m .37195 .83255 L .39465 .84379 L F
.37117 .83436 m .37195 .83255 L .30469 .81002 L .333 0 0 r
F
.37195 .83255 m .31774 .81348 L .30469 .81002 L F
.33286 .82116 m .39465 .84379 L .39556 .84425 L 0 .405 .757 r
F
.4023 .84659 m .43631 .81484 L .39465 .84379 L .606 .171 .188 r
F
.38517 .8391 m .37377 .82832 L .39465 .84379 L .51 0 0 r
F
.37195 .83255 m .37348 .82899 L .38517 .8391 L F
.37348 .82899 m .37377 .82832 L .38517 .8391 L F
.46763 .86945 m .45972 .87645 L .4543 .89581 L .322 0 .233 r
F
.4607 .86464 m .46176 .86916 L .44886 .88923 L .923 .598 .408 r
F
.4607 .86464 m .44886 .88923 L .44884 .88831 L F
.46457 .85692 m .46281 .86458 L .4607 .86464 L F
.46281 .86458 m .46176 .86916 L .4607 .86464 L F
.45972 .87645 m .46053 .87355 L .45935 .87678 L .322 0 .233 r
F
.46176 .86916 m .45972 .87645 L .44665 .89268 L .923 .598 .408 r
F
.45767 .84543 m .4561 .85176 L .46748 .84494 L .834 .47 .366 r
F
.45329 .86307 m .44664 .88986 L .45831 .86472 L F
.4561 .85176 m .45329 .86307 L .46664 .84677 L F
.45329 .86307 m .45831 .86472 L .46664 .84677 L F
.4561 .85176 m .46664 .84677 L .46748 .84494 L F
.44396 .87501 m .44664 .88986 L .4485 .88237 L F
.44723 .86795 m .4485 .88237 L .45767 .84543 L F
.44396 .87501 m .4485 .88237 L .44723 .86795 L F
.44723 .86795 m .4538 .85378 L .44592 .85909 L .736 .35 .32 r
F
.45027 .88546 m .44869 .88661 L .45068 .88464 L 0 0 0 r
F
.46748 .84494 m .46772 .84492 L .45899 .8647 L .923 .598 .408 r
F
.45886 .8647 m .45899 .8647 L .44665 .89268 L F
.46748 .84494 m .45899 .8647 L .45886 .8647 L F
.46772 .84492 m .46658 .85292 L .4607 .86464 L F
.45899 .8647 m .4607 .86464 L .44665 .89268 L F
.46772 .84492 m .4607 .86464 L .45899 .8647 L F
.44661 .86089 m .44592 .85909 L .44723 .86795 L 0 0 .307 r
F
.44661 .86089 m .44592 .85909 L .44612 .86073 L .72 .21 .01 r
F
.44592 .85909 m .44737 .85589 L .45435 .85259 L .948 .743 .592 r
F
.43907 .8479 m .4373 .81939 L .44592 .85909 L .886 .511 .323 r
F
.43457 .82301 m .4373 .81939 L .43907 .8479 L F
.40777 .84944 m .41313 .85649 L .41657 .85859 L .834 .47 .366 r
F
.40922 .84781 m .41149 .84523 L .40716 .84885 L .606 .171 .188 r
F
.40732 .84912 m .40716 .84885 L .40449 .85109 L F
.40922 .84781 m .40716 .84885 L .40732 .84912 L F
.40999 .8561 m .40285 .85023 L .41144 .85635 L .51 0 0 r
F
.41295 .85803 m .44353 .89655 L .41665 .86497 L .713 .229 0 r
F
.41202 .85628 m .41388 .85866 L .41295 .85803 L F
.41388 .85866 m .44353 .89655 L .41295 .85803 L F
.41266 .85621 m .44353 .89655 L .41202 .85628 L F
.37117 .83436 m .39835 .84654 L .40999 .8561 L .51 0 0 r
F
.39547 .84622 m .39583 .84646 L .37117 .83436 L 0 .301 .696 r
F
.39583 .84646 m .4106 .85644 L .39535 .8479 L F
.39583 .84646 m .39535 .8479 L .37117 .83436 L F
.39214 .84255 m .38485 .83493 L .39556 .84425 L 0 .405 .757 r
F
.38485 .83493 m .38522 .83505 L .39556 .84425 L F
.40922 .84781 m .44108 .85908 L .43879 .84635 L .834 .47 .366 r
F
.41149 .84523 m .41466 .83951 L .40449 .85109 L .606 .171 .188 r
F
.40864 .84846 m .44108 .85908 L .40922 .84781 L .834 .47 .366 r
F
.41041 .85327 m .41266 .85621 L .41202 .85628 L .713 .229 0 r
F
.41041 .85327 m .41202 .85628 L .40914 .8522 L F
.41202 .85628 m .41665 .86497 L .41157 .85633 L F
.41202 .85628 m .41157 .85633 L .40914 .8522 L F
.40285 .85023 m .4056 .85191 L .41157 .85633 L .51 0 0 r
F
.40848 .84864 m .44664 .88986 L .44108 .85908 L .834 .47 .366 r
F
.40767 .84956 m .40922 .84781 L .40732 .84912 L .606 .171 .188 r
F
.40634 .84795 m .40777 .84944 L .40848 .84864 L .834 .47 .366 r
F
.40777 .84944 m .44664 .88986 L .40848 .84864 L F
.40634 .84795 m .44108 .85908 L .40697 .84792 L F
.41518 .859 m .42616 .83605 L .40922 .84781 L .606 .171 .188 r
F
.41518 .859 m .40922 .84781 L .40767 .84956 L F
.41157 .85633 m .40732 .84912 L .40449 .85109 L F
.40762 .84962 m .41041 .85327 L .40914 .8522 L .713 .229 0 r
F
.41518 .859 m .40732 .84912 L .41157 .85633 L .606 .171 .188 r
F
.40059 .84819 m .4023 .84659 L .39465 .84379 L F
.38293 .831 m .38082 .83161 L .38667 .83554 L .266 .432 .841 r
F
.38082 .83161 m .37767 .83251 L .38386 .83459 L F
.38082 .83161 m .38386 .83459 L .38667 .83554 L F
.39656 .84297 m .38356 .83358 L .39734 .84227 L 0 .405 .757 r
F
.41466 .83951 m .43631 .81484 L .40059 .84819 L .606 .171 .188 r
F
.39656 .84297 m .39734 .84227 L .40634 .84795 L 0 .405 .757 r
F
.40082 .84605 m .39656 .84297 L .40634 .84795 L F
.40285 .85023 m .41157 .85633 L .41144 .85635 L .51 0 0 r
F
.40285 .85023 m .39835 .84654 L .4056 .85191 L F
.39534 .84404 m .38356 .83358 L .40082 .84605 L 0 .405 .757 r
F
.37117 .83436 m .37195 .83255 L .39835 .84654 L .51 0 0 r
F
.37195 .83255 m .39465 .84379 L .39835 .84654 L F
.39734 .84227 m .44159 .89426 L .39439 .8449 L .713 .229 0 r
F
.40914 .8522 m .41157 .85633 L .39734 .84227 L F
.40999 .8561 m .41144 .85635 L .4106 .85644 L .51 0 0 r
F
.41157 .85633 m .40951 .85657 L .39734 .84227 L .713 .229 0 r
F
.40697 .84792 m .40864 .84846 L .40922 .84781 L .834 .47 .366 r
F
.39734 .84227 m .39439 .8449 L .38667 .83554 L .713 .229 0 r
F
.44108 .85908 m .44396 .87501 L .44999 .86199 L .834 .47 .366 r
F
.44665 .86506 m .44612 .86073 L .42133 .86582 L .72 .21 .01 r
F
.44612 .86073 m .44592 .85909 L .44331 .85981 L F
.44612 .86073 m .44331 .85981 L .42133 .86582 L F
.42571 .85904 m .44193 .85445 L .44592 .85909 L .886 .511 .323 r
F
.41518 .859 m .44193 .85445 L .42571 .85904 L F
.41518 .859 m .42616 .83605 L .44193 .85445 L F
.42616 .83605 m .43745 .84526 L .44592 .85909 L F
.44592 .85909 m .44737 .85589 L .4462 .85086 L .627 .337 .458 r
F
.44507 .84605 m .44698 .85422 L .45767 .84543 L .834 .47 .366 r
F
.45569 .81507 m .46748 .84494 L .44507 .84605 L .878 .593 .501 r
F
.44409 .85069 m .44497 .84652 L .4373 .81939 L .627 .337 .458 r
F
.45569 .81507 m .44507 .84605 L .44897 .82751 L .878 .593 .501 r
F
.44507 .84605 m .44728 .81855 L .43881 .81927 L .627 .337 .458 r
F
.4462 .85086 m .4466 .83875 L .44507 .84605 L F
.4466 .83875 m .44728 .81855 L .44507 .84605 L F
.4462 .85086 m .43881 .81927 L .4373 .81939 L F
.45569 .81507 m .44897 .82751 L .45091 .81825 L .878 .593 .501 r
F
.4462 .85086 m .46205 .82355 L .44728 .81855 L .627 .337 .458 r
F
.42616 .83605 m .42864 .83088 L .41149 .84523 L .606 .171 .188 r
F
.42864 .83088 m .43457 .82301 L .43907 .8479 L .886 .511 .323 r
F
.42616 .83605 m .42864 .83088 L .43745 .84526 L F
.44154 .81377 m .43887 .81731 L .45569 .81507 L .456 0 .038 r
F
.4581 .77725 m .45571 .81469 L .46738 .79644 L .465 .19 .411 r
F
.47312 .76723 m .46738 .79644 L .49569 .75217 L F
.4581 .77725 m .46738 .79644 L .47312 .76723 L F
.45571 .81469 m .45569 .81507 L .4559 .81473 L F
.3959 .80959 m .42172 .7912 L .42297 .78968 L .459 .838 .606 r
F
.44563 .77417 m .43606 .78099 L .4423 .78045 L .91 .978 .78 r
F
.42297 .78968 m .42172 .7912 L .459 .76318 L .459 .838 .606 r
F
.42172 .7912 m .43119 .78446 L .459 .76318 L F
.459 .76318 m .45571 .81469 L .3959 .80959 L .546 .256 .425 r
F
.45571 .81469 m .45569 .81507 L .3959 .80959 L F
.46205 .82355 m .4694 .78615 L .43631 .81484 L .627 .337 .458 r
F
.45091 .81825 m .43879 .84635 L .42528 .83533 L .878 .593 .501 r
F
.44897 .82751 m .43879 .84635 L .45091 .81825 L F
.44897 .82751 m .44507 .84605 L .43879 .84635 L F
.44592 .85909 m .4462 .85086 L .44497 .84652 L .627 .337 .458 r
F
.44592 .85909 m .44497 .84652 L .44409 .85069 L F
.47011 .84107 m .46899 .84381 L .46778 .84451 L .796 .591 .624 r
F
.47238 .84124 m .46946 .84093 L .47011 .84107 L .736 .35 .32 r
F
.51528 .77438 m .47078 .84112 L .47011 .84107 L .796 .591 .624 r
F
.47078 .84112 m .46899 .84381 L .47011 .84107 L F
.47238 .84124 m .4644 .84484 L .44592 .85909 L .736 .35 .32 r
F
.44698 .85422 m .44999 .86199 L .45767 .84543 L .834 .47 .366 r
F
.44331 .85981 m .44592 .85909 L .44108 .85908 L .72 .21 .01 r
F
.44108 .85908 m .4487 .86157 L .44698 .85422 L .834 .47 .366 r
F
.4487 .86157 m .44999 .86199 L .44698 .85422 L F
.43879 .84635 m .44108 .85908 L .44698 .85422 L F
.43879 .84635 m .44698 .85422 L .44507 .84605 L F
.44737 .85589 m .46205 .82355 L .4462 .85086 L .627 .337 .458 r
F
.42133 .86582 m .44331 .85981 L .41518 .859 L .72 .21 .01 r
F
.44331 .85981 m .44108 .85908 L .41518 .859 L F
.44661 .86089 m .44612 .86073 L .44665 .86506 L F
.46748 .84494 m .44665 .89268 L .44511 .89317 L .923 .598 .408 r
F
.45274 .90517 m .45357 .86455 L .44723 .86795 L .736 .35 .32 r
F
.45357 .86455 m .44999 .86199 L .44723 .86795 L F
.44661 .86089 m .44723 .86795 L .44852 .87664 L 0 0 .307 r
F
.44706 .86505 m .44665 .86506 L .45071 .89837 L .72 .21 .01 r
F
.44661 .86089 m .44665 .86506 L .44706 .86505 L F
.45357 .86455 m .4538 .85378 L .44999 .86199 L .736 .35 .32 r
F
.46778 .84451 m .46899 .84381 L .46748 .84494 L .796 .591 .624 r
F
.46748 .84494 m .46912 .84372 L .46899 .84381 L .885 .968 .839 r
F
.46748 .84494 m .47166 .84195 L .46912 .84372 L F
.46772 .84492 m .46857 .84482 L .47052 .84299 L F
.45357 .86455 m .47238 .84124 L .4538 .85378 L .736 .35 .32 r
F
.47739 .85834 m .4604 .87505 L .46023 .87581 L .602 .252 .349 r
F
.46763 .86945 m .47238 .84124 L .46053 .87355 L .322 0 .233 r
F
.46763 .86945 m .46053 .87355 L .45972 .87645 L F
.45274 .90517 m .46313 .87136 L .45357 .86455 L .736 .35 .32 r
F
.46313 .87136 m .47238 .84124 L .45357 .86455 L F
.45678 .88736 m .4482 .86502 L .45041 .88942 L 0 0 .307 r
F
.4482 .86502 m .44852 .87664 L .45041 .88942 L F
.46038 .91248 m .47238 .84124 L .45274 .90517 L .736 .35 .32 r
F
.45761 .88952 m .45071 .89147 L .45274 .90517 L 0 0 .307 r
F
.45761 .88952 m .45678 .88736 L .45071 .89147 L F
.45678 .88736 m .45041 .88942 L .45071 .89147 L F
.45678 .88736 m .4482 .86502 L .45071 .89837 L .72 .21 .01 r
F
.4482 .86502 m .44661 .86089 L .44852 .87664 L 0 0 .307 r
F
.4482 .86502 m .44661 .86089 L .44706 .86505 L .72 .21 .01 r
F
.4482 .86502 m .44706 .86505 L .45071 .89837 L F
.44884 .88831 m .44886 .88923 L .44665 .89268 L .923 .598 .408 r
F
.44511 .89317 m .44665 .89268 L .44353 .89655 L F
.45071 .89837 m .44665 .86506 L .42133 .86582 L .72 .21 .01 r
F
.40634 .84795 m .40762 .84962 L .40777 .84944 L .834 .47 .366 r
F
.42616 .83605 m .41149 .84523 L .40922 .84781 L .606 .171 .188 r
F
.40557 .84512 m .40634 .84795 L .40274 .84568 L .502 .011 .023 r
F
.4106 .84413 m .41466 .83951 L .40557 .84512 L .606 .171 .188 r
F
.40634 .84795 m .40762 .84962 L .39734 .84227 L .713 .229 0 r
F
.40762 .84962 m .40914 .8522 L .39734 .84227 L F
.42864 .83088 m .41877 .83697 L .41149 .84523 L .606 .171 .188 r
F
.41877 .83697 m .41466 .83951 L .41149 .84523 L F
.4488 .81843 m .40634 .84795 L .45091 .81825 L .456 0 .038 r
F
.40557 .84512 m .40634 .84795 L .4488 .81843 L F
.42528 .83533 m .42616 .83605 L .40634 .84795 L .878 .593 .501 r
F
.42616 .83605 m .40922 .84781 L .40634 .84795 L F
.4471 .85591 m .39014 .83975 L .46129 .87833 L .266 .432 .841 r
F
.36471 .82896 m .37365 .83115 L .39214 .84255 L 0 .405 .757 r
F
.36946 .80734 m .32603 .81514 L .3452 .81462 L .363 0 0 r
F
.35953 .80649 m .32603 .81514 L .36946 .80734 L F
.37377 .82832 m .3959 .80959 L .43631 .81484 L .356 0 0 r
F
.42392 .8193 m .37767 .83251 L .31362 .78986 L .287 .546 .921 r
F
.37365 .83115 m .37463 .83139 L .37767 .83251 L 0 .405 .757 r
F
.37365 .83115 m .38485 .83493 L .39214 .84255 L F
.37767 .83251 m .37117 .83436 L .36074 .8263 L .287 .546 .921 r
F
.37767 .83251 m .36074 .8263 L .31362 .78986 L F
.37767 .83251 m .38356 .83358 L .38485 .83493 L 0 .405 .757 r
F
.37463 .83139 m .38356 .83358 L .37767 .83251 L F
.39014 .83975 m .37117 .83436 L .39547 .84622 L .266 .432 .841 r
F
.44159 .89426 m .44141 .89433 L .39466 .84524 L .713 .229 0 r
F
.44159 .89426 m .39466 .84524 L .39439 .8449 L F
.39466 .84524 m .39585 .8464 L .39583 .84646 L 0 .056 .566 r
F
.39014 .83975 m .39466 .84524 L .46129 .87833 L .266 .432 .841 r
F
.39466 .84524 m .39547 .84622 L .39585 .8464 L F
.39466 .84524 m .39585 .8464 L .46129 .87833 L F
.37767 .83251 m .37117 .83436 L .4471 .85591 L F
.39439 .8449 m .39466 .84524 L .38356 .83358 L .713 .229 0 r
F
.38485 .83493 m .38356 .83358 L .38522 .83505 L 0 .405 .757 r
F
.38667 .83554 m .39439 .8449 L .38356 .83358 L .713 .229 0 r
F
.38356 .83358 m .39603 .84585 L .39585 .8464 L 0 .056 .566 r
F
.38356 .83358 m .39585 .8464 L .39466 .84524 L F
.41157 .85633 m .41665 .86497 L .40951 .85657 L .713 .229 0 r
F
.41144 .85635 m .41157 .85633 L .41518 .859 L .51 0 0 r
F
.42864 .83088 m .43631 .81484 L .41466 .83951 L .606 .171 .188 r
F
.4373 .81939 m .42864 .83088 L .4488 .81843 L .456 0 .038 r
F
.42864 .83088 m .43631 .81484 L .4373 .81939 L .886 .511 .323 r
F
.42392 .8193 m .38293 .831 L .4471 .85591 L .266 .432 .841 r
F
.38293 .831 m .38667 .83554 L .4471 .85591 L F
.39583 .84646 m .41817 .86764 L .40585 .85699 L 0 .056 .566 r
F
.4106 .85644 m .41144 .85635 L .41308 .85751 L .51 0 0 r
F
.4106 .85644 m .41308 .85751 L .41518 .859 L F
.46129 .87833 m .4106 .85644 L .39547 .84622 L 0 .301 .696 r
F
.39603 .84585 m .41817 .86764 L .39583 .84646 L 0 .056 .566 r
F
.46129 .87833 m .41518 .859 L .4106 .85644 L 0 .301 .696 r
F
.46557 .84011 m .47011 .84107 L .47859 .82855 L .765 .548 .603 r
F
.46557 .84011 m .47859 .82855 L .48007 .82094 L F
.46557 .84011 m .51528 .77438 L .51522 .77383 L F
.45435 .85259 m .47979 .78445 L .46946 .84093 L .948 .743 .592 r
F
.44737 .85589 m .47979 .78445 L .45435 .85259 L F
.455 .90862 m .44717 .90956 L .44556 .90104 L .154 0 .282 r
F
.45285 .90596 m .46038 .91248 L .45274 .90517 L .736 .35 .32 r
F
.45729 .90876 m .45274 .90517 L .45285 .90596 L 0 0 .307 r
F
.44916 .9035 m .44737 .90249 L .45658 .9099 L 0 .06 .599 r
F
.46017 .9137 m .46038 .91248 L .45657 .90918 L .736 .35 .32 r
F
.45658 .9099 m .45657 .90918 L .45285 .90596 L F
.46017 .9137 m .45657 .90918 L .45658 .9099 L F
.45658 .9099 m .44737 .92565 L .455 .90862 L .154 0 .282 r
F
.45687 .92682 m .44737 .92565 L .45658 .9099 L F
.44353 .89865 m .45658 .9099 L .45447 .90767 L 0 .06 .599 r
F
.45687 .92682 m .45697 .93274 L .45434 .92651 L .154 0 .282 r
F
.46074 .94165 m .45344 .94581 L .45383 .93738 L F
.45712 .93309 m .45698 .93327 L .45434 .92651 L F
.45698 .93327 m .45399 .9341 L .45434 .92651 L F
.45447 .90767 m .45658 .9099 L .47832 .92739 L 0 .06 .599 r
F
.51892 .97525 m .47832 .92739 L .47844 .92736 L .318 .46 .846 r
F
.48441 .93327 m .47844 .92736 L .47935 .92711 L F
.51892 .97525 m .47844 .92736 L .48441 .93327 L F
.60854 .95524 m .62792 .97131 L .63927 .96839 L .718 .741 .869 r
F
.63382 .97409 m .46947 .91852 L .46129 .87833 L .47 .559 .865 r
F
.46836 .9175 m .47208 .92113 L .45845 .90968 L 0 .056 .566 r
F
.63382 .97409 m .46947 .91852 L .62105 1.04446 L .564 .499 .74 r
F
.46947 .91852 m .47214 .92114 L .62105 1.04446 L F
.46889 .91792 m .47068 .91969 L .4704 .91942 L 0 .056 .566 r
F
.46876 .91782 m .4704 .91942 L .46836 .9175 L F
.46947 .91852 m .46851 .91755 L .46129 .87833 L .47 .559 .865 r
F
.46889 .91792 m .4704 .91942 L .46876 .91782 L 0 .056 .566 r
F
.46947 .91852 m .46864 .91824 L .47214 .92114 L .564 .499 .74 r
F
.45761 .88952 m .45274 .90517 L .45729 .90876 L 0 0 .307 r
F
.47208 .92113 m .47633 .92541 L .45845 .90968 L 0 .056 .566 r
F
.45447 .90767 m .47832 .92739 L .47815 .92719 L 0 .06 .599 r
F
.45689 .93321 m .45697 .93274 L .44092 .92698 L .322 0 .233 r
F
.45697 .93274 m .44805 .91164 L .44092 .92698 L F
.45845 .90968 m .45272 .90587 L .47804 .92705 L 0 .06 .599 r
F
.45845 .90968 m .47804 .92705 L .47755 .92649 L F
.47208 .92113 m .47755 .92649 L .47633 .92541 L 0 .056 .566 r
F
.47068 .91969 m .47755 .92649 L .46836 .9175 L F
.51892 .97525 m .45698 .93327 L .47832 .92739 L .318 .46 .846 r
F
.62105 1.04446 m .45698 .93327 L .59149 1.08852 L .586 .451 .663 r
F
.45698 .93327 m .45696 .9333 L .59149 1.08852 L F
.48137 .92985 m .46074 .94165 L .45697 .93274 L .154 0 .282 r
F
.45697 .93274 m .46017 .9137 L .45658 .9099 L .736 .35 .32 r
F
.48137 .92985 m .45697 .93274 L .45687 .92682 L .154 0 .282 r
F
.48137 .92985 m .45687 .92682 L .45658 .9099 L F
.47935 .92711 m .47832 .92739 L .47508 .92357 L .318 .46 .846 r
F
.44063 .89576 m .44353 .89865 L .47815 .92719 L 0 .06 .599 r
F
.47804 .92705 m .47815 .92719 L .48137 .92985 L F
.44063 .89576 m .47815 .92719 L .47804 .92705 L F
.46074 .94165 m .45383 .93738 L .45698 .93327 L .154 0 .282 r
F
.45717 .93322 m .45698 .93327 L .45712 .93309 L F
.46074 .94165 m .45698 .93327 L .45717 .93322 L F
.45698 .93327 m .45689 .93321 L .47832 .92739 L .318 .46 .846 r
F
.47832 .92739 m .47832 .92739 L .47935 .92711 L F
.45698 .93327 m .47832 .92739 L .47832 .92739 L F
.47508 .92357 m .45689 .93321 L .46864 .91824 L F
.47832 .92739 m .45689 .93321 L .47508 .92357 L F
.47755 .92649 m .47804 .92705 L .48137 .92985 L 0 .06 .599 r
F
.46864 .91824 m .46772 .91584 L .45689 .93321 L 0 0 .307 r
F
.46772 .91584 m .45761 .88952 L .45729 .90891 L F
.45689 .93321 m .45697 .93274 L .4569 .93231 L .736 .35 .32 r
F
.45689 .93321 m .4569 .93231 L .45285 .90596 L F
.45697 .93274 m .45658 .9099 L .45285 .90596 L F
.46772 .91584 m .45729 .90891 L .45689 .93321 L 0 0 .307 r
F
.44353 .89655 m .44063 .89576 L .45272 .90587 L 0 .06 .599 r
F
.45729 .90876 m .45285 .90596 L .45729 .90891 L 0 0 .307 r
F
.44353 .89655 m .45272 .90587 L .45845 .90968 L 0 .06 .599 r
F
.46836 .9175 m .45678 .88736 L .4658 .91509 L .72 .21 .01 r
F
.46793 .91703 m .45845 .90968 L .44353 .89655 L 0 .056 .566 r
F
.46129 .87833 m .4658 .91509 L .46851 .91755 L 0 .142 .671 r
F
.47075 .91939 m .46911 .91809 L .46793 .91703 L 0 .056 .566 r
F
.46911 .91809 m .45845 .90968 L .46793 .91703 L F
.4658 .91509 m .45678 .88736 L .45071 .89837 L .72 .21 .01 r
F
.46129 .87833 m .41518 .859 L .4658 .91509 L 0 .142 .671 r
F
.45264 .90157 m .47075 .91939 L .44521 .89796 L 0 .056 .566 r
F
.46864 .91824 m .46836 .9175 L .4658 .91509 L .72 .21 .01 r
F
.46851 .91755 m .4658 .91509 L .46864 .91824 L 0 .142 .671 r
F
.46947 .91852 m .46864 .91824 L .46851 .91755 L .47 .559 .865 r
F
.47075 .91939 m .48137 .92985 L .47755 .92649 L 0 .056 .566 r
F
.47075 .91939 m .47755 .92649 L .46889 .91792 L F
.47815 .92719 m .47832 .92739 L .48137 .92985 L 0 .06 .599 r
F
.62105 1.04446 m .51892 .97525 L .47935 .92711 L .318 .46 .846 r
F
.45698 .93327 m .45383 .93738 L .45399 .9341 L .154 0 .282 r
F
.45698 .93327 m .45689 .93321 L .45696 .9333 L .586 .451 .663 r
F
.45729 .90891 m .45285 .90596 L .45689 .93321 L 0 0 .307 r
F
.44353 .89865 m .44685 .90197 L .44916 .9035 L 0 .06 .599 r
F
.44685 .90197 m .44737 .90249 L .44916 .9035 L F
.44402 .89682 m .44521 .89796 L .44353 .89655 L 0 .056 .566 r
F
.45264 .90157 m .44521 .89796 L .44402 .89682 L F
.44159 .89426 m .44353 .89655 L .44141 .89433 L .713 .229 0 r
F
.40585 .85699 m .45264 .90157 L .44353 .89655 L 0 .056 .566 r
F
.41817 .86764 m .45264 .90157 L .40585 .85699 L F
.44353 .89655 m .44063 .89576 L .44114 .89524 L 0 0 0 r
F
.44805 .91164 m .44725 .90975 L .44092 .92698 L .322 0 .233 r
F
.44717 .90956 m .44639 .90966 L .44615 .90714 L .154 0 .282 r
F
.44717 .90956 m .44615 .90714 L .44556 .90104 L F
.4373 .81939 m .44728 .81855 L .43631 .81484 L .627 .337 .458 r
F
.49727 .75112 m .49586 .73905 L .50944 .72953 L .597 .402 .587 r
F
.49586 .73905 m .4956 .73682 L .50944 .72953 L F
.4809 .81664 m .51522 .72405 L .48549 .79306 L .532 .326 .546 r
F
.51522 .72405 m .51532 .72378 L .51519 .72408 L F
.51522 .72405 m .51519 .72408 L .48549 .79306 L F
.51532 .72378 m .51423 .72476 L .48549 .79306 L F
.52722 .67573 m .52483 .71281 L .51865 .72081 L .657 .519 .684 r
F
.51532 .72378 m .52039 .71011 L .51518 .72529 L .894 .733 .676 r
F
.51562 .72352 m .51865 .72081 L .51518 .72529 L .657 .519 .684 r
F
.52722 .67573 m .51865 .72081 L .51562 .72352 L F
.51406 .72515 m .51423 .72476 L .50944 .72953 L .532 .326 .546 r
F
.51423 .72476 m .51 .72853 L .50944 .72953 L F
.51412 .75983 m .51425 .76 L .51318 .76156 L .778 .572 .62 r
F
.51522 .72405 m .51532 .72378 L .51518 .72529 L .894 .733 .676 r
F
.52722 .67573 m .51518 .72529 L .51738 .70163 L .657 .519 .684 r
F
.51538 .77664 m .54443 .64884 L .51481 .75748 L .41 .291 .606 r
F
.5146 .75842 m .51481 .75748 L .5146 .75828 L F
.51538 .77664 m .51481 .75748 L .5146 .75842 L F
.54443 .64884 m .54402 .64921 L .51423 .75964 L F
.51515 .72649 m .51425 .76 L .52422 .71553 L .682 .555 .703 r
F
.51412 .75983 m .51425 .76 L .51515 .72649 L F
.51358 .77704 m .5167 .80777 L .47239 .84124 L .796 .591 .624 r
F
.51528 .77438 m .51538 .77664 L .51358 .77704 L F
.51528 .77705 m .51538 .77664 L .51541 .77663 L .819 .694 .727 r
F
.51538 .77664 m .5167 .80777 L .51358 .77704 L .796 .591 .624 r
F
.51917 .77579 m .5167 .80777 L .51538 .77664 L F
.54597 .66491 m .55715 .67097 L .55311 .63987 L .574 .555 .795 r
F
.54443 .64884 m .54609 .64154 L .54765 .65901 L .819 .694 .727 r
F
.54754 .65778 m .56801 .58237 L .54609 .64154 L .411 .386 .721 r
F
.54765 .65901 m .55055 .64809 L .54754 .65778 L F
.55055 .64809 m .56801 .58237 L .54754 .65778 L F
.54465 .55957 m .61725 .52367 L .63541 .60654 L .683 .619 .778 r
F
.55311 .63987 m .61136 .58671 L .55715 .67097 L .564 .548 .795 r
F
.55886 .62993 m .55887 .62991 L .55962 .63052 L .712 .562 .682 r
F
.55887 .62991 m .55934 .62919 L .55962 .63052 L F
.55818 .6307 m .55962 .63052 L .55886 .62993 L .772 .532 .573 r
F
.57184 .57962 m .61136 .58671 L .55311 .63987 L .564 .548 .795 r
F
.5488 .67195 m .56349 .60343 L .54765 .65901 L .411 .386 .721 r
F
.56349 .60343 m .56801 .58237 L .54765 .65901 L F
.5514 .67841 m .55263 .68268 L .55715 .67097 L .682 .555 .703 r
F
.55025 .66723 m .55715 .67097 L .54382 .68823 L .657 .519 .684 r
F
.55715 .67097 m .61815 .68262 L .61136 .58671 L .636 .644 .841 r
F
.56257 .70616 m .56801 .58237 L .5488 .67195 L .411 .386 .721 r
F
.41627 .54547 m .47071 .53605 L .4713 .53753 L .729 .339 .311 r
F
.42171 .54435 m .42895 .54317 L .41981 .54467 L .125 .672 .704 r
F
.42171 .54435 m .41981 .54467 L .40966 .54633 L F
.41981 .54467 m .44163 .54108 L .41843 .5451 L .599 .105 .051 r
F
.44181 .54098 m .44163 .54108 L .41981 .54467 L F
.41077 .54613 m .47071 .53605 L .44181 .54098 L .125 .672 .704 r
F
.41077 .54613 m .44181 .54098 L .42171 .54435 L F
.41512 .5454 m .47071 .53605 L .41627 .54547 L .729 .339 .311 r
F
.47498 .52563 m .47368 .53314 L .47071 .53605 L .255 0 0 r
F
.48886 .54182 m .48577 .55858 L .47926 .53122 L .73 .396 .414 r
F
.4715 .53734 m .4723 .53655 L .47071 .53605 L .602 .275 .388 r
F
.47256 .5363 m .4723 .53655 L .47257 .53635 L 0 0 0 r
F
.47071 .53605 m .47861 .53172 L .4723 .53655 L .575 .401 .609 r
F
.47071 .53605 m .47861 .53172 L .47429 .53296 L 0 0 0 r
F
.4156 .50726 m .47073 .50819 L .48595 .55469 L .43 .62 .931 r
F
.48886 .54182 m .5058 .51681 L .49661 .54429 L .575 .401 .609 r
F
.47999 .53202 m .5058 .51681 L .48886 .54182 L F
.52136 .49676 m .5144 .54483 L .50924 .52801 L .752 .501 .553 r
F
.5058 .51681 m .51829 .50996 L .50847 .52551 L .575 .401 .609 r
F
.5058 .51681 m .50847 .52551 L .49661 .54429 L F
.5144 .54483 m .51324 .55285 L .50924 .52801 L .752 .501 .553 r
F
.53007 .56298 m .52666 .55385 L .51614 .5505 L .602 .275 .388 r
F
.51614 .5505 m .52985 .50362 L .53073 .50695 L .575 .401 .609 r
F
.51614 .5505 m .53073 .50695 L .52666 .55385 L F
.51829 .50996 m .52985 .50362 L .50942 .52862 L F
.51829 .50996 m .50942 .52862 L .50847 .52551 L F
.50942 .52862 m .52985 .50362 L .51614 .5505 L F
.5144 .54483 m .51614 .5505 L .51324 .55285 L .752 .501 .553 r
F
.53187 .46087 m .53409 .45713 L .51013 .51181 L .183 .006 .391 r
F
.50381 .50635 m .50053 .50825 L .50597 .50184 L .871 .798 .776 r
F
.50053 .50825 m .49905 .51775 L .5211 .48999 L .108 0 .251 r
F
.49905 .51775 m .51328 .51199 L .5211 .48999 L F
.5058 .51681 m .52985 .50362 L .51976 .50781 L 0 0 0 r
F
.47073 .50819 m .52658 .51559 L .54446 .57419 L .363 .591 .932 r
F
.55689 .57936 m .54576 .57499 L .49398 .56165 L .217 .596 .948 r
F
.54663 .57509 m .61136 .58671 L .54446 .57419 L .438 .648 .947 r
F
.4156 .50726 m .48595 .55469 L .47228 .55005 L .43 .62 .931 r
F
.54663 .57509 m .57184 .57962 L .57088 .5827 L .564 .548 .795 r
F
.51539 .56641 m .53007 .56298 L .5273 .5605 L .602 .275 .388 r
F
.51539 .56641 m .5273 .5605 L .51614 .5505 L F
.43595 .5467 m .47228 .55005 L .4156 .50726 L .28 .563 .932 r
F
.36452 .51251 m .4156 .50726 L .43595 .5467 L .423 .662 .96 r
F
.46442 .54932 m .36452 .51251 L .39778 .52843 L .217 .596 .948 r
F
.54886 .57579 m .54012 .57279 L .46442 .54932 L F
.55689 .57936 m .49398 .56165 L .46075 .5534 L F
.54886 .57579 m .39778 .52843 L .43595 .5467 L F
.48841 .56222 m .54463 .57473 L .54386 .57404 L .427 .617 .93 r
F
.48595 .55469 m .54386 .57404 L .47073 .50819 L F
.54012 .57279 m .47198 .55002 L .46442 .54932 L .217 .596 .948 r
F
.46075 .5534 m .49398 .56165 L .43595 .5467 L F
.48841 .56222 m .54386 .57404 L .48595 .55469 L .427 .617 .93 r
F
.54012 .57279 m .47444 .55024 L .47198 .55002 L .217 .596 .948 r
F
.47444 .55024 m .36452 .51251 L .46442 .54932 L F
.43595 .5467 m .48841 .56222 L .47228 .55005 L .28 .563 .932 r
F
.54386 .57404 m .54446 .57419 L .54463 .57473 L .363 .591 .932 r
F
.47073 .50819 m .54446 .57419 L .54386 .57404 L F
.56538 .58166 m .54919 .57616 L .55689 .57936 L .217 .596 .948 r
F
.54919 .57616 m .54576 .57499 L .55689 .57936 L F
.54446 .57419 m .61136 .58671 L .52658 .51559 L .438 .648 .947 r
F
.54463 .57473 m .54663 .57509 L .54446 .57419 L F
.47228 .55005 m .48595 .55469 L .48841 .56222 L .43 .62 .931 r
F
.56801 .58237 m .54886 .57579 L .54576 .57499 L .217 .596 .948 r
F
.56801 .58237 m .54576 .57499 L .56538 .58166 L F
.54463 .57473 m .54663 .57509 L .55311 .63987 L .564 .548 .795 r
F
.54663 .57509 m .57088 .5827 L .55311 .63987 L F
.54597 .66491 m .55311 .63987 L .54463 .57473 L .574 .555 .795 r
F
.51541 .77663 m .54443 .64884 L .54847 .66822 L .819 .694 .727 r
F
.51538 .77664 m .54443 .64884 L .51541 .77663 L F
.51865 .72081 m .52422 .71553 L .52483 .71281 L .682 .555 .703 r
F
.48549 .79306 m .51406 .72515 L .49536 .75449 L .532 .326 .546 r
F
.51406 .72515 m .50944 .72953 L .49536 .75449 L F
.48007 .82094 m .47859 .82855 L .51528 .77438 L .765 .548 .603 r
F
.49574 .75213 m .47708 .79927 L .48 .77687 L .778 .572 .62 r
F
.47011 .84107 m .46946 .84093 L .46935 .84101 L .736 .35 .32 r
F
.47238 .84124 m .47238 .84124 L .4644 .84484 L F
.47238 .84124 m .46935 .84101 L .4644 .84484 L F
.51528 .77438 m .47239 .84124 L .47078 .84112 L .796 .591 .624 r
F
.44025 .89595 m .44556 .90104 L .44737 .90249 L 0 .06 .599 r
F
.44025 .89595 m .44737 .90249 L .44353 .89865 L F
.45696 .9333 m .44385 .92956 L .45689 .93321 L .05 .273 .766 r
F
.44595 .93141 m .44385 .92956 L .45696 .9333 L F
.45344 .94581 m .44806 .93177 L .44927 .93198 L .154 0 .282 r
F
.45344 .94581 m .44487 .93122 L .44806 .93177 L F
.43971 .8955 m .441 .89672 L .44025 .89595 L 0 .06 .599 r
F
.441 .89672 m .44556 .90104 L .44025 .89595 L F
.44063 .89576 m .43986 .89554 L .44353 .89865 L F
.43986 .89554 m .43971 .8955 L .44025 .89595 L F
.43986 .89554 m .44025 .89595 L .44353 .89865 L F
.44487 .93122 m .44477 .93111 L .44486 .93126 L .648 .425 .566 r
F
.45344 .94581 m .44809 .94888 L .44522 .93331 L .154 0 .282 r
F
.44477 .93111 m .44092 .92698 L .44385 .92956 L .05 .273 .766 r
F
.44385 .92956 m .44092 .92698 L .44275 .9277 L F
.44385 .92956 m .44275 .9277 L .45689 .93321 L F
.59149 1.08852 m .45814 .94546 L .48542 .96613 L F
.47902 .8598 m .54196 .79388 L .50007 .82268 L .648 .316 .396 r
F
.55903 .78654 m .55947 .77654 L .55836 .77898 L .411 .386 .721 r
F
.55989 .77562 m .56347 .78983 L .53422 .7992 L .777 .619 .684 r
F
.51917 .77579 m .55934 .77262 L .5167 .80777 L .796 .591 .624 r
F
.54265 .77056 m .55934 .77262 L .51917 .77579 L F
.51754 .77616 m .53808 .76799 L .54131 .77085 L .819 .694 .727 r
F
.5268 .76167 m .55934 .77262 L .56557 .72812 L .771 .721 .806 r
F
.54265 .77056 m .55934 .77262 L .5268 .76167 L F
.56021 .77492 m .55989 .77562 L .5627 .77303 L .885 .968 .839 r
F
.5627 .77303 m .6493 .80083 L .5713 .82092 L .777 .619 .684 r
F
.5627 .77303 m .5713 .82092 L .55989 .77562 L F
.54382 .68823 m .53376 .73156 L .55263 .68268 L .682 .555 .703 r
F
.54382 .68823 m .55263 .68268 L .5514 .67841 L F
.56183 .71466 m .56257 .70616 L .5514 .67841 L .411 .386 .721 r
F
.55934 .77262 m .56021 .77492 L .5167 .80777 L .796 .591 .624 r
F
.52162 .73222 m .54402 .64921 L .52914 .68677 L .41 .291 .606 r
F
.54402 .64921 m .54281 .65029 L .52914 .68677 L F
.51783 .64964 m .52321 .65256 L .53251 .65149 L .574 .555 .795 r
F
.53384 .65833 m .52914 .68677 L .52722 .67573 L .657 .519 .684 r
F
.52914 .68677 m .52414 .65791 L .5328 .65145 L .566 .456 .688 r
F
.52914 .68677 m .5328 .65145 L .54281 .65029 L F
.54443 .64884 m .54765 .65901 L .54847 .66822 L .819 .694 .727 r
F
.53208 .60982 m .54579 .65315 L .54463 .57473 L .574 .555 .795 r
F
.54382 .68823 m .54847 .66822 L .5488 .67195 L .819 .694 .727 r
F
.52914 .68677 m .52483 .71281 L .52722 .67573 L .657 .519 .684 r
F
.50922 .66252 m .50359 .73222 L .51783 .64964 L .425 .303 .61 r
F
.4935 .70095 m .50359 .73222 L .50922 .66252 L F
.51783 .64964 m .50635 .73063 L .50359 .73222 L .657 .519 .684 r
F
.49536 .75449 m .49574 .75213 L .49727 .75112 L .597 .402 .587 r
F
.43631 .81484 m .459 .76318 L .4694 .78615 L .548 .227 .376 r
F
.459 .76318 m .46345 .77301 L .48048 .75952 L .465 .19 .411 r
F
.48612 .75856 m .49025 .6909 L .459 .76318 L .514 .332 .572 r
F
.48612 .75856 m .49025 .6909 L .49727 .75112 L .597 .402 .587 r
F
.44181 .77066 m .42887 .78162 L .4337 .7812 L .91 .978 .78 r
F
.44181 .77066 m .41938 .78968 L .459 .76318 L 0 0 0 r
F
.48995 .6913 m .4901 .6911 L .49023 .69081 L 0 0 .038 r
F
.49025 .6909 m .47815 .70714 L .47532 .72384 L .038 0 .439 r
F
.459 .76318 m .47428 .72633 L .49025 .6909 L 0 0 0 r
F
.49023 .69081 m .459 .76318 L .49025 .6909 L 0 0 .038 r
F
.49025 .6909 m .48494 .66709 L .47815 .70714 L .038 0 .439 r
F
.48349 .70287 m .459 .76318 L .4901 .6911 L 0 0 .038 r
F
.48349 .70287 m .4901 .6911 L .48995 .6913 L F
.47815 .70714 m .47348 .7208 L .48995 .6913 L F
.47682 .70892 m .48225 .65504 L .47526 .71102 L .038 0 .439 r
F
.47767 .63232 m .47953 .64098 L .47996 .64319 L 0 0 .181 r
F
.47953 .64098 m .49025 .6909 L .47996 .64319 L F
.47529 .62102 m .47728 .63032 L .47767 .63232 L F
.47728 .63032 m .49025 .6909 L .47767 .63232 L F
.4818 .61187 m .4737 .61185 L .48261 .63834 L 0 .108 .634 r
F
.4737 .61185 m .46916 .61184 L .4765 .62631 L F
.4737 .61185 m .4765 .62631 L .48261 .63834 L F
.46271 .59222 m .4818 .61187 L .47128 .61184 L 0 .217 .735 r
F
.49025 .6909 m .48295 .64947 L .4818 .61187 L 0 0 .231 r
F
.47728 .63032 m .49025 .6909 L .4818 .61187 L 0 0 .408 r
F
.47767 .63232 m .47937 .64113 L .47877 .63831 L 0 0 .181 r
F
.4765 .62631 m .46916 .61184 L .47879 .63814 L 0 .108 .634 r
F
.46916 .61184 m .47937 .64113 L .47879 .63814 L F
.47937 .64113 m .48132 .65022 L .48024 .64561 L 0 0 .181 r
F
.44149 .57038 m .46271 .59222 L .47128 .61184 L 0 .217 .735 r
F
.44149 .57038 m .47128 .61184 L .46916 .61184 L F
.42522 .55982 m .40495 .54711 L .4159 .55481 L 0 .327 .811 r
F
.43446 .56479 m .44149 .57038 L .42016 .5551 L .494 0 0 r
F
.40901 .54642 m .4083 .54652 L .39886 .54181 L F
.40901 .54642 m .41077 .54613 L .40929 .54639 L .125 .672 .704 r
F
.40495 .54711 m .40214 .54763 L .368 .55355 L F
.4083 .54652 m .40753 .54663 L .39886 .54181 L .494 0 0 r
F
.40753 .54663 m .39898 .54189 L .39886 .54181 L F
.41077 .54613 m .42171 .54435 L .40966 .54633 L .125 .672 .704 r
F
.43595 .5467 m .39888 .54184 L .40047 .52971 L 0 .474 .853 r
F
.39888 .54184 m .39877 .54182 L .39878 .54178 L F
.39886 .54181 m .39898 .54189 L .39878 .54178 L .494 0 0 r
F
.39888 .54184 m .39878 .54178 L .40047 .52971 L 0 .474 .853 r
F
.40753 .54663 m .40631 .5468 L .39898 .54189 L .494 0 0 r
F
.41169 .546 m .41981 .54467 L .41116 .54613 L .125 .672 .704 r
F
.41169 .546 m .41116 .54613 L .41018 .54626 L F
.40913 .5465 m .41512 .5454 L .41627 .54547 L .729 .339 .311 r
F
.40901 .54642 m .41512 .5454 L .40913 .5465 L F
.40495 .54711 m .368 .55355 L .36728 .55367 L .125 .672 .704 r
F
.39878 .54178 m .44149 .57038 L .38804 .53755 L .494 0 0 r
F
.39898 .54189 m .44149 .57038 L .39878 .54178 L F
.43595 .5467 m .40831 .54706 L .39888 .54184 L 0 .474 .853 r
F
.36452 .51251 m .36389 .52434 L .39862 .54169 L .347 .743 .984 r
F
.36051 .54682 m .36307 .54596 L .35749 .54527 L .244 .708 .948 r
F
.36275 .54592 m .36275 .546 L .36307 .54596 L .347 .743 .984 r
F
.35749 .54527 m .38804 .53755 L .32326 .5278 L .244 .708 .948 r
F
.36307 .54596 m .38804 .53755 L .35749 .54527 L F
.36307 .54596 m .373 .54262 L .38324 .54362 L .249 .741 .916 r
F
.39257 .54931 m .39684 .54865 L .37586 .55223 L .125 .672 .704 r
F
.36427 .55533 m .3638 .55426 L .37586 .55223 L .742 .932 .951 r
F
.47348 .7208 m .47259 .7234 L .48349 .70287 L 0 0 .038 r
F
.47259 .7234 m .459 .76318 L .48349 .70287 L F
.41938 .78968 m .3959 .80959 L .42973 .78471 L 0 0 0 r
F
.41938 .78968 m .42973 .78471 L .459 .76318 L F
.32603 .81514 m .32939 .81618 L .3452 .81462 L .363 0 0 r
F
.53025 .49925 m .53534 .49437 L .53409 .45713 L .192 .012 .394 r
F
.53534 .49437 m .54588 .45656 L .53409 .45713 L F
.53614 .46923 m .53883 .48186 L .53362 .50053 L .751 .554 .629 r
F
.53534 .49437 m .57625 .45511 L .54588 .45656 L .192 .012 .394 r
F
.52985 .50362 m .53302 .5003 L .53025 .49925 L F
.53025 .49925 m .53135 .49967 L .53137 .49957 L .161 .053 .474 r
F
.5144 .49481 m .5211 .48999 L .50597 .50184 L 0 0 0 r
F
.52289 .48773 m .5211 .48999 L .5144 .49481 L F
.52311 .48754 m .53199 .48013 L .52985 .50362 L .183 .006 .391 r
F
.5211 .48999 m .52136 .49676 L .52745 .48542 L .161 .053 .474 r
F
.52289 .48773 m .5211 .48999 L .52302 .48733 L .874 .731 .7 r
F
.52302 .48733 m .5211 .48999 L .53053 .46524 L F
.52289 .48773 m .53053 .46524 L .53493 .45371 L F
.52311 .48754 m .53409 .45713 L .53199 .48013 L .183 .006 .391 r
F
.5211 .48999 m .52745 .48542 L .53614 .46923 L .161 .053 .474 r
F
.52136 .49676 m .53364 .50021 L .53614 .46923 L F
.53366 .45703 m .53614 .46923 L .5211 .48999 L 0 0 .185 r
F
.53493 .45371 m .53511 .45607 L .53366 .45703 L F
.53409 .45713 m .53409 .45675 L .5719 .4496 L .21 .349 .786 r
F
.53409 .45675 m .56258 .43781 L .5719 .4496 L F
.53409 .45713 m .5719 .4496 L .56075 .45585 L F
.53511 .45607 m .53614 .46923 L .53366 .45703 L 0 0 .185 r
F
.55271 .40704 m .54917 .42033 L .53493 .45371 L F
.54917 .42033 m .53614 .46923 L .53493 .45371 L F
.56318 .38431 m .53614 .46923 L .55271 .40704 L F
.53409 .45675 m .53432 .40204 L .56258 .43781 L .21 .349 .786 r
F
.56075 .45585 m .5719 .4496 L .57625 .45511 L F
.50597 .50184 m .5211 .48999 L .50053 .50825 L 0 0 0 r
F
.57228 .35571 m .56318 .38431 L .55271 .40704 L 0 0 .185 r
F
.38186 .6932 m .33994 .64602 L .2571 .65563 L .864 .665 .632 r
F
.2747 .696 m .2571 .65563 L .38186 .6932 L .844 .728 .736 r
F
.41517 .73533 m .38186 .6932 L .2747 .696 L .826 .562 .541 r
F
.71116 .42244 m .68899 .40789 L .66754 .50633 L .12 .087 .542 r
F
.72184 .5176 m .66754 .50633 L .72193 .40173 L .394 .417 .766 r
F
.70272 .56015 m .72184 .5176 L .65877 .62221 L 0 0 0 r
F
.70272 .56015 m .70737 .5498 L .68656 .45729 L 1 .828 .524 r
F
.70737 .5498 m .72184 .5176 L .70898 .49562 L F
.70737 .5498 m .70898 .49562 L .68656 .45729 L F
.72193 .40173 m .71172 .40364 L .71116 .42244 L .12 .087 .542 r
F
.71172 .40364 m .68899 .40789 L .71116 .42244 L F
.29023 .73184 m .2747 .696 L .41517 .73533 L .818 .638 .658 r
F
.42756 .76968 m .41517 .73533 L .29023 .73184 L .787 .473 .457 r
F
.65755 .659 m .65877 .62221 L .70272 .56015 L 0 0 .194 r
F
.66285 .31404 m .59023 .40264 L .58787 .45766 L .668 .628 .8 r
F
.68899 .40789 m .58787 .45766 L .66285 .31404 L .676 .638 .804 r
F
.33994 .64602 m .30829 .59827 L .24518 .61407 L .885 .792 .752 r
F
.2571 .65563 m .24518 .61407 L .33994 .64602 L .864 .817 .801 r
F
.29786 .7608 m .29023 .73184 L .42756 .76968 L .791 .532 .547 r
F
.59907 .2393 m .57228 .35571 L .59023 .40264 L .695 .649 .8 r
F
.66285 .31404 m .59023 .40264 L .59907 .2393 L .665 .624 .798 r
F
.30829 .59827 m .30183 .5568 L .3737 .57668 L .8 .894 .91 r
F
.68656 .45729 m .69913 .43755 L .61993 .37062 L .869 .661 .619 r
F
.72193 .40173 m .68899 .40789 L .65931 .29684 L .173 .384 .829 r
F
.69913 .43755 m .72193 .40173 L .68574 .3907 L .869 .661 .619 r
F
.66476 .31725 m .66285 .31404 L .68899 .40789 L 0 0 .226 r
F
.69913 .43755 m .68574 .3907 L .61993 .37062 L .869 .661 .619 r
F
.65931 .29684 m .66027 .30153 L .66476 .31725 L 0 0 .226 r
F
.66027 .30153 m .66285 .31404 L .66476 .31725 L F
.63541 .60654 m .70272 .56015 L .65755 .659 L .861 .886 .853 r
F
.68656 .45729 m .72193 .40173 L .72184 .5176 L .974 .88 .676 r
F
0 0 0 r
1 Mabswid
.72184 .5176 Mdot
.72184 .5176 Mdot
.72184 .5176 Mdot
.72184 .5176 Mdot
.72184 .5176 Mdot
.72184 .5176 Mdot
.50053 .50825 Mdot
.50053 .50825 Mdot
.50053 .50825 Mdot
.50053 .50825 Mdot
.50053 .50825 Mdot
.50053 .50825 Mdot
.29023 .73184 m .2747 .696 L .20274 .67291 L .947 .663 .466 r
F
.20528 .69394 m .20274 .67291 L .29023 .73184 L .928 .754 .645 r
F
.29786 .7608 m .29023 .73184 L .20528 .69394 L .93 .609 .41 r
F
.2747 .696 m .2571 .65563 L .20055 .64942 L .967 .743 .548 r
F
.20274 .67291 m .20055 .64942 L .2747 .696 L .933 .825 .715 r
F
.30829 .59827 m .30183 .5568 L .24528 .57528 L .836 .913 .889 r
F
.24518 .61407 m .24528 .57528 L .30829 .59827 L .858 .907 .866 r
F
.20671 .71117 m .20528 .69394 L .29786 .7608 L .926 .675 .538 r
F
.29567 .78154 m .29786 .7608 L .20671 .71117 L .916 .565 .357 r
F
.61993 .37062 m .63665 .33929 L .52821 .31346 L .743 .551 .634 r
F
.57209 .23922 m .59907 .2393 L .66285 .31404 L .907 .507 .227 r
F
.55315 .22362 m .56452 .2275 L .57209 .23922 L F
.56452 .2275 m .59907 .2393 L .57209 .23922 L F
.65931 .29684 m .66285 .31404 L .55315 .22362 L 0 .376 .82 r
F
.63665 .33929 m .65931 .29684 L .61305 .30271 L .743 .551 .634 r
F
.63665 .33929 m .61305 .30271 L .52821 .31346 L F
0 0 0 r
.5211 .48999 Mdot
.5211 .48999 Mdot
.5211 .48999 Mdot
.5211 .48999 Mdot
.5211 .48999 Mdot
.5211 .48999 Mdot
.2571 .65563 m .24518 .61407 L .2004 .6251 L .973 .847 .655 r
F
.20055 .64942 m .2004 .6251 L .2571 .65563 L .937 .896 .761 r
F
0 0 0 r
.59907 .2393 Mdot
.59907 .2393 Mdot
.59907 .2393 Mdot
.53614 .46923 Mdot
.53614 .46923 Mdot
.53614 .46923 Mdot
.20626 .72363 m .20671 .71117 L .29567 .78154 L .917 .572 .37 r
F
.28539 .79375 m .29567 .78154 L .20626 .72363 L .901 .511 .271 r
F
.61725 .52367 m .68656 .45729 L .70272 .56015 L .781 .727 .803 r
F
.63541 .60654 m .70272 .56015 L .61725 .52367 L .812 .7 .74 r
F
0 0 0 r
.70272 .56015 Mdot
.70272 .56015 Mdot
.70272 .56015 Mdot
.70272 .56015 Mdot
.70272 .56015 Mdot
.70272 .56015 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.61993 .37062 m .65931 .29684 L .72193 .40173 L .858 .704 .69 r
F
0 0 0 r
.72193 .40173 Mdot
.72193 .40173 Mdot
.72193 .40173 Mdot
.72193 .40173 Mdot
.72193 .40173 Mdot
.72193 .40173 Mdot
.30183 .5568 m .32326 .5278 L .36051 .54682 L .626 .905 .984 r
F
.24518 .61407 m .24528 .57528 L .2037 .60172 L .94 .949 .758 r
F
.2004 .6251 m .2037 .60172 L .24518 .61407 L .923 .96 .785 r
F
.30183 .5568 m .32326 .5278 L .25963 .5428 L .648 .935 .968 r
F
.24528 .57528 m .25963 .5428 L .30183 .5568 L .777 .96 .927 r
F
.53432 .40204 m .52821 .31346 L .61993 .37062 L .592 .603 .832 r
F
.57625 .45511 m .61993 .37062 L .53432 .40204 L .555 .476 .721 r
F
0 0 0 r
.53432 .40204 Mdot
.53432 .40204 Mdot
.53432 .40204 Mdot
.20403 .7307 m .20626 .72363 L .28539 .79375 L .867 .422 .112 r
F
.2707 .79791 m .28539 .79375 L .20403 .7307 L .872 .431 .126 r
F
.61725 .52367 m .68656 .45729 L .57625 .45511 L .7 .581 .718 r
F
0 0 0 r
.61725 .52367 Mdot
.61725 .52367 Mdot
.61725 .52367 Mdot
.61725 .52367 Mdot
.61725 .52367 Mdot
.61725 .52367 Mdot
.57625 .45511 m .61993 .37062 L .68656 .45729 L .692 .643 .797 r
F
0 0 0 r
.57625 .45511 Mdot
.57625 .45511 Mdot
.57625 .45511 Mdot
.57625 .45511 Mdot
.57625 .45511 Mdot
.57625 .45511 Mdot
.48965 1.00684 m .57184 1.19984 L .35287 1.00087 L .793 .587 .622 r
F
.4094 .90261 m .35287 1.00087 L .48965 1.00684 L .689 .833 .953 r
F
0 0 0 r
.48965 1.00684 Mdot
.48965 1.00684 Mdot
.48965 1.00684 Mdot
.48965 1.00684 Mdot
.48965 1.00684 Mdot
.48965 1.00684 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.52821 .31346 m .55315 .22362 L .65931 .29684 L .752 .6 .688 r
F
0 0 0 r
.65931 .29684 Mdot
.65931 .29684 Mdot
.65931 .29684 Mdot
.65931 .29684 Mdot
.65931 .29684 Mdot
.65931 .29684 Mdot
.63927 .96839 m .73395 1.11094 L .8319 .98451 L .497 .423 .703 r
F
.75624 .8852 m .8319 .98451 L .63927 .96839 L .504 .355 .612 r
F
.54877 .86085 m .63927 .96839 L .75624 .8852 L .659 .649 .828 r
F
.24528 .57528 m .25963 .5428 L .21097 .58094 L .82 1 .803 r
F
.2037 .60172 m .21097 .58094 L .24528 .57528 L .861 .997 .784 r
F
.20528 .69394 m .20274 .67291 L .18906 .63714 L .838 .622 .075 r
F
.20671 .71117 m .20528 .69394 L .18906 .63714 L .839 .624 .078 r
F
.20274 .67291 m .20055 .64942 L .18906 .63714 L .866 .68 .151 r
F
.20626 .72363 m .20671 .71117 L .18906 .63714 L .871 .67 .142 r
F
0 0 0 r
.55315 .22362 Mdot
.55315 .22362 Mdot
.55315 .22362 Mdot
.20055 .64942 m .2004 .6251 L .18906 .63714 L .882 .763 .261 r
F
.35287 1.00087 m .38148 1.24217 L .57184 1.19984 L .734 .601 .708 r
F
.57184 1.19984 m .67709 1.25448 L .38148 1.24217 L .44 0 .056 r
F
.57184 1.19984 m .67709 1.25448 L .76436 1.1478 L .324 .123 .445 r
F
.38148 1.24217 m .56676 1.33276 L .67709 1.25448 L .547 .297 .488 r
F
.67709 1.25448 m .65708 1.21569 L .56676 1.33276 L .797 .779 .836 r
F
.73395 1.11094 m .75947 1.14187 L .57184 1.19984 L .125 0 0 r
F
.75947 1.14187 m .75436 1.14539 L .57184 1.19984 L F
.76079 1.14347 m .75114 1.15019 L .57184 1.19984 L F
.76351 1.14677 m .76017 1.14893 L .57184 1.19984 L F
.5731 1.27006 m .5644 1.10767 L .59149 1.08852 L .827 .805 .83 r
F
.56676 1.33276 m .56615 1.27484 L .5731 1.27006 L F
.56615 1.27484 m .5644 1.10767 L .5731 1.27006 L F
.75947 1.14187 m .76079 1.14347 L .75436 1.14539 L .125 0 0 r
F
.76079 1.14347 m .76351 1.14677 L .75114 1.15019 L F
.66522 1.21001 m .59149 1.08852 L .62105 1.04446 L .827 .789 .816 r
F
.67709 1.25448 m .65708 1.21569 L .66522 1.21001 L F
.65708 1.21569 m .59149 1.08852 L .66522 1.21001 L F
.65708 1.21569 m .59149 1.08852 L .5731 1.27006 L .797 .779 .836 r
F
.65708 1.21569 m .5731 1.27006 L .56676 1.33276 L F
.76351 1.14677 m .76436 1.1478 L .76017 1.14893 L .125 0 0 r
F
.20087 .7321 m .20403 .7307 L .2707 .79791 L .721 .216 0 r
F
.25571 .79464 m .2707 .79791 L .20087 .7321 L .793 .306 0 r
F
.38804 .53755 m .43595 .5467 L .44149 .57038 L .229 .532 .921 r
F
.38804 .53755 m .43595 .5467 L .36452 .51251 L .118 .551 .918 r
F
.32326 .5278 m .36452 .51251 L .38804 .53755 L .442 .77 .997 r
F
.20403 .7307 m .20626 .72363 L .18906 .63714 L .9 .71 .203 r
F
0 0 0 r
.52821 .31346 Mdot
.52821 .31346 Mdot
.52821 .31346 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.32326 .5278 m .36452 .51251 L .28613 .5187 L .399 .835 .949 r
F
.25963 .5428 m .28613 .5187 L .32326 .5278 L .619 .933 .964 r
F
.2004 .6251 m .2037 .60172 L .18906 .63714 L .838 .812 .326 r
F
0 0 0 r
.38148 1.24217 Mdot
.38148 1.24217 Mdot
.38148 1.24217 Mdot
.20087 .7321 m .20403 .7307 L .18906 .63714 L .899 .709 .2 r
F
0 0 0 r
.35287 1.00087 Mdot
.35287 1.00087 Mdot
.35287 1.00087 Mdot
.6493 .80083 m .75624 .8852 L .54877 .86085 L .687 .571 .719 r
F
.25963 .5428 m .28613 .5187 L .22174 .56419 L .556 .91 .707 r
F
.21097 .58094 m .22174 .56419 L .25963 .5428 L .729 .98 .756 r
F
.6493 .80083 m .75624 .8852 L .79942 .77066 L .544 .572 .833 r
F
.7079 .71061 m .79942 .77066 L .6493 .80083 L .533 .488 .751 r
F
.5627 .77303 m .6493 .80083 L .7079 .71061 L .697 .709 .857 r
F
.8319 .98451 m .80889 1.01099 L .73395 1.11094 L .584 .833 .465 r
F
.80889 1.01099 m .80285 1.01794 L .7941 1.02976 L F
.80889 1.01099 m .7941 1.02976 L .73395 1.11094 L F
.73346 1.10668 m .62105 1.04446 L .63382 .97409 L .828 .754 .782 r
F
.73395 1.11094 m .76436 1.1478 L .80285 1.01794 L 0 0 .239 r
F
.76436 1.1478 m .72399 1.11869 L .73346 1.10668 L .828 .754 .782 r
F
.72399 1.11869 m .62105 1.04446 L .73346 1.10668 L F
.2037 .60172 m .21097 .58094 L .18906 .63714 L .696 .771 .283 r
F
.75624 .8852 m .8319 .98451 L .83919 .83943 L .18 .251 .701 r
F
.79942 .77066 m .83919 .83943 L .75624 .8852 L .105 .087 .551 r
F
.43595 .5467 m .48841 .56222 L .4818 .61187 L .457 .505 .82 r
F
.19814 .72775 m .20087 .7321 L .18906 .63714 L .842 .646 .102 r
F
.19814 .72775 m .20087 .7321 L .25571 .79464 L 0 0 .517 r
F
0 0 0 r
.20087 .7321 Mdot
.20087 .7321 Mdot
.20087 .7321 Mdot
.20087 .7321 Mdot
.20087 .7321 Mdot
.24455 .78385 m .25571 .79464 L .19814 .72775 L .594 .113 0 r
F
.24455 .78385 m .25571 .79464 L .3174 .81737 L 0 .436 .809 r
F
0 0 0 r
.25571 .79464 Mdot
.25571 .79464 Mdot
.25571 .79464 Mdot
.25571 .79464 Mdot
.25571 .79464 Mdot
.25571 .79464 Mdot
.61815 .68262 m .7079 .71061 L .5627 .77303 L .656 .566 .741 r
F
.43631 .81484 m .459 .76318 L .3959 .80959 L .471 .149 .338 r
F
.36452 .51251 m .4156 .50726 L .32015 .50345 L .229 .73 .905 r
F
.28613 .5187 m .32015 .50345 L .36452 .51251 L .453 .854 .971 r
F
.21097 .58094 m .22174 .56419 L .18906 .63714 L 0 0 0 r
F
.21097 .58094 Mdot
.21097 .58094 Mdot
.21097 .58094 Mdot
.21097 .58094 Mdot
.21097 .58094 Mdot
.48841 .56222 m .54463 .57473 L .51783 .64964 L .55 .529 .784 r
F
.1974 .71776 m .19814 .72775 L .24455 .78385 L 0 .123 .671 r
F
.1974 .71776 m .19814 .72775 L .18906 .63714 L 0 0 .09 r
F
0 0 0 r
.19814 .72775 Mdot
.19814 .72775 Mdot
.19814 .72775 Mdot
.19814 .72775 Mdot
.19814 .72775 Mdot
.22174 .56419 m .23457 .55254 L .28613 .5187 L .529 .893 .684 r
F
.28613 .5187 m .32015 .50345 L .23457 .55254 L 0 0 0 r
F
.28613 .5187 Mdot
.28613 .5187 Mdot
.28613 .5187 Mdot
.28613 .5187 Mdot
.28613 .5187 Mdot
.28613 .5187 Mdot
.61815 .68262 m .7079 .71061 L .686 .61019 L .56 .638 .885 r
F
.61136 .58671 m .686 .61019 L .61815 .68262 L .492 .53 .824 r
F
.30469 .81002 m .3174 .81737 L .24455 .78385 L 0 .317 .681 r
F
0 0 0 r
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.7079 .71061 m .79942 .77066 L .74471 .65208 L .27 .472 .872 r
F
.686 .61019 m .74471 .65208 L .7079 .71061 L .177 .345 .795 r
F
.22174 .56419 m .23457 .55254 L .18906 .63714 L 0 0 .093 r
F
0 0 0 r
.22174 .56419 Mdot
.22174 .56419 Mdot
.22174 .56419 Mdot
.22174 .56419 Mdot
.22174 .56419 Mdot
.242 .76451 m .24455 .78385 L .30469 .81002 L .048 .429 .87 r
F
.242 .76451 m .24455 .78385 L .1974 .71776 L 0 .116 .666 r
F
0 0 0 r
.24455 .78385 Mdot
.24455 .78385 Mdot
.24455 .78385 Mdot
.24455 .78385 Mdot
.24455 .78385 Mdot
.24455 .78385 Mdot
.26411 .56729 m .2579 .5859 L .18906 .63714 L 0 0 .223 r
F
.26402 .55414 m .26411 .56729 L .18906 .63714 L .014 0 .265 r
F
.25795 .5472 m .26402 .55414 L .18906 .63714 L .05 0 .31 r
F
.24741 .54672 m .25795 .5472 L .18906 .63714 L .051 0 .311 r
F
.23457 .55254 m .24741 .54672 L .18906 .63714 L 0 0 .244 r
F
.20009 .70243 m .1974 .71776 L .18906 .63714 L 0 0 .299 r
F
.2071 .68245 m .20009 .70243 L .18906 .63714 L 0 0 .417 r
F
.21832 .65898 m .2071 .68245 L .18906 .63714 L 0 0 .428 r
F
.2323 .6337 m .21832 .65898 L .18906 .63714 L .017 0 .371 r
F
.24649 .60864 m .2323 .6337 L .18906 .63714 L .011 0 .288 r
F
.2579 .5859 m .24649 .60864 L .18906 .63714 L 0 0 .227 r
F
0 0 0 r
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.20009 .70243 m .1974 .71776 L .242 .76451 L 0 .198 .718 r
F
0 0 0 r
.1974 .71776 Mdot
.1974 .71776 Mdot
.1974 .71776 Mdot
.1974 .71776 Mdot
.1974 .71776 Mdot
.4156 .50726 m .47073 .50819 L .35639 .49692 L .108 .647 .85 r
F
.32015 .50345 m .35639 .49692 L .4156 .50726 L .27 .751 .928 r
F
.8319 .98451 m .80285 1.01794 L .77378 .87858 L .968 .738 .303 r
F
.83919 .83943 m .77378 .87858 L .8319 .98451 L .966 .92 .704 r
F
0 0 0 r
.8319 .98451 Mdot
.8319 .98451 Mdot
.8319 .98451 Mdot
.8319 .98451 Mdot
.8319 .98451 Mdot
.8319 .98451 Mdot
.23457 .55254 m .24741 .54672 L .32015 .50345 L F
.23457 .55254 Mdot
.23457 .55254 Mdot
.23457 .55254 Mdot
.23457 .55254 Mdot
.23457 .55254 Mdot
.32015 .50345 m .35639 .49692 L .24741 .54672 L .11 0 0 r
F
0 0 0 r
.32015 .50345 Mdot
.32015 .50345 Mdot
.32015 .50345 Mdot
.32015 .50345 Mdot
.32015 .50345 Mdot
.32015 .50345 Mdot
.79942 .77066 m .83919 .83943 L .74948 .70367 L .665 .235 0 r
F
.74471 .65208 m .74948 .70367 L .79942 .77066 L .893 .563 .07 r
F
0 0 0 r
.79942 .77066 Mdot
.79942 .77066 Mdot
.79942 .77066 Mdot
.79942 .77066 Mdot
.79942 .77066 Mdot
.79942 .77066 Mdot
.61136 .58671 m .686 .61019 L .57542 .53347 L .215 .573 .941 r
F
.52658 .51559 m .57542 .53347 L .61136 .58671 L .067 .459 .884 r
F
.2533 .73566 m .242 .76451 L .20009 .70243 L .098 .263 .745 r
F
.2071 .68245 m .20009 .70243 L .2533 .73566 L .147 .258 .723 r
F
0 0 0 r
.20009 .70243 Mdot
.20009 .70243 Mdot
.20009 .70243 Mdot
.20009 .70243 Mdot
.20009 .70243 Mdot
.4094 .90261 Mdot
.4094 .90261 Mdot
.4094 .90261 Mdot
.35639 .49692 m .38927 .49948 L .47073 .50819 L 0 .541 .73 r
F
.47073 .50819 m .52658 .51559 L .38927 .49948 L .116 0 0 r
F
0 0 0 r
.47073 .50819 Mdot
.47073 .50819 Mdot
.47073 .50819 Mdot
.47073 .50819 Mdot
.47073 .50819 Mdot
.47073 .50819 Mdot
.24741 .54672 m .25795 .5472 L .35639 .49692 L .053 0 0 r
F
0 0 0 r
.24741 .54672 Mdot
.24741 .54672 Mdot
.24741 .54672 Mdot
.24741 .54672 Mdot
.24741 .54672 Mdot
.43815 .89508 Mdot
.43815 .89508 Mdot
.43815 .89508 Mdot
.43815 .89508 Mdot
.43815 .89508 Mdot
.43815 .89508 Mdot
.31362 .78986 m .30469 .81002 L .37117 .83436 L .099 .459 .887 r
F
.31362 .78986 m .30469 .81002 L .242 .76451 L .093 .451 .883 r
F
0 0 0 r
.30469 .81002 Mdot
.30469 .81002 Mdot
.30469 .81002 Mdot
.30469 .81002 Mdot
.30469 .81002 Mdot
.30469 .81002 Mdot
.2533 .73566 m .242 .76451 L .31362 .78986 L .234 .428 .848 r
F
0 0 0 r
.242 .76451 Mdot
.242 .76451 Mdot
.242 .76451 Mdot
.242 .76451 Mdot
.242 .76451 Mdot
.242 .76451 Mdot
.35639 .49692 m .38927 .49948 L .25795 .5472 L .3 0 .064 r
F
0 0 0 r
.35639 .49692 Mdot
.35639 .49692 Mdot
.35639 .49692 Mdot
.35639 .49692 Mdot
.35639 .49692 Mdot
.35639 .49692 Mdot
.2815 .69791 m .2533 .73566 L .2071 .68245 L .299 .305 .699 r
F
.21832 .65898 m .2071 .68245 L .2815 .69791 L .292 .317 .716 r
F
0 0 0 r
.2071 .68245 Mdot
.2071 .68245 Mdot
.2071 .68245 Mdot
.2071 .68245 Mdot
.2071 .68245 Mdot
.686 .61019 m .74471 .65208 L .60149 .56462 L .494 0 0 r
F
.57542 .53347 m .60149 .56462 L .686 .61019 L .676 .135 0 r
F
0 0 0 r
.686 .61019 Mdot
.686 .61019 Mdot
.686 .61019 Mdot
.686 .61019 Mdot
.686 .61019 Mdot
.686 .61019 Mdot
.76436 1.1478 m .62105 1.04446 L .67709 1.25448 L .781 .764 .838 r
F
0 0 0 r
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.56676 1.33276 Mdot
.56676 1.33276 Mdot
.56676 1.33276 Mdot
.25795 .5472 m .26402 .55414 L .38927 .49948 L .315 0 .089 r
F
0 0 0 r
.25795 .5472 Mdot
.25795 .5472 Mdot
.25795 .5472 Mdot
.25795 .5472 Mdot
.25795 .5472 Mdot
.4302 .91094 Mdot
.4302 .91094 Mdot
.4302 .91094 Mdot
.41518 .859 Mdot
.41518 .859 Mdot
.41518 .859 Mdot
.41518 .859 Mdot
.41518 .859 Mdot
.41518 .859 Mdot
.52658 .51559 m .57542 .53347 L .41233 .51211 L .452 0 0 r
F
.38927 .49948 m .41233 .51211 L .52658 .51559 L .456 0 0 r
F
0 0 0 r
.52658 .51559 Mdot
.52658 .51559 Mdot
.52658 .51559 Mdot
.52658 .51559 Mdot
.52658 .51559 Mdot
.52658 .51559 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.32346 .65435 m .2815 .69791 L .21832 .65898 L .4 .291 .614 r
F
.2323 .6337 m .21832 .65898 L .32346 .65435 L .405 .364 .7 r
F
0 0 0 r
.21832 .65898 Mdot
.21832 .65898 Mdot
.21832 .65898 Mdot
.21832 .65898 Mdot
.21832 .65898 Mdot
.26402 .55414 m .26411 .56729 L .41233 .51211 L .465 .147 .341 r
F
.38927 .49948 m .41233 .51211 L .26402 .55414 L .402 .031 .216 r
F
0 0 0 r
.26402 .55414 Mdot
.26402 .55414 Mdot
.26402 .55414 Mdot
.26402 .55414 Mdot
.26402 .55414 Mdot
.80285 1.01794 m .63382 .97409 L .76436 1.1478 L .776 .745 .825 r
F
0 0 0 r
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.36865 .60968 m .32346 .65435 L .2323 .6337 L .446 .252 .523 r
F
.24649 .60864 m .2323 .6337 L .36865 .60968 L .481 .382 .666 r
F
0 0 0 r
.2323 .6337 Mdot
.2323 .6337 Mdot
.2323 .6337 Mdot
.2323 .6337 Mdot
.2323 .6337 Mdot
.26411 .56729 m .2579 .5859 L .41863 .53544 L .523 .292 .506 r
F
.41233 .51211 m .41863 .53544 L .26411 .56729 L .448 .117 .312 r
F
0 0 0 r
.26411 .56729 Mdot
.26411 .56729 Mdot
.26411 .56729 Mdot
.26411 .56729 Mdot
.26411 .56729 Mdot
.35834 .75431 m .31362 .78986 L .2533 .73566 L .391 .476 .827 r
F
.2815 .69791 m .2533 .73566 L .35834 .75431 L .407 .454 .797 r
F
0 0 0 r
.2533 .73566 Mdot
.2533 .73566 Mdot
.2533 .73566 Mdot
.2533 .73566 Mdot
.2533 .73566 Mdot
.2533 .73566 Mdot
.83919 .83943 m .77378 .87858 L .67463 .75066 L .919 .632 .483 r
F
.74948 .70367 m .67463 .75066 L .83919 .83943 L .893 .737 .681 r
F
0 0 0 r
.83919 .83943 Mdot
.83919 .83943 Mdot
.83919 .83943 Mdot
.83919 .83943 Mdot
.83919 .83943 Mdot
.83919 .83943 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.40353 .56876 m .36865 .60968 L .24649 .60864 L .462 .208 .443 r
F
.2579 .5859 m .24649 .60864 L .40353 .56876 L .522 .363 .606 r
F
0 0 0 r
.24649 .60864 Mdot
.24649 .60864 Mdot
.24649 .60864 Mdot
.24649 .60864 Mdot
.24649 .60864 Mdot
.41863 .53544 m .40353 .56876 L .2579 .5859 L .463 .168 .378 r
F
0 0 0 r
.2579 .5859 Mdot
.2579 .5859 Mdot
.2579 .5859 Mdot
.2579 .5859 Mdot
.2579 .5859 Mdot
.74471 .65208 m .74948 .70367 L .58691 .60719 L .82 .401 .246 r
F
.60149 .56462 m .58691 .60719 L .74471 .65208 L .864 .541 .438 r
F
0 0 0 r
.74471 .65208 Mdot
.74471 .65208 Mdot
.74471 .65208 Mdot
.74471 .65208 Mdot
.74471 .65208 Mdot
.74471 .65208 Mdot
.35834 .75431 m .31362 .78986 L .42392 .8193 L .402 .498 .842 r
F
0 0 0 r
.31362 .78986 Mdot
.31362 .78986 Mdot
.31362 .78986 Mdot
.31362 .78986 Mdot
.31362 .78986 Mdot
.31362 .78986 Mdot
.57542 .53347 m .60149 .56462 L .41863 .53544 L .634 .183 .163 r
F
.41233 .51211 m .41863 .53544 L .57542 .53347 L .67 .252 .244 r
F
0 0 0 r
.57542 .53347 Mdot
.57542 .53347 Mdot
.57542 .53347 Mdot
.57542 .53347 Mdot
.57542 .53347 Mdot
.57542 .53347 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.44809 .94888 Mdot
.44809 .94888 Mdot
.44809 .94888 Mdot
.41233 .51211 Mdot
.41233 .51211 Mdot
.41233 .51211 Mdot
.41233 .51211 Mdot
.41233 .51211 Mdot
.41233 .51211 Mdot
.38356 .83358 Mdot
.38356 .83358 Mdot
.38356 .83358 Mdot
.80285 1.01794 m .63382 .97409 L .61069 .88404 L .811 .694 .735 r
F
.77378 .87858 m .61069 .88404 L .80285 1.01794 L .767 .709 .798 r
F
0 0 0 r
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.43795 .70741 m .35834 .75431 L .2815 .69791 L .537 .453 .708 r
F
.32346 .65435 m .2815 .69791 L .43795 .70741 L .532 .487 .751 r
F
0 0 0 r
.2815 .69791 Mdot
.2815 .69791 Mdot
.2815 .69791 Mdot
.2815 .69791 Mdot
.2815 .69791 Mdot
.2815 .69791 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.48137 .92985 Mdot
.48137 .92985 Mdot
.48137 .92985 Mdot
.41863 .53544 m .40353 .56876 L .60149 .56462 L .706 .427 .5 r
F
0 0 0 r
.41863 .53544 Mdot
.41863 .53544 Mdot
.41863 .53544 Mdot
.41863 .53544 Mdot
.41863 .53544 Mdot
.41863 .53544 Mdot
.60149 .56462 m .58691 .60719 L .40353 .56876 L .671 .322 .374 r
F
0 0 0 r
.60149 .56462 Mdot
.60149 .56462 Mdot
.60149 .56462 Mdot
.60149 .56462 Mdot
.60149 .56462 Mdot
.60149 .56462 Mdot
.61069 .88404 m .46129 .87833 L .63382 .97409 L .573 .547 .788 r
F
.61069 .88404 m .46129 .87833 L .42392 .8193 L .562 .583 .833 r
F
0 0 0 r
.46129 .87833 Mdot
.46129 .87833 Mdot
.46129 .87833 Mdot
.46129 .87833 Mdot
.46129 .87833 Mdot
.46129 .87833 Mdot
.74948 .70367 m .67463 .75066 L .5261 .65642 L .789 .505 .508 r
F
.58691 .60719 m .5261 .65642 L .74948 .70367 L .788 .604 .651 r
F
0 0 0 r
.74948 .70367 Mdot
.74948 .70367 Mdot
.74948 .70367 Mdot
.74948 .70367 Mdot
.74948 .70367 Mdot
.74948 .70367 Mdot
.5261 .65642 m .43795 .70741 L .32346 .65435 L .614 .422 .599 r
F
.36865 .60968 m .32346 .65435 L .5261 .65642 L .618 .505 .702 r
F
0 0 0 r
.32346 .65435 Mdot
.32346 .65435 Mdot
.32346 .65435 Mdot
.32346 .65435 Mdot
.32346 .65435 Mdot
.32346 .65435 Mdot
.54251 .78895 m .42392 .8193 L .35834 .75431 L .583 .543 .775 r
F
.43795 .70741 m .35834 .75431 L .54251 .78895 L .581 .547 .782 r
F
0 0 0 r
.35834 .75431 Mdot
.35834 .75431 Mdot
.35834 .75431 Mdot
.35834 .75431 Mdot
.35834 .75431 Mdot
.35834 .75431 Mdot
.40353 .56876 m .36865 .60968 L .58691 .60719 L .677 .494 .63 r
F
0 0 0 r
.40353 .56876 Mdot
.40353 .56876 Mdot
.40353 .56876 Mdot
.40353 .56876 Mdot
.40353 .56876 Mdot
.40353 .56876 Mdot
.59149 1.08852 Mdot
.59149 1.08852 Mdot
.59149 1.08852 Mdot
.59149 1.08852 Mdot
.59149 1.08852 Mdot
.59149 1.08852 Mdot
.54251 .78895 m .42392 .8193 L .61069 .88404 L .588 .567 .798 r
F
0 0 0 r
.42392 .8193 Mdot
.42392 .8193 Mdot
.42392 .8193 Mdot
.42392 .8193 Mdot
.42392 .8193 Mdot
.42392 .8193 Mdot
.58691 .60719 m .5261 .65642 L .36865 .60968 L .656 .384 .496 r
F
0 0 0 r
.36865 .60968 Mdot
.36865 .60968 Mdot
.36865 .60968 Mdot
.36865 .60968 Mdot
.36865 .60968 Mdot
.36865 .60968 Mdot
.5644 1.10767 Mdot
.5644 1.10767 Mdot
.5644 1.10767 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.77378 .87858 m .61069 .88404 L .54251 .78895 L .771 .617 .688 r
F
.67463 .75066 m .54251 .78895 L .77378 .87858 L .741 .655 .764 r
F
0 0 0 r
.77378 .87858 Mdot
.77378 .87858 Mdot
.77378 .87858 Mdot
.77378 .87858 Mdot
.77378 .87858 Mdot
.77378 .87858 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.67463 .75066 m .54251 .78895 L .43795 .70741 L .708 .53 .645 r
F
.5261 .65642 m .43795 .70741 L .67463 .75066 L .694 .587 .732 r
F
0 0 0 r
.43795 .70741 Mdot
.43795 .70741 Mdot
.43795 .70741 Mdot
.43795 .70741 Mdot
.43795 .70741 Mdot
.43795 .70741 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{196.625, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400034000180P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000<Ad0034M000a7@00<Ad0034M000a7@00<Ad
0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad
0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad
0034M000a7@00<Ad0034M000a7@00<Ad0034M000K7@00a5dM01EM000K7@00e]GM01EM000K7@01EMK
EfYE05=d001/M007FeMKEfYYJP1AM000Jg@02e]GFeMKEe]EJUDA04id001[M00;Ee]GFeMKEe]YJVT0
CW@006]d00aKEe]GFeMKEe]EJUE=M000Jg@03EMKEe]GFeMKEe]GJVT0C7@006Yd00mGFeMKEe]GFeMK
Ee]GJUD0Bg@006Yd011KEe]GFeMKEe]GFeMKEfYYBW@006Yd015GFeMKEe]GFeMKEe]GFeMKE@19M000
JG@04UMKEe]GFeMKEe]GFeMKEe]GFdUd001YM00CFeMKEe]GFeMKEe]GFeMKEe]GF`18M000JG@05EMK
Ee]GFeMKEe]GFeMKEe]GFeMKE`16M000JG@05U]GFeMKEe]GFeMKEe]GFeMKEe]GFeM5M000J7@06E]G
FeMKEe]GFeMKEe]GFeMKEe]GFeMKEa40@g@006Qd011GFeMKEe]GFeMKEe]GFeMK2EM3M000J7@05U]G
FeMKEe]GFeMKEe]GFeMKEe]GFeL2F`03Ke]d045d001WM0034EMG01EG00=_Efl0@W@006Qd01]LEe]G
FeMKEe]GFeMKEe]GFeMKEe]GKe]_Ffl0@G@006Qd00=3G4<055L01FmGKeM_041d001XM00DG4=L@e]G
FeMKEe]GFeMKEe]GFeL2F`06Ke]_FfmK@7@006Qd00I3G4=L@e`?E`08KeM_EfmGKeLoM000J7@07Ua3
G4=L@ea3FeMKEe]GFeMKEe]GKe]_FfmKKe]_Fcid001XM009@ea3G4=L@ea300aG00U_EfmGKeM_Efl0
?W@006Qd019L@ea3G4=L@ea3G5MKEe]GFeL2F`0;Ke]_FfmKKe]_Ffl0?G@006Qd00e3G4=L@ea3G4=L
@ea300IG00e_EfmGKeM_EfmGKeM_03ad001XM00PG4=L@ea3G4=L@ea3G4=KEe]GKe]_FfmKKe]_FfmK
Ke/lM000J7@044=L@ea3G4=L@ea3G4=L@e`3E`0>KeM_EfmGKeM_EfmGKeLkM000J7@08Ua3G4=L@ea3
G4=L@ea3G4=L4FmKKe]_FfmKKe]_FfmKKe/jM000J7@03T=L@ea3G4=L@ea3G4=L0d<04EaGKeM_EfmG
KeM_EfmGKeM_03Yd001XM00SG4=L@ea3G4=L@ea3F4=H@eaGG5]_FfmKKe]_FfmKKe]_Ffl0>G@006Qd
00Q3G4=L@ea3G0U301=L@eaGKeM_EfmGKeM_EfmGKeM_03Qd001XM00TG4=L@ea3F4=H@eQ3F4=HEeaG
G5MLFfmKKe]_FfmK<5]_FfmK>7@006Qd00=3G4<034<05Ua3G4=L@fmGKeM_EfmGKeM_EfmGKeLgM000
J7@09Q53F4=H@eQ3F4=H@eQ3G5MLEeaGG5M_FfmKKe]_FfmKKe]_FflA=W@006Qd00<G@d<034<05Ua3
G4=L@ea3KeM_EfmGKeM_EfmGKeLgM000J7@09C0[F4=H@eQ3F4=H@eQGG5MLEeaGG5MLEfmKKe]_FfmK
Ke]_Fg<0=g@006Qd00<G;1L02T<065a3G4=L@ea3G4=LEfmGKeM_EfmGKeLWKcMd001XM00R<2/`@eQ3
F4=H@eQ3G5MLEeaGG5MLEeaGG5]_FfmKKe]_F`9_00=cM7@0=G@006Qd00@G;1L/2D<055a3G4=L@ea3
G4=L@eaGKeM_EfmG0Vl00g=_M00fM000J7@09C0[<2/`@eQ3F4=HEeaGG5MLEeaGG5MLEeaGG5]_FfmK
Ka=cKg<0=g@006Qd00HG;1L/5b`5@`0JG4=L@ea3G4=L@ea3G4=L@fmGKeM_4W=_LflgM000J7@09C0[
<2/`:eQ3F4=LEeaGG5MLEeaGG5MLEeaGG5M_FfmKLfmcKg<0=g@006Qd00LG;1L/5b`G00A301YL@ea3
G4=L@ea3G4=L@ea3G4=_EbM_LfmcKcMd001XM00N<2/`:c0[<5]HEeaGG5MLEeaGG5MLEeaGG5MLEeaG
0Vl01G=_Lfmc03Md001XM00U4A8G;1L/5b`AG4=L@ea3G4=L@ea3G4=L@ea3G4=L4G=_LfmcK`0gM000
J7@09A8V9bHW9RM3F5MLEeaGG5MLEeaGG5MLEeaGG5MLFg1_LfmcKg<0=g@006Md02I_4BHB9Q8V@dA3
A4=G@eM3Ed=G@eM3Ed=G@eM3Ee]LFd=_LfmcKcMd001VM00W9a4A9RLV9d=H@eQ3G5MLEeaGG5MLEeaG
G5MLEeaKL5]`KW=_Lfmc03Md001UM00X9W@BEbHB9T=4@dA3A4=G@eM3Ed=G@eM3Ed=G@eMKG5]LFg<[
LfmcKcMd001TM00Y9bHB4U/V9d=H@eQ3F4=H@eaGG5MLEeaGG5MLEeaKL5]`Fg1^LfmcKg<0=g@006Ad
02TB9Q8WEbI3A4=4@dA3A4=4@eM3Ed=G@eM3Ed=GFeaKG5]LFg=^@fmcK`0gM000Hg@0:RHA4BLBFd=H
@eQ3F4=H@eQ3F5MLEeaGG5MLEeaKL5]`Fg1KL5]cKTA_LcMd0015M0034GAd00Ad00<AM7@04g@0:a8V
4BLB9eM4@dA3A4=4@dA3A4=G@eM3Ed=G@eMKG5]LFeaKG5]LKW<[Lfl0=g@003id0Q403RDA9A4i9CTU
>BDj9CXU1CT00a5dM00<M00[4A8V9RLAFd=H@eQ3F4=H@eQ3F4=LEeaGG5MLFg1KL5]`Fg1KL5]cKW<_
L`0gM000?7@64@LU014j9CXU>RDi9CTU>BDi9CTU>@034@Ad0Q40:Q8A4ChWEdA3A4=4@dA3A4=4@dA3
Ed=G@eMKG5]LFeaKG5]LFea^LficKcMd000jM08A01DU4BDA>BDi9CTU>RDj9CXU>RDj9A4043T0;14V
4ULoEa9K@eM3Ed=H@eQ3F4=H@eQGG5MLFg1KL5]`Fg1KL5]`Fg=^Lfic=g@003Md1a459@0U>RDj9CXU
>RDj9ChV>RIB?E8mDSeB9CTU>BDi9CTU>BDi9CTU4@02E`0T?ULnEciG?ULnA4=4@dA3Ee]LFeaKG5]L
FeaKG5]LKW=^LfhA=W@003Id0Q4042DA9A4i9CTU>RDj9CXU>RD2>P07?SXn>Shj?P0?DPXi02=G@eM3
Ed=G@eM3Ed=G@a5KL5]`Fg1KL5]`Fg1KL5]cKW=^L`0gM000=G@54@DU04dj9CXU>RDj9ShV>RHj9SXV
>RIB?E8mDSeB?E8mDSeB?E8mDSeB?E8mDRDi9CTUEciG?ULnEciG@ea3FeMLFeaKG5]LFeaKG5]LFg=^
L`0hM000<g@34@0L9A4i9CXU>RDj9CXU?SXn>Shj?SXn>Shj?SXn4AiB01`A@eM3G5MLEeaKL5]`Fg1K
L5]`Fg1KL5]`KW=^>7@0039d11459@0K>RDj9ShV?RHj9SXV>RHj9SXV?bHn9UMBEe9G009B02LiDSUB
>E8iDSUB>E8iDSUB>E8iDSUB>E8iDD=L@ea3G4=KEe]GFeL00U/02UaKG5]LFeaKLfhiM000<7@24@08
9A4i9CXU>RD2>P0<?SXn>Shj?SXn>Shj0Sh0@Clj?SXn>SiFEeIGEUMFEeIGEULmDSeB?E8mDSeB?E8m
DSeB?E8mDSeAEeaGG5MLFg1KL5]`Fg1KL5]`Fg1KL6ic03Ud000_M0@A12D0:chV?RHn9ShV>RHj9SXV
?cho9ShV?RHn9SiBEe9GDUMBEe9GDUMBEe9GDUL00U809SUB>E8iDSUB>E8iDSUB>E4iG4=L@eaGFeMK
Ee]GFeMKEeaKG5]c>W@002ed00<A4Q800a80Ea4n>Shj?SXn>Shj?SXo?Sln?cXn>Shj?SXn>ShjEeIG
EUMFEeIGEUMFEeIGEUMFEeIGEUMFEceB?E8mDSeB?E8mDDeLEeaGL5]`Fg1KL5]`Fg1KL5]`KP0jM000
;7@00a4B4@044P0k?RHn9ShV>RHj?Sln?cho9ShV?RHn9ShV?RHn9UMBEe9GDUMBEe9GDUMBEe9GDUMB
Ee9GDUMBEe9GDUL00U806SUB>E8iDCUA@eaGFeMKEe]GFeMKEe]GFeLA>W@002]d00<A4Q801A80ECXn
>Shj?cho?Sln?cXn>Shj?SXn>Shj?SXn>SiFEeIGEUMFEeIGEUMFEeIGEUMFEeIGEUMFEeIGEUMFEeIG
EUMFEa5ACE5GL5]`Fg1KL5]`Fg1KL5/0?7@002]d0Q454P8A05Dn?cho?Sln?bHn9ShV?RHn9ShV?RHn
9ShV?Q5B?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?VYFDCUA>E]GFeMKEe]GFeMK
EgAK03]d000ZM0TB01/n?cho?Slj?SXn>Shj?SXn>Sho@cm3?d<n?ch01EL08E9FDUIBEU9FDUIBEU9F
DUIBEU9FDUIBEU9FDUIBEU9FDP02EP0BKeI_CE5=L5]`Fg1KL5]`H7AP?7@002Ud0Q454P0;4A8A?cho
9ShV?RH00Sh02D<n@ci3?T<n@`02?P0k9ShV?RIG@eM3Ed=G@eM3DSiB?U8nDSiB?U8nDSiB?U8nDSiB
?U8nDSiB?U9FJUIZEVXiDCUAEe]GFeL00U/00gAKM00lM000:G@00a4B4P054P8A01To@cm3?d<o@cm3
?d<o@cm3?Sln?cho?Sln011G02YFDUIBEU9FDUIBEU9FDUIBEU9FDUIBEU9_EVmFKeI_ESU=DE]`FgAP
M60nM000:7@00dDA4@034P0@4A8A4Si3?T<n@ci3?T<n@`8n04LV?RHn9ShV?RHn9UM3Ed=G@eM3Ed=G
@eM3Ed=G@eM3EciB?U8nDSiB?U8nDSiB?U8nDSiBEVYFJUIZEVYFJSUA>GAKM5]dF`0mM000:7@74P0<
4A8A@cm3?d<o@cm30Sl03Sho?Sln?cho?Sln?cho6UL03E9FDUIBEU9FDUIBEU800UH02fmFKeI_EVmF
KeI_008i00E=M61dH00nM0009g@00eXA4P024P1E4A8A4Q53?T<n@ci39ShV?RHn9ShV?RHn9ShV?RHn
@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@e8nDSiB?U8nDSiZEVYFJUIZEVYFJUIZEP02>@03
DE]d03id000WM00<4A8B4Q4B4A8A4Sm30Sl053ho?Sln?cho?Sln?cho?Sln?cho9EL015IBEU82EP0?
KeI_EVmFKeI_EVmFKeI_008i?g@002Md0a80FQ4B4A8A4Q4n9ShV?RHn9ShV?RHn9ShV?RHn9ShV?Q5G
@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ea5ZEVYFJUIZEVYFJUIZEVYFJP8i
00<AM7@0>g@002Id0a801A4B4A8A008B0413?d<o@cm3?d<o@cm3?d<o@cm3?Sln?d=H@eQ3Ee9GDUMB
Ee9GDUMBEe9GDUMBEe9GDUMBEe9GDUMBEe9GDUMB0UL056mGJU9_EVmFKeI_EVmFKeI_EVmF0STlM000
9W@0BA4B4A8A4Q4B4D<o@cm3?d<o@cm3?d<o@bXo:SlZ?bXo@eM3Ed=G@eM3EciG?ULnEciG?ULnEciG
?ULnEciG?ULnEciG?ULnEch00UL025]GFeMKDEIA0UH03VYFJUIZEVYFJUIZEVXi>g@002Ed00<A4Q40
1a8023m3?d<o@cm30Sl0D3ho?Sln?cho?Sln?d=H@eQ3F4=H@eQ3F4=GDUMBEe9GDUMBEe9GDUMBEe9G
DUMBEe9GDUMBKeM_EfmGKeM_EfYBJU9ZDVmFKeI_EVmFKeI_0STiM0009G@03A8A4Q4B4A8A4Sm3?d<0
0Sl0CBXo:SlZ?bXo:SlZ?bXo:Sm3Ed=G@eM3Ed=G@eM3Ed=G@eLnEciG?ULnEciG?ULnEciG?ULnEciG
?U]GFeMKEe]GFeMKEe]AEU5FDEIA009F00UZEVYFJUIZEST0>7@002Ad00<A4Q801Q80H14o?Sln?cho
?Sln?cho?Sln?cho?Sm3F4=H@eQ3F4=H@eQ3F4=H@eQ3F4=HDUMBEe9GDUMBEe9GDUMBEe9GDVmGKeM_
EfmGKeM_EfmGKe9ZDVYBJU9ZDVYBKeI_EVmFKcMd000UM0PB03a3:d<[@bXo:SlZ?bXo:SlZ?bXo:Sm3
Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3EciG?ULnEciG?ULnEch2E`0NFeMKEe]GFeMKEe]GFeMKEe]G
EU5FDEIAEU5FDEIA0UH016YFJSTeM0009G@00a8C4P044P0lA2]4:d@[A2]4:cln?cho?Sln?cho@eQ3
F4=H@eQ3F4=H@eQ3F4=H@eQ3F4=H@eQ3F4=H@eMBEe9GDUMB0UL09VmGKeM_EfmGKeM_EfmGKeM_EfmG
Ke9ZDVYBJU9ZDVYBJU9ZDVmF=7@002Ed1a80>b]3:d<[@b]3:d<[@b]3:clZ?bXo@eM3Ed=G@eM3Ed=G
@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G?ULn009G02UKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMFDEIA
EU5FDEIAEU5FDEIA4@0bM0009G@0118C4Q<24P1W:d@[A2]4:d@[A2]4:d@[A2]4:d@AF4=H@eQ3F4=H
@eQ3F4=H@eQ3F4=H@eQ3F4=H@eQ3F4=H@eQ3F4<AEfmGKeM_EfmGKeM_EfmGKeM_EfmGKeM_EfmGJU9Z
DVYBJU9ZDVYBJU9ZDP0bM0009G@54P0D4ClZ?bXo:SlZ?bXo:SlZ?bXo:Sl4@`1@?ULnEciG?ULnEciG
?ULnEciG?ULnEciG?ULnEciG?ULnEciG@eMFEeIKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKDEIAEU5F
DEIAEU5FDEHbM0009G@0?A8C4Q<B<2/o:cl[?b/o:cl[?b/o:cl[?d=H@eQ3F4=G@eM3Ed=G@eM3Ed=G
@eM3Ed=G@eM3Ed=G@eM3Ed<00UL0;eaGG5MLEf]FJeI[EVmGKeM_EfmGKeM_EfmGKeM_EfmGKeMZDVYB
JU9ZDVYBJU9]035d000UM0@B1B/03RXo:SlZ?bXo:SlZ?bXo2T<0CCiG?ULnEciG?ULnEciG?ULnEciG
?ULnEciG?UM3Ed=G@eM3Ed=GEUMFEeIGEUMFFeMKEe]GFeMKEe]GFeMKEe]GFe5FDEIAEU5FDEIE035d
000UM01_4Q<B4b/`:c0[<2/o:cl[?b/o:cl[?d=H@eQ3F4=H@eQ3F4=G@eM3Ed=G@eM3Ed=G@eM3Ed=G
@eM3Ed=LEeaGG5MLEeaGG5MLEV]FJeI[EV]FJeI[EVmGKeM_EfmGKeM_EfmGKeMZDVYBJU9ZDVeY031d
000UM08A00<B4B/022/022Xo:SlZ?bXo44<0BSiG?ULnEciG?ULnEciG?ULnEciG@eM3Ed=G@eM3Ed=G
@eM3EeIGEUMFEeIGEUMFEeIGEUMFFeMKEe]GFeMKEe]GEU5FDEIAEUEY<7@002Id0Q80KB`[A2]4:c0[
<2/`:cl[?b/o@eQ3F4=H@eQ3F4=H@eQ3F4=H@eQ3Ed=G@eM3Ed=G@eM3Ed=LEeaGG5MLEeaGG5MLEeaG
G5MLEf]FJeI[EV]FJeI[EV]FJeI[EV]FKeM_EfmGKeM_DVYBJU9]JFd0;g@002Id00<A4QL03B/00bXo
@`0F@`16EciG?ULnEciG?ULnEd=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@eMFEeIGEUMFEeIGEUMFEeIGEUMF
EeIGEU]GFeMKEeIAEUEYEBmd000VM08B030/5b`[A2]4:d@[A2]4:d@AF4=H@eQ3F4=H@eQ3F4=H@eQ3
F4=H@eQ3F4=G@eM3Ed<2E`0lG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5I[EV]FJeI[EV]FJeI[EV]F
JeI[EV]FJeI[EVmGKe9]JFeY;W@002Id0Q400aL[5`0<:`0>A2]3?d<o@cm3?d<o@cl>@`13EciG?UM3
Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=GEUMFEeIGEUMFEeIGEUMFEeIGEUMFEeIGEUMFEeIG4FUE
J@0^M0009W@0Ja8G;1L/5b`[A2]4:d@[A2]4;d@_F4=H@eQ3F4=H@eQ3F4=H@eQ3F4=H@eQ3F4=H4EaG
G5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGJeI[EV]FJeI[EV]FJeI[EV]FJeI[EV]FJeI[009_
00AYKFU];G@002Id00<A5a<00QL00b/G:`07:`0NA2]4:d@[A3m3?d<o@cm3?d<o@cm3?d<o@cm3?d<o
0T<00dA3E`04E`0k@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3EeIGEUMFEeIGEUMFEeIGEUMFEeIG
EUMFKe]_FfmEJED0;G@002Id06PA5aPG;1L/5d@[A2]4:d@_A2m4;d@_A4=H@eQ3F4=H@eQ3F4=H@eQ3
F4=H@ea3G4=L@e]GFeMKEe]GG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5I[EV]FJeI[EV]FJeI[EV]F
JeI[EPI_00=AJFd0;G@002Id00<C5a<011L00b/G:`05:`0JA2]4:d@[A2]4?d<o@cm3?d<o@cm3?d<o
@cl2@`08A4=4@dA3A4<=E`0b@eM3Ed=G@eM3Ed=G@eM3Ed=G@eMFEeIGEUMFEeIGEUMFEeIGEUMKKe]_
FfmKKe]YEFT/M0009W@0IA4C61LH5b`G;1M4:d@_A2m4;d@_A2m4;d@_F4=H@eQ3F4=H@eQ3F4=H@ea3
G4=L@ea3G4=LEe]GFeMKEe]GFeMKEe]GG5MLEeaGG5MLEeaGG5MLEeaGJeI[EV]FJeI[EV]FJeI[00]_
00=]JG@0:g@002Md00@G4aLC1QL2:`0YA2]4:d@[A2]4:d@[A2]3?d<o@cm3?d<o@cm4@dA3A4=4@dA3
A4=4@d@055L0:D=G@eM3Ed=G@eM3Ed=GEUMFEeIGEUMFEeI_FfmKKe]_FfmKKe]_>FUE02]d000XM01P
5a<H5b`G;1L/4D@_A2m4;d@_A2m4;d@_A2mH@eQ3F4=H@eQ3G4=L@ea3G4=L@ea3G4=L@eaGFeMKEe]G
FeMKEe]GFeMKEe]GFeMKEeaGG5MLEeaGG5MLEV]FJeI[EV]F3fl00fU]M00ZM000:G@011LC5a<45`0H
<1M4;d@_A2]4:d@[A2]4:d@[A3m3?d<o0T<054A3A4=4@dA3A4=4@dA3A4=4@dA36eL084=G@eM3EeIG
EUMFEe]_FfmKKe]_FfmKKe]_FfmKKeEY:W@002Yd00LG4aPG;1L/00<`0554;d@_A2m4;d@_A2m4;d@_
A4=H@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@e]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEeaG
G5M[EV/04fl00e5YM00YM000:g@24`@G030`5c0GA2m4;d@_A2m4;d@_A2m4;d@AA4=4@dA3A4=4@dA3
A4=4@dA3A4=4@dA3A4<RE`0H4E]_FfmKKe]_FfmKKe]_FfmKKe]_Fe5E:G@002]d00DC5a<H5`06<01>
A2m4;d@_A2m4;d@_A2m4;dA3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=LEe]GFeMKEe]GFeMKEe]G
FeMKEe]GFeMKEe]GFeMLFeaK5Vl00fedM00WM000;7@34`0e4AL`5c0G<1M4;d@_A2m4;d@_A2m4;d@_
A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4=4@d@06EL07e]GFeMKEe]GKeI_FfmKKe]_FfmKKe]_FfmK
Ke]_>FT0:7@002ed00<C5a`00Q`7<00o;d@_A2m4;d@_A2m4;d@_A4=L@ea3G4=L@ea3G4=L@ea3G4=L
@ea3G4=L@eaGFeMKEe]GFeMKEe]GFeMKEe]G009K00iLFeaKG5]LFeaKG5]_JQ=_00=AM7@09W@002id
03TC71LL5a`G<1L`5c0_A2m4;d@_A2m4;d@_A2m4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4<0
3UL0:5]GFeMKEe]GFeMKEe]GFeMKEfmFKeI_FfmKKe]_FfmKKe]_FfmKKa4WM000;g@57004<1``70<`
054_A2m4;d@_A2m4;d@_A2m4@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=KEe]GFeMKEe]GG5]L
FeaKG5]LFeaKG5]LFeaKG5]LJVmZKfX046l00e5dM00UM000;g@0>Q4G71LL5a`G71LL5c0_A2m4;d@_
A2m4;d@_A2m4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4<6E`0_FeMKEe]GFeMKEe]GFeMKEe]G
FeMKEe]GFeI_EVmFKeI_FfmKKe]_FfmKKe]_Fe409W@0035d00<K71`00Q`0FS0L<1``730AA2m4;d@_
A2m4;d@_A2m4@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4<AFeaKG5]LFeaKG5]LFeaKG5]LFeaK
G5]LFeaKG5]LJVmZKfY_JPi_9W@0039d06dA71LL5a`G71LL5a`G<2m4;d@_A2m4;d@_A2m4@dA3A4=4
@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4=KEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEVmFKeI_
EVmFKe]_FfmKKe]_Ffli02Ed000dM0039A/K00<L05X`730L<1`d<3@`A2m4;d@_A2m4;dA3G4=L@ea3
G4=L@ea3G4=L@ea3G4=L@ea3G4=L@fmGKe]LFeaKG5]LFeaKG5]LFeaKG5]LFeaKG5]LFeaZKfY_JVmZ
KfX;K`03DGAd029d000gM01Y71LL5a`G71LL5c0_<2l`;c0_A2m4;d@_A4=4@dA3A4=4@dA3A4=4@dA3
A4=4@dA3A4=4@dA3FeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GKeI_EVmFKeI_EVmFKe]_FfmK
Ke]_02Ad000jM01N6a4`730L<1`i<3@`=30d<3@_A2m4;dA3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3
G4=LEfmGKeM_EeaKG5]LFeaKG5]LFeaKG5]LFeaKG5]LFfmZKfY_JVmZKfY_JPQ_00=AM7@08G@003ad
06DG71LL5a`G72l`;c0_<2l`;c0_A2m4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A5MKEe]GFeMK
Ee]GFeMKEe]GFeMKEe]GFeMKEe]GFeM_EVmFKeI_EVmFKeI_EVmKKe]_F`0SM000?W@01Q4K71``708`
05Hd<3@`=30d<3@`=30A@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3G5M_EfmGKeM_EfmKG5]LFeaK
G5]LFeaKG5]LFeaKG5]_JVmZKfY_JVmZKfY_JPI_8W@0045d068K5a`G72l`;c0_<2l`:c0[<2]4@dA3
A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3FeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeM_EVmF
KeI_EVmFKeI_EVmFKe]_>B5d0014M00571L`<3@00S00EBl`;c0_<2l`;ea3G4=L@ea3G4=L@ea3G4=L
@ea3G4=L@ea3G4=_EfmGKeM_EfmGKeM_EeaKG5]LFeaKG5]LFeaKG5]LJVmZKfY_JVmZKfY_JVmZKfX0
0flQM000Ag@0GA/A6aLA:c0[<2/`:c13A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4=4@e]GFeMKEe]G
FeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]FKeI_EVmFKeI_EVmFKeI_EVmFK`0PM000BW@0Fa`_<3T`;c0_
<2l`@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3G5M_EfmGKeM_EfmGKeM_EfmGKe]LFeaKG5]LFeaK
G5]LJVmZKfY_JVmZKfY_JVmZKfY_JQ407g@004ad05PG<2/`9C0[<2/`@dA3A4=4@dA3A4=4@dA3A4=4
@dA3A4=4@dA3A5MKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEVmFKeI_EVmFKeI_EVmFKeIc
87@004ed05LG>Bl`;c0_<2mL@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3G5M_EfmGKeM_EfmGKeM_
EfmGKeM_EeaKG5]LFeaKG5]LJVmZKfY_JVmZKfY_JVmcM7<087@0051d04lG<2/`:c0[A4=4@dA3A4=4
@dA3A4=4@dA3A4=4@dA3A4=4@e]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GKeI_EVmFKeI_
EVmF009_00=cKg<087@0051d05@i4A`_<2l`;ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=_EfmG
KeM_EfmGKeM_EfmGKeM_EfmGKeM_FeaKG5]LFfmZKfY_JVmZKfYdLgAcM7<PM000DW@0BA<G5c0[<4=4
@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3FeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeM_
EVmFKeH00Vl01g=_LfmcKg<087@005=d054C5a<L;c13G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=L
EfmGKeM_EfmGKeM_EfmGKeM_EfmGKeM_EfmGKeMLFeaKKfY_JVmcM7=dLgAcM7<087@005=d00AZ4aLC
0QL0Bc13A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4=4Ee]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]G
FeMKEe]GKeIcKg=_LfmcKg=_L`0PM000E7@0D6XC5a<G4a53G4=L@ea3G4=L@ea3G4=L@ea3G4=L@ea3
G4=LEfmGKeM_EfmGKeM_EfmGKeM_EfmGKeM_EfmGKeM_EflAM7=dLgAcM7=dLgAc87@005Ed04mZ4aLC
5a=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA34E]LFeaKG5]LFeaKG5]LFeaKG5]LFeaKG5]LFeaK
G5]LKg=_LfmcKg=_Lfmc021d001FM01>JQ<G4aM4B4AL@ea3G4=L@ea3G4=L@ea3G4=L@ea3G4=L@g1K
L5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KKW=dLgAcM7=dLgAc87@005Ed0Q408ShC5a=4;d@_
A4=4@dA3A4=4@dA3A4=4@dA3A4=4@dA3A5L2F`0YG5]LFeaKG5]LFeaKG5]LFeaKG5]LFeaKG5]LFea]
LfmcKg=_LfmcKg<087@0051d04PAKe4iDCTG4a8C5dA8A4Q4B4AL@ea3G4=L@ea3G4=L@ea3G4=L@ea3
L5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5/2KP0:M7=dLgAcM7=dLb1d001@M008B4diCCTn
>BH24P1:4d@_A2m4;d@_A4=4@dA3A4=4@dA3A4=4@dA3A4=4Ee]GFeMLFeaKG5]LFeaKG5]LFeaKG5]L
FeaKG5]LFeaKKVmcKg=_LfmcKg<PM000Cg@0BUaPG54i4CXn4RHC4TA8A4Q4B4A8A4Q3G4=L@ea3G4=L
@ea3G4=L@ea3G5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`0Vh01g=dLgAcM7<08W@004md
00]PB618CCTn>BHU4P024@0S;d@_A2m4;d@_A2m4@dA3A4=4@dA3A4=4@dA3A4=KEe]GFeL00U/08UaK
G5]LFeaKG5]LFeaKG5]LFeaKG5]LFfi]LfmcKg=_LflQM000CW@02F1LH5aPKe4i?P029P8B03h_F4=8
A4Q4B4A8A4Q4B4=L@ea3G4=L@ea3G4=L@eaKL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL0=^
00IdLgAcM7<RM000CW@044QPB618H3U=4BHU4R/`:e`3@`12A2m4;d@_A2m4;dA3A4=4@dA3A4=4@dA3
FeMKEe]GFeMKEeaKG5]LFeaKG5]LFeaKG5]LFeaKG5]^KFi_LfmcKg=_8G@004ed04eLH5aPG61LH3TH
5aPA9Q8V4Q53F4=H@dQ4B4A8A4Q4B4=L@ea3G4=L@ea3G4=`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`
Fg1KL5]`F`03KP05LgAcM7<08W@004ed01=PB618H4QPB7<i9Q4V4BH[<2/`00M301i4;d@_A2m4;dA3
A4=4@dA3A4=4Ee]GFeMKEe]GFeL2F`0LG5]LFeaKG5]LFeaKG5]LFeaKG6e^KFi_LfmcKb5d001<M01>
H5aPG61LH5aPG7<B9Q8H@d@_A2m4@eQ3F4=H@eQ3B4A8A4Q4G4=L@ea3G4=L@g1KL5]`Fg1KL5]`Fg1K
L5]`Fg1KL5]`Fg1KL5]`Fg1K16h017AcM7<RM000C7@03DQPB618H4QPB6184CT00aL01cm3:c0[<5/0
2T<0=T@_A2m4@dA3A4=4@dAGFeMKEe]GFeMKEe]GFeMLFeaKG5]LFeaKG5]LFeaKG6e^KFi]LfmcKb5d
001;M01@G61LH5aPG61LH5aPG7<i61Mc@eL_A2m4;eQ3F4=H@eQ3F4=H@dQ4B4AL@ea3G4=LFg1KL5]`
Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg04KP03LgAc029d001:M00AB618H4QPB618H4QPB61_LcT0
0QL025`o@cl`:c0[3T<064@_A4=4@dA3FeMKEe]GFeMKEe]GFeMKE`9K01ILFeaKG5]LFeaKG5]LFfi]
KVe^Kg=_8G@004Yd055PG61LH5aPG61LH5aPG61_LeLH5ea3Ed=4;d@_F4=H@eQ3F4=H@eQ3F4=H@dQ4
G4=LFg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg001Fh00gAcM00QM000BG@07V18H4QPB618
H4QPB618H4QPKe4n5e]3?d<o@b/`:a9302Y4@e]GFeMKEe]GFeMKEe]GFeMKEe]GG5]LFeaKG5]LFeaK
KVe^KFi]LflQM000BG@0DUaPG61LH5aPG61LH5aPG61LLfmAEaQLEd=G@eL_A2mL@eQ3F4=H@eQ3F4=H
@eQ3F4=H4G1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg06KP03LgAd021d0018M00RB618H4QP
B618H4QPB618H4QPB7=_EchGFd<o@cl`:c0[<15300=`Fe`00U/04EMKEe]GFeMKEe]GFeMKEe]G009K
011LFeaKG5]LFea]KVe^KFi_8G@004Qd01IPG61LH5aPG61LH5aPG61LH5aPG7<i0UL0?1QLEd=G@eL_
A2m4@eQ3F4=H@eQ3F4=H@eQ3F5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`F`I^00<AM7@0
7g@004Md02EPB618H4QPB618H4QPB618H4QPB618LcUG?QMK@cm3?d<o<2/`00m300]`Fg1KG5]LFeaK
G002F`0JEe]GFeMKEe]GFeMKEeaKG5]LFea]KVe^KFhRM000Ag@065aPG61LH5aPG61LH5aPG61LH5aP
G61_L`=G03XHG5M3Ed=G@d@_A4=H@eQ3F4=H@eQ3F4=HFg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1K
L5]`Fg1K1FhSM000AW@0:DQPB618H4QPB618H4QPB618H4QPB618H6mL?ULn5cm3?d<o@cm3:c0[00a3
01a`Fg1KG5]LFeaKG5]LFeaKG5]LEe]GFeMKEe]G0U/01eaKG5]^KFh097@004Ed01`AH5aPG61LH5aP
G61LH5aPG61LH5aPG61LH5aA0eL0>AQ3Ed=G@eM3Ebm4;eQ3F4=H@eQ3F4=HFg1KL5]`Fg1KL5]`Fg1K
L5]`Fg1KL5]`Fg1KL5]`Fg1KL003KRAd0016M1UG018A@eLnEciG?d<o@cm3?d<o<2/9@`0UFg1KL5]`
FeaKG5]LFeaKG5]LFeaKG5]LFeaKG5MKEe]GG5]^K@0UM000AW@075aGKeM_EfmGKeM_EfmGKeM_EfmG
KeM_EfmGF4<5E`0g@eM3Ed=G@eM3A2mH@eQ3F4=H@g1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`
Fg1KL5]`KP0VM000AW@00eMKE`0GE`0C@eLiEciG5eLo@cm3?d<o@cm3:`07@`0TFg1KL5]`Fg1KG5]L
FeaKG5]LFeaKG5]LFeaKG5]LFeaKG5/A9W@004Id01eLEeaGKeM_EfmGKeM_EfmGKeM_EfmGKeM_Efm3
F004E`0f5eM3Ed=G@eM3Ed=G;dA3F4=H@g1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`
9g@004Id00AGFeMK65L054=G?ULnEaM3?d<o@cm3?d<o@cl`14<08e]`Fg1KL5]`Fg1KG5]LFeaKG5]L
FeaKG5]LFeaKG5]LFeaK02Md0016M00OG5MLEeaGKeM_EfmGKeM_EfmGKeM_EfmGKeM_EeQ3F004E`0d
5eM3Ed=G@eM3Ed=G@dA3F4=`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL2Md0016M006
Ee]GFeMK5UL05D=G@e4nEciG5d<o@cm3?d<o@cm3?`03@`0RFg1KL5]`Fg1KL5]LFeaKG5]LFeaKG5]L
FeaKG5]LFeaKG2Qd0016M00PG5MLEeaGG5M_EfmGKeM_EfmGKeM_EfmGKeM_Efm3F4<5E`0a5eM3Ed=G
@eM3Ed=G@eLAL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`F`0XM000AW@025MKEe]GFeMK
5UL024=G@eLnEciG0T<0;Sm3?d<o@cm3?d<oL5]`Fg1KL5]`Fg1KL5]LFeaKG5]LFeaKG5]LFeaKG5]L
Fe`XM000Ag@08EMLEeaGG5MLEeaGKeM_EfmGKeM_EfmGKeM_Efm3F4=H>@05E`0^@eM3Ed=G@eM3Ed=d
Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL2Ud0017M00;FeMKEe]GFeMKEe/04UL0=d=G
@eLnEciG?ULo@cm3?d<o@cm`Fg1KG5]LFg1KL5]`Fg1KL5]LFeaKG5]LFeaKG5]LFeaKG5/0:G@004Md
029GG5MLEeaGG5MLEeaGKeM_EfmGKeM_EfmGKeM_EeQ3F4=H1UL0;4=G@eM3Ed=GFgAKM5]`Fg1KL5]`
Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`:G@004Md00eKEe]GFeMKEe]GFeMK019G03A3Ed=G?ULnEciG
?d<o@cm3Fg1KL5]LFeaKG5]`Fg1KL5]`Fg1KG5]LFeaKG5]LFeaKG5]L:W@004Md02=GG5MLEeaGG5ML
EeaGG5M_EfmGKeM_EfmGKeM_Efm3F4=H@`07E`0Y@eM3Ee]dFgAKM5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`
Fg1KL5]`Fg1KL5/0:W@004Md00mKEe]GFeMKEe]GFeMKEe/045L0=4=G@eM3EciG?ULnEcm3?g1KL5]`
FeaKG5]LFeaKL5]`Fg1KL5]`FeaKG5]LFeaKG5]LFe`ZM000Ag@09EMLEeaGG5MLEeaGG5MLEeaGKeM_
EfmGKeM_EfmGKeMH@eQ3F4<01eL09T=dFgAKM5]dFg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`
:g@004Md015KEe]GFeMKEe]GFeMKEe]GF`0>E`0c@eM3Ed=G?ULnEciG?Q5KL5]`Fg1KL5]LFeaKG5]L
FeaKL5]`Fg1KG5]LFeaKG5]LFeaK02]d0017M00VEeaGG5MLEeaGG5MLEeaGG5MLEfmGKeM_EfmGKeM_
Efm3F4=H@eP5E`0WM5]dFgAKM5]dFg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`02]d0018M00B
Ee]GFeMKEe]GFeMKEe]GFeMK3UL0<4=G@eM3EciGFg1KG5]`Fg1KL5]`FeaKG5]LFeaKG5]LFg1KL5]`
FeaKG5]LFeaKG2ad0018M01@G5MLEeaGG5MLEeaGG5MLEeaGG5M_EfmGKeM_EfmGKeMH@eQ3F4<AFgAK
M5]dFgAKM5]dFgAKL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5//M000B7@055MKEe]GFeMKEe]GFeMK
Ee]GFeMK35L0<4=G@eM3Ee]`Fg1KG5]LFg1KL5]`FeaKG5]LFeaKG5]LFeaKG5]`Fg1KG5]LFeaKG2ad
0018M01?G5MLEeaGG5MLEeaGG5MLEeaGG5MLEfmGKeM_EfmGKeM_@eQ3F4=dFgAKM5]dFgAKM5]dFgAK
L5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL00]M000B7@05UMKEe]GFeMKEe]GFeMKEe]GFeMKEe/<E`0]
@eM3Ee]`Fg1KG5]LFg1KL5]`Fg1KG5]LFeaKG5]LFeaKG5]LFg1KL5]LFeaK02ed0018M01?G5MLEeaG
G5MLEeaGG5MLEeaGG5MLEeaGKeM_EfmGKeM_@eQ3F4=dFgAKM5]dFgAKM5]dFgAKL5]`Fg1KL5]`Fg1K
L5]`Fg1KL5]`Fg1KL00]M000B7@065MKEe]GFeMKEe]GFeMKEe]GFeMKEe]GF`YG02a3Ed=GFg1KL5]L
FeaKG5]`Fg1KL5]LFeaKG5]LFeaKG5]LFeaKG5]`FeaKG2id0018M01>G5MLEeaGG5MLEeaGG5MLEeaG
G5MLEeaGG5M_EfmGKeM_EeQ3F4=dFgAKM5]dFgAKM5]dFgAKL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1K
;W@004Qd01YGFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GF`YG02Y3Ee]`Fg1KG5]LFeaKL5]`Fg1KG5]L
FeaKG5]LFeaKG5]LFeaKG5]LFe`^M000B7@0CUaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5M_EfmG
KeM_@eQ3M5]dFgAKM5]dFgAKM5]dFgAKL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`4Bid0019M00MFeMKEe]G
FeMKEe]GFeMKEe]GFeMKEe]GFeMKEe/01UL0:D=GFg1KL5]LFeaKG5]LFg1KL5]LFeaKG5]LFeaKG5]L
FeaKG5]LFeaK02md0019M01;EeaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEfmGKeMH@gAKM5]d
FgAKM5]dFgAKM5]dFg1KL5]`Fg1KL5]`Fg1KL5]`Fg1K031d0019M00OFeMKEe]GFeMKEe]GFeMKEe]G
FeMKEe]GFeMKEe]GF`04E`0W@eMKL5]`FeaKG5]LFeaKL5]`Fg1KG5]LFeaKG5]LFeaKG5]LFeaK035d
0019M019EeaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGKeM_@gAKM5]dFgAKM5]dFgAKM5]d
Fg1KL5]`Fg1KL5]`Fg1KL5]`F`0bM000BG@08E]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]G
F`04E`0SFg1KL5]LFeaKG5]LFeaKL5]`FeaKG5]LFeaKG5]LFeaKG5/0<g@004Ud04QGG5MLEeaGG5ML
EeaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEfmGM5]dFgAKM5]dFgAKM5]dFgAKL5]`Fg1KL5]`Fg1KL5]`
Fg0cM000BG@08e]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMK009G029KL5]`FeaKG5]L
FeaKG5]`Fg1KG5]LFeaKG5]LFeaKG5]L=7@004Ud04IGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5ML
EeaGG5MLEeaGM5]dFgAKM5]dFgAKM5]dFgAKM5]`Fg1KL5]`Fg1KL5]`=G@004Ud02AKEe]GFeMKEe]G
FeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeL2F`0OL5]`FeaKG5]LFeaKG5]LFg1KG5]LFeaKG5]LFeaK
G00fM000BW@0@eaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5MLEgAKM5]dFgAKM5]dFgAK
M5]dFgAKL5]`Fg1KL5]`Fg00=g@004Yd04=GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeLi
9CUKL5]`FeaKG5]LFeaKG5]LFg1KL5]LFeaKG5]LFeaK03Md001:M00MG5MLEeaGG5MLEeaGG5MLEeaG
G5MLEeaGG5MLEe`01cT07WAKM5]dFgAKM5]dFgAKM5]dFgAKL5]`Fg1KL5]`FcQd001:M011Ee]GFeMK
Ee]GFeMKEe]GFeMKEe]GFeMKEcTU>BDi9CTU>BDiFg1KG5]LFeaKG5]LFeaKG5]LFg1KG5]LFeaKG5/0
>G@004Yd01ELEeaGG5MLEeaGG5MLEeaGG5MLEe`03cT077AKM5]dFgAKM5]dFgAKM5]dFgAKM5]`Fg1K
L5/jM000BW@0?eMKEe]GFeMKEe]GFeMKEe]G>BDi9CTU>BDi9CTU>BDi9CTU>E]`FeaKG5]LFeaKG5]L
FeaKG5]`FeaKG5]LF`0kM000BW@03EaGG5MLEeaGG5MLEe`05cT06gAKM5]dFgAKM5]dFgAKM5]dFgAK
M5]`Fg1KL00kM000BW@0?UMKEe]GFeMKEcTU>BDi9CTU>BDi9CTU>BDi9CTU>BDi9CTU>E]`FeaKG5]L
FeaKG5]LFeaKG5]LFeaKG5]L?7@004Yd00ELEeaGG00O>@0IM5]dFgAKM5]dFgAKM5]dFgAKM5]dFg1K
L00mM000BW@0?14i9CTU>BDi9CTU>BDi9CTU>BDi9CTU>BDi9CTU>BDi9CTU>E]`FeaKG5]LFeaKG5]L
FeaKG5]LFg1KG3id001=M00J?ULnEciG?ULnEciG?ULnEciG?ULnEciG?UL7>@0GM5]dFgAKM5]dFgAK
M5]dFgAKM5]dFg00?g@004md03Ho?Sln?cho?Sln?cho?Sln?cho?Sln?cho?Sln?choFg1KG5]LFeaK
G5]LFeaKG5]LFeaKG14oM000DG@0<CiG?ULnEciG?ULnEciG?ULnEciG?ULnEciG?ULnM5]dFgAKM5]d
FgAKM5]dFgAKM5/0@W@005=d02lo?Sln?cho?Sln?cho?Sln?cho?Sln?cho?SmKL5]LFeaKG5]LFeaK
G5]LFeaKG012M000EG@0:ciG?ULnEciG?ULnEciG?ULnEciG?ULnEcidFgAKM5]dFgAKM5]dFgAKM5/0
A7@005Md02Po?Sln?cho?Sln?cho?Sln?cho?Sln?e]`FeaKG5]LFeaKG5]LFeaKAG@005Ud02<nEciG
?ULnEciG?ULnEciG?ULnEcidFgAKM5]dFgAKM5]dF`18M000Fg@08Cln?cho?Sln?cho?Sln?cho?SmK
L5]LFeaKG5]LFeaKG018M000GW@075LnEciG?ULnEciG?ULnEcidFgAKM5]dFgAKM5]:M000H7@06Cho
?Sln?cho?Sln?choFg1KG5]LFeaKG5/0Bg@0069d01AG?ULnEciG?ULnEcidFgAKM5]dFdid001TM00B
?Sln?cho?Sln?e]LFeaKG5]LCW@006Id00iG?ULnEciG?WAKM5]dFe1d001XM00;?Sln?choFeaKG5/0
DG@006Yd00IG?ULnM5]DM000K7@013hoFeaDM000KW@00a5dM01CM000a7@00<Ad0034M000a7@00<Ad
0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad
0034M000a7@00<Ad0034M000a7@00<Ad0000\
\>"],
  ImageRangeCache->{{{0, 195.625}, {287, 0}} -> {0.150211, -0.000880781, \
0.00345369, 0.00345369}}]
}, Open  ]],

Cell["\<\
The triangles approximate the shape quite good. Plotting the mirror \
can take some time.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Timing[ShowSystem[seashellmirror, SurfacePoints -> Mesh, ShowLabels \
-> False, PlotPoints -> 40];]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.45284 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.217119 1.4694 -1.32544e-16 1.4694 [
[ 0 0 0 0 ]
[ 1 1.45284 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.45284 L
0 1.45284 L
closepath
clip
newpath
.5396 .62019 m .5934 .53462 L .50905 .60785 L .667 .555 .719 r
F
.5396 .62019 m .63121 .53603 L .5934 .53462 L F
.56678 .63262 m .63121 .53603 L .5396 .62019 L .604 .471 .673 r
F
.41803 .67217 m .5396 .62019 L .50905 .60785 L .731 .575 .68 r
F
.43609 .68863 m .5396 .62019 L .41803 .67217 L .699 .516 .637 r
F
.43609 .68863 m .56678 .63262 L .5396 .62019 L F
.50905 .60785 m .55302 .53386 L .47752 .59545 L .721 .634 .761 r
F
.50905 .60785 m .5934 .53462 L .55302 .53386 L F
.39856 .65511 m .50905 .60785 L .47752 .59545 L .761 .636 .722 r
F
.41803 .67217 m .50905 .60785 L .39856 .65511 L .731 .575 .68 r
F
.56678 .63262 m .66298 .53919 L .63121 .53603 L .604 .471 .673 r
F
.58867 .64535 m .66298 .53919 L .56678 .63262 L .522 .368 .613 r
F
.4516 .70437 m .56678 .63262 L .43609 .68863 L .663 .454 .592 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.53394 .62855 m
.56876 .60638 L
s
.4516 .70437 m .58867 .64535 L .56678 .63262 L .663 .454 .592 r
F
0 g
.52248 .67385 m
.52591 .67656 L
s
.52398 .63489 m
.53394 .62855 L
s
.51506 .64842 m
.51729 .64791 L
s
.47752 .59545 m .51406 .5331 L .44761 .58303 L .767 .717 .806 r
F
.47752 .59545 m .55302 .53386 L .51406 .5331 L F
0 g
.50907 .56865 m
.5091 .56866 L
s
.5091 .56866 m
.57774 .58468 L
s
.37899 .63763 m .47752 .59545 L .44761 .58303 L .788 .701 .768 r
F
.39856 .65511 m .47752 .59545 L .37899 .63763 L .761 .636 .722 r
F
0 g
.44081 .62014 m
.46743 .63595 L
s
.46743 .63595 m
.47178 .63854 L
s
.43967 .61018 m
.5797 .59119 L
s
.47322 .65099 m
.47398 .65105 L
s
.58867 .64535 m .68624 .54515 L .66298 .53919 L .522 .368 .613 r
F
.60395 .65846 m .68624 .54515 L .58867 .64535 L .404 .224 .52 r
F
0 g
.61946 .55861 m
.62457 .55196 L
s
.60765 .58172 m
.60876 .58102 L
s
.4637 .71928 m .58867 .64535 L .4516 .70437 L .623 .387 .539 r
F
0 g
.45338 .66533 m
.45789 .664 L
s
.4637 .71928 m .60395 .65846 L .58867 .64535 L .623 .387 .539 r
F
0 g
.53878 .68672 m
.54492 .69156 L
s
.5934 .53462 m .59395 .46347 L .55302 .53386 L .708 .651 .79 r
F
.5934 .53462 m .63586 .44765 L .59395 .46347 L F
.63121 .53603 m .63586 .44765 L .5934 .53462 L .622 .56 .763 r
F
0 g
.49716 .5657 m
.49717 .5657 L
s
.51108 .56397 m
.51112 .56396 L
s
.49247 .56761 m
.49247 .56761 L
s
.45784 .59377 m
.47379 .58441 L
s
.55302 .53386 m .55234 .479 L .51406 .5331 L .782 .747 .821 r
F
.55302 .53386 m .59395 .46347 L .55234 .479 L F
0 g
.51112 .56396 m
.51445 .5626 L
s
.30487 .7015 m .43609 .68863 L .41803 .67217 L .798 .578 .603 r
F
.31246 .71583 m .43609 .68863 L .30487 .7015 L .781 .536 .566 r
F
.31246 .71583 m .4516 .70437 L .43609 .68863 L F
.29648 .68638 m .41803 .67217 L .39856 .65511 L .815 .622 .641 r
F
.30487 .7015 m .41803 .67217 L .29648 .68638 L .798 .578 .603 r
F
0 g
.40531 .67951 m
.45338 .66533 L
s
.55953 .68154 m
.56784 .67584 L
s
.54492 .69156 m
.55953 .68154 L
s
.54492 .69156 m
.55221 .68895 L
s
.40139 .68732 m
.40404 .68739 L
s
.51158 .69058 m
.51587 .6907 L
s
.52872 .69108 m
.54492 .69156 L
s
.51089 .70109 m
.54492 .69156 L
s
.31883 .72923 m .4516 .70437 L .31246 .71583 L .764 .496 .529 r
F
.31883 .72923 m .4637 .71928 L .4516 .70437 L F
.66298 .53919 m .67266 .43358 L .63121 .53603 L .499 .443 .726 r
F
.63121 .53603 m .67266 .43358 L .63586 .44765 L .622 .56 .763 r
F
.28778 .67062 m .39856 .65511 L .37899 .63763 L .831 .668 .681 r
F
.29648 .68638 m .39856 .65511 L .28778 .67062 L .815 .622 .641 r
F
.47182 .73321 m .60395 .65846 L .4637 .71928 L .574 .307 .474 r
F
0 g
.49816 .70465 m
.49834 .7046 L
s
.57602 .67022 m
.57615 .67013 L
s
.32367 .74159 m .4637 .71928 L .31883 .72923 L .747 .456 .49 r
F
.32367 .74159 m .47182 .73321 L .4637 .71928 L F
0 g
.44173 .72044 m
.44193 .72038 L
s
.56051 .51192 m
.65082 .5035 L
s
.44761 .58303 m .4805 .53241 L .42178 .57092 L .803 .817 .863 r
F
.44761 .58303 m .51406 .5331 L .4805 .53241 L F
.36069 .61998 m .44761 .58303 L .42178 .57092 L .807 .772 .821 r
F
.37899 .63763 m .44761 .58303 L .36069 .61998 L .788 .701 .768 r
F
.60395 .65846 m .69962 .55456 L .68624 .54515 L .404 .224 .52 r
F
0 g
.62457 .55196 m
.64773 .52183 L
s
.61195 .67187 m .69962 .55456 L .60395 .65846 L .21 0 .351 r
F
0 g
.63177 .62177 m
.63239 .62163 L
s
.63239 .62163 m
.63303 .62148 L
s
.51729 .64791 m
.63177 .62177 L
s
.62341 .6377 m
.62347 .63766 L
s
.47182 .73321 m .61195 .67187 L .60395 .65846 L .574 .307 .474 r
F
0 g
.57615 .67013 m
.62341 .6377 L
s
.44193 .72038 m
.49326 .70602 L
s
.40404 .68739 m
.51158 .69058 L
s
.49326 .70602 m
.49816 .70465 L
s
.51406 .5331 m .51676 .49376 L .4805 .53241 L .848 .877 .862 r
F
.51406 .5331 m .55234 .479 L .51676 .49376 L F
0 g
.51435 .52389 m
.54735 .51485 L
s
.50531 .52636 m
.51435 .52389 L
s
.51445 .5626 m
.65182 .5068 L
s
.66298 .53919 m .7004 .42403 L .67266 .43358 L .499 .443 .726 r
F
.68624 .54515 m .7004 .42403 L .66298 .53919 L .275 .239 .636 r
F
0 g
.35508 .67893 m
.35546 .67904 L
s
.3358 .68787 m
.33829 .68781 L
s
.47576 .74604 m .61195 .67187 L .47182 .73321 L .509 .203 .383 r
F
0 g
.54907 .70611 m
.54917 .70644 L
s
.56429 .68463 m
.56569 .68413 L
s
.3268 .75283 m .47182 .73321 L .32367 .74159 L .729 .414 .448 r
F
.3268 .75283 m .47576 .74604 L .47182 .73321 L F
.27929 .65441 m .37899 .63763 L .36069 .61998 L .846 .718 .723 r
F
0 g
.36155 .63305 m
.39866 .62105 L
s
.28778 .67062 m .37899 .63763 L .27929 .65441 L .831 .668 .681 r
F
0 g
.37475 .71734 m
.37943 .71865 L
s
.37943 .71865 m
.38067 .71899 L
s
.35893 .72672 m
.3592 .72672 L
s
.59395 .46347 m .56369 .42803 L .55234 .479 L .812 .75 .794 r
F
0 g
.56175 .5081 m
.56203 .50787 L
s
.59395 .46347 m .59936 .39544 L .56369 .42803 L .812 .75 .794 r
F
0 g
.56203 .50787 m
.57814 .4943 L
s
.63586 .44765 m .59936 .39544 L .59395 .46347 L .717 .663 .796 r
F
.61195 .67187 m .70283 .56733 L .69962 .55456 L .21 0 .351 r
F
.6127 .68522 m .70283 .56733 L .61195 .67187 L 0 0 0 r
F
.47576 .74604 m .6127 .68522 L .61195 .67187 L .509 .203 .383 r
F
0 g
.55094 .71265 m
.55107 .7131 L
s
.63586 .44765 m .63291 .36204 L .59936 .39544 L .717 .663 .796 r
F
.67266 .43358 m .63291 .36204 L .63586 .44765 L .602 .583 .804 r
F
.47561 .75759 m .6127 .68522 L .47576 .74604 L .407 .048 .24 r
F
0 g
.55223 .71714 m
.55494 .72664 L
s
.52272 .72701 m
.52279 .72701 L
s
.43666 .728 m
.52272 .72701 L
s
.53377 .72689 m
.55494 .72664 L
s
.32814 .76286 m .47576 .74604 L .3268 .75283 L .708 .367 .397 r
F
.32814 .76286 m .47561 .75759 L .47576 .74604 L F
.42178 .57092 m .4555 .53265 L .40207 .55975 L .792 .935 .924 r
F
.42178 .57092 m .4805 .53241 L .46088 .5326 L F
.46088 .5326 m .4684 .52683 L .4555 .53265 L .781 .998 .813 r
F
.4684 .52683 m .46805 .52692 L .4555 .53265 L F
.4805 .53241 m .49054 .51139 L .46088 .5326 L F
.4694 .52624 m .45697 .53134 L .46962 .52613 L 0 0 0 r
F
.45697 .53134 m .45199 .53338 L .45691 .53135 L F
.45697 .53134 m .45691 .53135 L .46962 .52613 L F
.4636 .53065 m .46333 .53072 L .46088 .5326 L .781 .998 .813 r
F
.46805 .52692 m .46962 .52613 L .46922 .52664 L 0 0 0 r
F
.4793 .51942 m .46962 .52613 L .4818 .51701 L F
.46922 .52664 m .46962 .52613 L .4793 .51942 L F
.51632 .48455 m .50287 .50124 L .52232 .47602 L F
.4805 .53241 m .51676 .49376 L .50433 .5013 L .781 .998 .813 r
F
.50174 .50305 m .50433 .5013 L .50196 .50274 L F
.4805 .53241 m .50433 .5013 L .50174 .50305 L F
.49721 .5061 m .49822 .50523 L .50169 .50308 L 0 0 0 r
F
.49822 .50523 m .50287 .50124 L .50178 .50294 L F
.49822 .50523 m .50178 .50294 L .50169 .50308 L F
.4805 .53241 m .50196 .50274 L .4926 .51459 L .781 .998 .813 r
F
.51676 .49376 m .5167 .49336 L .50433 .5013 L .744 .873 .454 r
F
.515 .49445 m .51575 .48981 L .50433 .5013 L F
.51575 .48981 m .51294 .49184 L .50433 .5013 L F
.51158 .56315 m .51444 .55873 L .51816 .56757 L .543 .31 .512 r
F
.51093 .55837 m .51444 .55873 L .51158 .56315 L F
.50708 .51923 m .50963 .51222 L .51057 .5174 L .21 0 .352 r
F
.49626 .51201 m .50723 .49893 L .50963 .51222 L F
.49626 .51201 m .50963 .51222 L .50708 .51923 L F
.50939 .4944 m .52232 .47602 L .51973 .48342 L 0 0 0 r
F
.51676 .49376 m .5307 .46488 L .51973 .48342 L .744 .873 .454 r
F
.51642 .49154 m .51973 .48342 L .51611 .48954 L F
.51676 .49376 m .51973 .48342 L .51642 .49154 L F
.52423 .47238 m .52232 .47602 L .53098 .45384 L 0 0 0 r
F
.52138 .47938 m .52232 .47602 L .52423 .47238 L F
.52118 .47986 m .5219 .47743 L .52138 .47938 L F
.5219 .47743 m .52232 .47602 L .52138 .47938 L F
.50939 .4944 m .51973 .48342 L .51611 .48954 L F
.5307 .46488 m .53381 .45844 L .52008 .48256 L .744 .873 .454 r
F
.51973 .48342 m .52008 .48256 L .51611 .48954 L F
.5307 .46488 m .52008 .48256 L .51973 .48342 L F
.53172 .48756 m .53381 .45844 L .51676 .49376 L .917 .885 .786 r
F
.55234 .479 m .53381 .45844 L .53172 .48756 L F
.53381 .45844 m .53625 .42532 L .5357 .4321 L .716 .629 .065 r
F
.53381 .45844 m .53298 .46576 L .53047 .46912 L F
.52801 .49832 m .52949 .48863 L .54433 .51157 L .285 .208 .591 r
F
.52949 .48863 m .53298 .46576 L .54138 .49966 L F
.52949 .48863 m .54138 .49966 L .54433 .51157 L F
.52956 .46612 m .53011 .46795 L .52059 .48232 L .716 .629 .065 r
F
.53381 .45844 m .53047 .46912 L .52956 .46612 L F
.53165 .45584 m .53098 .45384 L .53331 .43438 L 0 0 .006 r
F
.52934 .46629 m .53381 .45844 L .52945 .46578 L .744 .873 .454 r
F
.51973 .48342 m .52232 .47602 L .52118 .47986 L 0 0 0 r
F
.51611 .48954 m .52934 .46629 L .51595 .48853 L .744 .873 .454 r
F
.52934 .46629 m .52945 .46578 L .51595 .48853 L F
.53381 .45844 m .52059 .48232 L .52138 .47938 L .716 .629 .065 r
F
.52145 .48117 m .53011 .46795 L .52888 .48806 L 0 0 0 r
F
.52888 .48806 m .53011 .46795 L .53047 .46912 L 0 0 .006 r
F
.52059 .48232 m .53047 .46912 L .51768 .48993 L .285 .208 .591 r
F
.53047 .46912 m .53298 .46576 L .53041 .46983 L F
.53047 .46912 m .53041 .46983 L .51768 .48993 L F
.53059 .46953 m .53066 .46687 L .53165 .45584 L 0 0 .006 r
F
.53066 .46687 m .53084 .45951 L .53154 .45632 L F
.53066 .46687 m .53154 .45632 L .53165 .45584 L F
.53084 .45951 m .53098 .45384 L .53165 .45584 L F
.52114 .48088 m .53098 .45384 L .53011 .46795 L 0 0 0 r
F
.53011 .46795 m .52145 .48117 L .52059 .48232 L .716 .629 .065 r
F
.52114 .48088 m .53011 .46795 L .52145 .48117 L 0 0 0 r
F
.53011 .46795 m .53047 .46912 L .52145 .48117 L .716 .629 .065 r
F
.51768 .48993 m .53041 .46983 L .52801 .49832 L .285 .208 .591 r
F
.50981 .4941 m .51595 .48853 L .51065 .49299 L .744 .873 .454 r
F
.50433 .5013 m .51294 .49184 L .50981 .4941 L F
.51294 .49184 m .51595 .48853 L .50981 .4941 L F
.50433 .5013 m .51065 .49299 L .50196 .50274 L F
.50691 .49794 m .50939 .4944 L .50874 .50362 L 0 0 0 r
F
.5167 .49336 m .51642 .49154 L .515 .49445 L .744 .873 .454 r
F
.51062 .50948 m .51809 .48811 L .51902 .48621 L 0 0 0 r
F
.51768 .48993 m .54433 .51157 L .5146 .49852 L .285 .208 .591 r
F
.5146 .49852 m .51902 .48621 L .51924 .48575 L 0 0 0 r
F
.51062 .50948 m .51902 .48621 L .5146 .49852 L F
.5146 .49852 m .54433 .51157 L .5428 .51206 L .285 .208 .591 r
F
.54372 .56269 m .55977 .56786 L .54567 .56618 L .55 .438 .679 r
F
.53195 .54155 m .5543 .56268 L .54372 .56269 L F
.5543 .56268 m .55977 .56786 L .54372 .56269 L F
.52194 .56533 m .5328 .56572 L .54367 .57428 L .666 .547 .71 r
F
.5328 .56572 m .54522 .56801 L .54367 .57428 L F
.52307 .5627 m .54372 .56269 L .54522 .56801 L .494 .321 .575 r
F
.52297 .56391 m .5328 .56572 L .52194 .56533 L .666 .547 .71 r
F
.54567 .56618 m .55977 .56786 L .54367 .57428 L F
.53002 .56521 m .54522 .56801 L .54605 .571 L .494 .321 .575 r
F
.52307 .5627 m .54522 .56801 L .53002 .56521 L F
.52297 .56391 m .52307 .5627 L .53002 .56521 L F
.54522 .56801 m .54469 .56615 L .54567 .56618 L .474 .357 .64 r
F
.53195 .54155 m .53551 .53293 L .5543 .56268 L .55 .438 .679 r
F
.5267 .51896 m .52694 .51598 L .53527 .53254 L .494 .321 .575 r
F
.5146 .49852 m .53333 .50751 L .53127 .51024 L .285 .208 .591 r
F
.52694 .51598 m .52962 .51243 L .53527 .53254 L .494 .321 .575 r
F
.53527 .53254 m .52962 .51243 L .53547 .532 L .474 .357 .64 r
F
.53551 .53293 m .54433 .51157 L .5543 .56268 L .55 .438 .679 r
F
.5428 .51206 m .54433 .51157 L .53195 .54155 L F
.54567 .56618 m .52962 .51243 L .54611 .56439 L .474 .357 .64 r
F
.5543 .56268 m .54433 .51157 L .55977 .56786 L .55 .438 .679 r
F
.54611 .56439 m .52962 .51243 L .54658 .51196 L .474 .357 .64 r
F
.5146 .49852 m .53666 .51403 L .51184 .51901 L .285 .208 .591 r
F
.52694 .51598 m .52778 .50586 L .52962 .51243 L .494 .321 .575 r
F
.53127 .51024 m .5428 .51206 L .53419 .5123 L .285 .208 .591 r
F
.53333 .50751 m .5428 .51206 L .53127 .51024 L F
.51447 .52501 m .5428 .51206 L .53195 .54155 L .55 .438 .679 r
F
.50995 .51987 m .51057 .5174 L .51106 .52012 L .21 0 .352 r
F
.50708 .51923 m .51057 .5174 L .50995 .51987 L F
.51404 .52523 m .51019 .52161 L .51041 .52138 L .494 .321 .575 r
F
.51404 .52523 m .51041 .52138 L .51341 .52114 L F
.4946 .5142 m .50169 .50308 L .50196 .50274 L 0 0 0 r
F
.48623 .52725 m .49442 .51443 L .4946 .5142 L F
.48706 .52612 m .50105 .52364 L .49399 .52666 L .523 .324 .553 r
F
.48621 .52727 m .49399 .52666 L .48327 .53124 L F
.48706 .52612 m .49399 .52666 L .48621 .52727 L F
.49935 .50465 m .50196 .50274 L .49973 .50409 L .781 .998 .813 r
F
.4926 .51459 m .50169 .50308 L .49935 .50465 L F
.50169 .50308 m .50196 .50274 L .49935 .50465 L F
.4805 .53241 m .49973 .50409 L .49054 .51139 L F
.46785 .5296 m .46882 .52887 L .47789 .52709 L 0 0 0 r
F
.46785 .5296 m .47789 .52709 L .47785 .52714 L F
.47732 .52797 m .49013 .51956 L .47975 .52778 L F
.48322 .5172 m .4818 .51701 L .49721 .5061 L F
.47206 .52643 m .4818 .51701 L .48413 .51732 L F
.49054 .51139 m .46333 .53072 L .4636 .53065 L .781 .998 .813 r
F
.49822 .50523 m .4818 .51701 L .5022 .50181 L 0 0 0 r
F
.49721 .5061 m .49471 .50787 L .49822 .50523 L F
.49471 .50787 m .4818 .51701 L .49822 .50523 L F
.50939 .4944 m .50196 .50274 L .51632 .48455 L F
.50169 .50308 m .50287 .50124 L .51632 .48455 L F
.5022 .50181 m .4818 .51701 L .50287 .50124 L F
.49973 .50409 m .51065 .49299 L .4917 .50896 L .744 .873 .454 r
F
.50196 .50274 m .50283 .50177 L .49973 .50409 L F
.50283 .50177 m .51065 .49299 L .49973 .50409 L F
.45199 .53338 m .45191 .5334 L .46962 .52613 L 0 0 0 r
F
.46805 .52692 m .46138 .52963 L .4694 .52624 L F
.46138 .52963 m .42437 .54469 L .4694 .52624 L F
.49054 .51139 m .4917 .50896 L .46333 .53072 L .781 .998 .813 r
F
.46432 .53047 m .46805 .52692 L .46575 .53018 L 0 0 0 r
F
.46315 .52938 m .46805 .52692 L .46432 .53047 L F
.46805 .52692 m .46922 .52664 L .46539 .53146 L F
.46506 .53116 m .46539 .53146 L .46206 .53566 L F
.46506 .53116 m .46206 .53566 L .46189 .53566 L F
.46575 .53018 m .46539 .53146 L .46506 .53116 L F
.46805 .52692 m .46619 .53009 L .46575 .53018 L F
.46619 .53009 m .46539 .53146 L .46575 .53018 L F
.46805 .52692 m .458 .53101 L .4555 .53265 L .781 .998 .813 r
F
.4555 .53265 m .458 .53101 L .46369 .52989 L 0 0 0 r
F
.46882 .52887 m .4798 .52409 L .47789 .52709 L F
.46785 .5296 m .46922 .52664 L .47206 .52643 L F
.46663 .53053 m .46708 .52985 L .46785 .5296 L F
.46708 .52985 m .46922 .52664 L .46785 .5296 L F
.47116 .52845 m .47785 .52714 L .47209 .52838 L F
.47952 .52453 m .49013 .51956 L .47893 .52691 L F
.47785 .52714 m .47893 .52691 L .47732 .52797 L F
.47952 .52453 m .47893 .52691 L .47785 .52714 L F
.46449 .53375 m .46663 .53053 L .46785 .5296 L F
.47093 .52728 m .4798 .52409 L .46882 .52887 L F
.46539 .53146 m .46653 .53002 L .46663 .53053 L F
.46653 .53002 m .46922 .52664 L .46708 .52985 L F
.46653 .53002 m .46708 .52985 L .46663 .53053 L F
.47785 .52714 m .47746 .52723 L .46909 .52921 L F
.47179 .52664 m .4798 .52409 L .47093 .52728 L F
.47206 .52643 m .46922 .52664 L .4793 .51942 L F
.47952 .52453 m .49721 .5061 L .49013 .51956 L F
.48413 .51732 m .49721 .5061 L .47952 .52453 L F
.48413 .51732 m .48322 .5172 L .48686 .51431 L F
.49064 .51173 m .48686 .51431 L .49721 .5061 L F
.48413 .51732 m .48686 .51431 L .49064 .51173 L F
.51642 .49154 m .51595 .48853 L .515 .49445 L .744 .873 .454 r
F
.50939 .4944 m .51809 .48811 L .51062 .50948 L 0 0 0 r
F
.51341 .52114 m .51041 .52138 L .51305 .51877 L .494 .321 .575 r
F
.51019 .52161 m .51184 .51901 L .51305 .51877 L F
.50723 .49893 m .51239 .51497 L .51184 .51901 L .21 0 .352 r
F
.51108 .52021 m .51184 .51901 L .51142 .52213 L F
.50723 .49893 m .51184 .51901 L .51108 .52021 L F
.52694 .51598 m .51294 .51729 L .52778 .50586 L .494 .321 .575 r
F
.51294 .51729 m .50772 .51778 L .51563 .51308 L F
.51294 .51729 m .51563 .51308 L .52778 .50586 L F
.50874 .50362 m .51062 .50948 L .50772 .51778 L 0 0 0 r
F
.50939 .4944 m .51062 .50948 L .50874 .50362 L F
.49442 .51443 m .50169 .50308 L .4946 .5142 L F
.48636 .52707 m .50196 .50274 L .50311 .50144 L F
.48623 .52725 m .50196 .50274 L .48636 .52707 L F
.48541 .52851 m .50311 .50144 L .4872 .52597 L F
.47975 .52778 m .49013 .51956 L .48606 .52728 L F
.48621 .52727 m .49442 .51443 L .48623 .52725 L F
.49721 .5061 m .50169 .50308 L .48621 .52727 L F
.49721 .5061 m .48621 .52727 L .48606 .52728 L F
.47943 .52747 m .48706 .52612 L .48621 .52727 L .523 .324 .553 r
F
.47975 .52778 m .48621 .52727 L .48327 .53124 L F
.47943 .52747 m .48621 .52727 L .47975 .52778 L F
.48606 .52728 m .48621 .52727 L .48541 .52851 L 0 0 0 r
F
.48447 .52607 m .48741 .52564 L .47943 .52747 L .523 .324 .553 r
F
.48741 .52564 m .50105 .52364 L .48706 .52612 L F
.48741 .52564 m .48706 .52612 L .47943 .52747 L F
.48541 .52851 m .48623 .52725 L .48636 .52707 L 0 0 0 r
F
.49626 .51201 m .50967 .52096 L .48914 .52298 L .21 0 .352 r
F
.50967 .52096 m .50863 .52153 L .48109 .52378 L F
.50105 .52364 m .50669 .52701 L .51093 .55837 L .523 .324 .553 r
F
.50551 .53752 m .50722 .52231 L .50907 .52335 L .543 .31 .512 r
F
.50722 .52231 m .50863 .52153 L .50907 .52335 L F
.51012 .52717 m .50866 .52153 L .51404 .52523 L .494 .321 .575 r
F
.50967 .52096 m .51032 .52139 L .50863 .52153 L .21 0 .352 r
F
.50866 .52153 m .5082 .51974 L .50999 .52142 L .494 .321 .575 r
F
.50866 .52153 m .50999 .52142 L .51404 .52523 L F
.5199 .56813 m .50907 .52335 L .52051 .56729 L F
.50708 .51923 m .51098 .52036 L .51032 .52139 L .21 0 .352 r
F
.50907 .52335 m .5082 .51974 L .50912 .52328 L .494 .321 .575 r
F
.50907 .52335 m .50912 .52328 L .52051 .56729 L F
.50708 .51923 m .51106 .52012 L .51098 .52036 L .21 0 .352 r
F
.51032 .52139 m .51098 .52036 L .51059 .52157 L F
.48109 .52378 m .50692 .52237 L .48447 .52607 L F
.50692 .52237 m .50105 .52364 L .48447 .52607 L F
.51098 .52036 m .51106 .52012 L .51108 .52021 L F
.51019 .52161 m .5082 .51974 L .51184 .51901 L .494 .321 .575 r
F
.51032 .52139 m .51059 .52157 L .48109 .52378 L .21 0 .352 r
F
.51059 .52157 m .50692 .52237 L .48109 .52378 L F
.50722 .52231 m .49859 .52217 L .50772 .51778 L .543 .31 .512 r
F
.50669 .52701 m .50105 .52364 L .50722 .52231 L F
.50105 .52364 m .49859 .52217 L .50722 .52231 L F
.51059 .52157 m .51142 .52213 L .50692 .52237 L .21 0 .352 r
F
.50692 .52237 m .51142 .52213 L .50105 .52364 L F
.48327 .53124 m .50105 .52364 L .51093 .55837 L .523 .324 .553 r
F
.50551 .53752 m .48541 .52851 L .49099 .52583 L .543 .31 .512 r
F
.49941 .524 m .49099 .52583 L .49859 .52217 L F
.50551 .53752 m .49099 .52583 L .49941 .524 L F
.49099 .52583 m .48777 .52516 L .49859 .52217 L 0 0 0 r
F
.48541 .52851 m .4872 .52597 L .49099 .52583 L F
.4872 .52597 m .48777 .52516 L .49099 .52583 L F
.4793 .52627 m .48447 .52607 L .47885 .5269 L .21 0 .352 r
F
.48109 .52378 m .48447 .52607 L .4793 .52627 L F
.51575 .48981 m .51595 .48853 L .51294 .49184 L .744 .873 .454 r
F
.51065 .49299 m .51595 .48853 L .49626 .51201 L .21 0 .352 r
F
.50691 .49794 m .50311 .50144 L .50939 .4944 L 0 0 0 r
F
.4872 .52597 m .49626 .51201 L .50691 .49794 L F
.49626 .51201 m .50311 .50144 L .50691 .49794 L F
.49054 .51139 m .49973 .50409 L .4917 .50896 L .781 .998 .813 r
F
.4917 .50896 m .49626 .51201 L .48109 .52378 L .21 0 .352 r
F
.49626 .51201 m .48914 .52298 L .48109 .52378 L F
.4917 .50896 m .50645 .49653 L .50269 .50351 L F
.50645 .49653 m .51065 .49299 L .50691 .49794 L F
.50645 .49653 m .50691 .49794 L .50269 .50351 L F
.49322 .50998 m .50269 .50351 L .49626 .51201 L F
.4917 .50896 m .50269 .50351 L .49322 .50998 L F
.46805 .52692 m .46205 .52836 L .458 .53101 L .781 .998 .813 r
F
.4555 .53265 m .46369 .52989 L .46406 .53022 L 0 0 0 r
F
.458 .53101 m .46315 .52938 L .46369 .52989 L F
.46432 .53047 m .46882 .52887 L .46785 .5296 L F
.4555 .53265 m .46406 .53022 L .46432 .53047 L F
.46406 .53022 m .46882 .52887 L .46432 .53047 L F
.4555 .53265 m .46432 .53047 L .46042 .53127 L F
.40207 .55975 m .4555 .53265 L .4534 .53301 L .549 .93 .848 r
F
.40207 .55975 m .43213 .54409 L .42579 .54468 L F
.43213 .54409 m .4534 .53301 L .42634 .54445 L F
.43213 .54409 m .42634 .54445 L .42579 .54468 L F
.45065 .53512 m .42439 .54469 L .45253 .53323 L 0 0 0 r
F
.44713 .537 m .43578 .54084 L .45037 .53523 L F
.43578 .54084 m .42439 .54469 L .45065 .53512 L F
.44534 .54418 m .46088 .5326 L .4555 .53265 L .792 .935 .924 r
F
.42178 .57092 m .46088 .5326 L .44534 .54418 L F
.44961 .53616 m .44713 .537 L .45065 .53512 L 0 0 0 r
F
.44713 .537 m .45037 .53523 L .45065 .53512 L F
.42942 .54407 m .42439 .54469 L .44961 .53616 L F
.42439 .54469 m .42437 .54469 L .46805 .52692 L F
.4684 .52683 m .4917 .50896 L .46205 .52836 L .781 .998 .813 r
F
.458 .53101 m .4917 .50896 L .48758 .51472 L 0 0 0 r
F
.47179 .52664 m .48758 .51472 L .48117 .52366 L F
.45864 .53163 m .45253 .53323 L .46805 .52692 L F
.458 .53101 m .48758 .51472 L .47179 .52664 L F
.47785 .52714 m .46909 .52921 L .46904 .52923 L F
.46785 .5296 m .47785 .52714 L .46904 .52923 L F
.46909 .52921 m .47746 .52723 L .47096 .52862 L F
.47043 .52907 m .47206 .52643 L .48413 .51732 L F
.46038 .53699 m .478 .53501 L .47773 .53759 L .455 .123 .313 r
F
.46206 .53566 m .478 .53501 L .46038 .53699 L F
.45199 .53338 m .42437 .54469 L .45191 .5334 L 0 0 0 r
F
.42613 .54446 m .42437 .54469 L .42634 .54445 L .124 .673 .727 r
F
.42285 .54473 m .44072 .53519 L .41995 .54496 L .549 .93 .848 r
F
.42613 .54446 m .4265 .54423 L .42285 .54473 L F
.4265 .54423 m .44072 .53519 L .42285 .54473 L F
.42285 .54473 m .39689 .54825 L .42437 .54469 L .124 .673 .727 r
F
.39689 .54825 m .39483 .54857 L .42437 .54469 L F
.38685 .54962 m .38677 .54963 L .39978 .54792 L F
.39956 .54795 m .39978 .54792 L .42437 .54469 L F
.38685 .54962 m .39978 .54792 L .39956 .54795 L F
.39689 .54825 m .38685 .54962 L .39483 .54857 L F
.37768 .55058 m .36453 .54799 L .37592 .55105 L .164 .683 .886 r
F
.36453 .54799 m .35527 .54616 L .36434 .54831 L F
.36453 .54799 m .36434 .54831 L .37592 .55105 L F
.37309 .54387 m .38531 .54366 L .38811 .54032 L .317 .806 .849 r
F
.3969 .5558 m .44072 .53519 L .38979 .55037 L .549 .93 .848 r
F
.41833 .54489 m .44072 .53519 L .42131 .54432 L .067 0 0 r
F
.41671 .5452 m .41721 .545 L .41833 .54489 L F
.41721 .545 m .44072 .53519 L .41833 .54489 L F
.45864 .53163 m .46315 .52938 L .46432 .53047 L 0 0 0 r
F
.4555 .53265 m .46628 .52963 L .4534 .53301 L F
.44961 .53616 m .45253 .53323 L .45864 .53163 L F
.42613 .54446 m .4534 .53301 L .44072 .53519 L .549 .93 .848 r
F
.42579 .54468 m .42634 .54445 L .42613 .54446 L F
.42634 .54445 m .4534 .53301 L .42613 .54446 L F
.47561 .75759 m .60678 .69801 L .6127 .68522 L .407 .048 .24 r
F
.47174 .76773 m .60678 .69801 L .47561 .75759 L .224 0 0 r
F
.32771 .77165 m .47561 .75759 L .32814 .76286 L .683 .31 .333 r
F
.32771 .77165 m .47174 .76773 L .47561 .75759 L F
.32563 .77916 m .47174 .76773 L .32771 .77165 L .649 .238 .251 r
F
.32563 .77916 m .46474 .77634 L .47174 .76773 L F
.32209 .7854 m .46474 .77634 L .32563 .77916 L .6 .145 .143 r
F
.32209 .7854 m .45531 .78341 L .46474 .77634 L F
.31734 .7904 m .45531 .78341 L .32209 .7854 L .533 .032 .01 r
F
.31734 .7904 m .44421 .78901 L .45531 .78341 L F
.31163 .7942 m .44421 .78901 L .31734 .7904 L .449 0 0 r
F
.31163 .7942 m .43216 .7933 L .44421 .78901 L F
.30524 .79687 m .43216 .7933 L .31163 .7942 L .364 0 0 r
F
.30524 .79687 m .41977 .79653 L .43216 .7933 L F
.41977 .79653 m .50268 .74157 L .52201 .73787 L .78 .948 .93 r
F
.50268 .74157 m .50378 .74084 L .50454 .74071 L F
.50268 .74157 m .50454 .74071 L .52201 .73787 L F
.29843 .79848 m .41976 .79653 L .30524 .79687 L .3 0 0 r
F
.41976 .79653 m .41977 .79653 L .41976 .79653 L F
.41976 .79653 m .41976 .79653 L .30524 .79687 L F
.29143 .7991 m .39578 .80107 L .40754 .79902 L .275 0 0 r
F
.39578 .80107 m .39763 .79991 L .40754 .79902 L .786 .975 .912 r
F
.29843 .79848 m .40754 .79902 L .41977 .79653 L .3 0 0 r
F
.29143 .7991 m .39671 .79902 L .29843 .79848 L .275 0 0 r
F
.20771 .73496 m .29143 .7991 L .29843 .79848 L .836 .368 .065 r
F
.20771 .73496 m .2559 .7687 L .20936 .73535 L F
.2559 .7687 m .26585 .77567 L .25697 .76933 L F
.2559 .7687 m .25697 .76933 L .20936 .73535 L F
.19057 .63127 m .20771 .73496 L .20936 .73535 L .914 .703 .204 r
F
.19057 .63127 m .20614 .7337 L .20771 .73496 L .892 .677 .161 r
F
.20614 .7337 m .26994 .78262 L .20771 .73496 L .815 .331 0 r
F
.26994 .78262 m .27676 .78785 L .20771 .73496 L F
.28835 .79673 m .28827 .79667 L .26514 .77895 L F
.26523 .77902 m .26514 .77895 L .20771 .73496 L F
.28835 .79673 m .26514 .77895 L .26523 .77902 L F
.27596 .78275 m .29843 .79848 L .28401 .78826 L .836 .368 .065 r
F
.26994 .78262 m .28835 .79673 L .27676 .78785 L .815 .331 0 r
F
.28835 .79673 m .29143 .7991 L .28827 .79667 L F
.22114 .7452 m .28448 .79876 L .29143 .7991 L F
.34662 .80005 m .38408 .80083 L .34119 .80003 L .292 0 0 r
F
.38408 .80083 m .3842 .80084 L .29143 .7991 L F
.28448 .79876 m .34662 .80005 L .29143 .7991 L F
.34662 .80005 m .34119 .80003 L .29143 .7991 L F
.39258 .801 m .39354 .80102 L .29143 .7991 L F
.39474 .80105 m .39477 .80105 L .29143 .7991 L F
.39522 .80106 m .39525 .80106 L .29143 .7991 L F
.3109 .79987 m .38466 .80297 L .32927 .79969 L F
.38408 .80083 m .39258 .801 L .3842 .80084 L F
.39258 .801 m .39474 .80105 L .39354 .80102 L F
.39474 .80105 m .39522 .80106 L .39477 .80105 L F
.39522 .80106 m .39578 .80107 L .39525 .80106 L F
.34662 .80005 m .38421 .80294 L .39578 .80107 L F
.32927 .79969 m .34939 .80088 L .34662 .80005 L F
.34939 .80088 m .38421 .80294 L .34662 .80005 L F
.35589 .80149 m .38406 .80294 L .3518 .80158 L .342 0 0 r
F
.29128 .7989 m .3109 .79987 L .32927 .79969 L .292 0 0 r
F
.38359 .80292 m .38362 .80293 L .36219 .80202 L .342 0 0 r
F
.36222 .80202 m .36219 .80202 L .28448 .79876 L F
.38359 .80292 m .36219 .80202 L .36222 .80202 L F
.38406 .80294 m .38414 .80295 L .38362 .80293 L F
.38406 .80294 m .38362 .80293 L .38359 .80292 L F
.35589 .80149 m .36499 .8041 L .38406 .80294 L F
.27103 .78758 m .28448 .79876 L .27032 .78679 L .815 .331 0 r
F
.21457 .7407 m .27103 .78758 L .22114 .7452 L F
.27103 .78758 m .27032 .78679 L .22114 .7452 L F
.20614 .7337 m .21457 .7407 L .22114 .7452 L F
.19057 .63127 m .20475 .73158 L .20614 .7337 L .856 .64 .102 r
F
.20475 .73158 m .25304 .77227 L .20614 .7337 L .785 .288 0 r
F
.25304 .77227 m .26347 .78105 L .25515 .77418 L F
.25304 .77227 m .25515 .77418 L .20614 .7337 L F
.26347 .78105 m .2697 .78644 L .20614 .7337 L F
.2802 .79515 m .28002 .79505 L .20614 .7337 L F
.26347 .78105 m .2802 .79515 L .2697 .78644 L F
.2802 .79515 m .28448 .79876 L .28002 .79505 L F
.26347 .78105 m .27779 .79749 L .28448 .79876 L F
.22629 .74973 m .27779 .79749 L .26347 .78105 L F
.21786 .74263 m .22107 .74631 L .22629 .74973 L F
.22107 .74631 m .27779 .79749 L .22629 .74973 L F
.26585 .77567 m .26791 .77702 L .20936 .73535 L .836 .368 .065 r
F
.27596 .78275 m .28401 .78826 L .20936 .73535 L F
.20936 .73535 m .29843 .79848 L .30524 .79687 L .851 .401 .131 r
F
.20475 .73158 m .21204 .73816 L .21786 .74263 L .785 .288 0 r
F
.21204 .73816 m .22107 .74631 L .21786 .74263 L F
.20936 .73535 m .30524 .79687 L .21099 .73487 L .851 .401 .131 r
F
.19057 .63127 m .20936 .73535 L .21099 .73487 L .927 .719 .232 r
F
.19057 .63127 m .20364 .72861 L .20475 .73158 L .805 .589 .028 r
F
.20364 .72861 m .24596 .76792 L .20475 .73158 L .742 .238 0 r
F
.24596 .76792 m .2491 .77133 L .20475 .73158 L F
.26443 .78508 m .26339 .78449 L .20475 .73158 L F
.21527 .73941 m .22745 .75197 L .23111 .75412 L F
.24596 .76792 m .26443 .78508 L .2491 .77133 L F
.26443 .78508 m .27227 .79235 L .26339 .78449 L F
.27227 .79235 m .27779 .79749 L .27189 .79216 L F
.27227 .79235 m .27189 .79216 L .26339 .78449 L F
.28448 .79876 m .29148 .79905 L .29128 .7989 L .292 0 0 r
F
.29148 .79905 m .3109 .79987 L .29128 .7989 L F
.27779 .79749 m .35589 .80149 L .28448 .79876 L .342 0 0 r
F
.28511 .79786 m .29376 .79872 L .30836 .79905 L F
.35589 .80149 m .3518 .80158 L .28448 .79876 L F
.30836 .79905 m .36163 .8038 L .35589 .80149 L F
.36163 .8038 m .36499 .8041 L .35589 .80149 L F
.29376 .79872 m .36419 .80414 L .30836 .79905 L F
.36419 .80414 m .36499 .8041 L .30836 .79905 L F
.23111 .75412 m .27158 .79527 L .27583 .79567 L .742 .238 0 r
F
.27779 .79749 m .28551 .79808 L .28511 .79786 L .342 0 0 r
F
.28551 .79808 m .29376 .79872 L .28511 .79786 L F
.39671 .79902 m .40056 .79899 L .29843 .79848 L .275 0 0 r
F
.40684 .79902 m .40689 .79901 L .29843 .79848 L F
.27158 .79527 m .36258 .80382 L .27779 .79749 L .407 0 0 r
F
.36429 .80416 m .37429 .80371 L .36544 .80439 L .799 .946 .92 r
F
.36258 .80382 m .36321 .80395 L .27779 .79749 L .407 0 0 r
F
.36321 .80395 m .36419 .80414 L .36209 .80398 L F
.36321 .80395 m .36209 .80398 L .27779 .79749 L F
.48827 .7482 m .49728 .74405 L .4966 .74479 L .803 .728 .781 r
F
.40754 .79902 m .45266 .76755 L .488 .74924 L .792 .953 .922 r
F
.48851 .75007 m .488 .74924 L .50114 .74243 L F
.40754 .79902 m .488 .74924 L .48851 .75007 L F
.51145 .66498 m .51063 .66126 L .51259 .66253 L .872 .767 .743 r
F
.51063 .66126 m .51055 .66088 L .51078 .66084 L F
.48664 .63111 m .48391 .5954 L .49569 .64475 L .859 .611 .562 r
F
.48617 .64817 m .49488 .65427 L .48857 .68612 L .803 .643 .683 r
F
.47696 .63169 m .47432 .61495 L .48536 .65165 L .957 .664 .437 r
F
.47432 .61495 m .47932 .62451 L .48544 .64925 L F
.49488 .65427 m .50819 .66359 L .50292 .66964 L .803 .643 .683 r
F
.49631 .64568 m .50819 .66359 L .48617 .64817 L F
.49026 .60917 m .5107 .66077 L .50576 .6518 L .732 .556 .654 r
F
.48031 .58182 m .49379 .61684 L .49026 .60917 L F
.49379 .61684 m .51073 .66087 L .49026 .60917 L F
.49978 .64483 m .49234 .61744 L .49987 .63914 L .784 .572 .613 r
F
.48541 .63616 m .48857 .68612 L .48563 .6577 L .803 .643 .683 r
F
.48544 .64925 m .48563 .6577 L .48546 .65601 L F
.48541 .63616 m .48563 .6577 L .48544 .64925 L F
.43703 .54238 m .47436 .5738 L .43638 .54276 L .627 .339 .461 r
F
.44628 .53746 m .46685 .53755 L .46672 .54581 L .455 .123 .313 r
F
.44856 .53657 m .47773 .53759 L .44628 .53746 L F
.44368 .5364 m .46206 .53566 L .46038 .53699 L F
.44087 .5405 m .46081 .5457 L .43824 .54197 L F
.46738 .57339 m .43634 .54433 L .43671 .5442 L .68 .316 .35 r
F
.43327 .54413 m .43638 .54276 L .43655 .54332 L .462 0 .036 r
F
.43623 .54416 m .43655 .54332 L .43682 .54417 L F
.43327 .54413 m .43655 .54332 L .43623 .54416 L F
.44822 .56514 m .43605 .54464 L .43835 .54744 L .745 .291 .174 r
F
.44958 .5661 m .43835 .54744 L .45931 .57295 L F
.44822 .56514 m .43835 .54744 L .44958 .5661 L F
.47432 .61495 m .4714 .59647 L .47932 .62451 L .957 .664 .437 r
F
.44958 .5661 m .47449 .59938 L .45858 .58105 L .722 .458 .527 r
F
.47449 .59938 m .475 .60006 L .47407 .59898 L F
.47449 .59938 m .47407 .59898 L .45858 .58105 L F
.44958 .5661 m .48074 .58805 L .47647 .60202 L F
.46929 .58578 m .44822 .56514 L .46969 .58559 L .745 .291 .174 r
F
.45348 .57995 m .47059 .5957 L .47069 .59647 L .797 .547 .561 r
F
.45542 .58417 m .47069 .59647 L .47174 .60452 L F
.45542 .58417 m .47174 .60452 L .45962 .59333 L F
.43703 .54238 m .42942 .54407 L .44396 .53837 L 0 0 0 r
F
.43674 .54255 m .4365 .5426 L .43703 .54238 L F
.4365 .5426 m .42942 .54407 L .43703 .54238 L F
.43703 .54238 m .45088 .54498 L .47093 .56812 L .627 .339 .461 r
F
.43703 .54238 m .47093 .56812 L .47436 .5738 L F
.48074 .5807 m .51073 .66087 L .48031 .58182 L .732 .556 .654 r
F
.51862 .56772 m .51938 .56885 L .51575 .57205 L .666 .547 .71 r
F
.55842 .64163 m .56026 .63082 L .56046 .63099 L .684 .561 .71 r
F
.55835 .6413 m .55538 .62434 L .56026 .63082 L F
.55339 .65127 m .55562 .64785 L .55208 .66146 L .743 .634 .739 r
F
.55562 .64785 m .55871 .6431 L .55654 .64912 L F
.55562 .64785 m .55654 .64912 L .55208 .66146 L F
.51938 .56885 m .5532 .61986 L .51905 .57604 L .666 .547 .71 r
F
.55835 .6413 m .55871 .6431 L .55339 .65127 L .743 .634 .739 r
F
.55692 .65362 m .56046 .63099 L .58171 .64862 L .684 .561 .71 r
F
.5532 .61986 m .56049 .63085 L .55196 .61979 L .666 .547 .71 r
F
.55608 .65379 m .56046 .63099 L .55692 .65362 L .684 .561 .71 r
F
.56026 .63082 m .58015 .63368 L .58171 .64862 L F
.56049 .63085 m .56201 .63315 L .56026 .63082 L .666 .547 .71 r
F
.56049 .63085 m .56026 .63082 L .55196 .61979 L F
.5532 .61986 m .55196 .61979 L .51905 .57604 L F
.53822 .62386 m .53893 .61908 L .55531 .64742 L .699 .548 .679 r
F
.53893 .61908 m .55196 .61979 L .55531 .64742 L F
.55531 .64742 m .55196 .61979 L .55835 .6413 L .684 .561 .71 r
F
.54367 .57428 m .55977 .56786 L .56026 .58112 L .666 .547 .71 r
F
.51972 .56837 m .56026 .58112 L .5618 .62248 L F
.51941 .56797 m .5199 .56813 L .51972 .56837 L F
.5199 .56813 m .56026 .58112 L .51972 .56837 L F
.52297 .56391 m .51969 .56197 L .52307 .5627 L .494 .321 .575 r
F
.52051 .56729 m .51969 .56197 L .52297 .56391 L F
.52051 .56729 m .51012 .52717 L .51404 .52523 L F
.51938 .56885 m .51903 .57638 L .51575 .57205 L .666 .547 .71 r
F
.50551 .53752 m .50907 .52335 L .5199 .56813 L .543 .31 .512 r
F
.51862 .56772 m .5618 .62248 L .56049 .63085 L .666 .547 .71 r
F
.51941 .56797 m .5618 .62248 L .51862 .56772 L F
.51816 .56757 m .5199 .56813 L .52193 .57651 L .543 .31 .512 r
F
.50551 .53752 m .5199 .56813 L .51816 .56757 L F
.5152 .56256 m .51941 .56797 L .51862 .56772 L .666 .547 .71 r
F
.5152 .56256 m .56026 .58112 L .51941 .56797 L F
.52193 .57651 m .52051 .56729 L .52297 .56391 L .494 .321 .575 r
F
.55196 .61979 m .54605 .571 L .55538 .62434 L .684 .561 .71 r
F
.55196 .61979 m .55538 .62434 L .55835 .6413 L F
.55835 .6413 m .56026 .63082 L .55842 .64163 L F
.51817 .6172 m .52008 .59652 L .52254 .60769 L .732 .552 .648 r
F
.52002 .61933 m .52254 .60769 L .52681 .62715 L F
.51817 .6172 m .52254 .60769 L .52002 .61933 L F
.52201 .73787 m .54122 .69047 L .54767 .69951 L .794 .728 .79 r
F
.51259 .66253 m .5107 .66077 L .5108 .66072 L .872 .767 .743 r
F
.51905 .57604 m .53007 .59071 L .51903 .57638 L .666 .547 .71 r
F
.53007 .59071 m .5622 .63344 L .52993 .59079 L F
.53007 .59071 m .52993 .59079 L .51903 .57638 L F
.56201 .63315 m .5622 .63344 L .51905 .57604 L F
.51575 .57205 m .56021 .63081 L .53996 .62086 L F
.53822 .62386 m .53313 .60905 L .53893 .61908 L .699 .548 .679 r
F
.51575 .57205 m .53996 .62086 L .51619 .5798 L .666 .547 .71 r
F
.52957 .63033 m .52441 .594 L .53822 .62386 L .699 .548 .679 r
F
.52441 .594 m .52193 .57651 L .53313 .60905 L F
.52441 .594 m .53313 .60905 L .53822 .62386 L F
.56021 .63081 m .55611 .63022 L .54065 .62205 L .666 .547 .71 r
F
.52602 .63298 m .55002 .65387 L .54456 .67511 L .743 .634 .739 r
F
.52002 .61933 m .52957 .63033 L .52602 .63298 L F
.52957 .63033 m .55002 .65387 L .52602 .63298 L F
.52002 .61933 m .54456 .67511 L .53586 .68971 L F
.52373 .61311 m .5274 .61505 L .53333 .65684 L .732 .552 .648 r
F
.52008 .59652 m .5274 .61505 L .52373 .61311 L F
.52008 .59652 m .52441 .594 L .5274 .61505 L F
.48115 .58178 m .49344 .59072 L .51071 .66076 L .732 .556 .654 r
F
.48074 .5807 m .51071 .66076 L .5107 .66077 L F
.51217 .65572 m .51304 .65685 L .51105 .6609 L .743 .634 .739 r
F
.51063 .66126 m .488 .74924 L .48905 .72833 L .803 .728 .781 r
F
.47717 .72401 m .48307 .74465 L .43402 .77462 L .839 .839 .846 r
F
.48362 .72444 m .50351 .68194 L .48828 .73079 L .872 .767 .743 r
F
.488 .74924 m .48695 .74751 L .48713 .74528 L .803 .728 .781 r
F
.488 .74924 m .48713 .74528 L .48819 .74557 L F
.51997 .68204 m .51334 .66194 L .52304 .67625 L .829 .73 .755 r
F
.50944 .66888 m .51051 .67022 L .49728 .74405 L .803 .728 .781 r
F
.51065 .6704 m .51334 .66194 L .51997 .68204 L .829 .73 .755 r
F
.5112 .66665 m .51279 .66211 L .51105 .6677 L .872 .767 .743 r
F
.51065 .66135 m .51145 .66498 L .51051 .67022 L .803 .728 .781 r
F
.51065 .66135 m .51051 .67022 L .50944 .66888 L F
.51145 .66498 m .50033 .74076 L .49728 .74405 L F
.46201 .74939 m .46672 .73829 L .47361 .74583 L .935 .84 .726 r
F
.46672 .73829 m .47543 .72665 L .47361 .74583 L F
.47653 .71519 m .48843 .68713 L .48021 .72421 L F
.48707 .69328 m .4894 .69415 L .48021 .72421 L F
.48843 .68713 m .4888 .68985 L .48707 .69328 L F
.4888 .68985 m .4894 .69415 L .48707 .69328 L F
.48857 .68612 m .49357 .68042 L .4888 .68985 L .803 .643 .683 r
F
.39671 .79902 m .40684 .79902 L .40056 .79899 L .275 0 0 r
F
.39578 .80107 m .42696 .77894 L .43322 .77557 L .786 .975 .912 r
F
.42885 .78022 m .43322 .77557 L .45402 .76435 L F
.39578 .80107 m .43322 .77557 L .42885 .78022 L F
.43402 .77462 m .47019 .7547 L .43193 .77708 L .839 .839 .846 r
F
.47019 .7547 m .47251 .75371 L .43193 .77708 L F
.48307 .74465 m .4838 .7472 L .43402 .77462 L F
.43322 .77557 m .47361 .74583 L .45402 .76435 L .786 .975 .912 r
F
.45342 .75482 m .45704 .75235 L .46201 .74939 L .486 .876 .693 r
F
.476 .72537 m .44533 .76136 L .46404 .74184 L .839 .839 .846 r
F
.46471 .74096 m .46404 .74184 L .46415 .74173 L F
.476 .72537 m .46404 .74184 L .46471 .74096 L F
.46201 .74939 m .46471 .74096 L .46672 .73829 L .935 .84 .726 r
F
.45967 .75065 m .46459 .74112 L .46201 .74939 L .964 .935 .627 r
F
.45641 .75241 m .45835 .74973 L .45967 .75065 L F
.4588 .74912 m .46459 .74112 L .45858 .74989 L F
.44533 .76136 m .44856 .75875 L .46415 .74173 L .839 .839 .846 r
F
.44279 .76562 m .46201 .74939 L .47361 .74583 L .721 .988 .872 r
F
.43515 .7734 m .43591 .77262 L .44868 .75865 L .839 .839 .846 r
F
.44856 .75875 m .44868 .75865 L .46415 .74173 L F
.43402 .77462 m .44868 .75865 L .44856 .75875 L F
.44533 .76136 m .43402 .77462 L .44856 .75875 L F
.45172 .75655 m .46201 .74939 L .44279 .76562 L .721 .988 .872 r
F
.44279 .76562 m .47361 .74583 L .43623 .77236 L F
.43623 .77236 m .47361 .74583 L .43322 .77557 L .786 .975 .912 r
F
.39763 .79991 m .42885 .78022 L .40868 .79822 L F
.42885 .78022 m .45402 .76435 L .41812 .79117 L F
.42885 .78022 m .41812 .79117 L .40868 .79822 L F
.43322 .77557 m .43193 .77708 L .44782 .76 L .839 .839 .846 r
F
.45402 .76435 m .47251 .75371 L .40868 .79822 L .786 .975 .912 r
F
.40754 .79902 m .48851 .75007 L .41977 .79653 L .792 .953 .922 r
F
.48851 .75007 m .50114 .74243 L .48937 .75026 L F
.48851 .75007 m .48937 .75026 L .41977 .79653 L F
.51063 .66126 m .51078 .66084 L .51259 .66253 L .872 .767 .743 r
F
.51073 .66087 m .49728 .74405 L .48827 .7482 L .803 .728 .781 r
F
.50114 .74243 m .47251 .75371 L .50378 .74084 L .792 .953 .922 r
F
.48827 .7482 m .4966 .74479 L .49465 .74579 L .803 .728 .781 r
F
.48827 .7482 m .4962 .74521 L .48783 .74992 L F
.45266 .76755 m .47251 .75371 L .50114 .74243 L .792 .953 .922 r
F
.47251 .75371 m .50186 .74112 L .50378 .74084 L F
.488 .74924 m .48783 .74992 L .48695 .74751 L .803 .728 .781 r
F
.50114 .74243 m .50268 .74157 L .41977 .79653 L .792 .953 .922 r
F
.48783 .74992 m .48629 .75591 L .48678 .7497 L .803 .728 .781 r
F
.48783 .74992 m .48678 .7497 L .48695 .74751 L F
.43193 .77708 m .48629 .75591 L .41864 .79267 L .839 .839 .846 r
F
.4838 .7472 m .48629 .75591 L .43193 .77708 L F
.43193 .77708 m .41864 .79267 L .43918 .76968 L F
.43193 .77708 m .43918 .76968 L .44782 .76 L F
.43718 .77123 m .44782 .76 L .46415 .74173 L F
.43322 .77557 m .43922 .76918 L .43718 .77123 L F
.43922 .76918 m .44782 .76 L .43718 .77123 L F
.45342 .75482 m .46201 .74939 L .45179 .75647 L .486 .876 .693 r
F
.45429 .75412 m .45704 .75235 L .45342 .75482 L F
.46091 .74606 m .4517 .75621 L .45736 .7508 L .839 .839 .846 r
F
.4517 .75621 m .44763 .76071 L .45337 .75486 L F
.46415 .74173 m .44782 .76 L .46091 .74606 L F
.44782 .76 m .41864 .79267 L .46091 .74606 L F
.39575 .79529 m .45179 .75647 L .38983 .79956 L .721 .988 .872 r
F
.45179 .75647 m .46201 .74939 L .45172 .75655 L F
.44027 .76316 m .39575 .79529 L .37934 .80245 L .799 .946 .92 r
F
.39575 .79529 m .38923 .79999 L .38919 .8 L F
.39575 .79529 m .38919 .8 L .37934 .80245 L F
.4517 .75621 m .45429 .75412 L .45736 .7508 L .839 .839 .846 r
F
.44211 .76198 m .45342 .75482 L .39919 .79282 L .486 .876 .693 r
F
.45179 .75647 m .45172 .75655 L .38981 .79958 L .721 .988 .872 r
F
.38983 .79956 m .38981 .79958 L .38816 .80072 L F
.45179 .75647 m .38981 .79958 L .38983 .79956 L F
.45342 .75482 m .45179 .75647 L .39575 .79529 L .486 .876 .693 r
F
.44211 .76198 m .39575 .79529 L .44027 .76316 L .799 .946 .92 r
F
.39919 .79282 m .39575 .79529 L .38792 .80071 L .486 .876 .693 r
F
.45342 .75482 m .39575 .79529 L .39919 .79282 L F
.38816 .80072 m .45172 .75655 L .44279 .76562 L .721 .988 .872 r
F
.44211 .76198 m .45429 .75412 L .45342 .75482 L .486 .876 .693 r
F
.45429 .75412 m .38923 .79999 L .39575 .79529 L .799 .946 .92 r
F
.45429 .75412 m .39575 .79529 L .44211 .76198 L F
.45429 .75412 m .37934 .80245 L .37429 .80371 L F
.38137 .80039 m .44211 .76198 L .38792 .80071 L .486 .876 .693 r
F
.44211 .76198 m .39919 .79282 L .38792 .80071 L F
.45337 .75486 m .41864 .79267 L .45429 .75412 L .839 .839 .846 r
F
.44763 .76071 m .41864 .79267 L .45337 .75486 L F
.43402 .77462 m .43497 .77365 L .43591 .77262 L F
.43402 .77462 m .43591 .77262 L .43515 .7734 L F
.43402 .77462 m .43322 .77557 L .43497 .77365 L F
.38891 .80024 m .44279 .76562 L .42696 .77894 L .721 .988 .872 r
F
.44279 .76562 m .43623 .77236 L .42696 .77894 L F
.42696 .77894 m .43623 .77236 L .43322 .77557 L .786 .975 .912 r
F
.39251 .8 m .42696 .77894 L .39781 .79963 L .721 .988 .872 r
F
.38891 .80024 m .42696 .77894 L .39251 .8 L F
.45429 .75412 m .41864 .79267 L .38923 .79999 L .799 .946 .92 r
F
.38792 .80071 m .39575 .79529 L .38816 .80072 L .721 .988 .872 r
F
.39575 .79529 m .38983 .79956 L .38816 .80072 L F
.4577 .74873 m .47974 .6925 L .46459 .74112 L .964 .935 .627 r
F
.45858 .74989 m .46459 .74112 L .45967 .75065 L F
.47432 .61495 m .48544 .64925 L .48545 .65194 L .957 .664 .437 r
F
.48387 .65715 m .48688 .67428 L .48211 .68644 L .874 .745 .717 r
F
.48546 .65859 m .48688 .67428 L .48387 .65715 L F
.48743 .67511 m .4873 .67462 L .48546 .65601 L .803 .643 .683 r
F
.4805 .65411 m .47696 .63169 L .48274 .64713 L .957 .664 .437 r
F
.4888 .68985 m .48843 .68713 L .48546 .65601 L .803 .643 .683 r
F
.48843 .68713 m .4875 .67973 L .48546 .65601 L F
.46459 .74112 m .46471 .74096 L .46201 .74939 L .964 .935 .627 r
F
.48021 .72421 m .48556 .74735 L .47717 .72401 L .839 .839 .846 r
F
.48556 .74735 m .4854 .74744 L .47717 .72401 L F
.48562 .74808 m .48422 .74868 L .47717 .72401 L F
.48362 .72444 m .48449 .73467 L .48021 .72421 L F
.48449 .73467 m .48556 .74735 L .48021 .72421 L F
.51304 .65685 m .51624 .66101 L .51386 .66177 L .743 .634 .739 r
F
.51304 .65685 m .51407 .66301 L .51243 .6606 L F
.51304 .65685 m .51225 .66173 L .51105 .6609 L F
.51131 .65682 m .50833 .64226 L .5135 .65404 L .784 .572 .613 r
F
.50038 .60346 m .51131 .65682 L .51073 .66087 L .732 .556 .654 r
F
.5072 .63969 m .50719 .61755 L .5135 .65404 L .784 .572 .613 r
F
.51817 .6172 m .51185 .60379 L .51244 .60206 L .732 .552 .648 r
F
.51614 .60521 m .51244 .60206 L .51455 .59581 L F
.51817 .6172 m .51244 .60206 L .51614 .60521 L F
.5072 .63674 m .50224 .5941 L .50719 .61755 L .784 .572 .613 r
F
.50651 .6334 m .50224 .5941 L .5072 .63674 L F
.50224 .5941 m .50314 .59416 L .50719 .61755 L F
.50718 .5877 m .50811 .56538 L .5147 .59537 L .65 .463 .618 r
F
.50718 .59443 m .5147 .59537 L .51244 .60206 L F
.49169 .57193 m .50718 .5877 L .50718 .59443 L F
.50718 .5877 m .5147 .59537 L .50718 .59443 L F
.48285 .58046 m .47103 .55794 L .4815 .55712 L .608 .314 .444 r
F
.48265 .57701 m .50079 .594 L .48286 .58067 L .65 .463 .618 r
F
.48215 .58129 m .46468 .54583 L .48285 .58046 L .608 .314 .444 r
F
.50079 .594 m .48288 .58094 L .48286 .58067 L .65 .463 .618 r
F
.48288 .58094 m .48285 .58046 L .48306 .58085 L .608 .314 .444 r
F
.48215 .58129 m .48285 .58046 L .48288 .58094 L F
.48175 .58149 m .49344 .59072 L .48115 .58178 L .732 .556 .654 r
F
.48031 .58182 m .50576 .6518 L .49995 .63932 L F
.48031 .58182 m .49995 .63932 L .49961 .63839 L F
.49987 .63914 m .48296 .58294 L .48302 .58293 L .784 .572 .613 r
F
.50079 .594 m .50052 .59398 L .48288 .58094 L .65 .463 .618 r
F
.50052 .59398 m .49244 .58888 L .48288 .58094 L F
.50052 .59398 m .50224 .5941 L .50651 .6334 L .784 .572 .613 r
F
.5057 .62941 m .50651 .6334 L .5072 .63969 L F
.50052 .59398 m .50651 .6334 L .5057 .62941 L F
.50314 .59416 m .50079 .594 L .48196 .57637 L .65 .463 .618 r
F
.48192 .57611 m .48196 .57637 L .47936 .57393 L F
.50314 .59416 m .48196 .57637 L .48192 .57611 L F
.50038 .60346 m .49244 .58888 L .50052 .59398 L .784 .572 .613 r
F
.49344 .59072 m .50038 .60346 L .51071 .66075 L .732 .556 .654 r
F
.49344 .59072 m .51071 .66075 L .51071 .66076 L F
.49987 .63914 m .50052 .59398 L .5072 .63969 L .784 .572 .613 r
F
.50811 .56538 m .51575 .57205 L .51674 .58935 L .65 .463 .618 r
F
.51905 .60769 m .5154 .59331 L .52008 .59652 L .732 .552 .648 r
F
.5154 .59331 m .51674 .58935 L .52008 .59652 L F
.51817 .6172 m .51614 .60521 L .51905 .60769 L F
.50811 .56538 m .51674 .58935 L .5147 .59537 L .65 .463 .618 r
F
.51614 .60521 m .51159 .5783 L .51905 .60769 L .732 .552 .648 r
F
.5147 .59537 m .51674 .58935 L .51793 .61004 L .65 .463 .618 r
F
.5154 .59331 m .51159 .5783 L .51674 .58935 L .732 .552 .648 r
F
.4814 .55535 m .46468 .54583 L .48106 .5495 L .608 .314 .444 r
F
.47103 .55794 m .46468 .54583 L .48413 .55691 L F
.47644 .54978 m .4815 .55712 L .47936 .57393 L .65 .463 .618 r
F
.4815 .55712 m .51244 .60206 L .48263 .57671 L F
.4815 .55712 m .48263 .57671 L .47936 .57393 L F
.48413 .55691 m .4814 .55535 L .48443 .55026 L .608 .314 .444 r
F
.4814 .55535 m .48106 .5495 L .48443 .55026 L F
.49169 .57193 m .49932 .56889 L .50718 .5877 L .65 .463 .618 r
F
.49932 .56889 m .50717 .56576 L .50717 .57507 L F
.49932 .56889 m .50717 .57507 L .50718 .5877 L F
.4845 .58229 m .49244 .58888 L .48074 .5807 L .732 .556 .654 r
F
.49244 .58888 m .49291 .58975 L .48074 .5807 L F
.49841 .59384 m .49861 .5948 L .48074 .5807 L F
.48416 .55694 m .4847 .54483 L .49678 .56688 L .608 .314 .444 r
F
.47962 .52788 m .49349 .54138 L .49104 .54234 L .523 .324 .553 r
F
.47975 .52778 m .49358 .54134 L .47962 .52788 L F
.49358 .54134 m .51093 .55837 L .49349 .54138 L F
.49358 .54134 m .49349 .54138 L .47962 .52788 L F
.4815 .55712 m .48474 .55739 L .49169 .57193 L .65 .463 .618 r
F
.4847 .54483 m .48967 .54288 L .49678 .56688 L .608 .314 .444 r
F
.50289 .56083 m .50326 .55757 L .52104 .57666 L .543 .31 .512 r
F
.50037 .56333 m .49648 .56585 L .50018 .55424 L F
.49678 .56688 m .49648 .56585 L .50037 .56333 L F
.50326 .55757 m .51093 .55837 L .51158 .56315 L F
.50326 .55757 m .51816 .56757 L .51077 .56519 L F
.51616 .57142 m .50326 .55757 L .51647 .57097 L F
.50466 .55908 m .5152 .56256 L .49169 .57193 L .65 .463 .618 r
F
.50072 .58018 m .50018 .55424 L .50326 .55757 L .543 .31 .512 r
F
.49104 .54234 m .51093 .55837 L .50192 .55612 L .523 .324 .553 r
F
.49349 .54138 m .51093 .55837 L .49104 .54234 L F
.47867 .52864 m .50192 .55612 L .47845 .53074 L F
.47854 .52864 m .47116 .52845 L .47886 .52848 L 0 0 0 r
F
.47043 .52907 m .47116 .52845 L .47854 .52864 L F
.46279 .53509 m .47507 .52883 L .478 .53501 L .455 .123 .313 r
F
.47507 .52883 m .47867 .52864 L .478 .53501 L F
.44628 .53746 m .46672 .54581 L .44087 .5405 L F
.46672 .54581 m .46934 .54688 L .46468 .54583 L F
.46672 .54581 m .46468 .54583 L .44087 .5405 L F
.46648 .56072 m .4627 .54585 L .46666 .54985 L .68 .316 .35 r
F
.4627 .54585 m .46468 .54583 L .46666 .54985 L F
.46429 .55709 m .46216 .54586 L .46648 .56072 L F
.46216 .54586 m .4627 .54585 L .46648 .56072 L F
.46429 .55709 m .45026 .54442 L .46216 .54586 L F
.46934 .54688 m .47644 .54978 L .46147 .54587 L .455 .123 .313 r
F
.46468 .54583 m .46147 .54587 L .44087 .5405 L F
.46934 .54688 m .46147 .54587 L .46468 .54583 L F
.46216 .54586 m .46058 .53753 L .4627 .54585 L .68 .316 .35 r
F
.4627 .54585 m .46058 .53753 L .46468 .54583 L F
.44627 .54082 m .45864 .53163 L .46058 .53753 L 0 0 0 r
F
.43795 .54201 m .45036 .54451 L .43703 .54238 L .627 .339 .461 r
F
.45036 .54451 m .47644 .54978 L .45088 .54498 L F
.45036 .54451 m .45088 .54498 L .43703 .54238 L F
.46081 .5457 m .45026 .54442 L .43824 .54197 L .455 .123 .313 r
F
.46216 .54586 m .45026 .54442 L .46058 .53753 L .68 .316 .35 r
F
.43824 .54197 m .47644 .54978 L .43795 .54201 L .627 .339 .461 r
F
.45026 .54442 m .43736 .54287 L .44627 .54082 L .68 .316 .35 r
F
.45026 .54442 m .44627 .54082 L .46058 .53753 L F
.43736 .54287 m .43937 .5418 L .44627 .54082 L 0 0 0 r
F
.43937 .5418 m .45864 .53163 L .44627 .54082 L F
.43497 .54338 m .42942 .54407 L .43695 .54251 L F
.42996 .54386 m .4215 .54475 L .43463 .54341 L .124 .673 .727 r
F
.42996 .54386 m .43463 .54341 L .43436 .54343 L F
.42131 .54432 m .44072 .53519 L .43599 .5415 L .067 0 0 r
F
.39689 .54825 m .44072 .53519 L .41671 .5452 L F
.38907 .54929 m .42431 .54344 L .38531 .54366 L F
.42747 .54292 m .43599 .5415 L .38531 .54366 L F
.41671 .5452 m .43599 .5415 L .38907 .54929 L F
.38531 .54366 m .43638 .54276 L .43497 .54338 L .462 0 .036 r
F
.43259 .54358 m .42996 .54386 L .43436 .54343 L .124 .673 .727 r
F
.38531 .54366 m .43497 .54338 L .4267 .54407 L .462 0 .036 r
F
.37323 .54896 m .38907 .54929 L .38531 .54366 L .615 .938 .956 r
F
.3759 .54993 m .38907 .54929 L .37323 .54896 L F
.35527 .54616 m .34967 .54529 L .37592 .55105 L .164 .683 .886 r
F
.36474 .54764 m .38531 .54366 L .36599 .54555 L .317 .806 .849 r
F
.37323 .54896 m .38531 .54366 L .36474 .54764 L .615 .938 .956 r
F
.36275 .54514 m .33928 .54301 L .37768 .55058 L .164 .683 .886 r
F
.3459 .54302 m .38811 .54032 L .34336 .54263 L .317 .806 .849 r
F
.37309 .54387 m .38811 .54032 L .3459 .54302 L F
.37859 .55063 m .38907 .54929 L .37039 .5502 L .615 .938 .956 r
F
.42285 .54473 m .42437 .54469 L .42613 .54446 L .124 .673 .727 r
F
.42613 .54446 m .41995 .54496 L .3969 .5558 L .549 .93 .848 r
F
.38531 .54366 m .42325 .54403 L .40089 .54621 L .462 0 .036 r
F
.42325 .54403 m .41742 .54484 L .40089 .54621 L F
.41742 .54484 m .39471 .54839 L .42285 .54473 L .124 .673 .727 r
F
.39471 .54839 m .39183 .54891 L .42285 .54473 L F
.38824 .5494 m .39232 .54887 L .42285 .54473 L F
.40387 .54671 m .38659 .54965 L .41742 .54484 L F
.38979 .55037 m .39689 .54825 L .41671 .5452 L .067 0 0 r
F
.38979 .55037 m .41671 .5452 L .38907 .54929 L F
.40387 .54671 m .37592 .55105 L .38659 .54965 L .124 .673 .727 r
F
.40089 .54621 m .41223 .54556 L .40918 .54598 L .462 0 .036 r
F
.42579 .54468 m .42613 .54446 L .3969 .5558 L .549 .93 .848 r
F
.40207 .55975 m .42579 .54468 L .3969 .5558 L F
.40089 .54621 m .43313 .5453 L .40573 .547 L .462 0 .036 r
F
.42325 .54403 m .4267 .54407 L .41742 .54484 L F
.4145 .5449 m .41742 .54484 L .43371 .54346 L .124 .673 .727 r
F
.41742 .54484 m .41934 .5448 L .43118 .5437 L F
.41742 .54484 m .43118 .5437 L .43371 .54346 L F
.41934 .5448 m .4215 .54475 L .43371 .54346 L F
.4215 .54475 m .42285 .54473 L .42613 .54446 L F
.4215 .54475 m .42634 .54445 L .43528 .54334 L F
.4267 .54407 m .43632 .54416 L .40089 .54621 L .462 0 .036 r
F
.38531 .54366 m .43599 .5415 L .43638 .54276 L F
.38531 .54366 m .40391 .5467 L .38811 .54032 L F
.40391 .5467 m .4089 .54579 L .38811 .54032 L F
.4089 .54579 m .40976 .54547 L .38811 .54032 L F
.39736 .54702 m .39761 .54751 L .40903 .54574 L .164 .683 .886 r
F
.38811 .54032 m .40976 .54547 L .39983 .54578 L .643 .215 .214 r
F
.38657 .54819 m .40903 .54574 L .40978 .54546 L .164 .683 .886 r
F
.41529 .54488 m .40387 .54671 L .41742 .54484 L .124 .673 .727 r
F
.4145 .5449 m .41218 .5453 L .41529 .54488 L F
.41218 .5453 m .40387 .54671 L .41529 .54488 L F
.41218 .5453 m .39851 .54745 L .40387 .54671 L F
.4145 .5449 m .41125 .54542 L .41218 .5453 L F
.41125 .54542 m .39851 .54745 L .41218 .5453 L F
.40976 .54547 m .40903 .54574 L .41111 .54542 L .164 .683 .886 r
F
.39619 .54409 m .39983 .54578 L .39872 .54382 L .643 .215 .214 r
F
.39983 .54578 m .40324 .54408 L .4021 .54347 L F
.39872 .54382 m .4021 .54347 L .39695 .54069 L F
.39983 .54578 m .4021 .54347 L .39872 .54382 L F
.39417 .54314 m .39619 .54409 L .3964 .54315 L F
.39417 .54314 m .3964 .54315 L .39695 .54069 L F
.38811 .54032 m .39417 .54314 L .39695 .54069 L F
.39619 .54409 m .39872 .54382 L .39695 .54069 L F
.40502 .54316 m .405 .54317 L .40525 .54317 L .264 .671 .967 r
F
.40701 .54406 m .39923 .54479 L .40978 .54546 L .164 .683 .886 r
F
.4018 .5441 m .39923 .54479 L .40701 .54406 L F
.39923 .54479 m .3894 .54786 L .40978 .54546 L F
.40976 .54547 m .41016 .54556 L .39983 .54578 L .643 .215 .214 r
F
.40456 .54659 m .40612 .54685 L .4089 .54579 L .462 0 .036 r
F
.40391 .5467 m .40612 .54685 L .40456 .54659 L F
.40391 .5467 m .40573 .547 L .40612 .54685 L F
.40918 .54598 m .43632 .54416 L .43313 .5453 L F
.41223 .54556 m .43632 .54416 L .40918 .54598 L F
.40573 .547 m .43313 .5453 L .42125 .54954 L F
.43632 .54416 m .43619 .54438 L .42125 .54954 L F
.44177 .55428 m .43232 .55136 L .43605 .54464 L .745 .291 .174 r
F
.43605 .54464 m .43614 .5444 L .46969 .58559 L F
.46738 .57339 m .43671 .5442 L .46651 .5688 L .68 .316 .35 r
F
.43671 .5442 m .4357 .54325 L .43682 .54417 L F
.43671 .5442 m .43682 .54417 L .46651 .5688 L F
.43632 .54416 m .43682 .54417 L .43619 .54438 L .462 0 .036 r
F
.45952 .5731 m .43528 .54334 L .46738 .57339 L .68 .316 .35 r
F
.43232 .55136 m .43682 .54417 L .43942 .55252 L .462 0 .036 r
F
.42125 .54954 m .43619 .54438 L .43232 .55136 L F
.43619 .54438 m .43682 .54417 L .43232 .55136 L F
.45251 .57236 m .42918 .55701 L .44822 .56514 L .745 .291 .174 r
F
.4383 .56461 m .42918 .55701 L .45251 .57236 L F
.37768 .55058 m .37859 .55063 L .4145 .5449 L .164 .683 .886 r
F
.4089 .54579 m .42781 .54996 L .41016 .54556 L .462 0 .036 r
F
.42781 .54996 m .42499 .54909 L .41016 .54556 L F
.40573 .547 m .43232 .55136 L .4089 .54579 L F
.43232 .55136 m .42781 .54996 L .4089 .54579 L F
.41016 .54556 m .42499 .54909 L .40363 .54643 L .643 .215 .214 r
F
.41908 .54835 m .4198 .54918 L .40363 .54643 L F
.4089 .54579 m .41016 .54556 L .40976 .54547 L .462 0 .036 r
F
.41016 .54556 m .40363 .54643 L .39983 .54578 L .643 .215 .214 r
F
.43058 .55449 m .42547 .55141 L .43605 .54464 L .745 .291 .174 r
F
.39851 .54745 m .37592 .55105 L .40387 .54671 L .124 .673 .727 r
F
.40175 .54668 m .42192 .5498 L .42691 .5584 L .643 .215 .214 r
F
.42192 .5498 m .42524 .55032 L .42639 .55586 L F
.42192 .5498 m .42639 .55586 L .42691 .5584 L F
.44111 .57265 m .43094 .56205 L .45077 .57835 L .679 .139 0 r
F
.43094 .56205 m .42896 .55936 L .45077 .57835 L F
.42896 .55936 m .42639 .55586 L .43237 .56138 L F
.42896 .55936 m .43237 .56138 L .45077 .57835 L F
.42918 .55701 m .43058 .55449 L .44822 .56514 L .745 .291 .174 r
F
.44822 .56514 m .43058 .55449 L .43232 .55136 L F
.44822 .56514 m .43232 .55136 L .44177 .55428 L F
.42499 .54909 m .42519 .5501 L .4198 .54918 L .643 .215 .214 r
F
.42499 .54909 m .4198 .54918 L .41908 .54835 L F
.40363 .54643 m .42519 .5501 L .40175 .54668 L F
.42519 .5501 m .42524 .55032 L .40175 .54668 L F
.42609 .55442 m .4145 .5449 L .41466 .54489 L .745 .291 .174 r
F
.45734 .5805 m .45058 .57488 L .45055 .57484 L F
.45734 .5805 m .4383 .56461 L .45251 .57236 L F
.45348 .57995 m .47069 .59647 L .45542 .58417 L .797 .547 .561 r
F
.45309 .57911 m .4548 .58073 L .45348 .57995 L F
.4548 .58073 m .47059 .5957 L .45348 .57995 L F
.45077 .57835 m .4145 .5449 L .45734 .5805 L .745 .291 .174 r
F
.45281 .5785 m .45363 .57929 L .45309 .57911 L .797 .547 .561 r
F
.45363 .57929 m .47059 .5957 L .45309 .57911 L F
.45962 .59333 m .47012 .60302 L .47261 .61833 L F
.45962 .59333 m .47387 .62076 L .47038 .61678 L F
.42612 .55455 m .4145 .5449 L .42609 .55442 L .745 .291 .174 r
F
.45055 .57484 m .42612 .55455 L .42609 .55442 L F
.45058 .57488 m .42612 .55455 L .45055 .57484 L F
.42691 .5584 m .43942 .55252 L .44813 .56829 L .643 .215 .214 r
F
.42547 .55141 m .4241 .54478 L .43605 .54464 L .745 .291 .174 r
F
.42918 .55701 m .42609 .55442 L .43058 .55449 L F
.42609 .55442 m .42547 .55141 L .43058 .55449 L F
.42524 .55032 m .43942 .55252 L .42691 .5584 L .643 .215 .214 r
F
.42691 .5584 m .42896 .55936 L .40189 .54476 L F
.42896 .55936 m .4192 .55357 L .40189 .54476 L F
.43094 .56205 m .4145 .5449 L .42639 .55586 L .679 .139 0 r
F
.42758 .55854 m .41842 .55223 L .4145 .5449 L F
.40052 .5434 m .40324 .54408 L .4018 .5441 L .749 .348 .291 r
F
.40052 .5434 m .4018 .5441 L .40136 .54404 L F
.39695 .54069 m .4021 .54347 L .40052 .5434 L F
.4021 .54347 m .40324 .54408 L .40052 .5434 L F
.40052 .5434 m .40136 .54404 L .40386 .54316 L F
.40525 .54317 m .40386 .54316 L .4018 .5441 L .164 .683 .886 r
F
.39695 .54069 m .40052 .5434 L .40386 .54316 L .749 .348 .291 r
F
.40386 .54316 m .39406 .54314 L .40136 .54404 L .164 .683 .886 r
F
.40386 .54316 m .40136 .54404 L .4018 .5441 L F
.40447 .54295 m .40386 .54316 L .40493 .54309 L .749 .348 .291 r
F
.39695 .54069 m .40386 .54316 L .40447 .54295 L F
.40525 .54317 m .4018 .5441 L .40701 .54406 L .164 .683 .886 r
F
.4018 .5441 m .40124 .54408 L .39923 .54479 L F
.42079 .55451 m .4205 .55423 L .4192 .55357 L .643 .215 .214 r
F
.42896 .55936 m .4205 .55423 L .42079 .55451 L F
.40649 .54408 m .40525 .54317 L .41842 .55223 L .679 .139 0 r
F
.41851 .55232 m .41842 .55223 L .42758 .55854 L F
.40649 .54408 m .41842 .55223 L .41851 .55232 L F
.40189 .54476 m .42359 .5558 L .40324 .54408 L .643 .215 .214 r
F
.42359 .5558 m .41851 .55232 L .40324 .54408 L F
.40324 .54408 m .41851 .55232 L .40143 .5441 L .749 .348 .291 r
F
.42359 .5558 m .44813 .56829 L .41851 .55232 L .643 .215 .214 r
F
.41851 .55232 m .41993 .55368 L .40143 .5441 L .749 .348 .291 r
F
.42896 .55936 m .44813 .56829 L .4205 .55423 L .643 .215 .214 r
F
.39983 .54578 m .40363 .54643 L .40175 .54668 L F
.39983 .54578 m .42691 .5584 L .40189 .54476 L F
.40143 .5441 m .41993 .55368 L .44218 .57505 L .749 .348 .291 r
F
.42919 .56022 m .40649 .54408 L .42758 .55854 L .679 .139 0 r
F
.43094 .56205 m .42317 .55634 L .42919 .56022 L F
.42317 .55634 m .40649 .54408 L .42919 .56022 L F
.37722 .54445 m .38531 .54366 L .37309 .54387 L .317 .806 .849 r
F
.39406 .54314 m .35702 .54305 L .4018 .5441 L .164 .683 .886 r
F
.40136 .54404 m .4018 .5441 L .40143 .5441 L .749 .348 .291 r
F
.40136 .54404 m .4099 .55053 L .40386 .54316 L F
.4099 .55053 m .42878 .56487 L .40915 .54777 L F
.4099 .55053 m .40915 .54777 L .40386 .54316 L F
.40978 .54546 m .40976 .54547 L .4145 .5449 L .164 .683 .886 r
F
.40976 .54547 m .41111 .54542 L .4145 .5449 L F
.41232 .54449 m .40978 .54546 L .4145 .5449 L F
.40525 .54317 m .40978 .54546 L .41232 .54449 L F
.41842 .55223 m .40525 .54317 L .40988 .54403 L .679 .139 0 r
F
.4377 .56984 m .40525 .54317 L .43094 .56205 L F
.40603 .54325 m .40782 .54288 L .40587 .5431 L 0 .222 .744 r
F
.4086 .54575 m .40814 .54405 L .40603 .54325 L F
.40814 .54405 m .40782 .54288 L .40603 .54325 L F
.36504 .54273 m .405 .54317 L .40502 .54316 L .264 .671 .967 r
F
.4055 .54311 m .36504 .54273 L .40502 .54316 L F
.35272 .54246 m .38811 .54032 L .39695 .54069 L .024 0 0 r
F
.34383 .54296 m .34336 .54263 L .33928 .54301 L .264 .671 .967 r
F
.34336 .54263 m .33915 .5427 L .33928 .54301 L F
.34336 .54263 m .38811 .54032 L .35272 .54246 L .024 0 0 r
F
.3459 .54302 m .34336 .54263 L .34349 .54272 L .317 .806 .849 r
F
.36599 .54555 m .37309 .54387 L .3459 .54302 L F
.36599 .54555 m .37722 .54445 L .37309 .54387 L F
.39923 .54479 m .35702 .54305 L .37768 .55058 L .164 .683 .886 r
F
.34383 .54296 m .33928 .54301 L .3459 .54302 L .264 .671 .967 r
F
.3459 .54302 m .33928 .54301 L .36275 .54514 L .164 .683 .886 r
F
.35527 .54616 m .33928 .54301 L .34967 .54529 L F
.36599 .54555 m .34293 .54265 L .32526 .54356 L .317 .806 .849 r
F
.35345 .54286 m .33725 .53835 L .34383 .54296 L .264 .671 .967 r
F
.35272 .54246 m .39695 .54069 L .33779 .53429 L .024 0 0 r
F
.34254 .53503 m .39695 .54069 L .40493 .54309 L .269 0 0 r
F
.39083 .54246 m .34601 .53879 L .35345 .54286 L .264 .671 .967 r
F
.34601 .53879 m .33725 .53835 L .35345 .54286 L F
.36401 .5397 m .33533 .53391 L .33725 .53835 L F
.37727 .54037 m .35144 .5364 L .36401 .5397 L F
.35144 .5364 m .33533 .53391 L .36401 .5397 L F
.3947 .54222 m .40075 .5429 L .39923 .54283 L .269 0 0 r
F
.35272 .54246 m .33817 .5345 L .33221 .53369 L .024 0 0 r
F
.33814 .53449 m .33779 .53429 L .33221 .53369 L F
.33221 .53369 m .40075 .5429 L .3947 .54222 L .269 0 0 r
F
.33221 .53369 m .40493 .54309 L .40075 .5429 L F
.33779 .53429 m .39695 .54069 L .34254 .53503 L F
.39627 .5427 m .36504 .54273 L .4055 .54311 L .264 .671 .967 r
F
.39083 .54246 m .37513 .54263 L .39627 .5427 L F
.37513 .54263 m .36504 .54273 L .39627 .5427 L F
.33221 .53369 m .3508 .53623 L .35144 .5364 L .269 0 0 r
F
.40459 .54311 m .40895 .54703 L .40493 .54309 L .749 .348 .291 r
F
.40895 .54703 m .40885 .54666 L .40493 .54309 L F
.41123 .54858 m .40525 .54317 L .44111 .57265 L .679 .139 0 r
F
.40895 .54703 m .42878 .56487 L .40885 .54666 L .749 .348 .291 r
F
.40401 .54329 m .42878 .56487 L .40459 .54311 L F
.45491 .58217 m .46682 .60881 L .45906 .58916 L .797 .547 .561 r
F
.46682 .60881 m .46618 .60653 L .45906 .58916 L F
.45348 .57995 m .47038 .61678 L .45491 .58217 L F
.47038 .61678 m .47036 .61609 L .45906 .58916 L F
.47038 .61678 m .47387 .62076 L .47453 .62582 L F
.47344 .62343 m .47209 .62011 L .45906 .58916 L F
.4626 .59133 m .45637 .58443 L .46247 .58915 L .679 .139 0 r
F
.46269 .59285 m .46016 .59031 L .4626 .59133 L F
.46016 .59031 m .45637 .58443 L .4626 .59133 L F
.44903 .5809 m .41123 .54858 L .44111 .57265 L F
.41252 .54972 m .41123 .54858 L .44903 .5809 L F
.42878 .56487 m .44218 .57505 L .41205 .54932 L .749 .348 .291 r
F
.40883 .54662 m .40525 .54317 L .41205 .54932 L 0 .222 .744 r
F
.41061 .54811 m .41205 .54932 L .41036 .54788 L .749 .348 .291 r
F
.42878 .56487 m .41205 .54932 L .41061 .54811 L F
.45858 .58105 m .47059 .5957 L .45281 .5785 L .797 .547 .561 r
F
.46247 .58915 m .45491 .58217 L .45734 .5805 L .745 .291 .174 r
F
.45309 .57911 m .45348 .57995 L .45491 .58217 L .797 .547 .561 r
F
.45491 .58217 m .45077 .57835 L .45309 .57911 L .745 .291 .174 r
F
.45491 .58217 m .45309 .57911 L .45734 .5805 L F
.44111 .57265 m .45077 .57835 L .45491 .58217 L .679 .139 0 r
F
.45637 .58443 m .45491 .58217 L .46247 .58915 L F
.45491 .58217 m .45906 .58916 L .45839 .58757 L .797 .547 .561 r
F
.44111 .57265 m .45491 .58217 L .45637 .58443 L .679 .139 0 r
F
.45309 .57911 m .45491 .58217 L .45674 .58364 L .797 .547 .561 r
F
.45491 .58217 m .45839 .58757 L .45674 .58364 L F
.45674 .58364 m .45934 .58963 L .45807 .58602 L F
.45934 .58963 m .46403 .60042 L .46008 .59088 L F
.45934 .58963 m .46008 .59088 L .45807 .58602 L F
.46532 .60346 m .4645 .6005 L .46247 .58915 L .787 .521 0 r
F
.46532 .60346 m .46277 .59063 L .46736 .60847 L F
.46403 .60042 m .46495 .60253 L .45807 .58602 L .797 .547 .561 r
F
.46277 .59063 m .46286 .59065 L .4674 .60858 L .787 .521 0 r
F
.46277 .59063 m .4674 .60858 L .46736 .60847 L F
.47261 .61833 m .47174 .60452 L .47387 .62076 L .797 .547 .561 r
F
.47012 .60302 m .47174 .60452 L .47261 .61833 L F
.47564 .6233 m .46323 .58877 L .4714 .59647 L .957 .664 .437 r
F
.47312 .61968 m .46323 .58877 L .47564 .6233 L F
.46896 .61235 m .46323 .58877 L .47696 .63169 L F
.47696 .63169 m .47312 .61968 L .47564 .6233 L F
.4714 .59647 m .4727 .59777 L .47932 .62451 L F
.48498 .62897 m .47601 .60352 L .47647 .60202 L .859 .611 .562 r
F
.48498 .62897 m .47647 .60202 L .48261 .60897 L F
.475 .60006 m .47647 .60202 L .47362 .59868 L .722 .458 .527 r
F
.475 .60006 m .47362 .59868 L .45858 .58105 L F
.47647 .60202 m .467 .59132 L .45858 .58105 L F
.485 .62963 m .46969 .58559 L .48498 .62897 L .859 .611 .562 r
F
.48544 .64925 m .47932 .62451 L .485 .62963 L F
.47932 .62451 m .46969 .58559 L .485 .62963 L F
.485 .62963 m .49631 .64568 L .48617 .64817 L .803 .643 .683 r
F
.48664 .63111 m .49631 .64568 L .485 .62963 L F
.46486 .57518 m .48096 .58731 L .48074 .58805 L .722 .458 .527 r
F
.46774 .57692 m .48096 .58731 L .46486 .57518 L F
.4433 .55771 m .48074 .58805 L .44958 .5661 L F
.46305 .57323 m .48031 .58182 L .48096 .58731 L F
.48498 .62897 m .47961 .58361 L .48436 .60121 L .859 .611 .562 r
F
.48388 .61193 m .485 .62963 L .48446 .64744 L .803 .643 .683 r
F
.485 .62963 m .48541 .63616 L .4852 .63863 L F
.485 .62963 m .4852 .63863 L .48446 .64744 L F
.48436 .60121 m .47961 .58361 L .48391 .5954 L .859 .611 .562 r
F
.49631 .64568 m .48707 .60225 L .49978 .64483 L .784 .572 .613 r
F
.48707 .60225 m .49234 .61744 L .49978 .64483 L F
.49885 .64375 m .51067 .66074 L .50819 .66359 L .803 .643 .683 r
F
.50576 .6518 m .51067 .66074 L .49885 .64375 L F
.48664 .63111 m .48498 .62897 L .48436 .60121 L .859 .611 .562 r
F
.48391 .5954 m .48707 .60225 L .49631 .64568 L F
.49569 .64475 m .49631 .64568 L .49955 .66092 L F
.48391 .5954 m .49631 .64568 L .49569 .64475 L F
.48486 .62743 m .50819 .66359 L .48493 .62854 L .803 .643 .683 r
F
.49885 .64375 m .50819 .66359 L .48486 .62743 L F
.49955 .66092 m .49978 .64483 L .50936 .65953 L .784 .572 .613 r
F
.49978 .64483 m .49987 .63914 L .50576 .6518 L F
.49978 .64483 m .50576 .6518 L .50936 .65953 L F
.48388 .61193 m .49885 .64375 L .48486 .62743 L .803 .643 .683 r
F
.49753 .64093 m .50576 .6518 L .49885 .64375 L F
.48388 .61193 m .50202 .64498 L .49753 .64093 L F
.50202 .64498 m .50576 .6518 L .49753 .64093 L F
.48917 .66433 m .48507 .6297 L .48664 .63111 L .859 .611 .562 r
F
.48507 .6297 m .48498 .62897 L .48664 .63111 L F
.48238 .6558 m .48274 .64713 L .48545 .65439 L .957 .664 .437 r
F
.48546 .65601 m .4875 .67973 L .48546 .65859 L .803 .643 .683 r
F
.48546 .65859 m .48545 .65439 L .48782 .66071 L .957 .664 .437 r
F
.48238 .6558 m .48545 .65439 L .48546 .65859 L F
.47696 .63169 m .48536 .65165 L .48917 .66433 L F
.48541 .63616 m .48546 .65859 L .48446 .64744 L .803 .643 .683 r
F
.48917 .66433 m .48544 .64925 L .48498 .62897 L .859 .611 .562 r
F
.48493 .62854 m .48664 .63111 L .485 .62963 L .803 .643 .683 r
F
.47453 .62582 m .48388 .61193 L .48446 .64744 L .797 .547 .561 r
F
.47601 .60352 m .46969 .58559 L .4803 .58947 L .859 .611 .562 r
F
.47059 .5957 m .48388 .61193 L .47453 .62582 L .797 .547 .561 r
F
.46896 .61235 m .46851 .61074 L .46865 .61105 L .957 .664 .437 r
F
.46851 .61074 m .46247 .58915 L .46865 .61105 L F
.46865 .61105 m .46247 .58915 L .46323 .58877 L F
.4674 .60858 m .46247 .58915 L .46896 .61235 L F
.46495 .60253 m .48446 .64744 L .46112 .5931 L .797 .547 .561 r
F
.46495 .60253 m .46112 .5931 L .45807 .58602 L F
.47402 .6247 m .48446 .64744 L .45674 .58364 L F
.46005 .59126 m .46413 .59975 L .46243 .59809 L .872 .635 .576 r
F
.46413 .59975 m .4645 .6005 L .46243 .59809 L F
.46243 .59809 m .4645 .6005 L .46614 .60877 L F
.45965 .5901 m .46614 .60877 L .46299 .60472 L F
.46682 .60881 m .47038 .61678 L .46618 .60653 L .797 .547 .561 r
F
.47038 .61678 m .47344 .62343 L .47036 .61609 L F
.47344 .62343 m .47402 .6247 L .47209 .62011 L F
.4805 .65411 m .46896 .61235 L .47696 .63169 L .957 .664 .437 r
F
.47857 .65184 m .46896 .61235 L .4805 .65411 L F
.46736 .60847 m .4674 .60858 L .46855 .61311 L .787 .521 0 r
F
.45965 .5901 m .46026 .5914 L .46005 .59126 L .872 .635 .576 r
F
.46026 .5914 m .4645 .6005 L .46005 .59126 L F
.47989 .67136 m .48211 .68644 L .47529 .70058 L .874 .745 .717 r
F
.48228 .6562 m .48214 .68086 L .47989 .67136 L F
.48214 .68086 m .48211 .68644 L .47989 .67136 L F
.48203 .65719 m .47529 .70058 L .47461 .68703 L F
.48228 .6562 m .48211 .6573 L .48203 .65719 L F
.48211 .6573 m .47529 .70058 L .48203 .65719 L F
.4777 .65062 m .46668 .61028 L .47748 .64831 L .787 .521 0 r
F
.47461 .68703 m .47529 .70058 L .46695 .71784 L .874 .745 .717 r
F
.46695 .71784 m .48211 .68644 L .46199 .73779 L F
.48198 .66537 m .46199 .73779 L .48191 .66703 L F
.48199 .66408 m .46199 .73779 L .48198 .66537 L F
.48228 .6562 m .46199 .73779 L .48204 .66389 L F
.48382 .65802 m .48211 .68644 L .48228 .6562 L F
.48304 .67024 m .48198 .66587 L .48204 .66389 L .957 .664 .437 r
F
.48446 .64744 m .48382 .65802 L .48228 .6562 L .874 .745 .717 r
F
.48238 .6558 m .48228 .6562 L .48204 .66389 L F
.4875 .67973 m .48743 .6792 L .48546 .65859 L .803 .643 .683 r
F
.47361 .74583 m .51016 .66133 L .51063 .66126 L .872 .767 .743 r
F
.47361 .74583 m .51063 .66126 L .50351 .68194 L F
.47361 .74583 m .49052 .705 L .49066 .7064 L F
.49488 .65427 m .50094 .66585 L .48857 .68612 L .803 .643 .683 r
F
.50094 .66585 m .50292 .66964 L .49362 .68032 L F
.50094 .66585 m .49362 .68032 L .48857 .68612 L F
.48857 .68612 m .4888 .68985 L .48785 .68024 L F
.4888 .68985 m .49362 .68032 L .4894 .69415 L .935 .84 .726 r
F
.50721 .66472 m .49955 .66092 L .50936 .65953 L .872 .767 .743 r
F
.4825 .72437 m .49465 .67913 L .50721 .66472 L F
.49465 .67913 m .49955 .66092 L .50721 .66472 L F
.51016 .66133 m .51055 .66088 L .51063 .66126 L F
.49066 .7064 m .50936 .65953 L .51048 .66057 L F
.49052 .705 m .50936 .65953 L .49066 .7064 L F
.51055 .66088 m .51067 .66074 L .51078 .66084 L F
.48021 .72421 m .49955 .66092 L .4825 .72437 L F
.51067 .66074 m .51073 .66087 L .48857 .68612 L .803 .643 .683 r
F
.48843 .68713 m .49955 .66092 L .49362 .68032 L .935 .84 .726 r
F
.48843 .68713 m .49362 .68032 L .4888 .68985 L F
.48046 .72014 m .48362 .72444 L .47717 .72401 L .839 .839 .846 r
F
.47917 .72166 m .476 .72537 L .46471 .74096 L F
.46672 .73829 m .46471 .74096 L .46415 .74173 L F
.47917 .72166 m .46471 .74096 L .46672 .73829 L F
.46672 .73829 m .48733 .67839 L .48843 .68713 L .935 .84 .726 r
F
.46672 .73829 m .48305 .6845 L .48733 .67839 L F
.48743 .6792 m .48706 .67621 L .48546 .65859 L .803 .643 .683 r
F
.48815 .68203 m .48785 .68024 L .4873 .67462 L F
.48815 .68203 m .4873 .67462 L .48743 .67511 L F
.48305 .6845 m .49348 .66291 L .49955 .66092 L .935 .84 .726 r
F
.48765 .68146 m .48731 .679 L .48706 .67621 L .803 .643 .683 r
F
.48765 .68146 m .48706 .67621 L .48743 .6792 L F
.48706 .67621 m .48917 .66433 L .49348 .66291 L .935 .84 .726 r
F
.47984 .69225 m .48211 .68644 L .46471 .74096 L .964 .935 .627 r
F
.48638 .67119 m .46471 .74096 L .46459 .74112 L F
.46471 .74096 m .48211 .68644 L .46672 .73829 L .935 .84 .726 r
F
.48211 .68644 m .48305 .6845 L .46672 .73829 L F
.46672 .73829 m .47653 .71519 L .47543 .72665 L F
.47653 .71519 m .48021 .72421 L .47361 .74583 L F
.48211 .68644 m .49001 .70894 L .46199 .73779 L .874 .745 .717 r
F
.48688 .67428 m .48706 .67621 L .48211 .68644 L F
.48706 .67621 m .49001 .70894 L .48211 .68644 L F
.48211 .68644 m .48917 .66433 L .48305 .6845 L .935 .84 .726 r
F
.48305 .6845 m .48662 .67275 L .48706 .67621 L F
.48662 .67275 m .48917 .66433 L .48706 .67621 L F
.48304 .67024 m .48204 .66389 L .48917 .66433 L .957 .664 .437 r
F
.48204 .66389 m .4805 .65411 L .48236 .6563 L F
.48204 .66389 m .48236 .6563 L .48917 .66433 L F
.48139 .67922 m .48304 .67024 L .48499 .66926 L .964 .935 .627 r
F
.46564 .60813 m .46614 .60877 L .47386 .64774 L .872 .635 .576 r
F
.46902 .7135 m .48074 .6773 L .48139 .67922 L .964 .935 .627 r
F
.46912 .71292 m .48074 .6773 L .46902 .7135 L F
.47883 .67964 m .47048 .70829 L .47716 .68642 L .874 .745 .717 r
F
.47807 .68089 m .47048 .70829 L .47883 .67964 L F
.4796 .67834 m .48043 .67638 L .47773 .68487 L 0 0 0 r
F
.48043 .67638 m .48061 .67693 L .47773 .68487 L F
.48043 .67638 m .48304 .67024 L .48061 .67693 L F
.4768 .68762 m .48242 .67197 L .46812 .71602 L .964 .935 .627 r
F
.48242 .67197 m .48304 .67024 L .48247 .67198 L F
.48242 .67197 m .48247 .67198 L .46812 .71602 L F
.46812 .71602 m .46912 .71292 L .46902 .7135 L F
.48194 .67079 m .48197 .66603 L .48304 .67024 L .787 .521 0 r
F
.45626 .75069 m .45429 .75412 L .37678 .80217 L .799 .946 .92 r
F
.45806 .74953 m .45649 .75143 L .45626 .75069 L F
.45649 .75143 m .45429 .75412 L .45626 .75069 L F
.47917 .72166 m .45736 .7508 L .45926 .74875 L .839 .839 .846 r
F
.45835 .74973 m .45429 .75412 L .45806 .74953 L .799 .946 .92 r
F
.45799 .74948 m .44188 .75992 L .44295 .75812 L F
.45805 .74953 m .3746 .80351 L .45799 .74948 L F
.45805 .74953 m .37678 .80217 L .37671 .80216 L F
.45806 .74953 m .37678 .80217 L .45805 .74953 L F
.45945 .7468 m .4588 .74912 L .45835 .74973 L .964 .935 .627 r
F
.45805 .74953 m .37461 .80351 L .3746 .80351 L .799 .946 .92 r
F
.45805 .74953 m .37461 .80351 L .45805 .74953 L F
.45799 .74949 m .45835 .74973 L .45641 .75241 L .964 .935 .627 r
F
.40997 .77708 m .3746 .80351 L .36272 .80423 L .799 .946 .92 r
F
.44295 .75812 m .39749 .78831 L .40997 .77708 L F
.39749 .78831 m .3746 .80351 L .40997 .77708 L F
.44188 .75992 m .3746 .80351 L .44295 .75812 L F
.45776 .74974 m .36983 .80015 L .3925 .79132 L F
.45776 .74974 m .3925 .79132 L .41713 .77639 L F
.37647 .80104 m .38534 .79566 L .37786 .8014 L 0 0 0 r
F
.38534 .79566 m .40757 .78218 L .38526 .79662 L F
.38534 .79566 m .38526 .79662 L .37786 .8014 L F
.36321 .80395 m .36366 .80394 L .36372 .80392 L .799 .946 .92 r
F
.3746 .80351 m .37429 .80371 L .36272 .80423 L F
.36198 .80466 m .37429 .80371 L .35549 .80839 L F
.36419 .80414 m .37421 .80492 L .36499 .8041 L .342 0 0 r
F
.36321 .80395 m .37421 .80492 L .36419 .80414 L .407 0 0 r
F
.36258 .80382 m .36375 .80393 L .36321 .80395 L F
.3746 .80351 m .37461 .80351 L .37429 .80371 L .799 .946 .92 r
F
.36499 .8041 m .37421 .80492 L .38406 .80294 L .342 0 0 r
F
.36375 .80393 m .37421 .80492 L .36321 .80395 L .407 0 0 r
F
.36429 .80416 m .36544 .80439 L .36198 .80466 L .799 .946 .92 r
F
.36712 .80425 m .36787 .80625 L .37421 .80492 L .407 0 0 r
F
.36375 .80393 m .3647 .80446 L .36712 .80425 L F
.3647 .80446 m .36787 .80625 L .36712 .80425 L F
.36272 .80423 m .36401 .80475 L .3661 .80386 L .799 .946 .92 r
F
.36366 .80394 m .3661 .80386 L .37253 .80112 L F
.36272 .80423 m .3661 .80386 L .36366 .80394 L F
.36983 .80015 m .37081 .80015 L .37202 .79929 L F
.38137 .80039 m .44168 .76149 L .44232 .76111 L .486 .876 .693 r
F
.44055 .76275 m .44232 .76111 L .45493 .7536 L F
.38137 .80039 m .44232 .76111 L .44055 .76275 L F
.45799 .74948 m .36983 .80015 L .45776 .74974 L .799 .946 .92 r
F
.45945 .7468 m .46459 .74112 L .4588 .74912 L .964 .935 .627 r
F
.49001 .70894 m .48362 .72444 L .48046 .72014 L .839 .839 .846 r
F
.49001 .70894 m .47917 .72166 L .45926 .74875 L F
.46242 .73733 m .49001 .70894 L .45926 .74875 L .874 .745 .717 r
F
.45739 .74907 m .48638 .67119 L .47974 .6925 L .964 .935 .627 r
F
.45739 .74907 m .47974 .6925 L .4577 .74873 L F
.46812 .71602 m .48549 .66788 L .48638 .67119 L F
.45561 .74782 m .48638 .67119 L .45739 .74907 L F
.38137 .80039 m .45493 .7536 L .45445 .75399 L .486 .876 .693 r
F
.45801 .74945 m .45835 .74973 L .45799 .74949 L .964 .935 .627 r
F
.45877 .74862 m .45835 .74973 L .45801 .74945 L F
.45586 .75183 m .41713 .77639 L .4532 .75424 L .799 .946 .92 r
F
.45776 .74974 m .41713 .77639 L .45586 .75183 L F
.41713 .77639 m .44084 .76202 L .4532 .75424 L F
.42541 .77065 m .45005 .75597 L .43013 .76851 L 0 0 0 r
F
.45005 .75597 m .45039 .75584 L .37786 .8014 L F
.44168 .76149 m .4532 .75424 L .45406 .75375 L .486 .876 .693 r
F
.45495 .75331 m .45406 .75375 L .45641 .75241 L F
.44168 .76149 m .45406 .75375 L .45495 .75331 L F
.40757 .78218 m .43013 .76851 L .37786 .8014 L 0 0 0 r
F
.44168 .76149 m .45641 .75241 L .45493 .7536 L .486 .876 .693 r
F
.45556 .74685 m .45369 .7538 L .4532 .75424 L .936 .882 .757 r
F
.44168 .76149 m .45055 .75577 L .4532 .75424 L .486 .876 .693 r
F
.37786 .8014 m .43267 .76697 L .37914 .80174 L 0 0 0 r
F
.43267 .76697 m .44012 .76245 L .37914 .80174 L F
.45039 .75584 m .45051 .75579 L .37914 .80174 L F
.38137 .80039 m .45704 .75235 L .44211 .76198 L .486 .876 .693 r
F
.45556 .74685 m .45242 .75469 L .44774 .75689 L .936 .882 .757 r
F
.38127 .80037 m .45051 .75579 L .38137 .80039 L .486 .876 .693 r
F
.45051 .75579 m .45055 .75577 L .38137 .80039 L F
.4532 .75424 m .44084 .76202 L .45226 .75509 L .799 .946 .92 r
F
.45242 .75469 m .45226 .75509 L .45051 .75579 L .936 .882 .757 r
F
.45242 .75469 m .45051 .75579 L .44774 .75689 L F
.45051 .75579 m .45241 .75457 L .45055 .75577 L .486 .876 .693 r
F
.45226 .75509 m .3971 .78953 L .4272 .77781 L .799 .946 .92 r
F
.44084 .76202 m .3971 .78953 L .45226 .75509 L F
.43267 .76697 m .45039 .75584 L .44012 .76245 L 0 0 0 r
F
.4532 .75424 m .45241 .75457 L .45431 .75354 L .486 .876 .693 r
F
.45055 .75577 m .45241 .75457 L .4532 .75424 L F
.45242 .75469 m .4532 .75424 L .45226 .75509 L .936 .882 .757 r
F
.45556 .74685 m .4532 .75424 L .45242 .75469 L F
.4107 .7806 m .3971 .78953 L .41617 .77753 L .799 .946 .92 r
F
.4107 .7806 m .41617 .77753 L .44084 .76202 L F
.41713 .77639 m .4107 .7806 L .44084 .76202 L F
.42541 .77065 m .43013 .76851 L .40757 .78218 L 0 0 0 r
F
.38548 .79405 m .38534 .79566 L .4272 .77781 L .799 .946 .92 r
F
.36795 .80123 m .36349 .80379 L .37253 .80112 L F
.36349 .80379 m .36372 .80392 L .37253 .80112 L F
.36983 .80015 m .36795 .80123 L .37477 .80017 L F
.36795 .80123 m .37253 .80112 L .37477 .80017 L F
.38534 .79566 m .3647 .80446 L .36497 .80427 L .571 .935 .92 r
F
.38534 .79566 m .36497 .80427 L .38544 .79444 L F
.37502 .80065 m .42387 .77156 L .40757 .78218 L 0 0 0 r
F
.42387 .77156 m .42541 .77065 L .42432 .77135 L F
.42387 .77156 m .42432 .77135 L .40757 .78218 L F
.42387 .77156 m .43376 .76765 L .45002 .756 L F
.41713 .77639 m .3925 .79132 L .3971 .78953 L .799 .946 .92 r
F
.38544 .79444 m .41737 .77674 L .42387 .77156 L 0 0 0 r
F
.42224 .77286 m .43376 .76765 L .42387 .77156 L F
.41737 .77674 m .43054 .76944 L .42224 .77286 L F
.43054 .76944 m .43376 .76765 L .42224 .77286 L F
.42387 .77156 m .45002 .756 L .45003 .75599 L F
.43632 .76144 m .43848 .76058 L .43536 .76535 L .936 .882 .757 r
F
.37502 .80065 m .40757 .78218 L .37647 .80104 L 0 0 0 r
F
.38974 .79238 m .43376 .76765 L .38544 .79444 L F
.39258 .79102 m .43345 .76787 L .38989 .79231 L F
.39163 .79198 m .38534 .79566 L .38544 .79444 L .571 .935 .92 r
F
.4272 .77781 m .38544 .79444 L .40986 .78272 L F
.43345 .76787 m .43376 .76765 L .37502 .80065 L 0 0 0 r
F
.3963 .78724 m .40324 .78355 L .39258 .79102 L .308 0 .029 r
F
.40324 .78355 m .41389 .77868 L .39258 .79102 L F
.43061 .76901 m .43253 .76824 L .39258 .79102 L F
.43253 .76824 m .43345 .76787 L .43108 .76921 L F
.43253 .76824 m .43108 .76921 L .39258 .79102 L F
.43323 .76699 m .43392 .76754 L .43226 .76873 L .936 .882 .757 r
F
.43323 .76699 m .43253 .76824 L .43357 .76701 L F
.43253 .76824 m .43226 .76873 L .43273 .7681 L F
.43253 .76824 m .43273 .7681 L .43357 .76701 L F
.40324 .78355 m .43061 .76901 L .41389 .77868 L .308 0 .029 r
F
.40324 .78355 m .42268 .77513 L .43061 .76901 L F
.3963 .78724 m .40272 .7843 L .40324 .78355 L F
.40272 .7843 m .42268 .77513 L .40324 .78355 L F
.43226 .76873 m .43345 .76787 L .4272 .77781 L .936 .882 .757 r
F
.43345 .76787 m .43379 .76774 L .4272 .77781 L F
.45487 .73554 m .44169 .76467 L .4272 .77781 L F
.42925 .77413 m .4272 .77781 L .4301 .77379 L F
.42925 .77413 m .4301 .77379 L .4344 .76785 L F
.43226 .76873 m .42925 .77413 L .4344 .76785 L F
.4272 .77781 m .38994 .7937 L .39163 .79198 L .571 .935 .92 r
F
.4272 .77781 m .42145 .77944 L .41175 .78924 L F
.4272 .77781 m .41175 .78924 L .41461 .78831 L F
.42145 .77944 m .4091 .78451 L .40356 .79753 L F
.38544 .79444 m .36497 .80427 L .37991 .79373 L F
.36272 .80423 m .36429 .80416 L .36198 .80466 L .799 .946 .92 r
F
.36272 .80423 m .35549 .80839 L .36401 .80475 L F
.3647 .80446 m .35549 .80839 L .36133 .80476 L .571 .935 .92 r
F
.36349 .80379 m .36321 .80395 L .36372 .80392 L .799 .946 .92 r
F
.36321 .80395 m .36272 .80423 L .36366 .80394 L F
.27935 .796 m .35774 .80507 L .36375 .80393 L .407 0 0 r
F
.35276 .80551 m .35549 .80839 L .34043 .80843 L .571 .935 .92 r
F
.33968 .8071 m .34043 .80843 L .32842 .80846 L F
.35276 .80551 m .34043 .80843 L .33968 .8071 L F
.36133 .80476 m .35606 .80804 L .35276 .80551 L F
.27935 .796 m .36439 .80698 L .36787 .80625 L .407 0 0 r
F
.27158 .79527 m .28 .79633 L .27935 .796 L F
.28 .79633 m .36439 .80698 L .27935 .796 L F
.22745 .75197 m .27158 .79527 L .23111 .75412 L .742 .238 0 r
F
.20364 .72861 m .21009 .73493 L .21527 .73941 L F
.21009 .73493 m .22745 .75197 L .21527 .73941 L F
.21099 .73487 m .31163 .7942 L .2125 .73353 L .861 .43 .188 r
F
.21099 .73487 m .30524 .79687 L .31163 .7942 L F
.19057 .63127 m .21099 .73487 L .2125 .73353 L .933 .726 .246 r
F
.19057 .63127 m .20292 .72478 L .20364 .72861 L .734 .525 0 r
F
.26481 .78832 m .27158 .79527 L .26413 .78796 L .677 .176 0 r
F
.20292 .72478 m .24429 .76726 L .20364 .72861 L F
.24429 .76726 m .26481 .78832 L .24142 .76549 L F
.24429 .76726 m .24142 .76549 L .20364 .72861 L F
.26481 .78832 m .26413 .78796 L .20364 .72861 L F
.21966 .74197 m .26608 .79204 L .27158 .79527 L F
.27045 .79461 m .35227 .80514 L .27158 .79527 L .469 0 0 r
F
.29686 .79672 m .35227 .80514 L .27045 .79461 L F
.35276 .80551 m .32842 .80846 L .33158 .80738 L .571 .935 .92 r
F
.31894 .80849 m .32721 .80847 L .31712 .809 L F
.32721 .80847 m .35549 .80839 L .32724 .80884 L F
.32721 .80847 m .32724 .80884 L .31712 .809 L F
.26608 .79204 m .29686 .79672 L .27045 .79461 L .469 0 0 r
F
.2742 .79328 m .28235 .79516 L .28079 .79428 L F
.26608 .79204 m .27514 .79378 L .2742 .79328 L F
.27514 .79378 m .28235 .79516 L .2742 .79328 L F
.21558 .73827 m .26608 .79204 L .21966 .74197 L .677 .176 0 r
F
.20292 .72478 m .21558 .73827 L .21966 .74197 L F
.2125 .73353 m .31734 .7904 L .21382 .73134 L .869 .456 .238 r
F
.2125 .73353 m .31163 .7942 L .31734 .7904 L F
.19057 .63127 m .2125 .73353 L .21382 .73134 L .933 .727 .246 r
F
.24362 .76657 m .25809 .78298 L .24857 .77294 L .585 .101 0 r
F
.25809 .78298 m .26608 .79204 L .25698 .78235 L F
.25809 .78298 m .25698 .78235 L .20292 .72478 L F
.24362 .76657 m .26156 .78774 L .26608 .79204 L F
.20267 .72012 m .24362 .76657 L .20292 .72478 L F
.24362 .76657 m .24857 .77294 L .20292 .72478 L F
.21785 .73733 m .26156 .78774 L .24362 .76657 L F
.21382 .73134 m .32209 .7854 L .21489 .72829 L .875 .48 .282 r
F
.21382 .73134 m .31734 .7904 L .32209 .7854 L F
.19057 .63127 m .21382 .73134 L .21489 .72829 L .928 .72 .235 r
F
.21208 .72596 m .25834 .78223 L .26156 .78774 L 0 0 .528 r
F
.20301 .71463 m .20839 .72121 L .21208 .72596 L F
.20839 .72121 m .25834 .78223 L .21208 .72596 L F
.28079 .79428 m .28822 .79628 L .28676 .79519 L .469 0 0 r
F
.28235 .79516 m .28822 .79628 L .28079 .79428 L F
.35606 .80804 m .35549 .80839 L .35276 .80551 L .571 .935 .92 r
F
.32429 .80697 m .34861 .80552 L .31894 .80849 L F
.35227 .80514 m .35276 .80551 L .27158 .79527 L .469 0 0 r
F
.35774 .80507 m .3647 .80446 L .36375 .80393 L .407 0 0 r
F
.34861 .80552 m .36133 .80476 L .35134 .80564 L .571 .935 .92 r
F
.34861 .80552 m .35134 .80564 L .31894 .80849 L F
.28676 .79519 m .33977 .80596 L .35227 .80514 L .469 0 0 r
F
.38587 .78952 m .36172 .80452 L .35647 .80486 L .571 .935 .92 r
F
.35647 .80486 m .36133 .80476 L .32429 .80697 L F
.36172 .80452 m .36137 .80474 L .35647 .80486 L F
.36137 .80474 m .36133 .80476 L .35647 .80486 L F
.30523 .79953 m .35518 .80909 L .2975 .79737 L .469 0 0 r
F
.30523 .79953 m .2975 .79737 L .28676 .79519 L F
.28822 .79628 m .30523 .79953 L .28676 .79519 L F
.33867 .80532 m .33906 .806 L .3035 .7992 L .517 0 0 r
F
.30836 .79978 m .3035 .7992 L .26608 .79204 L F
.33867 .80532 m .3035 .7992 L .30836 .79978 L F
.26156 .78774 m .32086 .80126 L .26608 .79204 L F
.27114 .79036 m .29529 .79696 L .26985 .78963 L F
.32086 .80126 m .30836 .79978 L .26608 .79204 L F
.29529 .79696 m .32698 .80562 L .26985 .78963 L F
.32925 .80557 m .35647 .80486 L .32429 .80697 L .571 .935 .92 r
F
.32086 .80126 m .33867 .80532 L .30836 .79978 L .517 0 0 r
F
.26985 .78963 m .3273 .80562 L .33867 .80532 L F
.38587 .78952 m .35647 .80486 L .32925 .80557 L .571 .935 .92 r
F
.33748 .80323 m .32925 .80557 L .3456 .80419 L F
.32925 .80557 m .32703 .8062 L .33128 .80661 L F
.33977 .80596 m .35518 .80909 L .35227 .80514 L .469 0 0 r
F
.33867 .80532 m .33984 .80615 L .33906 .806 L .517 0 0 r
F
.33867 .80532 m .34033 .8065 L .3431 .80633 L F
.32703 .8062 m .33045 .80675 L .33128 .80661 L .571 .935 .92 r
F
.32925 .80557 m .34666 .81101 L .33867 .80532 L .517 0 0 r
F
.33158 .80738 m .32842 .80846 L .31894 .80849 L .571 .935 .92 r
F
.33128 .80661 m .31712 .809 L .33207 .80702 L F
.3273 .80562 m .33177 .80686 L .32925 .80557 L .517 0 0 r
F
.33177 .80686 m .34666 .81101 L .32925 .80557 L F
.33413 .80613 m .33128 .80661 L .33494 .80664 L .571 .935 .92 r
F
.33207 .80702 m .34666 .81101 L .33177 .80686 L .517 0 0 r
F
.33128 .80661 m .33207 .80702 L .33494 .80664 L .571 .935 .92 r
F
.32925 .80557 m .33128 .80661 L .3456 .80419 L F
.32698 .80562 m .3273 .80562 L .26985 .78963 L .517 0 0 r
F
.3269 .80457 m .33343 .80669 L .32698 .80562 L .539 0 0 r
F
.35995 .80177 m .3456 .80419 L .3554 .80392 L .571 .935 .92 r
F
.3456 .80419 m .33413 .80613 L .34895 .80459 L F
.3456 .80419 m .34895 .80459 L .3554 .80392 L F
.33748 .80323 m .3456 .80419 L .35995 .80177 L F
.33413 .80613 m .33494 .80664 L .3554 .80392 L F
.3647 .80446 m .36133 .80476 L .38587 .78952 L F
.35885 .80188 m .33494 .80664 L .34986 .80275 L .181 .715 .778 r
F
.36535 .80274 m .37395 .79893 L .36661 .8029 L .502 .096 .203 r
F
.36541 .80273 m .36858 .80172 L .37007 .80067 L F
.35227 .80514 m .36439 .80698 L .35276 .80551 L .469 0 0 r
F
.35227 .80514 m .35518 .80909 L .36439 .80698 L F
.35774 .80507 m .36787 .80625 L .3647 .80446 L .407 0 0 r
F
.38874 .79286 m .38544 .79444 L .38547 .7942 L .571 .935 .92 r
F
.38874 .79286 m .38547 .7942 L .38587 .78952 L F
.3963 .78724 m .42561 .77558 L .4296 .77195 L .308 0 .029 r
F
.43345 .76787 m .43392 .76754 L .43379 .76774 L .936 .882 .757 r
F
.44645 .75855 m .45226 .75509 L .44169 .76467 L F
.4435 .76067 m .44645 .75855 L .44169 .76467 L F
.43345 .76787 m .44418 .7618 L .43376 .76765 L 0 0 0 r
F
.43323 .76699 m .43536 .76535 L .43392 .76754 L .936 .882 .757 r
F
.45005 .75597 m .45226 .75509 L .44645 .75855 L F
.43376 .76765 m .44418 .7618 L .45005 .75597 L 0 0 0 r
F
.43253 .76824 m .44418 .7618 L .43345 .76787 L .308 0 .029 r
F
.43431 .76704 m .44418 .7618 L .43253 .76824 L F
.44271 .76258 m .43973 .7673 L .44418 .7618 L F
.43431 .76704 m .43936 .76728 L .44271 .76258 L F
.43936 .76728 m .43973 .7673 L .44271 .76258 L F
.43226 .76873 m .4344 .76785 L .43562 .76617 L .936 .882 .757 r
F
.43496 .76707 m .42816 .77649 L .42411 .77707 L .846 .987 .712 r
F
.42145 .77944 m .40986 .78272 L .4091 .78451 L .571 .935 .92 r
F
.43496 .76707 m .41132 .78885 L .41096 .78891 L .846 .987 .712 r
F
.43528 .77182 m .43655 .77123 L .3963 .78724 L .308 0 .029 r
F
.40986 .78272 m .38874 .79286 L .38705 .7909 L .571 .935 .92 r
F
.40232 .78486 m .38705 .7909 L .38587 .78952 L F
.40986 .78272 m .38705 .7909 L .40232 .78486 L F
.38544 .79444 m .37991 .79373 L .3857 .79143 L F
.35518 .80909 m .3963 .78724 L .36439 .80698 L .308 0 .029 r
F
.37569 .80058 m .39258 .79102 L .37502 .80065 L 0 0 0 r
F
.39258 .79102 m .38989 .79231 L .37502 .80065 L F
.37502 .80065 m .38974 .79238 L .38544 .79444 L F
.36439 .80698 m .37502 .80065 L .37421 .80492 L F
.37671 .80216 m .37678 .80217 L .37461 .80351 L .799 .946 .92 r
F
.37502 .80065 m .37914 .80174 L .37421 .80492 L 0 0 0 r
F
.36439 .80698 m .37569 .80058 L .37502 .80065 L F
.3963 .78724 m .39258 .79102 L .36439 .80698 L .308 0 .029 r
F
.38994 .7937 m .38534 .79566 L .39163 .79198 L .571 .935 .92 r
F
.40986 .78272 m .40232 .78486 L .39606 .79372 L F
.35518 .80909 m .3999 .78828 L .3963 .78724 L .308 0 .029 r
F
.40986 .78272 m .39606 .79372 L .40356 .79753 L .571 .935 .92 r
F
.40079 .78701 m .43528 .77182 L .40232 .78486 L .308 0 .029 r
F
.40441 .78618 m .43528 .77182 L .40079 .78701 L F
.3999 .78828 m .40441 .78618 L .40079 .78701 L F
.3999 .78828 m .40232 .78486 L .3963 .78724 L F
.3967 .78959 m .3999 .78828 L .39667 .78978 L .502 .096 .203 r
F
.3967 .78959 m .39667 .78978 L .35518 .80909 L F
.37395 .79893 m .3967 .78959 L .35518 .80909 L F
.39606 .79372 m .3967 .78959 L .39572 .79398 L .571 .935 .92 r
F
.3967 .78959 m .39722 .78631 L .39657 .78965 L F
.3967 .78959 m .39657 .78965 L .39572 .79398 L F
.40232 .78486 m .39722 .78631 L .39606 .79372 L F
.39722 .78631 m .38804 .7905 L .39572 .79398 L F
.3857 .79143 m .37991 .79373 L .38587 .78952 L F
.38587 .78952 m .37321 .7955 L .40356 .79753 L F
.37421 .80492 m .38127 .80037 L .38137 .80039 L .486 .876 .693 r
F
.38406 .80294 m .38466 .80297 L .38414 .80295 L .342 0 0 r
F
.38406 .80294 m .37421 .80492 L .38466 .80297 L F
.38421 .80294 m .38532 .80286 L .39578 .80107 L .292 0 0 r
F
.37421 .80492 m .38137 .80039 L .38466 .80297 L .486 .876 .693 r
F
.38137 .80039 m .38792 .80071 L .38466 .80297 L F
.37321 .7955 m .37449 .80139 L .40356 .79753 L .571 .935 .92 r
F
.38971 .79246 m .42299 .77723 L .3999 .78828 L .502 .096 .203 r
F
.37395 .79893 m .40109 .78692 L .38971 .79246 L F
.40109 .78692 m .42299 .77723 L .38971 .79246 L F
.43632 .76144 m .43536 .76535 L .43323 .76699 L .936 .882 .757 r
F
.43273 .7681 m .43562 .76617 L .44949 .74698 L F
.44402 .75953 m .44705 .75778 L .44645 .75855 L F
.44402 .75953 m .44645 .75855 L .4435 .76067 L F
.45487 .73554 m .44705 .75778 L .44402 .75953 L F
.44072 .76524 m .44949 .74698 L .44418 .7618 L .283 .063 .393 r
F
.45487 .73554 m .45556 .74685 L .44705 .75778 L .936 .882 .757 r
F
.45556 .74685 m .48638 .67119 L .45561 .74782 L .964 .935 .627 r
F
.46199 .73779 m .45926 .74875 L .47807 .68089 L .874 .745 .717 r
F
.46199 .73779 m .47807 .68089 L .47794 .68111 L F
.45652 .74326 m .48304 .67024 L .45566 .74646 L .964 .935 .627 r
F
.4641 .71157 m .4623 .71912 L .45446 .72887 L .936 .882 .757 r
F
.45556 .74685 m .4768 .68762 L .46812 .71602 L .964 .935 .627 r
F
.45526 .74758 m .45566 .74646 L .45556 .74685 L F
.45566 .74646 m .4768 .68762 L .45556 .74685 L F
.4623 .71912 m .45652 .74326 L .45487 .73554 L .936 .882 .757 r
F
.45652 .74326 m .45558 .74719 L .45556 .74685 L F
.45652 .74326 m .45556 .74685 L .45487 .73554 L F
.4623 .71912 m .45487 .73554 L .45446 .72887 L F
.44588 .7578 m .4623 .71912 L .45241 .75457 L 0 0 0 r
F
.48191 .66707 m .47716 .68642 L .48173 .67128 L .874 .745 .717 r
F
.4623 .71912 m .4796 .67834 L .45667 .74263 L 0 0 0 r
F
.4623 .71912 m .45667 .74263 L .45241 .75457 L F
.4796 .67834 m .47773 .68487 L .4778 .68431 L F
.48173 .67128 m .4796 .67834 L .48172 .67151 L .874 .745 .717 r
F
.4796 .67834 m .47716 .68642 L .47967 .67824 L F
.4796 .67834 m .47967 .67824 L .48172 .67151 L F
.4796 .67834 m .47716 .68642 L .45241 .75457 L 0 0 0 r
F
.4796 .67834 m .48136 .67541 L .48304 .67024 L F
.48074 .6773 m .48304 .67024 L .48139 .67922 L .964 .935 .627 r
F
.48136 .67541 m .45926 .74875 L .48064 .68189 L .874 .745 .717 r
F
.48183 .67116 m .47987 .6779 L .48136 .67541 L F
.47987 .6779 m .45926 .74875 L .48136 .67541 L F
.4778 .68431 m .47773 .68487 L .47716 .68642 L 0 0 0 r
F
.47048 .70829 m .45926 .74875 L .48183 .67116 L .874 .745 .717 r
F
.46967 .70281 m .47972 .67955 L .46943 .70334 L 0 0 0 r
F
.47972 .67955 m .48057 .6776 L .47972 .67956 L F
.48057 .6776 m .48057 .67758 L .47972 .67956 L F
.4623 .71912 m .48067 .6773 L .4796 .67834 L F
.48047 .67787 m .48136 .67541 L .48087 .67981 L .872 .635 .576 r
F
.48067 .6773 m .48192 .67448 L .48136 .67541 L 0 0 0 r
F
.48067 .6773 m .48136 .67541 L .4796 .67834 L F
.47794 .68111 m .47807 .68089 L .48195 .66693 L .874 .745 .717 r
F
.48195 .6669 m .48195 .66693 L .48253 .66483 L F
.47794 .68111 m .48195 .66693 L .48195 .6669 L F
.4805 .65411 m .48782 .66071 L .48917 .66433 L .957 .664 .437 r
F
.48238 .6558 m .48204 .66389 L .48253 .66483 L .874 .745 .717 r
F
.48204 .66389 m .48191 .66703 L .48195 .6669 L F
.48204 .66389 m .48195 .6669 L .48253 .66483 L F
.48198 .66587 m .47748 .64831 L .47721 .64627 L .957 .664 .437 r
F
.48304 .67024 m .48197 .66603 L .48198 .66587 L F
.48197 .66603 m .47748 .64831 L .48198 .66587 L F
.48191 .66707 m .47807 .68089 L .47883 .67964 L .874 .745 .717 r
F
.48253 .66483 m .48191 .66707 L .48183 .67116 L F
.48191 .66707 m .48172 .67151 L .48183 .67116 L F
.47117 .63281 m .48195 .67008 L .48136 .67541 L .872 .635 .576 r
F
.46943 .70334 m .48057 .67758 L .4623 .71912 L 0 0 0 r
F
.48057 .67758 m .48192 .67448 L .48067 .6773 L F
.48057 .67758 m .48067 .6773 L .4623 .71912 L F
.48006 .679 m .48087 .67981 L .48064 .68189 L .872 .635 .576 r
F
.48047 .67787 m .48087 .67981 L .48006 .679 L F
.48001 .67915 m .48005 .67902 L .48064 .68189 L F
.48005 .67902 m .48006 .679 L .48064 .68189 L F
.48001 .67915 m .48064 .68189 L .4802 .67887 L F
.48152 .67539 m .48051 .67976 L .48192 .67448 L 0 0 0 r
F
.47972 .67955 m .47972 .67956 L .46943 .70334 L F
.48064 .68189 m .45558 .74719 L .4623 .71912 L .936 .882 .757 r
F
.48064 .68189 m .4623 .71912 L .47265 .69622 L F
.45314 .74106 m .46704 .70995 L .47265 .69622 L 0 0 0 r
F
.46967 .70281 m .47265 .69622 L .47503 .69041 L F
.45314 .74106 m .47265 .69622 L .46967 .70281 L F
.47265 .69622 m .4623 .71912 L .4641 .71157 L .936 .882 .757 r
F
.45556 .74685 m .45586 .75183 L .45369 .7538 L F
.45241 .75457 m .45739 .74907 L .45693 .75065 L .964 .935 .627 r
F
.45241 .75457 m .45693 .75065 L .45431 .75354 L F
.45241 .75457 m .45526 .74758 L .45739 .74907 L F
.48064 .68189 m .45586 .75183 L .45558 .74719 L .936 .882 .757 r
F
.45739 .74907 m .45799 .74949 L .45641 .75241 L .964 .935 .627 r
F
.45926 .74875 m .45835 .74973 L .45806 .74953 L .799 .946 .92 r
F
.45926 .74875 m .45776 .74974 L .45586 .75183 L F
.45926 .74875 m .45805 .74953 L .45805 .74953 L F
.45926 .74875 m .45806 .74953 L .45805 .74953 L F
.45926 .74875 m .45805 .74953 L .45799 .74948 L F
.45926 .74875 m .45799 .74948 L .45776 .74974 L F
.45945 .7468 m .45877 .74862 L .45801 .74945 L .964 .935 .627 r
F
.45739 .74907 m .45945 .7468 L .45799 .74949 L F
.48064 .68189 m .45926 .74875 L .45586 .75183 L .936 .882 .757 r
F
.48064 .68189 m .47265 .69622 L .47412 .7129 L F
.47516 .69424 m .48064 .68189 L .47392 .69939 L .958 .74 .565 r
F
.44593 .75775 m .46967 .70281 L .44588 .7578 L 0 0 0 r
F
.46967 .70281 m .46943 .70334 L .44588 .7578 L F
.44588 .7578 m .46943 .70334 L .4623 .71912 L F
.45003 .75599 m .45002 .756 L .45005 .75597 L F
.44774 .75689 m .45005 .75597 L .44645 .75855 L .936 .882 .757 r
F
.45039 .75584 m .45241 .75457 L .45051 .75579 L 0 0 0 r
F
.45005 .75597 m .45241 .75457 L .45039 .75584 L F
.45005 .75597 m .44418 .7618 L .45241 .75457 L F
.44418 .7618 m .44588 .7578 L .45241 .75457 L F
.44418 .7618 m .45401 .73962 L .45314 .74106 L F
.4802 .67887 m .48064 .68189 L .48033 .68259 L .958 .74 .565 r
F
.47785 .68606 m .48033 .68259 L .47516 .69424 L F
.4802 .67887 m .48033 .68259 L .47785 .68606 L F
.4802 .67887 m .47516 .69424 L .4759 .69116 L F
.47265 .69622 m .45877 .73015 L .47412 .7129 L .936 .882 .757 r
F
.45401 .73962 m .46613 .71224 L .45314 .74106 L 0 0 0 r
F
.46613 .71224 m .48051 .67976 L .46525 .71394 L F
.46613 .71224 m .46525 .71394 L .45314 .74106 L F
.43273 .7681 m .44949 .74698 L .45056 .74475 L .936 .882 .757 r
F
.43226 .76873 m .43562 .76617 L .43273 .7681 L F
.44949 .74698 m .4657 .71321 L .45045 .74765 L .283 .063 .393 r
F
.45446 .72887 m .45487 .73554 L .43848 .76058 L .936 .882 .757 r
F
.45446 .72887 m .43848 .76058 L .43632 .76144 L F
.44535 .74522 m .43323 .76699 L .45078 .74429 L F
.45412 .73733 m .45078 .74429 L .46083 .73129 L F
.44535 .74522 m .45078 .74429 L .45412 .73733 L F
.43323 .76699 m .43357 .76701 L .46083 .73129 L F
.44901 .74664 m .43496 .76707 L .44419 .75243 L .846 .987 .712 r
F
.44853 .7463 m .44419 .75243 L .4482 .74607 L F
.44901 .74664 m .44419 .75243 L .44853 .7463 L F
.47265 .69622 m .44535 .74522 L .45877 .73015 L .936 .882 .757 r
F
.44535 .74522 m .46083 .73129 L .47412 .7129 L F
.4489 .74656 m .46468 .71297 L .4657 .71321 L .283 .063 .393 r
F
.44853 .7463 m .46991 .70183 L .4489 .74656 L F
.45056 .74475 m .44949 .74698 L .46083 .73129 L .936 .882 .757 r
F
.45594 .73806 m .44949 .74698 L .45813 .73337 L .846 .987 .712 r
F
.44949 .74698 m .43496 .76707 L .44901 .74664 L F
.43061 .76901 m .43431 .76704 L .43253 .76824 L .308 0 .029 r
F
.43061 .76901 m .43973 .7673 L .43431 .76704 L F
.42268 .77513 m .43973 .7673 L .43061 .76901 L F
.43825 .7677 m .4489 .74656 L .44072 .76524 L .283 .063 .393 r
F
.4489 .74656 m .4657 .71321 L .44949 .74698 L F
.4489 .74656 m .44949 .74698 L .44072 .76524 L F
.42582 .77461 m .42395 .77709 L .42299 .77723 L .846 .987 .712 r
F
.4482 .74607 m .42395 .77709 L .44761 .74566 L F
.4482 .74607 m .43496 .76707 L .42395 .77709 L F
.43555 .77167 m .43655 .77123 L .43573 .77161 L .502 .096 .203 r
F
.42299 .77723 m .43345 .77267 L .42395 .77709 L F
.42299 .77723 m .43646 .77136 L .43555 .77167 L F
.42299 .77723 m .42395 .77709 L .3999 .78828 L F
.40109 .78692 m .42283 .77738 L .42299 .77723 L F
.4012 .78692 m .42283 .77738 L .40109 .78692 L F
.42283 .77738 m .43646 .77136 L .42299 .77723 L F
.44761 .74566 m .42582 .77461 L .42193 .77738 L .846 .987 .712 r
F
.42582 .77461 m .42299 .77723 L .42193 .77738 L F
.37396 .79895 m .41138 .78797 L .42283 .77738 L .502 .096 .203 r
F
.42193 .77738 m .42395 .77709 L .41718 .78325 L .846 .987 .712 r
F
.3431 .80633 m .34666 .81101 L .35518 .80909 L .517 0 0 r
F
.34666 .81101 m .36535 .80274 L .35518 .80909 L .502 .096 .203 r
F
.36535 .80274 m .36661 .8029 L .35518 .80909 L F
.34666 .81101 m .4012 .78692 L .40109 .78692 L F
.36858 .80172 m .3936 .79378 L .37007 .80067 L F
.3936 .79378 m .39354 .79356 L .37007 .80067 L F
.4111 .78823 m .41138 .78797 L .37007 .80067 L F
.37007 .80067 m .37407 .79944 L .37396 .79895 L F
.41202 .78738 m .41718 .78325 L .41006 .78973 L .846 .987 .712 r
F
.42411 .77707 m .4272 .77781 L .41132 .78885 L F
.41096 .78891 m .41132 .78885 L .41006 .78973 L F
.41461 .78831 m .41175 .78924 L .40356 .79753 L .571 .935 .92 r
F
.41006 .78973 m .4272 .77781 L .40356 .79753 L .846 .987 .712 r
F
.41202 .78738 m .41071 .78895 L .41468 .7875 L F
.41071 .78895 m .40356 .79753 L .41468 .7875 L F
.39606 .79372 m .39572 .79398 L .39583 .79403 L .571 .935 .92 r
F
.39606 .79372 m .39583 .79403 L .40356 .79753 L F
.41468 .7875 m .42874 .78264 L .41516 .78695 L .502 .096 .203 r
F
.4111 .78823 m .42874 .78264 L .41138 .78797 L F
.43825 .7677 m .44853 .7463 L .4489 .74656 L .283 .063 .393 r
F
.44853 .7463 m .46098 .72801 L .4617 .72616 L F
.46468 .71297 m .46991 .70183 L .46816 .70656 L F
.46468 .71297 m .46816 .70656 L .4657 .71321 L F
.46704 .70995 m .48051 .67976 L .47503 .69041 L 0 0 0 r
F
.46991 .70183 m .47677 .68756 L .46619 .71208 L .283 .063 .393 r
F
.46991 .70183 m .46619 .71208 L .4657 .71321 L F
.47677 .68756 m .47754 .68649 L .4657 .71321 L F
.46362 .71492 m .4617 .72616 L .47677 .68756 L F
.44853 .7463 m .4617 .72616 L .46362 .71492 L F
.45895 .73161 m .46098 .72801 L .44853 .7463 L F
.46098 .72801 m .47152 .70937 L .47366 .70047 L F
.47187 .70112 m .47366 .70047 L .4759 .69116 L F
.46098 .72801 m .47366 .70047 L .47187 .70112 L F
.47365 .70011 m .48064 .68189 L .47366 .70047 L .958 .74 .565 r
F
.47366 .70047 m .48064 .68189 L .47412 .7129 L F
.47366 .70047 m .47412 .7129 L .47513 .69994 L F
.46098 .72801 m .4759 .69116 L .47677 .68756 L .283 .063 .393 r
F
.47503 .69041 m .47857 .68355 L .481 .6766 L 0 0 0 r
F
.47033 .62992 m .48047 .67787 L .48006 .679 L .872 .635 .576 r
F
.46467 .60138 m .48446 .64744 L .4645 .6005 L .797 .547 .561 r
F
.4645 .6005 m .46785 .61677 L .46766 .61647 L .872 .635 .576 r
F
.46299 .60472 m .46564 .60813 L .48005 .67902 L F
.46299 .60472 m .48005 .67902 L .48001 .67915 L F
.46564 .60813 m .47386 .64774 L .48006 .679 L F
.46564 .60813 m .48006 .679 L .48005 .67902 L F
.47905 .67493 m .48001 .67915 L .47933 .6728 L F
.48001 .67915 m .4802 .67887 L .47933 .6728 L F
.4726 .64672 m .47905 .67493 L .47874 .67014 L F
.47117 .63281 m .48047 .67787 L .47033 .62992 L F
.47117 .63281 m .48136 .67541 L .48047 .67787 L F
.47905 .67493 m .47933 .6728 L .47856 .66747 L F
.47186 .64639 m .4802 .67887 L .47614 .69047 L .958 .74 .565 r
F
.4726 .64672 m .47874 .67014 L .47713 .6625 L .872 .635 .576 r
F
.4726 .64672 m .47856 .66747 L .47239 .64256 L F
.46766 .61647 m .47117 .63281 L .47033 .62992 L F
.46785 .61677 m .47117 .63281 L .46766 .61647 L F
.4784 .65781 m .47524 .64688 L .4777 .65062 L .787 .521 0 r
F
.4819 .66992 m .48187 .66978 L .4819 .6699 L F
.48187 .66978 m .47748 .64831 L .4819 .6699 L F
.4819 .6699 m .47748 .64831 L .48197 .66603 L F
.47983 .66277 m .47748 .64831 L .4819 .66992 L F
.48136 .67541 m .48192 .67448 L .48254 .67213 L 0 0 0 r
F
.48136 .67541 m .48254 .67213 L .48304 .67024 L F
.4818 .6749 m .48197 .66603 L .48192 .67448 L .787 .521 0 r
F
.48204 .66389 m .48199 .66408 L .48198 .66537 L .874 .745 .717 r
F
.48204 .66389 m .47857 .65184 L .4805 .65411 L .957 .664 .437 r
F
.48198 .66587 m .47857 .65184 L .48204 .66389 L F
.47342 .64413 m .46668 .61028 L .4777 .65062 L .787 .521 0 r
F
.47117 .63281 m .4645 .6005 L .46532 .60346 L F
.46668 .61028 m .46532 .60346 L .46855 .61311 L F
.46532 .60346 m .46736 .60847 L .46855 .61311 L F
.46668 .61028 m .46855 .61311 L .47748 .64831 L F
.481 .6766 m .48051 .67976 L .48152 .67539 L 0 0 0 r
F
.47857 .68355 m .48051 .67976 L .481 .6766 L F
.48057 .6776 m .48192 .67448 L .48057 .67758 L F
.48051 .67976 m .47748 .64831 L .4818 .6749 L .787 .521 0 r
F
.4805 .65411 m .48274 .64713 L .48238 .6558 L .957 .664 .437 r
F
.48446 .64744 m .48238 .6558 L .48253 .66483 L .874 .745 .717 r
F
.47721 .64627 m .4674 .60858 L .46896 .61235 L .957 .664 .437 r
F
.47748 .64831 m .4674 .60858 L .47721 .64627 L F
.4645 .6005 m .48446 .64744 L .48195 .67008 L .872 .635 .576 r
F
.4645 .6005 m .48195 .67008 L .47117 .63281 L F
.46016 .59031 m .4645 .6005 L .45965 .5901 L F
.45974 .59021 m .4726 .64672 L .47207 .63838 L F
.45965 .5901 m .4726 .64672 L .45974 .59021 L F
.46 .59054 m .45308 .58189 L .45637 .58443 L .679 .139 0 r
F
.46125 .5921 m .47207 .63838 L .46316 .59588 L .872 .635 .576 r
F
.45974 .59021 m .47207 .63838 L .46125 .5921 L F
.4569 .58982 m .45827 .59054 L .46316 .59588 L .83 .438 .308 r
F
.45827 .59054 m .46125 .5921 L .46202 .59363 L F
.45827 .59054 m .46202 .59363 L .46316 .59588 L F
.45354 .58665 m .41123 .54858 L .45664 .58885 L .679 .139 0 r
F
.45404 .58707 m .46316 .59588 L .4507 .58432 L .83 .438 .308 r
F
.45235 .58581 m .4507 .58432 L .45354 .58665 L .679 .139 0 r
F
.4507 .58432 m .41123 .54858 L .45354 .58665 L F
.40493 .54309 m .40885 .54666 L .40528 .54319 L .749 .348 .291 r
F
.40885 .54666 m .42878 .56487 L .40878 .54642 L F
.40883 .54662 m .40587 .5431 L .40525 .54317 L 0 .222 .744 r
F
.40885 .54666 m .40878 .54642 L .40528 .54319 L .749 .348 .291 r
F
.40957 .54732 m .40878 .54642 L .40883 .54662 L 0 .222 .744 r
F
.40878 .54642 m .40587 .5431 L .40883 .54662 L F
.43733 .57403 m .40883 .54662 L .45053 .58418 L F
.4507 .58432 m .46316 .59588 L .4375 .57421 L .83 .438 .308 r
F
.4507 .58432 m .4375 .57421 L .43733 .57403 L F
.40883 .54662 m .41205 .54932 L .45603 .58914 L 0 .222 .744 r
F
.46 .59054 m .45637 .58443 L .46158 .59251 L .679 .139 0 r
F
.46284 .59531 m .44111 .57265 L .45308 .58189 L F
.46284 .59531 m .45308 .58189 L .46 .59054 L F
.45807 .58602 m .45945 .58923 L .45916 .58796 L .797 .547 .561 r
F
.4086 .54575 m .40587 .5431 L .40878 .54642 L 0 .222 .744 r
F
.45734 .5805 m .44822 .56514 L .46929 .58578 L .745 .291 .174 r
F
.44813 .56829 m .45858 .58105 L .45281 .5785 L .797 .547 .561 r
F
.44813 .56829 m .45309 .57911 L .45674 .58364 L F
.44218 .57505 m .44813 .56829 L .45916 .58796 L .749 .348 .291 r
F
.44111 .57265 m .4377 .56984 L .43094 .56205 L .679 .139 0 r
F
.41993 .55368 m .44813 .56829 L .44218 .57505 L .749 .348 .291 r
F
.41036 .54788 m .43159 .56532 L .40867 .54601 L F
.43159 .56532 m .43139 .56488 L .40867 .54601 L F
.40878 .54642 m .40867 .54601 L .40528 .54319 L F
.41036 .54788 m .40867 .54601 L .40878 .54642 L F
.44218 .57505 m .45916 .58796 L .41036 .54788 L F
.45664 .58885 m .41252 .54972 L .44903 .5809 L .679 .139 0 r
F
.41851 .55232 m .44813 .56829 L .41993 .55368 L .749 .348 .291 r
F
.41842 .55223 m .40988 .54403 L .4145 .5449 L .679 .139 0 r
F
.40528 .54319 m .45916 .58796 L .41016 .54466 L .749 .348 .291 r
F
.42308 .56032 m .4086 .54575 L .40957 .54732 L 0 .222 .744 r
F
.43733 .57403 m .42287 .5598 L .42308 .56032 L F
.42287 .5598 m .4086 .54575 L .42308 .56032 L F
.43581 .57242 m .4086 .54575 L .43733 .57403 L F
.43159 .56532 m .45916 .58796 L .43139 .56488 L .749 .348 .291 r
F
.43361 .57007 m .4086 .54575 L .43366 .57012 L 0 .222 .744 r
F
.42241 .55797 m .45314 .5862 L .43733 .57403 L .83 .438 .308 r
F
.42241 .55797 m .43733 .57403 L .43022 .56646 L F
.42607 .56004 m .45314 .5862 L .42241 .55797 L F
.46123 .59424 m .46316 .59588 L .46371 .59945 L F
.46364 .5998 m .46371 .59945 L .4654 .60755 L .07 .081 .562 r
F
.46364 .5998 m .46371 .59945 L .46383 .60025 L .83 .438 .308 r
F
.46123 .59424 m .46371 .59945 L .46364 .5998 L F
.46473 .60597 m .46364 .5998 L .4654 .60755 L .07 .081 .562 r
F
.46364 .5998 m .46284 .59531 L .46371 .59945 L F
.46772 .61626 m .46592 .60905 L .4645 .6005 L .787 .521 0 r
F
.47342 .64413 m .46641 .61135 L .46772 .61626 L F
.46641 .61135 m .46592 .60905 L .46772 .61626 L F
.46592 .60905 m .46302 .59522 L .4645 .6005 L F
.47342 .64413 m .4645 .6005 L .47117 .63281 L F
.46504 .60522 m .46278 .59437 L .46523 .60582 L F
.47221 .63905 m .46592 .60905 L .47342 .64413 L F
.4645 .6005 m .4631 .59551 L .46277 .59213 L F
.4645 .6005 m .46277 .59213 L .46247 .58915 L F
.46316 .59588 m .47207 .63838 L .47029 .61002 L .872 .635 .576 r
F
.46592 .60905 m .46278 .59437 L .46302 .59522 L .787 .521 0 r
F
.47099 .63391 m .46504 .60522 L .46592 .60905 L F
.47239 .64256 m .47605 .65732 L .47221 .63905 L .872 .635 .576 r
F
.4726 .64672 m .47101 .61503 L .47029 .61002 L F
.47231 .64026 m .46544 .60775 L .46504 .60522 L .787 .521 0 r
F
.47641 .65999 m .47194 .63871 L .47231 .64026 L F
.47194 .63871 m .46544 .60775 L .47231 .64026 L F
.46544 .60775 m .46469 .60417 L .46479 .60448 L F
.46544 .60775 m .46479 .60448 L .46504 .60522 L F
.47941 .67334 m .4802 .67887 L .47765 .66631 L .958 .74 .565 r
F
.4779 .66663 m .47765 .66631 L .47593 .65787 L F
.47941 .67334 m .47765 .66631 L .4779 .66663 L F
.47713 .6625 m .47874 .67014 L .47856 .66747 L .872 .635 .576 r
F
.4779 .66663 m .47605 .65732 L .47856 .66747 L .787 .521 0 r
F
.47593 .65787 m .46469 .60417 L .47609 .65856 L F
.47609 .65856 m .46544 .60775 L .47641 .65999 L F
.47872 .66768 m .47342 .64413 L .47902 .66805 L F
.47902 .66805 m .47342 .64413 L .47524 .64688 L F
.47982 .67254 m .47524 .64688 L .4784 .65781 L F
.47605 .65732 m .47221 .63905 L .47342 .64413 L F
.47605 .65732 m .47342 .64413 L .47982 .67254 L F
.47221 .63905 m .47856 .66747 L .47101 .61503 L .872 .635 .576 r
F
.47605 .65732 m .47856 .66747 L .47221 .63905 L F
.47888 .67155 m .47099 .63391 L .47221 .63905 L .787 .521 0 r
F
.47888 .67155 m .47221 .63905 L .47605 .65732 L F
.47868 .67093 m .47099 .63391 L .47888 .67155 L F
.47807 .66403 m .47856 .66747 L .47593 .65787 L .958 .74 .565 r
F
.47856 .66747 m .47941 .67334 L .4779 .66663 L F
.47856 .66747 m .4779 .66663 L .47593 .65787 L F
.47982 .67254 m .47872 .66768 L .47902 .66805 L .787 .521 0 r
F
.48051 .67976 m .4779 .66663 L .47982 .67254 L F
.4779 .66663 m .47856 .66747 L .47982 .67254 L F
.47882 .67167 m .47593 .65787 L .47886 .67177 L F
.47593 .65787 m .47609 .65856 L .47886 .67177 L F
.47593 .65787 m .4802 .67887 L .47161 .6454 L .958 .74 .565 r
F
.46504 .60522 m .46284 .59531 L .46283 .59459 L .787 .521 0 r
F
.46473 .60597 m .46496 .60588 L .46364 .5998 L .07 .081 .562 r
F
.46469 .60417 m .46284 .59531 L .46504 .60522 L .787 .521 0 r
F
.46496 .60588 m .46608 .60543 L .46383 .60025 L .07 .081 .562 r
F
.46496 .60588 m .46383 .60025 L .46364 .5998 L F
.4375 .57421 m .4642 .60264 L .46433 .60354 L .83 .438 .308 r
F
.46429 .60349 m .46433 .60354 L .46429 .60348 L F
.4375 .57421 m .46123 .59424 L .4642 .60264 L F
.45252 .58836 m .43733 .57403 L .45603 .58914 L 0 .222 .744 r
F
.44079 .57736 m .43733 .57403 L .45252 .58836 L F
.43684 .57365 m .4375 .57421 L .46433 .60354 L .83 .438 .308 r
F
.44751 .58525 m .46429 .60349 L .4583 .59541 L F
.43733 .57403 m .45053 .58418 L .45603 .58914 L 0 .222 .744 r
F
.46284 .59531 m .46 .59054 L .46278 .59437 L .679 .139 0 r
F
.46 .59054 m .46158 .59251 L .46278 .59437 L F
.45916 .58796 m .46016 .59031 L .45972 .59013 L .872 .635 .576 r
F
.45916 .58796 m .45974 .59021 L .46125 .5921 L F
.45916 .58796 m .45972 .59013 L .45965 .5901 L F
.45916 .58796 m .45965 .5901 L .45974 .59021 L F
.41016 .54466 m .45916 .58796 L .46125 .5921 L .83 .438 .308 r
F
.45827 .59054 m .45354 .58665 L .45664 .58885 L .679 .139 0 r
F
.41016 .54466 m .46125 .5921 L .4569 .58982 L .83 .438 .308 r
F
.44565 .58237 m .4583 .59541 L .45431 .59004 L F
.46429 .60349 m .46429 .60348 L .45833 .59545 L F
.45831 .59543 m .45833 .59545 L .45433 .59006 L F
.46429 .60349 m .45833 .59545 L .45831 .59543 L F
.46429 .60349 m .45433 .59006 L .45431 .59004 L F
.46123 .59424 m .46383 .60025 L .4642 .60264 L F
.46284 .59541 m .45312 .58892 L .46284 .59531 L 0 .222 .744 r
F
.46288 .59808 m .45723 .59278 L .46284 .59541 L F
.45723 .59278 m .45312 .58892 L .46284 .59541 L F
.47029 .61002 m .47807 .66403 L .47593 .65787 L .958 .74 .565 r
F
.47099 .63391 m .46592 .60905 L .47221 .63905 L .787 .521 0 r
F
.47031 .63747 m .46653 .61436 L .47574 .65733 L .07 .081 .562 r
F
.46473 .60597 m .4654 .60755 L .47882 .67167 L F
.47029 .61002 m .47593 .65787 L .47131 .63728 L .958 .74 .565 r
F
.47029 .61002 m .47131 .63728 L .47492 .63548 L F
.47337 .61698 m .47492 .63548 L .48037 .63278 L F
.47029 .61002 m .47492 .63548 L .47337 .61698 L F
.46504 .60522 m .46523 .60582 L .46592 .60905 L .787 .521 0 r
F
.46798 .61887 m .46841 .61082 L .46608 .60543 L .07 .081 .562 r
F
.47031 .63747 m .46473 .60597 L .46653 .61436 L F
.47031 .63747 m .46608 .60543 L .46473 .60597 L F
.47183 .64603 m .47031 .63747 L .47574 .65733 L F
.47183 .64603 m .47112 .64104 L .47031 .63747 L F
.47112 .64104 m .46608 .60543 L .47031 .63747 L F
.47183 .64603 m .47024 .62963 L .46798 .61887 L F
.47131 .63728 m .47593 .65787 L .47161 .6454 L .958 .74 .565 r
F
.47131 .63728 m .47151 .64276 L .47263 .64393 L F
.47151 .64276 m .47199 .64485 L .47263 .64393 L F
.47057 .62578 m .46863 .61044 L .47009 .62667 L .07 .081 .562 r
F
.46863 .61044 m .46829 .60953 L .47183 .64603 L F
.46722 .60672 m .47029 .61002 L .46909 .61165 L .897 .5 .256 r
F
.46608 .60543 m .46316 .59588 L .47029 .61002 L .83 .438 .308 r
F
.46433 .60354 m .46383 .60025 L .46608 .60543 L F
.46383 .60025 m .46316 .59588 L .46608 .60543 L F
.46608 .60543 m .47029 .61002 L .46663 .60521 L F
.46608 .60543 m .46629 .60535 L .46364 .5998 L .07 .081 .562 r
F
.46829 .60953 m .46481 .60037 L .46364 .5998 L F
.46159 .59859 m .46663 .60521 L .46153 .59846 L .83 .438 .308 r
F
.46663 .60521 m .47029 .61002 L .46665 .60521 L F
.46663 .60521 m .46665 .60521 L .46153 .59846 L F
.46841 .61082 m .46829 .60953 L .46629 .60535 L .07 .081 .562 r
F
.46841 .61082 m .46629 .60535 L .46608 .60543 L F
.46665 .60521 m .47029 .61002 L .46722 .60672 L .897 .5 .256 r
F
.46829 .60953 m .46752 .60167 L .46481 .60037 L .07 .081 .562 r
F
.46409 .60261 m .46378 .60147 L .45712 .59273 L .83 .438 .308 r
F
.45314 .5862 m .45404 .58707 L .4507 .58432 L F
.45312 .58892 m .45603 .58914 L .46284 .59531 L 0 .222 .744 r
F
.45214 .58828 m .45252 .58836 L .45312 .58892 L F
.45252 .58836 m .45603 .58914 L .45312 .58892 L F
.46409 .60261 m .45712 .59273 L .457 .59256 L .83 .438 .308 r
F
.45546 .59112 m .457 .59256 L .42574 .55153 L F
.46409 .60261 m .457 .59256 L .45546 .59112 L F
.46433 .60354 m .46409 .60261 L .42574 .55153 L F
.42574 .55153 m .46159 .59859 L .42607 .55168 L F
.46159 .59859 m .46153 .59846 L .42607 .55168 L F
.45723 .59278 m .46255 .5998 L .45642 .5924 L .897 .5 .256 r
F
.46289 .59862 m .45214 .58828 L .45312 .58892 L 0 .222 .744 r
F
.44491 .58122 m .45431 .59004 L .42574 .55153 L .83 .438 .308 r
F
.44565 .58237 m .45431 .59004 L .44491 .58122 L F
.43022 .56646 m .44079 .57736 L .42574 .55153 L F
.44079 .57736 m .44565 .58237 L .44491 .58122 L F
.44079 .57736 m .44491 .58122 L .42574 .55153 L F
.45214 .58828 m .44079 .57736 L .45252 .58836 L 0 .222 .744 r
F
.45273 .58867 m .43562 .57203 L .45258 .58857 L F
.45273 .58867 m .45258 .58857 L .45606 .59196 L F
.45582 .59168 m .45273 .58867 L .45606 .59196 L F
.46289 .59862 m .45312 .58892 L .46288 .59808 L F
.43917 .56925 m .45723 .59278 L .45642 .5924 L .897 .5 .256 r
F
.44 .57005 m .45723 .59278 L .43917 .56925 L F
.43562 .57203 m .43626 .57269 L .4561 .59201 L 0 .222 .744 r
F
.43562 .57203 m .4561 .59201 L .45606 .59196 L F
.44751 .58525 m .4583 .59541 L .44565 .58237 L .83 .438 .308 r
F
.44911 .58514 m .43554 .57195 L .44912 .58516 L 0 .222 .744 r
F
.43554 .57195 m .43556 .57196 L .44912 .58516 L F
.45431 .59004 m .45433 .59006 L .42574 .55153 L .83 .438 .308 r
F
.43492 .56488 m .45642 .5924 L .44031 .57294 L .897 .5 .256 r
F
.42607 .55168 m .43785 .56748 L .43492 .56488 L F
.43785 .56748 m .45642 .5924 L .43492 .56488 L F
.41016 .54466 m .42607 .56004 L .42241 .55797 L .83 .438 .308 r
F
.42609 .55442 m .41657 .54648 L .42547 .55141 L .745 .291 .174 r
F
.41016 .54466 m .43022 .56646 L .42574 .55153 L .83 .438 .308 r
F
.39122 .54302 m .39406 .54314 L .40386 .54316 L .264 .671 .967 r
F
.36504 .54273 m .40386 .54316 L .40398 .54316 L F
.3508 .53623 m .40814 .54405 L .35144 .5364 L .269 0 0 r
F
.40926 .54435 m .409 .54275 L .40782 .54288 L 0 .222 .744 r
F
.4095 .54456 m .40814 .54405 L .41016 .54466 L .269 0 0 r
F
.40951 .54461 m .40947 .54447 L .40926 .54435 L 0 .222 .744 r
F
.40947 .54447 m .409 .54275 L .40926 .54435 L F
.41873 .54942 m .41016 .54466 L .42607 .55168 L .403 0 0 r
F
.42276 .55952 m .40782 .54288 L .4086 .54575 L 0 .222 .744 r
F
.45178 .58774 m .42182 .55717 L .42276 .55952 L F
.42182 .55717 m .40782 .54288 L .42276 .55952 L F
.42497 .55134 m .42488 .55115 L .41824 .54819 L .403 0 0 r
F
.4095 .54456 m .41016 .54466 L .40947 .54447 L .269 0 0 r
F
.40947 .54447 m .41016 .54466 L .41873 .54942 L .403 0 0 r
F
.35144 .5364 m .40814 .54405 L .4095 .54456 L .269 0 0 r
F
.35144 .5364 m .39627 .5427 L .33469 .53199 L F
.39627 .5427 m .39758 .54271 L .33469 .53199 L F
.39738 .54267 m .39758 .54271 L .39746 .54267 L F
.39738 .54267 m .39746 .54267 L .34312 .52622 L F
.33469 .53199 m .39738 .54267 L .34312 .52622 L F
.39758 .54271 m .40011 .54272 L .34312 .52622 L F
.40661 .54299 m .39627 .5427 L .4055 .54311 L .264 .671 .967 r
F
.40886 .54275 m .40314 .54273 L .40661 .54299 L F
.40314 .54273 m .39627 .5427 L .40661 .54299 L F
.40364 .54374 m .40342 .5436 L .40275 .54348 L .269 0 0 r
F
.40398 .54316 m .40386 .54316 L .405 .54317 L .264 .671 .967 r
F
.40386 .54316 m .40401 .54329 L .40459 .54311 L .749 .348 .291 r
F
.39923 .54283 m .40493 .54309 L .40814 .54405 L .269 0 0 r
F
.40342 .5436 m .40127 .54221 L .40275 .54348 L F
.40275 .54348 m .40127 .54221 L .34312 .52622 L F
.40108 .54257 m .39083 .54246 L .39627 .5427 L .264 .671 .967 r
F
.39858 .54238 m .39083 .54246 L .40108 .54257 L F
.39627 .5427 m .40364 .54374 L .39758 .54271 L .269 0 0 r
F
.40364 .54374 m .4095 .54456 L .40127 .54221 L F
.35447 .52953 m .40251 .54268 L .39858 .54238 L .403 0 0 r
F
.35621 .52985 m .40251 .54268 L .35447 .52953 L F
.34312 .52622 m .39858 .54238 L .37275 .53531 L F
.34312 .52622 m .40314 .54273 L .40251 .54268 L F
.4095 .54456 m .40947 .54447 L .40127 .54221 L .269 0 0 r
F
.4062 .5423 m .39442 .54124 L .39858 .54238 L .264 .671 .967 r
F
.41373 .54222 m .4049 .54177 L .4062 .5423 L F
.4049 .54177 m .39442 .54124 L .4062 .5423 L F
.40918 .54271 m .39627 .5427 L .40886 .54275 L F
.41373 .54222 m .40698 .5424 L .40918 .54271 L F
.40698 .5424 m .39627 .5427 L .40918 .54271 L F
.39858 .54238 m .37727 .54037 L .39083 .54246 L F
.39758 .54271 m .40364 .54374 L .40011 .54272 L .269 0 0 r
F
.45178 .58774 m .4106 .54444 L .40951 .54461 L 0 .222 .744 r
F
.4106 .54444 m .409 .54275 L .40905 .54295 L F
.4106 .54444 m .40905 .54295 L .40951 .54461 L F
.46909 .61165 m .47029 .61002 L .47337 .61698 L .897 .5 .256 r
F
.47886 .67177 m .47609 .65856 L .47641 .65999 L .787 .521 0 r
F
.47131 .63728 m .47263 .64393 L .48037 .63278 L .958 .74 .565 r
F
.47634 .67146 m .47183 .64603 L .47882 .67167 L .07 .081 .562 r
F
.47183 .64603 m .47574 .65733 L .47882 .67167 L F
.47634 .67146 m .47422 .65469 L .47183 .64603 L F
.47199 .64485 m .47454 .65609 L .48037 .63278 L .958 .74 .565 r
F
.47454 .65609 m .47657 .66504 L .47772 .65526 L F
.47454 .65609 m .47772 .65526 L .48037 .63278 L F
.47446 .65659 m .47193 .61913 L .46863 .61044 L .07 .081 .562 r
F
.46909 .61165 m .47337 .61698 L .4726 .62089 L .897 .5 .256 r
F
.4749 .65375 m .47239 .62267 L .47446 .65659 L .07 .081 .562 r
F
.47239 .62267 m .47108 .6065 L .47219 .62298 L F
.47239 .62267 m .47219 .62298 L .47446 .65659 L F
.46863 .61044 m .47108 .6065 L .46752 .60167 L F
.47193 .61913 m .47108 .6065 L .46863 .61044 L F
.47024 .62963 m .46841 .61082 L .46798 .61887 L F
.47284 .62154 m .47337 .61698 L .48037 .63278 L .897 .5 .256 r
F
.47255 .62111 m .4726 .62089 L .47284 .62154 L F
.4726 .62089 m .47337 .61698 L .47284 .62154 L F
.47707 .66725 m .47587 .66195 L .47634 .67146 L .07 .081 .562 r
F
.47492 .64292 m .47392 .63883 L .47634 .67146 L F
.4726 .62089 m .47215 .6197 L .47634 .67146 L F
.47634 .67146 m .4749 .65375 L .47446 .65659 L F
.47161 .6454 m .47186 .64639 L .47356 .69784 L .958 .74 .565 r
F
.47186 .64639 m .47614 .69047 L .47356 .69784 L F
.47336 .69232 m .47446 .68929 L .47686 .66632 L F
.47657 .66504 m .47686 .66632 L .48037 .63278 L F
.47336 .69232 m .47686 .66632 L .47657 .66504 L F
.47412 .7129 m .44826 .74599 L .45332 .73861 L .846 .987 .712 r
F
.47412 .7129 m .45594 .73806 L .45813 .73337 L F
.47513 .69994 m .47412 .7129 L .47227 .71282 L .981 .833 .437 r
F
.47152 .70937 m .47729 .69916 L .47366 .70047 L .283 .063 .393 r
F
.47169 .70867 m .47342 .70569 L .47164 .70887 L .527 .3 .513 r
F
.47169 .70867 m .47164 .70887 L .45895 .73161 L F
.47366 .70047 m .4754 .69873 L .47677 .68756 L .283 .063 .393 r
F
.47729 .69916 m .4803 .69383 L .47366 .70047 L F
.4759 .69116 m .47516 .69424 L .47356 .69784 L .958 .74 .565 r
F
.47356 .69784 m .47516 .69424 L .47365 .70011 L F
.47516 .69424 m .47392 .69939 L .47365 .70011 L F
.47737 .67728 m .47634 .67146 L .47884 .67644 L .07 .081 .562 r
F
.47634 .67146 m .47882 .67167 L .48051 .67976 L F
.47737 .67728 m .47749 .67093 L .47634 .67146 L F
.47686 .66632 m .47752 .66926 L .48037 .63278 L .958 .74 .565 r
F
.48037 .63278 m .47763 .66792 L .47763 .66393 L .981 .833 .437 r
F
.47763 .66792 m .47752 .66926 L .47755 .6678 L F
.47763 .66792 m .47755 .6678 L .47763 .66393 L F
.47733 .66573 m .47492 .64292 L .47587 .66195 L .07 .081 .562 r
F
.47733 .66573 m .47587 .66195 L .47707 .66725 L F
.47492 .64292 m .4726 .62089 L .47392 .63883 L F
.47242 .62178 m .47733 .66576 L .47732 .66579 L .437 .333 .639 r
F
.47242 .62178 m .47255 .62111 L .47733 .66576 L F
.47752 .66926 m .47733 .66573 L .47707 .66725 L .07 .081 .562 r
F
.47242 .62178 m .47755 .66779 L .47753 .66777 L .437 .333 .639 r
F
.47787 .67076 m .47707 .66725 L .47634 .67146 L .07 .081 .562 r
F
.47356 .69784 m .47561 .69388 L .47752 .66926 L .958 .74 .565 r
F
.47356 .69784 m .47752 .66926 L .47686 .66632 L F
.47255 .62111 m .4727 .62181 L .47755 .6678 L .437 .333 .639 r
F
.47787 .67076 m .47755 .6678 L .47752 .66926 L .07 .081 .562 r
F
.47755 .66779 m .47755 .6678 L .47787 .67076 L .437 .333 .639 r
F
.47255 .62111 m .47755 .6678 L .47755 .66779 L F
.47732 .66742 m .47688 .67757 L .47641 .67784 L .981 .833 .437 r
F
.47743 .6676 m .47688 .67757 L .47732 .66742 L F
.47356 .69784 m .47366 .70047 L .47561 .69388 L .958 .74 .565 r
F
.47366 .70047 m .47513 .69994 L .47561 .69388 L F
.47423 .70162 m .47402 .70495 L .47342 .70569 L .981 .833 .437 r
F
.4769 .66674 m .47402 .70495 L .47648 .66606 L F
.47755 .6678 m .47733 .66573 L .47752 .66926 L .07 .081 .562 r
F
.47161 .6454 m .47584 .67123 L .47657 .66504 L .958 .74 .565 r
F
.47422 .65469 m .47167 .64345 L .47183 .64603 L .07 .081 .562 r
F
.47161 .6454 m .47657 .66504 L .47199 .64485 L .958 .74 .565 r
F
.47629 .66575 m .47242 .62178 L .47516 .64642 L .437 .333 .639 r
F
.47648 .66606 m .47516 .64642 L .47753 .66777 L F
.47629 .66575 m .47516 .64642 L .47648 .66606 L F
.47732 .66579 m .47733 .66576 L .47755 .66779 L F
.47763 .66393 m .47733 .66728 L .47781 .6547 L .981 .833 .437 r
F
.47733 .66728 m .47402 .70495 L .47781 .6547 L F
.47781 .6547 m .4769 .66674 L .47648 .66606 L F
.47763 .66393 m .47743 .6676 L .47732 .66742 L F
.48037 .63278 m .47763 .66393 L .47781 .6547 L F
.47752 .66926 m .47688 .67757 L .47763 .66393 L F
.48192 .67448 m .48194 .67079 L .48304 .67024 L .787 .521 0 r
F
.4818 .6749 m .47983 .66277 L .4819 .66992 L F
.47781 .6547 m .47648 .66606 L .48254 .67474 L .981 .833 .437 r
F
.47781 .6547 m .48254 .67474 L .48257 .67418 L F
.47648 .66606 m .47423 .70162 L .47311 .70607 L F
.47337 .69267 m .47356 .69784 L .47436 .69023 L .958 .74 .565 r
F
.47337 .69267 m .47436 .69023 L .47446 .68929 L F
.47336 .69232 m .47337 .69267 L .47446 .68929 L F
.47581 .67175 m .47311 .70607 L .47158 .70796 L .981 .833 .437 r
F
.47648 .66606 m .47311 .70607 L .47581 .67175 L F
.47641 .67784 m .47547 .69415 L .47487 .69531 L F
.47547 .69415 m .47513 .69994 L .47487 .69531 L F
.47487 .69531 m .47513 .69994 L .47402 .70495 L F
.47688 .67757 m .47513 .69994 L .47641 .67784 L F
.4754 .69873 m .4803 .69383 L .47757 .68899 L .283 .063 .393 r
F
.4754 .69873 m .47757 .68899 L .47677 .68756 L F
.47677 .68756 m .48051 .67976 L .47754 .68649 L F
.48638 .67119 m .48211 .68644 L .47984 .69225 L .964 .935 .627 r
F
.47677 .68756 m .4803 .69383 L .48051 .67976 L .283 .063 .393 r
F
.47701 .67398 m .47158 .70796 L .47803 .6891 L .981 .833 .437 r
F
.47648 .66606 m .47581 .67175 L .47701 .67398 L F
.47581 .67175 m .47158 .70796 L .47701 .67398 L F
.47342 .70569 m .4803 .69383 L .47402 .70495 L .527 .3 .513 r
F
.47342 .70569 m .47402 .70495 L .45895 .73161 L F
.46074 .72777 m .47169 .70867 L .46092 .72806 L F
.45949 .73046 m .46092 .72806 L .45895 .73161 L F
.46074 .72777 m .46092 .72806 L .45949 .73046 L F
.47412 .7129 m .41718 .78325 L .44115 .75245 L .846 .987 .712 r
F
.45912 .74132 m .45903 .74145 L .45901 .74198 L F
.45655 .73585 m .45716 .73478 L .45813 .73337 L F
.44949 .74698 m .45716 .73478 L .45655 .73585 L F
.44949 .74698 m .44901 .74664 L .45716 .73478 L F
.45813 .73337 m .44901 .74664 L .4482 .74607 L F
.45198 .74394 m .45895 .73161 L .45798 .73298 L .283 .063 .393 r
F
.45198 .74394 m .45798 .73298 L .44853 .7463 L F
.44418 .7618 m .44593 .75775 L .44588 .7578 L 0 0 0 r
F
.44949 .74698 m .45045 .74765 L .44418 .7618 L .283 .063 .393 r
F
.4296 .77195 m .43655 .77123 L .43973 .7673 L .308 0 .029 r
F
.43655 .77123 m .43825 .7677 L .44418 .7618 L .283 .063 .393 r
F
.43655 .77123 m .45198 .74394 L .44853 .7463 L F
.45332 .73861 m .4482 .74607 L .44761 .74566 L .846 .987 .712 r
F
.44826 .74599 m .4482 .74607 L .45332 .73861 L F
.45949 .73046 m .44711 .7453 L .45131 .74413 L F
.42816 .77649 m .4272 .77781 L .42411 .77707 L F
.42283 .77738 m .42874 .78264 L .43646 .77136 L .502 .096 .203 r
F
.41898 .78094 m .41718 .78325 L .41202 .78738 L .846 .987 .712 r
F
.41138 .78797 m .42874 .78264 L .42283 .77738 L .502 .096 .203 r
F
.41605 .78684 m .42028 .78544 L .41513 .78728 L .613 .221 .277 r
F
.42028 .78544 m .42874 .78264 L .41468 .7875 L F
.42561 .77558 m .43655 .77123 L .4296 .77195 L .308 0 .029 r
F
.4379 .76655 m .41468 .7875 L .43065 .77646 L 0 0 0 r
F
.37449 .80139 m .41468 .7875 L .36541 .80273 L .502 .096 .203 r
F
.41468 .7875 m .41516 .78695 L .36541 .80273 L F
.41202 .78738 m .41468 .7875 L .43203 .77185 L .846 .987 .712 r
F
.42028 .78544 m .41468 .7875 L .41024 .78903 L .613 .221 .277 r
F
.41605 .78684 m .42022 .79542 L .42874 .78264 L F
.41666 .78613 m .41468 .7875 L .41605 .78684 L 0 0 0 r
F
.40866 .78929 m .41605 .78684 L .41024 .78903 L .613 .221 .277 r
F
.41605 .78684 m .41513 .78728 L .41024 .78903 L F
.40623 .79834 m .42022 .79542 L .41605 .78684 L F
.40684 .79902 m .40754 .79902 L .40689 .79901 L .275 0 0 r
F
.39763 .79991 m .40868 .79822 L .40754 .79902 L .786 .975 .912 r
F
.40737 .79796 m .42022 .79542 L .40623 .79834 L .685 .288 .29 r
F
.40737 .79796 m .41104 .8086 L .42022 .79542 L F
.4095 .79533 m .41468 .7875 L .40576 .7985 L 0 0 0 r
F
.40482 .80109 m .41104 .8086 L .40737 .79796 L .685 .288 .29 r
F
.40215 .80662 m .41104 .8086 L .40482 .80109 L F
.40095 .80913 m .39465 .81219 L .39687 .8176 L .363 0 .14 r
F
.40203 .80687 m .39854 .80939 L .40095 .80913 L F
.39854 .80939 m .39465 .81219 L .40095 .80913 L F
.4006 .80628 m .39465 .81219 L .40203 .80687 L 0 0 0 r
F
.39817 .80927 m .40676 .80882 L .4006 .80628 L .685 .288 .29 r
F
.40676 .80882 m .41104 .8086 L .4006 .80628 L F
.40335 .80886 m .41104 .8086 L .40095 .80913 L .736 .315 .248 r
F
.47174 .76773 m .59526 .70965 L .60678 .69801 L .224 0 0 r
F
.46474 .77634 m .59526 .70965 L .47174 .76773 L 0 0 0 r
F
.45531 .78341 m .57952 .71964 L .46474 .77634 L .473 .887 .771 r
F
.46474 .77634 m .53559 .74134 L .59526 .70965 L 0 0 0 r
F
.53559 .74134 m .57952 .71964 L .59131 .71216 L F
.53559 .74134 m .59131 .71216 L .59526 .70965 L F
.44421 .78901 m .56108 .72766 L .46274 .7795 L .674 .97 .917 r
F
.45402 .78406 m .46274 .7795 L .45531 .78341 L F
.44421 .78901 m .46274 .7795 L .45402 .78406 L F
.43216 .7933 m .54146 .73365 L .44421 .78901 L .749 .96 .938 r
F
.43216 .7933 m .52201 .73787 L .54146 .73365 L F
.41977 .79653 m .52201 .73787 L .43216 .7933 L .78 .948 .93 r
F
.4532 .75424 m .45431 .75354 L .45591 .75268 L .486 .876 .693 r
F
.4532 .75424 m .45591 .75268 L .45641 .75241 L F
.45431 .75354 m .45693 .75065 L .45641 .75241 L .964 .935 .627 r
F
.45445 .75399 m .45493 .7536 L .45704 .75235 L .486 .876 .693 r
F
.45493 .7536 m .45641 .75241 L .46201 .74939 L F
.45835 .74973 m .4588 .74912 L .45858 .74989 L .964 .935 .627 r
F
.48819 .74557 m .48713 .74528 L .48875 .72479 L .803 .728 .781 r
F
.48828 .73079 m .48629 .75591 L .48362 .72444 L .839 .839 .846 r
F
.45402 .76435 m .47361 .74583 L .48753 .74323 L .786 .975 .912 r
F
.47019 .7547 m .4838 .7472 L .47251 .75371 L .839 .839 .846 r
F
.45402 .76435 m .48513 .74474 L .47251 .75371 L .786 .975 .912 r
F
.41104 .8086 m .41889 .80024 L .42022 .79542 L .726 .492 .572 r
F
.46672 .74721 m .45486 .76036 L .46446 .76192 L 0 0 0 r
F
.41889 .80024 m .43306 .78453 L .42022 .79542 L .726 .492 .572 r
F
.43306 .78453 m .45268 .76277 L .44005 .77547 L F
.43306 .78453 m .44005 .77547 L .42022 .79542 L F
.42022 .79542 m .44005 .77547 L .4318 .77955 L .647 .417 .556 r
F
.46726 .76413 m .47276 .76405 L .47385 .75891 L .726 .492 .572 r
F
.46651 .76856 m .47276 .76405 L .46726 .76413 L F
.45531 .78341 m .56108 .72766 L .57952 .71964 L .473 .887 .771 r
F
.44421 .78901 m .54146 .73365 L .56108 .72766 L .674 .97 .917 r
F
.47021 .74657 m .46446 .76192 L .46452 .76901 L .275 .088 .437 r
F
.46651 .76856 m .46452 .76901 L .4646 .77994 L F
.47021 .74657 m .46452 .76901 L .46651 .76856 L F
.46741 .76835 m .47276 .76405 L .46651 .76856 L .789 .547 .571 r
F
.48513 .74474 m .4853 .74478 L .47251 .75371 L .786 .975 .912 r
F
.47361 .74583 m .48362 .72444 L .48421 .74385 L .872 .767 .743 r
F
.48556 .74735 m .48562 .74808 L .4854 .74744 L .839 .839 .846 r
F
.48819 .74557 m .48875 .72479 L .4893 .7232 L .803 .728 .781 r
F
.47251 .75371 m .48753 .74323 L .50186 .74112 L .792 .953 .922 r
F
.47361 .74583 m .48021 .72421 L .4825 .72437 L .872 .767 .743 r
F
.4679 .73949 m .448 .75924 L .45486 .76036 L 0 0 0 r
F
.4679 .73949 m .45486 .76036 L .46672 .74721 L F
.43533 .77429 m .44497 .76118 L .44625 .75902 L .647 .417 .556 r
F
.45241 .75457 m .45511 .74712 L .45526 .74758 L .964 .935 .627 r
F
.4679 .73949 m .44625 .75902 L .44455 .76189 L 0 0 0 r
F
.43877 .76536 m .44408 .75622 L .44302 .75956 L .527 .3 .513 r
F
.44711 .7453 m .4434 .75534 L .45131 .74413 L .846 .987 .712 r
F
.4434 .75534 m .44145 .76062 L .44408 .75622 L F
.4434 .75534 m .44408 .75622 L .45131 .74413 L F
.44408 .75622 m .46133 .72651 L .45481 .73827 L .527 .3 .513 r
F
.44408 .75622 m .45481 .73827 L .44302 .75956 L F
.43877 .76536 m .44302 .75956 L .43655 .77123 L F
.46133 .72651 m .45895 .73161 L .43655 .77123 L F
.43877 .76536 m .44489 .75727 L .44408 .75622 L F
.43555 .77167 m .43646 .77136 L .43655 .77123 L .502 .096 .203 r
F
.43011 .78028 m .43877 .76536 L .43655 .77123 L .527 .3 .513 r
F
.43011 .78028 m .44079 .76365 L .43877 .76536 L F
.44079 .76365 m .44489 .75727 L .43877 .76536 L F
.4318 .77955 m .44389 .76299 L .43533 .77429 L .647 .417 .556 r
F
.4598 .74753 m .44439 .76215 L .448 .75924 L 0 0 0 r
F
.44439 .76215 m .44389 .76299 L .448 .75924 L F
.44389 .76299 m .44497 .76118 L .43533 .77429 L .647 .417 .556 r
F
.42509 .78812 m .44625 .75902 L .42874 .78264 L F
.42022 .79542 m .44625 .75902 L .42509 .78812 L F
.45511 .74712 m .45652 .74326 L .45526 .74758 L .964 .935 .627 r
F
.45652 .74326 m .45566 .74646 L .45526 .74758 L F
.45526 .74758 m .45556 .74685 L .45561 .74782 L F
.45131 .74413 m .44408 .75622 L .4679 .73949 L .846 .987 .712 r
F
.42874 .78264 m .43011 .78028 L .43655 .77123 L .527 .3 .513 r
F
.43011 .78028 m .44612 .75885 L .44489 .75727 L F
.44408 .75622 m .44145 .76062 L .44518 .75764 L .846 .987 .712 r
F
.44408 .75622 m .44518 .75764 L .4679 .73949 L F
.45911 .73952 m .45661 .74265 L .45901 .74198 L F
.45949 .73046 m .45661 .74265 L .45911 .73952 L F
.45949 .73046 m .45131 .74413 L .45661 .74265 L F
.46135 .72822 m .45949 .73046 L .45903 .74145 L F
.46135 .72822 m .45903 .74145 L .45912 .74132 L F
.47412 .7129 m .46135 .72822 L .4679 .73949 L F
.47156 .71598 m .47402 .70495 L .47157 .71596 L .981 .833 .437 r
F
.47156 .71598 m .47157 .71596 L .46963 .72471 L F
.46965 .72456 m .47156 .71598 L .46963 .72471 L F
.46135 .72822 m .45901 .74198 L .4679 .73949 L .846 .987 .712 r
F
.44489 .75727 m .46916 .72699 L .46965 .72456 L .527 .3 .513 r
F
.46626 .72401 m .46965 .72456 L .47134 .7161 L F
.44489 .75727 m .46965 .72456 L .46626 .72401 L F
.47342 .70569 m .47402 .70495 L .46965 .72456 L .981 .833 .437 r
F
.46133 .72651 m .46308 .72349 L .46074 .72777 L .527 .3 .513 r
F
.46308 .72349 m .47169 .70867 L .46074 .72777 L F
.47227 .71282 m .47412 .7129 L .46963 .72471 L .981 .833 .437 r
F
.44408 .75622 m .4741 .7114 L .46133 .72651 L .527 .3 .513 r
F
.4741 .7114 m .48036 .70205 L .47442 .70969 L F
.4741 .7114 m .47442 .70969 L .46133 .72651 L F
.46535 .75807 m .46683 .7473 L .46446 .76192 L 0 0 .088 r
F
.46683 .7473 m .46672 .74721 L .46446 .76192 L F
.4704 .74543 m .47218 .75239 L .47858 .73672 L .726 .492 .572 r
F
.47218 .75239 m .47385 .75891 L .47406 .75794 L F
.47218 .75239 m .47406 .75794 L .47858 .73672 L F
.46741 .76323 m .47385 .75891 L .4704 .74543 L F
.41104 .8086 m .45626 .77283 L .43032 .78808 L F
.46446 .76192 m .45486 .77164 L .45824 .77453 L .363 0 .14 r
F
.46452 .76901 m .45824 .77453 L .4646 .77994 L F
.46446 .76192 m .45824 .77453 L .46452 .76901 L F
.40204 .82101 m .44198 .78884 L .41104 .8086 L .789 .547 .571 r
F
.44198 .78884 m .45599 .77651 L .41104 .8086 L F
.45626 .77283 m .45486 .77164 L .43032 .78808 L .726 .492 .572 r
F
.40204 .82101 m .46233 .79285 L .46455 .78673 L .789 .547 .571 r
F
.46461 .78094 m .4622 .784 L .46538 .78769 L .61 .236 .308 r
F
.46567 .7869 m .46538 .78769 L .46592 .78832 L F
.46461 .78094 m .46538 .78769 L .46567 .7869 L F
.47677 .79588 m .47138 .80955 L .47944 .79433 L .692 .491 .61 r
F
.45833 .80691 m .4645 .79009 L .46233 .79285 L .875 .71 .674 r
F
.46233 .79285 m .4645 .79009 L .46381 .78966 L .789 .613 .662 r
F
.46645 .79131 m .46347 .79098 L .46745 .79695 L .61 .236 .308 r
F
.46592 .78832 m .46437 .79001 L .46645 .79131 L F
.46437 .79001 m .46347 .79098 L .46645 .79131 L F
.46233 .79285 m .46381 .78966 L .46455 .78673 L .789 .613 .662 r
F
.40204 .82101 m .46455 .78673 L .46447 .78664 L .789 .547 .571 r
F
.45824 .77453 m .44244 .78879 L .4646 .77994 L .363 0 .14 r
F
.44244 .78879 m .45405 .78763 L .4646 .77994 L F
.40204 .82101 m .46461 .78656 L .45543 .78749 L .789 .547 .571 r
F
.42285 .80425 m .45543 .78749 L .44198 .78884 L F
.40204 .82101 m .45543 .78749 L .42285 .80425 L F
.43259 .80992 m .44887 .82071 L .46233 .79285 L .846 .586 .546 r
F
.43073 .81158 m .40056 .82661 L .40193 .82816 L .61 .236 .308 r
F
.41225 .82803 m .40193 .82816 L .40639 .83323 L F
.43073 .81158 m .40193 .82816 L .41225 .82803 L F
.42517 .82786 m .44887 .82071 L .41225 .82803 L .902 .603 .47 r
F
.427 .82784 m .4287 .82728 L .42517 .82786 L F
.4287 .82728 m .44887 .82071 L .42517 .82786 L F
.41225 .82803 m .44887 .82071 L .43259 .80992 L .846 .586 .546 r
F
.48296 .76873 m .46745 .79695 L .46839 .79996 L .692 .491 .61 r
F
.47911 .77328 m .46745 .79695 L .48296 .76873 L F
.46939 .78364 m .46567 .7869 L .46645 .79131 L .543 .335 .549 r
F
.47677 .79588 m .47602 .79625 L .47138 .80955 L .692 .491 .61 r
F
.47602 .79625 m .46839 .79996 L .47106 .80849 L F
.47602 .79625 m .47106 .80849 L .47138 .80955 L F
.51063 .66126 m .48905 .72833 L .50351 .68194 L .803 .728 .781 r
F
.50351 .68194 m .51145 .66498 L .48421 .74385 L .872 .767 .743 r
F
.51145 .66498 m .51279 .66211 L .5112 .66665 L F
.51145 .66498 m .5112 .66665 L .48421 .74385 L F
.51279 .66211 m .51334 .66194 L .51065 .6704 L F
.51105 .6677 m .51065 .6704 L .48753 .74323 L F
.51279 .66211 m .51065 .6704 L .51105 .6677 L F
.50749 .73482 m .53464 .68954 L .53531 .68963 L .804 .719 .77 r
F
.5135 .65404 m .50072 .58018 L .51644 .63592 L .732 .552 .648 r
F
.51997 .68204 m .52304 .67625 L .50915 .72285 L .829 .73 .755 r
F
.52304 .67625 m .52649 .6763 L .50619 .73399 L F
.52304 .67625 m .50619 .73399 L .50915 .72285 L F
.53364 .67986 m .53586 .68971 L .52798 .67633 L .743 .634 .739 r
F
.53116 .67638 m .52798 .67633 L .51316 .65116 L F
.53364 .67986 m .52798 .67633 L .53116 .67638 L F
.50794 .73392 m .52677 .67676 L .53461 .68954 L .804 .719 .77 r
F
.53586 .68971 m .53461 .68954 L .51316 .65116 L .743 .634 .739 r
F
.50619 .73399 m .52649 .6763 L .50794 .73392 L .804 .719 .77 r
F
.52649 .6763 m .52677 .67676 L .50794 .73392 L F
.53461 .68954 m .53269 .68927 L .5238 .67192 L .743 .634 .739 r
F
.53461 .68954 m .5238 .67192 L .51316 .65116 L F
.52002 .61933 m .53364 .67986 L .51316 .65116 L F
.52649 .6763 m .53333 .65684 L .52677 .67676 L .804 .719 .77 r
F
.50559 .74054 m .53586 .68971 L .52201 .73787 L F
.53586 .68971 m .55358 .65995 L .54122 .69047 L F
.53586 .68971 m .54122 .69047 L .52201 .73787 L F
.51259 .66253 m .5108 .66072 L .51279 .66211 L .872 .767 .743 r
F
.52212 .66865 m .53269 .68927 L .51105 .6609 L .743 .634 .739 r
F
.50794 .73392 m .53461 .68954 L .50749 .73482 L .804 .719 .77 r
F
.53461 .68954 m .53464 .68954 L .50749 .73482 L F
.54669 .66684 m .55208 .66146 L .55113 .66407 L .743 .634 .739 r
F
.54122 .69047 m .55358 .65995 L .54767 .69951 L .794 .728 .79 r
F
.54456 .67511 m .55113 .66407 L .53816 .69994 L .743 .634 .739 r
F
.54669 .66684 m .55113 .66407 L .54456 .67511 L F
.52152 .67623 m .53045 .68895 L .52121 .67739 L .803 .728 .781 r
F
.50454 .74071 m .55358 .65995 L .50559 .74054 L .804 .719 .77 r
F
.50749 .73482 m .55358 .65995 L .50454 .74071 L F
.53045 .68895 m .53816 .69994 L .53023 .68939 L .803 .728 .781 r
F
.53045 .68895 m .53023 .68939 L .52121 .67739 L F
.50378 .74084 m .50749 .73482 L .50454 .74071 L .804 .719 .77 r
F
.53269 .68927 m .53816 .69994 L .53054 .68896 L .743 .634 .739 r
F
.53269 .68927 m .53054 .68896 L .51105 .6609 L F
.55611 .63022 m .55208 .66146 L .54669 .66684 L F
.53461 .68954 m .53333 .65684 L .55608 .65379 L .804 .719 .77 r
F
.52677 .67676 m .53333 .65684 L .53461 .68954 L F
.53461 .68954 m .53816 .69994 L .53269 .68927 L .743 .634 .739 r
F
.53586 .68971 m .53653 .69267 L .53461 .68954 L F
.53653 .69267 m .53816 .69994 L .53461 .68954 L F
.51145 .66498 m .52089 .70805 L .50454 .73405 L .803 .728 .781 r
F
.50129 .73418 m .50454 .73405 L .50033 .74076 L F
.51145 .66498 m .50454 .73405 L .50129 .73418 L F
.52089 .70805 m .50943 .73094 L .50033 .74076 L F
.50378 .74084 m .50619 .73399 L .50794 .73392 L .804 .719 .77 r
F
.50915 .72285 m .50619 .73399 L .50378 .74084 L .829 .73 .755 r
F
.51182 .66242 m .52152 .67623 L .51152 .6645 L .803 .728 .781 r
F
.52152 .67623 m .52121 .67739 L .51152 .6645 L F
.5174 .69174 m .53816 .69994 L .52276 .71656 L F
.51152 .6645 m .52121 .67739 L .5174 .69174 L F
.52121 .67739 m .53816 .69994 L .5174 .69174 L F
.51073 .66087 m .52276 .71656 L .51065 .66135 L F
.48753 .74323 m .51997 .68204 L .50378 .74084 L .829 .73 .755 r
F
.51997 .68204 m .50915 .72285 L .50378 .74084 L F
.52304 .67625 m .53333 .65684 L .52649 .6763 L F
.53461 .68954 m .55608 .65379 L .53464 .68954 L .804 .719 .77 r
F
.53531 .68963 m .55608 .65379 L .55358 .65995 L F
.53464 .68954 m .55608 .65379 L .53531 .68963 L F
.51105 .6609 m .53054 .68896 L .51098 .66122 L .743 .634 .739 r
F
.53054 .68896 m .53816 .69994 L .53045 .68895 L F
.53054 .68896 m .53045 .68895 L .51098 .66122 L F
.51073 .66087 m .51182 .66242 L .51152 .6645 L .803 .728 .781 r
F
.52089 .70805 m .52276 .71656 L .50943 .73094 L F
.50378 .74084 m .50794 .73392 L .50749 .73482 L .804 .719 .77 r
F
.50114 .74243 m .50378 .74084 L .50268 .74157 L .792 .953 .922 r
F
.49104 .75921 m .49368 .78034 L .50779 .73478 L .875 .71 .674 r
F
.47602 .79625 m .49368 .78034 L .49104 .75921 L F
.48589 .78921 m .49368 .78034 L .47987 .79278 L .953 .819 .675 r
F
.52042 .71698 m .50673 .74774 L .53049 .72409 L .808 .634 .665 r
F
.49368 .78034 m .50373 .75737 L .50779 .73478 L .812 .687 .726 r
F
.50373 .75737 m .50437 .7559 L .50457 .75467 L F
.50373 .75737 m .50457 .75467 L .50779 .73478 L F
.50437 .7559 m .51378 .72337 L .50779 .73478 L F
.51674 .71229 m .51384 .72311 L .52042 .71698 L .692 .491 .61 r
F
.51384 .72311 m .51087 .73425 L .5167 .72371 L F
.51384 .72311 m .5167 .72371 L .52042 .71698 L F
.50779 .73478 m .51384 .72311 L .50918 .72214 L .719 .599 .722 r
F
.51378 .72337 m .51384 .72311 L .50779 .73478 L .812 .687 .726 r
F
.52042 .71698 m .51046 .73579 L .50673 .74774 L .808 .634 .665 r
F
.50673 .74774 m .50471 .75472 L .53049 .72409 L F
.5024 .75746 m .51541 .74714 L .53049 .72409 L F
.51261 .61783 m .51202 .60415 L .51817 .6172 L .732 .552 .648 r
F
.51138 .61797 m .51202 .60415 L .51261 .61783 L F
.51138 .61797 m .50072 .58018 L .51202 .60415 L F
.50052 .59398 m .51793 .61004 L .49841 .59384 L .65 .463 .618 r
F
.5013 .59447 m .51793 .61004 L .50052 .59398 L F
.49841 .59384 m .51793 .61004 L .49861 .5948 L .732 .556 .654 r
F
.50717 .56576 m .50811 .56538 L .50718 .5877 L .65 .463 .618 r
F
.51185 .60379 m .50072 .58018 L .51455 .59581 L .732 .552 .648 r
F
.51244 .60206 m .51793 .61004 L .50079 .594 L .65 .463 .618 r
F
.51244 .60206 m .50079 .594 L .50314 .59416 L F
.51644 .63592 m .51138 .61797 L .51817 .6172 L .732 .552 .648 r
F
.50038 .60346 m .51793 .61004 L .51505 .63038 L .732 .556 .654 r
F
.49861 .5948 m .51793 .61004 L .50038 .60346 L F
.51418 .65317 m .52212 .66865 L .51217 .65572 L .743 .634 .739 r
F
.51433 .65882 m .51644 .63592 L .53333 .65684 L .732 .552 .648 r
F
.51644 .63592 m .51817 .6172 L .51965 .62107 L F
.51644 .63592 m .51965 .62107 L .53333 .65684 L F
.51817 .6172 m .52681 .62715 L .53333 .65684 L F
.51793 .61004 m .52002 .61933 L .51077 .6607 L .743 .634 .739 r
F
.51793 .61004 m .51077 .6607 L .51076 .66069 L F
.51077 .6607 m .51098 .66122 L .51073 .66087 L F
.52002 .61933 m .51105 .6609 L .51077 .6607 L F
.51105 .6609 m .51098 .66122 L .51077 .6607 L F
.5107 .66077 m .51067 .66074 L .50576 .6518 L .732 .556 .654 r
F
.51076 .66069 m .50936 .65953 L .51179 .65918 L .872 .767 .743 r
F
.5107 .66077 m .51013 .66025 L .51076 .66069 L F
.51013 .66025 m .50936 .65953 L .51076 .66069 L F
.5108 .66072 m .51179 .65918 L .51433 .65882 L F
.48753 .74323 m .51065 .6704 L .51997 .68204 L .829 .73 .755 r
F
.51243 .6606 m .51407 .66301 L .51225 .66173 L .743 .634 .739 r
F
.51279 .66211 m .51433 .65882 L .51334 .66194 L .872 .767 .743 r
F
.51386 .66177 m .52212 .66865 L .51407 .66301 L .743 .634 .739 r
F
.51624 .66101 m .52212 .66865 L .51386 .66177 L F
.52304 .67625 m .51433 .65882 L .53333 .65684 L .829 .73 .755 r
F
.51334 .66194 m .51433 .65882 L .52304 .67625 L F
.50038 .60346 m .51505 .63038 L .51131 .65682 L .732 .556 .654 r
F
.51316 .65116 m .51418 .65317 L .51217 .65572 L .743 .634 .739 r
F
.51433 .65882 m .5135 .65404 L .51644 .63592 L .732 .552 .648 r
F
.50936 .65953 m .50933 .65932 L .51433 .65882 L .784 .572 .613 r
F
.50933 .65932 m .5135 .65404 L .51433 .65882 L F
.51279 .66211 m .5108 .66072 L .51433 .65882 L .872 .767 .743 r
F
.51244 .60206 m .5147 .59537 L .51793 .61004 L .65 .463 .618 r
F
.52889 .61543 m .52914 .61597 L .51793 .61004 L .666 .547 .71 r
F
.51619 .5798 m .53996 .62086 L .51793 .61004 L F
.51793 .61004 m .52914 .61597 L .52279 .61668 L .743 .634 .739 r
F
.51793 .61004 m .55002 .65387 L .52002 .61933 L F
.50939 .69103 m .52171 .60882 L .51723 .60442 L .627 .537 .734 r
F
.51187 .60086 m .5119 .61289 L .51237 .61215 L .609 .514 .722 r
F
.49987 .63914 m .48302 .58293 L .48971 .58716 L .784 .572 .613 r
F
.5072 .6549 m .5072 .63969 L .50936 .65953 L F
.49987 .63914 m .5072 .63969 L .5072 .6549 L F
.5072 .63969 m .50651 .6334 L .5072 .63674 L F
.5107 .66077 m .51076 .66069 L .5108 .66072 L .872 .767 .743 r
F
.51076 .66069 m .51077 .6607 L .51073 .66087 L .743 .634 .739 r
F
.51076 .66069 m .51179 .65918 L .5108 .66072 L .872 .767 .743 r
F
.51071 .66076 m .51071 .66075 L .51073 .66087 L .732 .556 .654 r
F
.50912 .65572 m .5072 .63969 L .50833 .64226 L .784 .572 .613 r
F
.50933 .65932 m .50892 .65548 L .50912 .65572 L F
.50892 .65548 m .5072 .63969 L .50912 .65572 L F
.51016 .66133 m .51048 .66057 L .51055 .66088 L .872 .767 .743 r
F
.4888 .68985 m .51073 .66087 L .49001 .70894 L .803 .643 .683 r
F
.49357 .68042 m .51073 .66087 L .4888 .68985 L F
.48861 .73124 m .5112 .66665 L .49048 .73377 L .872 .767 .743 r
F
.5112 .66665 m .51105 .6677 L .49048 .73377 L F
.50351 .68194 m .51063 .66126 L .51145 .66498 L F
.50933 .65932 m .50833 .64226 L .51131 .65682 L .784 .572 .613 r
F
.5107 .66077 m .51071 .66076 L .51073 .66087 L .732 .556 .654 r
F
.49987 .63914 m .48871 .58205 L .50038 .60346 L .784 .572 .613 r
F
.49961 .63839 m .49995 .63932 L .49987 .63914 L .732 .556 .654 r
F
.48048 .58326 m .49987 .63914 L .48274 .60235 L F
.48031 .58182 m .49987 .63914 L .48048 .58326 L F
.49234 .61744 m .48296 .58294 L .49987 .63914 L .784 .572 .613 r
F
.48274 .60235 m .49987 .63914 L .48388 .61193 L .732 .556 .654 r
F
.49987 .63914 m .50576 .6518 L .50168 .64437 L F
.49987 .63914 m .50168 .64437 L .48388 .61193 L F
.49955 .66092 m .49631 .64568 L .49978 .64483 L .784 .572 .613 r
F
.51055 .66088 m .51048 .66057 L .51067 .66074 L .872 .767 .743 r
F
.51073 .66087 m .51063 .66126 L .49001 .70894 L .803 .728 .781 r
F
.51063 .66126 m .4893 .7232 L .49001 .70894 L F
.5107 .66077 m .51073 .66087 L .51067 .66074 L .732 .556 .654 r
F
.49344 .59072 m .49861 .5948 L .50038 .60346 L F
.48857 .68612 m .48785 .68024 L .48815 .68203 L .803 .643 .683 r
F
.48843 .68713 m .48733 .67839 L .49955 .66092 L .935 .84 .726 r
F
.50351 .68194 m .48905 .72833 L .4893 .7232 L .803 .728 .781 r
F
.48261 .60897 m .47647 .60202 L .4803 .58947 L .859 .611 .562 r
F
.47647 .60202 m .48096 .58731 L .48388 .61193 L .722 .458 .527 r
F
.4803 .58947 m .46969 .58559 L .47961 .58361 L .859 .611 .562 r
F
.48391 .5954 m .47961 .58361 L .48296 .58294 L F
.48707 .60225 m .48296 .58294 L .49234 .61744 L .784 .572 .613 r
F
.48917 .66433 m .48664 .63111 L .49955 .66092 L .859 .611 .562 r
F
.48664 .63111 m .49569 .64475 L .49955 .66092 L F
.48391 .5954 m .48296 .58294 L .48707 .60225 L F
.46738 .57339 m .48031 .58182 L .46305 .57323 L .722 .458 .527 r
F
.46969 .58559 m .46738 .57339 L .48225 .58308 L .68 .316 .35 r
F
.46767 .748 m .46958 .74603 L .46751 .74786 L .726 .492 .572 r
F
.46958 .74603 m .46868 .74668 L .46751 .74786 L F
.46963 .72471 m .47412 .7129 L .47143 .7244 L .981 .833 .437 r
F
.46926 .72789 m .47143 .7244 L .4679 .73949 L F
.46963 .72471 m .47143 .7244 L .46926 .72789 L F
.45735 .74961 m .44455 .76189 L .4598 .74753 L 0 0 0 r
F
.46965 .72456 m .46926 .72789 L .47157 .72487 L .981 .833 .437 r
F
.46926 .72789 m .4679 .73949 L .47157 .72487 L F
.46652 .753 m .47157 .72487 L .46535 .75807 L 0 0 .088 r
F
.47201 .72446 m .47157 .72487 L .46652 .753 L F
.46683 .7473 m .4679 .73949 L .46672 .74721 L F
.47157 .72487 m .4679 .73949 L .46535 .75807 L F
.4679 .73949 m .45735 .74961 L .4598 .74753 L 0 0 0 r
F
.43057 .78017 m .44625 .75902 L .43011 .78028 L .527 .3 .513 r
F
.44518 .75764 m .44625 .75902 L .4679 .73949 L .846 .987 .712 r
F
.45967 .74092 m .48044 .71292 L .45944 .74103 L .527 .3 .513 r
F
.47201 .72446 m .46939 .73806 L .48044 .71292 L .647 .417 .556 r
F
.47444 .72113 m .48044 .71292 L .47344 .72243 L F
.47996 .71308 m .48044 .71292 L .48039 .70579 L .527 .3 .513 r
F
.47996 .71308 m .48039 .70579 L .48036 .70205 L F
.47134 .7161 m .47996 .71308 L .48036 .70205 L F
.44489 .75727 m .48036 .70205 L .44408 .75622 L F
.47342 .70569 m .47952 .70249 L .47896 .69614 L F
.47952 .70249 m .48036 .70205 L .47896 .69614 L F
.47896 .69614 m .48036 .70205 L .4803 .69383 L F
.472 .7128 m .48036 .70205 L .47342 .70569 L F
.48044 .71292 m .4788 .69435 L .4791 .69104 L .437 .333 .639 r
F
.47899 .6864 m .47737 .67728 L .48051 .67976 L .07 .081 .562 r
F
.47737 .67728 m .47884 .67644 L .48051 .67976 L F
.4803 .69383 m .47899 .6864 L .48051 .67976 L F
.4803 .69383 m .47787 .67076 L .47749 .67093 L F
.4803 .69383 m .47749 .67093 L .47737 .67728 L F
.4791 .69104 m .47629 .66575 L .47787 .67076 L .437 .333 .639 r
F
.4788 .69435 m .47701 .67398 L .4791 .69104 L F
.47701 .67398 m .47629 .66575 L .47672 .66962 L F
.47701 .67398 m .47672 .66962 L .4791 .69104 L F
.47158 .70796 m .47378 .70394 L .4781 .69015 L .981 .833 .437 r
F
.48035 .70051 m .47787 .67076 L .4803 .69383 L .437 .333 .639 r
F
.48044 .71292 m .47787 .67076 L .48035 .70051 L F
.4788 .69435 m .48014 .67982 L .47701 .67398 L F
.48023 .68945 m .48014 .67982 L .4788 .69435 L F
.48023 .68945 m .48201 .68331 L .48014 .67982 L F
.48044 .71292 m .48201 .68331 L .48023 .68945 L F
.48044 .71292 m .48023 .68945 L .4788 .69435 L F
.46958 .74603 m .47858 .73672 L .46868 .74668 L .726 .492 .572 r
F
.46997 .74588 m .47858 .73672 L .46767 .748 L F
.44455 .76189 m .44439 .76215 L .4598 .74753 L 0 0 0 r
F
.448 .75924 m .45774 .76659 L .46446 .76192 L F
.45128 .76171 m .47858 .73672 L .44712 .75857 L .647 .417 .556 r
F
.44005 .77547 m .47858 .73672 L .4318 .77955 L F
.478 .73717 m .47072 .7452 L .47692 .74069 L .275 .088 .437 r
F
.46916 .72699 m .48044 .71292 L .47134 .7161 L .527 .3 .513 r
F
.44612 .75885 m .48044 .71292 L .44489 .75727 L F
.46434 .73478 m .48044 .71292 L .45967 .74092 L .647 .417 .556 r
F
.44844 .75646 m .48044 .71292 L .44524 .76073 L F
.46817 .74084 m .47903 .73094 L .48044 .71292 L F
.48004 .71392 m .47991 .71425 L .48037 .70878 L .598 .448 .65 r
F
.48037 .70878 m .48114 .69342 L .48201 .68331 L F
.47201 .72446 m .47444 .72113 L .4719 .72456 L .647 .417 .556 r
F
.47444 .72113 m .47344 .72243 L .46828 .72946 L F
.48085 .69776 m .4734 .72316 L .48008 .70951 L 0 0 .088 r
F
.48149 .68807 m .47938 .69725 L .48085 .69776 L F
.47938 .69725 m .4734 .72316 L .48085 .69776 L F
.48114 .69342 m .48134 .68954 L .48149 .68807 L .598 .448 .65 r
F
.48114 .69342 m .48149 .68807 L .48201 .68331 L F
.47914 .72955 m .48201 .68331 L .48044 .71292 L F
.46817 .74084 m .47858 .73672 L .47903 .73094 L .647 .417 .556 r
F
.47858 .73672 m .48201 .68331 L .47914 .72955 L .598 .448 .65 r
F
.4875 .67973 m .48765 .68146 L .48743 .6792 L .803 .643 .683 r
F
.48638 .67119 m .48658 .67245 L .48211 .68644 L .964 .935 .627 r
F
.48843 .68713 m .48765 .68146 L .4875 .67973 L .803 .643 .683 r
F
.48638 .67119 m .48549 .66788 L .48917 .66433 L .964 .935 .627 r
F
.48638 .67119 m .48917 .66433 L .48658 .67245 L F
.4888 .68985 m .49001 .70894 L .48765 .68146 L .803 .643 .683 r
F
.48765 .68146 m .49001 .70894 L .48731 .679 L F
.48545 .65194 m .48544 .64925 L .48917 .66433 L .957 .664 .437 r
F
.48918 .65476 m .48149 .68807 L .49706 .67482 L 0 0 .088 r
F
.47984 .71515 m .48085 .69776 L .48037 .70878 L .598 .448 .65 r
F
.48085 .69776 m .48134 .68954 L .48114 .69342 L F
.48085 .69776 m .48114 .69342 L .48037 .70878 L F
.47989 .71432 m .48286 .69846 L .48085 .69776 L F
.47858 .73672 m .47984 .71515 L .47991 .71425 L F
.47858 .73672 m .47991 .71425 L .48004 .71392 L F
.47882 .73258 m .48228 .71117 L .48106 .71278 L F
.47984 .71515 m .48106 .71278 L .47989 .71432 L F
.47882 .73258 m .48106 .71278 L .47984 .71515 L F
.4851 .69925 m .48669 .6998 L .49003 .69175 L 0 0 .088 r
F
.49126 .68667 m .49003 .69175 L .49706 .67482 L F
.4851 .69925 m .49003 .69175 L .49126 .68667 L F
.4893 .7232 m .48875 .72479 L .49001 .70894 L .803 .728 .781 r
F
.49001 .70894 m .48875 .72479 L .48362 .72444 L .839 .839 .846 r
F
.49706 .67482 m .48476 .71505 L .50452 .6922 L .275 .088 .437 r
F
.48201 .72528 m .48373 .71945 L .48798 .70025 L .701 .531 .655 r
F
.48373 .71945 m .48457 .71586 L .48798 .70025 L F
.47276 .76405 m .4789 .73914 L .48201 .72528 L F
.48875 .72479 m .48828 .73079 L .48362 .72444 L .839 .839 .846 r
F
.48362 .72444 m .48828 .73079 L .48421 .74385 L .872 .767 .743 r
F
.48476 .71505 m .48305 .72234 L .50452 .6922 L .275 .088 .437 r
F
.48421 .74385 m .48861 .73124 L .48753 .74323 L .872 .767 .743 r
F
.48861 .73124 m .49048 .73377 L .48753 .74323 L F
.47276 .76405 m .50077 .7082 L .49539 .7125 L .701 .531 .655 r
F
.4789 .73914 m .49539 .7125 L .48305 .72234 L F
.47276 .76405 m .49539 .7125 L .4789 .73914 L F
.50452 .6922 m .49539 .7125 L .49777 .70866 L .543 .335 .549 r
F
.48305 .72234 m .49539 .7125 L .50452 .6922 L .275 .088 .437 r
F
.50452 .6922 m .49993 .70516 L .50217 .70538 L .543 .335 .549 r
F
.50582 .69733 m .50217 .70538 L .508 .70595 L F
.50452 .6922 m .50217 .70538 L .50582 .69733 L F
.48584 .74082 m .46567 .7869 L .46939 .78364 L F
.46634 .7818 m .4866 .73923 L .47276 .76405 L .789 .613 .662 r
F
.4866 .73923 m .50199 .70579 L .47276 .76405 L F
.49157 .72879 m .50199 .70579 L .4866 .73923 L F
.4696 .78345 m .46645 .79131 L .46988 .78321 L .543 .335 .549 r
F
.48584 .74082 m .46939 .78364 L .49157 .72879 L F
.46939 .78364 m .46645 .79131 L .4696 .78345 L F
.48513 .74474 m .48753 .74323 L .4853 .74478 L .786 .975 .912 r
F
.46939 .78364 m .4696 .78345 L .49157 .72879 L .543 .335 .549 r
F
.48662 .76427 m .50779 .73478 L .47073 .78247 L .875 .71 .674 r
F
.49104 .75921 m .47073 .78247 L .47302 .78046 L F
.47073 .78247 m .50779 .73478 L .46988 .78321 L F
.50518 .71109 m .50779 .73478 L .5089 .70432 L .789 .613 .662 r
F
.50077 .7082 m .50199 .70579 L .50182 .70573 L .701 .531 .655 r
F
.50882 .70025 m .5089 .70432 L .50996 .70239 L .543 .335 .549 r
F
.51575 .65346 m .51674 .71229 L .51977 .70818 L .609 .514 .722 r
F
.5091 .69879 m .52171 .60882 L .50939 .69103 L .719 .599 .722 r
F
.51015 .69343 m .5091 .69879 L .51208 .70636 L .47 .41 .709 r
F
.5091 .69879 m .50882 .70025 L .50996 .70239 L F
.5091 .69879 m .50996 .70239 L .51208 .70636 L F
.5058 .68976 m .50452 .6922 L .50648 .69587 L F
.50826 .69586 m .50648 .69587 L .50882 .70025 L F
.5078 .69474 m .50648 .69587 L .50826 .69586 L F
.50798 .69408 m .50648 .69587 L .50808 .69451 L F
.50648 .69587 m .508 .70595 L .5089 .70432 L .543 .335 .549 r
F
.50648 .69587 m .5089 .70432 L .50882 .70025 L F
.50582 .69733 m .508 .70595 L .50648 .69587 L F
.50437 .7559 m .50619 .75174 L .51378 .72337 L .812 .687 .726 r
F
.51208 .70636 m .50911 .7139 L .51087 .73425 L .692 .491 .61 r
F
.50779 .73478 m .50918 .72214 L .50899 .71014 L .719 .599 .722 r
F
.50885 .70562 m .50899 .71014 L .5089 .70432 L F
.50779 .73478 m .50899 .71014 L .50885 .70562 L F
.50918 .72214 m .50912 .71526 L .50907 .71248 L F
.50899 .71014 m .50907 .71248 L .5089 .70432 L F
.50918 .72214 m .50907 .71248 L .50899 .71014 L F
.51208 .70636 m .50907 .71248 L .50907 .7128 L .692 .491 .61 r
F
.51208 .70636 m .50907 .7128 L .50911 .7139 L F
.50911 .7139 m .50932 .73705 L .51087 .73425 L F
.50894 .70605 m .511 .70855 L .51208 .70636 L .543 .335 .549 r
F
.49993 .70516 m .50897 .70793 L .50894 .70605 L F
.50897 .70793 m .511 .70855 L .50894 .70605 L F
.51455 .66215 m .51674 .71229 L .51575 .65346 L .609 .514 .722 r
F
.50077 .7082 m .50182 .70573 L .49539 .7125 L .701 .531 .655 r
F
.50768 .69443 m .50939 .69103 L .50766 .69439 L F
.50798 .69408 m .50839 .69579 L .50939 .69103 L .789 .613 .662 r
F
.50766 .69439 m .50939 .69103 L .50731 .69351 L .701 .531 .655 r
F
.50798 .69408 m .50939 .69103 L .50794 .69413 L .789 .613 .662 r
F
.50182 .70573 m .49993 .70516 L .49539 .7125 L .701 .531 .655 r
F
.48562 .74808 m .48629 .75591 L .48422 .74868 L .839 .839 .846 r
F
.49157 .72879 m .4696 .78345 L .48458 .74853 L .543 .335 .549 r
F
.4696 .78345 m .46988 .78321 L .48458 .74853 L F
.47664 .76015 m .46567 .7869 L .47764 .75805 L F
.47764 .75805 m .46567 .7869 L .48584 .74082 L F
.46607 .78591 m .46461 .78094 L .46567 .7869 L F
.46697 .77188 m .46669 .77632 L .47276 .76405 L .789 .547 .571 r
F
.46669 .77632 m .46634 .7818 L .46735 .77898 L F
.46669 .77632 m .46735 .77898 L .47276 .76405 L F
.46639 .77513 m .46461 .78094 L .46669 .77632 L .275 .088 .437 r
F
.46653 .77872 m .46461 .78094 L .46607 .78591 L .543 .335 .549 r
F
.47276 .76405 m .48798 .70025 L .47406 .75794 L .701 .531 .655 r
F
.46741 .76835 m .46697 .77188 L .47276 .76405 L .789 .547 .571 r
F
.45626 .77283 m .47385 .75891 L .45486 .77164 L .726 .492 .572 r
F
.46639 .77513 m .47021 .74657 L .46461 .78094 L .275 .088 .437 r
F
.47079 .74606 m .47021 .74657 L .46639 .77513 L F
.46718 .76854 m .46704 .77083 L .46741 .76835 L .789 .547 .571 r
F
.46704 .77083 m .46697 .77188 L .46741 .76835 L F
.44198 .78884 m .44244 .78879 L .45824 .77453 L .363 0 .14 r
F
.40054 .82326 m .46233 .79285 L .40204 .82101 L .846 .586 .546 r
F
.40278 .82305 m .46233 .79285 L .40054 .82326 L F
.45599 .77651 m .45824 .77453 L .41104 .8086 L .789 .547 .571 r
F
.41104 .8086 m .46651 .76856 L .46726 .76413 L .726 .492 .572 r
F
.42022 .79542 m .4318 .77955 L .43533 .77429 L .647 .417 .556 r
F
.40335 .80886 m .40204 .82101 L .41104 .8086 L .736 .315 .248 r
F
.40438 .80518 m .40203 .80687 L .40136 .81595 L .363 0 .14 r
F
.40001 .82075 m .40204 .82101 L .40335 .80886 L .736 .315 .248 r
F
.40203 .80687 m .39687 .8176 L .39816 .82076 L .363 0 .14 r
F
.40041 .81645 m .39816 .82076 L .39968 .82075 L F
.40203 .80687 m .40034 .81294 L .40041 .81645 L F
.40034 .81294 m .39816 .82076 L .40041 .81645 L F
.40049 .82074 m .40204 .82101 L .40001 .82075 L .764 .294 .128 r
F
.40049 .82074 m .40054 .82326 L .40204 .82101 L F
.40203 .80687 m .39924 .82338 L .40081 .82323 L .363 0 .14 r
F
.39837 .80903 m .40335 .80886 L .39828 .80914 L .736 .315 .248 r
F
.4006 .80628 m .40215 .80662 L .40482 .80109 L .685 .288 .29 r
F
.40982 .79713 m .40576 .7985 L .39672 .80964 L 0 0 0 r
F
.39739 .80947 m .39672 .80964 L .39465 .81219 L F
.40982 .79713 m .39672 .80964 L .39739 .80947 L F
.42402 .78304 m .40576 .7985 L .40982 .79713 L F
.41661 .78657 m .41468 .7875 L .4095 .79533 L F
.41468 .7875 m .40356 .79753 L .39767 .80722 L F
.41468 .7875 m .39767 .80722 L .3961 .80979 L F
.39672 .80964 m .3961 .80979 L .39465 .81219 L F
.41468 .7875 m .3961 .80979 L .39672 .80964 L F
.40335 .80886 m .40095 .80913 L .39817 .80927 L .736 .315 .248 r
F
.32703 .8062 m .31712 .809 L .33045 .80675 L .571 .935 .92 r
F
.33207 .80702 m .31712 .809 L .31702 .80881 L .181 .715 .778 r
F
.32207 .80764 m .31702 .80881 L .31657 .80798 L F
.33207 .80702 m .31702 .80881 L .32207 .80764 L F
.26156 .78774 m .27114 .79036 L .26985 .78963 L .517 0 0 r
F
.25834 .78223 m .3269 .80457 L .26156 .78774 L .539 0 0 r
F
.3269 .80457 m .32698 .80562 L .26156 .78774 L F
.28006 .78931 m .32536 .80699 L .3294 .80684 L F
.28006 .78931 m .32244 .80437 L .3269 .80457 L F
.25834 .78223 m .28428 .79191 L .28006 .78931 L F
.28428 .79191 m .32477 .80701 L .28006 .78931 L F
.33207 .80702 m .31657 .80798 L .31622 .80733 L .181 .715 .778 r
F
.33207 .80702 m .31622 .80733 L .32914 .80685 L F
.32477 .80701 m .33909 .81235 L .32536 .80699 L .539 0 0 r
F
.32477 .80701 m .32536 .80699 L .28006 .78931 L F
.32637 .80665 m .32477 .80701 L .31738 .80426 L .52 0 0 r
F
.32107 .80474 m .31738 .80426 L .25834 .78223 L F
.32637 .80665 m .31738 .80426 L .32107 .80474 L F
.25682 .77571 m .31912 .80342 L .25834 .78223 L F
.31912 .80342 m .32192 .80505 L .25834 .78223 L F
.31912 .80342 m .32637 .80665 L .32192 .80505 L F
.25675 .77541 m .25947 .77663 L .25682 .77571 L F
.25947 .77663 m .32637 .80665 L .25682 .77571 L F
.25675 .77541 m .32044 .80653 L .32637 .80665 L F
.26585 .77567 m .27596 .78275 L .26791 .77702 L .836 .368 .065 r
F
.25718 .76715 m .30346 .79493 L .25675 .77541 L .434 0 0 r
F
.30346 .79493 m .32215 .80615 L .26235 .77804 L F
.30346 .79493 m .26235 .77804 L .25675 .77541 L F
.33343 .80669 m .33266 .80688 L .32698 .80562 L .539 0 0 r
F
.33494 .80664 m .33207 .80702 L .33343 .80669 L .181 .715 .778 r
F
.32698 .80562 m .33207 .80702 L .3273 .80562 L .517 0 0 r
F
.33207 .80702 m .33177 .80686 L .3273 .80562 L F
.33676 .80778 m .33207 .80702 L .32698 .80562 L .539 0 0 r
F
.3269 .80457 m .33184 .80675 L .33343 .80669 L F
.33343 .80669 m .33207 .80702 L .32914 .80685 L .181 .715 .778 r
F
.33676 .80778 m .34666 .81101 L .33207 .80702 L .539 0 0 r
F
.32244 .80437 m .34296 .81166 L .3269 .80457 L F
.34986 .80275 m .33343 .80669 L .32288 .80634 L .181 .715 .778 r
F
.32215 .80615 m .32044 .80653 L .31794 .8053 L .434 0 0 r
F
.32134 .80577 m .31794 .8053 L .25675 .77541 L F
.32215 .80615 m .31794 .8053 L .32134 .80577 L F
.3294 .80684 m .33909 .81235 L .34296 .81166 L .539 0 0 r
F
.37321 .7955 m .3554 .80392 L .37449 .80139 L .571 .935 .92 r
F
.37292 .80051 m .36428 .8026 L .35885 .80188 L .181 .715 .778 r
F
.37363 .8009 m .38464 .79725 L .37449 .80139 L .613 .221 .277 r
F
.3742 .80123 m .36428 .8026 L .37292 .80051 L .181 .715 .778 r
F
.34666 .81101 m .37449 .80139 L .36541 .80273 L .502 .096 .203 r
F
.38464 .79725 m .39175 .79528 L .37449 .80139 L .613 .221 .277 r
F
.40866 .78929 m .41024 .78903 L .37449 .80139 L F
.37449 .80139 m .33494 .80664 L .39499 .79836 L .181 .715 .778 r
F
.33343 .80669 m .33676 .80778 L .33266 .80688 L .539 0 0 r
F
.33343 .80669 m .34296 .81166 L .33676 .80778 L F
.33184 .80675 m .34296 .81166 L .33343 .80669 L F
.34033 .8065 m .34666 .81101 L .3431 .80633 L .517 0 0 r
F
.33676 .80778 m .34296 .81166 L .34666 .81101 L .539 0 0 r
F
.33909 .81235 m .37363 .8009 L .37449 .80139 L .613 .221 .277 r
F
.39499 .79836 m .3742 .80123 L .37363 .8009 L .181 .715 .778 r
F
.39499 .79836 m .37363 .8009 L .38614 .79922 L F
.40356 .79753 m .37449 .80139 L .39499 .79836 L F
.38466 .80297 m .38891 .80024 L .39578 .80107 L .721 .988 .872 r
F
.38891 .80024 m .39781 .79963 L .39578 .80107 L F
.39499 .79836 m .38614 .79922 L .38987 .80181 L .181 .715 .778 r
F
.39573 .8008 m .38987 .80181 L .39767 .80722 L F
.39499 .79836 m .38987 .80181 L .39573 .8008 L F
.38987 .80181 m .3921 .80704 L .39767 .80722 L F
.38421 .80294 m .38466 .80297 L .38532 .80286 L .292 0 0 r
F
.38466 .80297 m .38792 .80071 L .38816 .80072 L .721 .988 .872 r
F
.38614 .79922 m .38832 .80208 L .38987 .80181 L .181 .715 .778 r
F
.38832 .80208 m .3921 .80704 L .38987 .80181 L F
.34296 .81166 m .37449 .80139 L .34666 .81101 L .613 .221 .277 r
F
.33909 .81235 m .37449 .80139 L .34296 .81166 L F
.33915 .81233 m .33958 .81224 L .36448 .80643 L F
.33958 .81224 m .38831 .80207 L .36448 .80643 L F
.38831 .80207 m .38814 .80184 L .36448 .80643 L F
.40356 .79753 m .39499 .79836 L .39573 .8008 L .181 .715 .778 r
F
.40226 .79967 m .39573 .8008 L .39767 .80722 L F
.40356 .79753 m .39573 .8008 L .40226 .79967 L F
.36448 .80643 m .40623 .79834 L .40798 .79629 L .613 .221 .277 r
F
.38831 .80207 m .40623 .79834 L .38814 .80184 L F
.38832 .80208 m .40623 .79834 L .38831 .80207 L F
.40737 .79796 m .40623 .79834 L .38832 .80208 L .685 .288 .29 r
F
.33919 .81233 m .38832 .80208 L .33915 .81233 L .613 .221 .277 r
F
.38832 .80208 m .38831 .80207 L .33915 .81233 L F
.38561 .80254 m .38832 .80208 L .33909 .81235 L .685 .288 .29 r
F
.33915 .81233 m .38754 .80106 L .37363 .8009 L .613 .221 .277 r
F
.38754 .80106 m .40798 .79629 L .38614 .79922 L F
.38754 .80106 m .38614 .79922 L .37363 .8009 L F
.32914 .80685 m .31694 .80731 L .32024 .80657 L .181 .715 .778 r
F
.32914 .80685 m .31574 .80643 L .32495 .80662 L F
.32536 .80699 m .33909 .81235 L .3294 .80684 L .539 0 0 r
F
.33343 .80669 m .32914 .80685 L .31556 .80609 L .181 .715 .778 r
F
.32637 .80665 m .33909 .81235 L .32477 .80701 L .52 0 0 r
F
.32637 .80665 m .33298 .81265 L .33909 .81235 L F
.33909 .81235 m .33919 .81233 L .33915 .81233 L .613 .221 .277 r
F
.33298 .81265 m .37406 .80454 L .33909 .81235 L .685 .288 .29 r
F
.37406 .80454 m .38189 .80319 L .33909 .81235 L F
.38189 .80319 m .38561 .80254 L .33909 .81235 L F
.39767 .80722 m .39218 .80714 L .39526 .81118 L .181 .715 .778 r
F
.35415 .80847 m .38131 .81014 L .37406 .80454 L .685 .288 .29 r
F
.33298 .81265 m .37472 .81049 L .35415 .80847 L F
.37472 .81049 m .38131 .81014 L .35415 .80847 L F
.37817 .81022 m .38131 .81014 L .37472 .81049 L .736 .315 .248 r
F
.37374 .81046 m .37472 .81049 L .33298 .81265 L F
.37817 .81022 m .37472 .81049 L .37374 .81046 L F
.39218 .80714 m .35109 .80658 L .38459 .81007 L .181 .715 .778 r
F
.39424 .80984 m .38459 .81007 L .39526 .81118 L F
.39218 .80714 m .38459 .81007 L .39424 .80984 L F
.38459 .81007 m .38068 .80966 L .38131 .81014 L F
.38464 .79725 m .40866 .78929 L .39175 .79528 L .613 .221 .277 r
F
.37363 .8009 m .40798 .79629 L .41605 .78684 L F
.38614 .79922 m .37363 .8009 L .37292 .80051 L .181 .715 .778 r
F
.38614 .79922 m .36932 .80086 L .3921 .80704 L F
.27024 .77499 m .31963 .8055 L .32019 .80564 L .434 0 0 r
F
.30346 .79493 m .32019 .80564 L .32215 .80615 L F
.27024 .77499 m .32019 .80564 L .30346 .79493 L F
.34986 .80275 m .32918 .8055 L .32773 .80491 L .181 .715 .778 r
F
.32564 .80597 m .32288 .80634 L .32019 .80564 L F
.32773 .80491 m .32019 .80564 L .33114 .80631 L F
.32019 .80564 m .32288 .80634 L .31556 .80609 L F
.32019 .80564 m .31556 .80609 L .32101 .80617 L F
.32495 .80662 m .31574 .80643 L .31556 .80609 L F
.32044 .80653 m .33298 .81265 L .32637 .80665 L .52 0 0 r
F
.32215 .80615 m .33298 .81265 L .32044 .80653 L .434 0 0 r
F
.32215 .80615 m .32918 .81139 L .33298 .81265 L F
.32158 .806 m .32918 .81139 L .32215 .80615 L F
.32163 .80656 m .32918 .81139 L .32158 .806 L F
.32164 .80673 m .32906 .81132 L .32163 .80656 L F
.32906 .81132 m .32918 .81139 L .32163 .80656 L F
.37302 .81044 m .37374 .81046 L .33298 .81265 L .736 .315 .248 r
F
.36932 .80086 m .37663 .80652 L .3921 .80704 L .181 .715 .778 r
F
.36428 .8026 m .33494 .80664 L .35885 .80188 L F
.33494 .80664 m .33343 .80669 L .34986 .80275 L F
.32773 .80491 m .33114 .80631 L .39218 .80714 L F
.32773 .80491 m .39218 .80714 L .3921 .80704 L F
.38131 .81014 m .39817 .80927 L .37406 .80454 L .685 .288 .29 r
F
.38131 .81014 m .35803 .8073 L .37963 .81018 L .181 .715 .778 r
F
.38068 .80966 m .35803 .8073 L .38131 .81014 L F
.35803 .8073 m .35746 .8074 L .37916 .8102 L F
.37963 .81018 m .37916 .8102 L .39465 .81219 L F
.35803 .8073 m .37916 .8102 L .37963 .81018 L F
.37601 .81027 m .37374 .81046 L .37302 .81044 L .736 .315 .248 r
F
.3776 .81023 m .37374 .81046 L .37601 .81027 L F
.3776 .81023 m .37817 .81022 L .37374 .81046 L F
.35109 .80658 m .34475 .80834 L .37124 .81038 L .181 .715 .778 r
F
.32949 .81138 m .37124 .81038 L .33298 .81265 L .736 .315 .248 r
F
.37124 .81038 m .37601 .81027 L .37302 .81044 L F
.37124 .81038 m .37302 .81044 L .33298 .81265 L F
.35109 .80658 m .37124 .81038 L .37916 .8102 L .181 .715 .778 r
F
.40737 .79796 m .38832 .80208 L .38561 .80254 L .685 .288 .29 r
F
.3921 .80704 m .39218 .80714 L .39767 .80722 L .181 .715 .778 r
F
.37406 .80454 m .39366 .80066 L .38189 .80319 L .685 .288 .29 r
F
.39366 .80066 m .39719 .8001 L .38561 .80254 L F
.39366 .80066 m .38561 .80254 L .38189 .80319 L F
.39366 .80066 m .40737 .79796 L .39719 .8001 L F
.37406 .80454 m .39817 .80927 L .40737 .79796 L F
.37124 .81038 m .39837 .80903 L .37601 .81027 L .736 .315 .248 r
F
.32949 .81138 m .36448 .81019 L .37124 .81038 L F
.37124 .81038 m .35326 .809 L .36955 .81034 L .149 0 0 r
F
.32918 .81139 m .32949 .81138 L .33298 .81265 L .736 .315 .248 r
F
.32918 .81139 m .39613 .82023 L .38904 .81298 L F
.39465 .81219 m .38825 .81217 L .39613 .82023 L .149 0 0 r
F
.39465 .81219 m .39613 .82023 L .39816 .82076 L F
.32918 .81139 m .40209 .81333 L .36448 .81019 L .736 .315 .248 r
F
.32024 .80657 m .31622 .80733 L .31574 .80643 L .181 .715 .778 r
F
.31694 .80731 m .31622 .80733 L .32024 .80657 L F
.32164 .80676 m .31556 .80609 L .32168 .8072 L .149 0 0 r
F
.32164 .80669 m .31997 .80653 L .32164 .80676 L F
.31997 .80653 m .31556 .80609 L .32164 .80676 L F
.2701 .77491 m .27039 .77509 L .27024 .77499 L .434 0 0 r
F
.26459 .77171 m .27039 .77509 L .2701 .77491 L F
.32123 .8063 m .31556 .80609 L .32163 .80656 L .181 .715 .778 r
F
.32163 .80656 m .31556 .80609 L .32164 .80669 L .149 0 0 r
F
.32019 .80564 m .32163 .80656 L .32158 .806 L .434 0 0 r
F
.34605 .80651 m .32101 .80617 L .34841 .80732 L .181 .715 .778 r
F
.32101 .80617 m .31556 .80609 L .32123 .8063 L F
.32101 .80617 m .32123 .8063 L .34841 .80732 L F
.31963 .8055 m .32164 .80673 L .32163 .80656 L .434 0 0 r
F
.31963 .8055 m .32163 .80656 L .32019 .80564 L F
.26459 .77171 m .32918 .81139 L .27039 .77509 L F
.3236 .80703 m .32918 .81139 L .32164 .80676 L 0 .243 .707 r
F
.33433 .80907 m .37959 .81705 L .32883 .80853 L .764 .294 .128 r
F
.37959 .81705 m .39304 .81943 L .38044 .81729 L F
.37959 .81705 m .38044 .81729 L .32883 .80853 L F
.33433 .80907 m .33574 .80957 L .33708 .80956 L F
.35412 .80989 m .3228 .8068 L .33326 .80901 L .149 0 0 r
F
.3228 .8068 m .32164 .80669 L .32415 .80719 L F
.3228 .8068 m .32415 .80719 L .33326 .80901 L F
.3236 .80703 m .32883 .80853 L .32918 .81139 L 0 .243 .707 r
F
.32164 .80669 m .32168 .8072 L .32927 .80857 L .149 0 0 r
F
.32164 .80669 m .32927 .80857 L .33062 .80871 L F
.32883 .80853 m .39304 .81943 L .32918 .81139 L .764 .294 .128 r
F
.39304 .81943 m .39564 .8201 L .32918 .81139 L F
.39816 .82076 m .39613 .82023 L .39926 .82343 L .149 0 0 r
F
.39926 .82343 m .39923 .82342 L .40056 .82661 L F
.39923 .82342 m .39657 .82283 L .39916 .82528 L F
.39923 .82342 m .39916 .82528 L .40056 .82661 L F
.39916 .82528 m .40046 .82658 L .40056 .82661 L F
.39657 .82283 m .39916 .82532 L .39916 .82528 L F
.39916 .82532 m .40046 .82658 L .39916 .82528 L F
.39506 .83146 m .39901 .82919 L .39901 .82614 L .846 .586 .546 r
F
.39506 .83146 m .39901 .82614 L .39872 .82598 L F
.40056 .82661 m .39913 .82621 L .40053 .827 L .356 0 0 r
F
.39872 .82598 m .39901 .82614 L .39901 .82555 L .846 .586 .546 r
F
.39901 .82919 m .39915 .82548 L .39901 .82555 L F
.39901 .82555 m .39915 .82548 L .39916 .82532 L F
.38904 .81298 m .40001 .82075 L .40209 .81333 L .736 .315 .248 r
F
.39613 .82023 m .40001 .82075 L .38904 .81298 L F
.40049 .82074 m .40001 .82075 L .39613 .82023 L .764 .294 .128 r
F
.39564 .8201 m .39613 .82023 L .32918 .81139 L F
.38825 .81217 m .38551 .81217 L .39613 .82023 L .149 0 0 r
F
.38551 .81217 m .39304 .81943 L .39613 .82023 L F
.40049 .82074 m .39613 .82023 L .39564 .8201 L .764 .294 .128 r
F
.33744 .80962 m .396 .82228 L .39304 .81943 L F
.33304 .809 m .39916 .82532 L .39603 .82231 L F
.33304 .809 m .39506 .83146 L .39916 .82532 L F
.33098 .80887 m .39506 .83146 L .33304 .809 L F
.33574 .80957 m .39603 .82231 L .33708 .80956 L F
.39603 .82231 m .396 .82228 L .33708 .80956 L F
.39613 .82023 m .39339 .81976 L .39926 .82343 L .149 0 0 r
F
.3374 .80963 m .396 .82228 L .33744 .80962 L .764 .294 .128 r
F
.396 .82228 m .396 .82228 L .33744 .80962 L F
.33326 .80901 m .33321 .80915 L .33485 .80933 L .149 0 0 r
F
.34572 .81075 m .3733 .82232 L .33098 .80887 L .718 .185 0 r
F
.3733 .82232 m .39506 .83146 L .37575 .82465 L F
.3733 .82232 m .37575 .82465 L .33098 .80887 L F
.35412 .80989 m .33326 .80901 L .34191 .80953 L .149 0 0 r
F
.35708 .81367 m .39506 .83146 L .34572 .81075 L .718 .185 0 r
F
.35708 .81367 m .34572 .81075 L .35038 .81134 L F
.35412 .80989 m .33485 .80933 L .33538 .80943 L .149 0 0 r
F
.35042 .81135 m .33538 .80943 L .3436 .81107 L F
.34765 .81162 m .3436 .81107 L .34676 .8117 L F
.35042 .81135 m .3436 .81107 L .34765 .81162 L F
.33708 .80956 m .3374 .80963 L .33744 .80962 L .764 .294 .128 r
F
.35412 .80989 m .33538 .80943 L .35042 .81135 L .149 0 0 r
F
.36123 .81167 m .35412 .80989 L .35042 .81135 L F
.37706 .81214 m .35904 .81037 L .36123 .81167 L F
.35904 .81037 m .35412 .80989 L .36123 .81167 L F
.34819 .81169 m .39282 .83898 L .35008 .81167 L .718 .185 0 r
F
.3492 .81182 m .39282 .83898 L .34819 .81169 L 0 .082 .565 r
F
.35274 .81164 m .35708 .81367 L .35038 .81134 L .718 .185 0 r
F
.35497 .81316 m .39282 .83898 L .35657 .81344 L F
.35657 .81344 m .39282 .83898 L .39506 .83146 L F
.35008 .81167 m .39282 .83898 L .35274 .81164 L F
.39916 .82532 m .39913 .8262 L .40046 .82658 L .149 0 0 r
F
.40081 .82323 m .39924 .82338 L .40056 .82661 L .363 0 .14 r
F
.40261 .82307 m .40081 .82323 L .4006 .82607 L F
.40065 .82651 m .40295 .82304 L .40056 .82661 L F
.40295 .82304 m .40292 .82304 L .40056 .82661 L F
.4528 .79832 m .46233 .79285 L .40793 .82095 L .846 .586 .546 r
F
.4528 .79832 m .40793 .82095 L .40944 .82027 L F
.40292 .82304 m .40292 .82304 L .40056 .82661 L .363 0 .14 r
F
.4528 .79832 m .40419 .82292 L .4042 .82292 L .846 .586 .546 r
F
.40793 .82095 m .46233 .79285 L .40278 .82305 L F
.40793 .82095 m .40278 .82305 L .40332 .823 L F
.40407 .82294 m .40793 .82095 L .40332 .823 L F
.46158 .76484 m .43273 .78496 L .40336 .823 L .363 0 .14 r
F
.4042 .82292 m .40336 .823 L .40065 .82651 L F
.40944 .82027 m .40793 .82095 L .40407 .82294 L .846 .586 .546 r
F
.40944 .82027 m .40407 .82294 L .40419 .82292 L F
.46158 .76484 m .40336 .823 L .4042 .82292 L .363 0 .14 r
F
.46117 .74881 m .47858 .73672 L .45676 .74536 L .647 .417 .556 r
F
.46889 .7427 m .47201 .72446 L .46652 .753 L 0 0 .088 r
F
.4734 .72316 m .47248 .72402 L .46889 .7427 L F
.47248 .72402 m .47201 .72446 L .46889 .7427 L F
.46997 .74588 m .46652 .753 L .47021 .74657 L F
.46767 .748 m .46652 .753 L .46997 .74588 L F
.46652 .753 m .46751 .75377 L .47021 .74657 L F
.46785 .74814 m .46741 .76323 L .4704 .74543 L .726 .492 .572 r
F
.46652 .753 m .46446 .76192 L .46751 .75377 L 0 0 .088 r
F
.45351 .7634 m .43694 .78104 L .45774 .76659 L 0 0 0 r
F
.4318 .77955 m .45128 .76171 L .44712 .75857 L .647 .417 .556 r
F
.448 .75924 m .43694 .78104 L .45351 .7634 L 0 0 0 r
F
.44625 .75902 m .44612 .75885 L .43011 .78028 L .527 .3 .513 r
F
.42874 .78264 m .43057 .78017 L .43011 .78028 L F
.448 .75924 m .4006 .80628 L .43694 .78104 L 0 0 0 r
F
.46446 .76192 m .45785 .76668 L .46158 .76484 L .363 0 .14 r
F
.4006 .80628 m .40203 .80687 L .46446 .76192 L 0 0 0 r
F
.43306 .78453 m .46785 .74814 L .45268 .76277 L .726 .492 .572 r
F
.41889 .80024 m .43032 .78808 L .43306 .78453 L F
.45785 .76668 m .43306 .78453 L .46158 .76484 L .363 0 .14 r
F
.43306 .78453 m .43273 .78496 L .46158 .76484 L F
.43032 .78808 m .46785 .74814 L .43306 .78453 L .726 .492 .572 r
F
.43306 .78453 m .42417 .79093 L .43273 .78496 L .363 0 .14 r
F
.43032 .78808 m .46459 .76512 L .46785 .74814 L .726 .492 .572 r
F
.46459 .76512 m .46741 .76323 L .46785 .74814 L F
.43273 .78496 m .42417 .79093 L .40295 .82304 L .363 0 .14 r
F
.40336 .823 m .40295 .82304 L .40065 .82651 L F
.43273 .78496 m .40295 .82304 L .40336 .823 L F
.35252 .81295 m .3532 .81336 L .40046 .82658 L .149 0 0 r
F
.4042 .82292 m .40056 .82661 L .4052 .82242 L .363 0 .14 r
F
.44244 .78879 m .40056 .82661 L .45405 .78763 L F
.40292 .82304 m .4006 .82607 L .40056 .82661 L F
.42417 .79093 m .40261 .82307 L .40292 .82304 L F
.40261 .82307 m .4006 .82607 L .40292 .82304 L F
.40946 .82026 m .40056 .82661 L .41026 .8199 L .61 .236 .308 r
F
.4646 .77994 m .40883 .82058 L .46461 .78094 L .363 0 .14 r
F
.40883 .82058 m .40056 .82661 L .40946 .82026 L F
.40883 .82058 m .40946 .82026 L .46461 .78094 L F
.41026 .8199 m .40056 .82661 L .44682 .80356 L .61 .236 .308 r
F
.48064 .80638 m .47788 .81044 L .47554 .81784 L .808 .634 .665 r
F
.47788 .81044 m .4744 .81558 L .4754 .81758 L F
.47788 .81044 m .4754 .81758 L .47554 .81784 L F
.48483 .79042 m .47788 .81044 L .49368 .78034 L .953 .819 .675 r
F
.48913 .78728 m .47138 .80955 L .4744 .81558 L .808 .634 .665 r
F
.52201 .73787 m .58171 .64862 L .54146 .73365 L .794 .728 .79 r
F
.54146 .73365 m .60896 .64054 L .56108 .72766 L .799 .757 .815 r
F
.54146 .73365 m .58171 .64862 L .60896 .64054 L F
.54362 .72827 m .53589 .74128 L .56122 .73085 L .92 .85 .758 r
F
.53589 .74128 m .52741 .76848 L .56122 .73085 L F
.56122 .73085 m .53073 .77631 L .58444 .73387 L .897 .854 .792 r
F
.52862 .77794 m .53053 .777 L .53073 .77631 L .814 .762 .804 r
F
.52982 .77766 m .48868 .82073 L .50222 .81881 L .897 .854 .792 r
F
.52676 .7805 m .48868 .82073 L .52982 .77766 L F
.49964 .80284 m .52982 .77766 L .51305 .78558 L .88 .959 .848 r
F
.52982 .77766 m .52862 .77794 L .51305 .78558 L F
.56122 .73085 m .53401 .76457 L .53073 .77631 L .897 .854 .792 r
F
.53073 .77631 m .58092 .73751 L .58444 .73387 L F
.51305 .78558 m .52862 .77794 L .58086 .73679 L .814 .762 .804 r
F
.51305 .78558 m .58086 .73679 L .52741 .76848 L F
.49922 .80298 m .48868 .82073 L .50443 .80122 L .92 .85 .758 r
F
.51305 .78558 m .52741 .76848 L .53956 .72949 L .814 .762 .804 r
F
.53963 .727 m .5365 .732 L .53977 .729 L .896 .772 .717 r
F
.53963 .727 m .53977 .729 L .53984 .72889 L F
.54012 .72716 m .53984 .72894 L .54135 .72755 L F
.53963 .727 m .53984 .72894 L .54012 .72716 L F
.49024 .80604 m .51305 .78558 L .53985 .72887 L .92 .842 .75 r
F
.53956 .72949 m .53865 .73573 L .53985 .72887 L .814 .762 .804 r
F
.53865 .73573 m .53887 .73528 L .53985 .72887 L F
.54362 .72827 m .53887 .73528 L .53589 .74128 L .92 .85 .758 r
F
.52741 .76848 m .53521 .75919 L .53956 .72949 L .814 .762 .804 r
F
.5365 .732 m .49011 .8061 L .54135 .72755 L .896 .772 .717 r
F
.49011 .8061 m .4806 .8213 L .49058 .80589 L F
.50381 .79405 m .51305 .78558 L .50343 .79421 L .793 .955 .624 r
F
.51046 .78864 m .51305 .78558 L .49122 .80561 L F
.51554 .77551 m .50475 .79368 L .52741 .76848 L .92 .85 .758 r
F
.50695 .7928 m .49964 .80284 L .51305 .78558 L .793 .955 .624 r
F
.50475 .79368 m .49922 .80298 L .50783 .79245 L .92 .85 .758 r
F
.50475 .79368 m .4806 .8213 L .48868 .82073 L F
.49177 .80513 m .4806 .8213 L .50475 .79368 L F
.49122 .80561 m .50381 .79405 L .49024 .80604 L .793 .955 .624 r
F
.50381 .79405 m .50343 .79421 L .49024 .80604 L F
.53887 .73528 m .49122 .80561 L .53589 .74128 L .92 .85 .758 r
F
.49122 .80561 m .4806 .8213 L .49177 .80513 L F
.49122 .80561 m .49177 .80513 L .53589 .74128 L F
.54135 .72755 m .4806 .8213 L .54362 .72827 L .896 .772 .717 r
F
.51033 .76337 m .4806 .8213 L .53963 .727 L F
.49368 .78034 m .53307 .73514 L .50033 .76515 L .812 .687 .726 r
F
.48811 .79096 m .51438 .75659 L .49368 .78034 L .92 .842 .75 r
F
.47855 .80917 m .50661 .76799 L .48811 .79096 L F
.50661 .76799 m .51438 .75659 L .48811 .79096 L F
.48064 .80638 m .51438 .75659 L .47855 .80917 L F
.51033 .76337 m .47554 .81784 L .4806 .8213 L .896 .772 .717 r
F
.49466 .78665 m .47554 .81784 L .51033 .76337 L F
.50033 .76515 m .51763 .7487 L .50437 .7559 L .812 .687 .726 r
F
.51763 .7487 m .51835 .74481 L .50437 .7559 L F
.53049 .72409 m .51835 .74481 L .5175 .74941 L .896 .772 .717 r
F
.53049 .72409 m .5175 .74941 L .53963 .727 L F
.48814 .79634 m .47554 .81784 L .49466 .78665 L F
.48064 .80638 m .47554 .81784 L .48814 .79634 L .808 .634 .665 r
F
.54113 .72617 m .53963 .727 L .54081 .72738 L .722 .627 .751 r
F
.54121 .72585 m .54109 .72594 L .54113 .72617 L F
.54109 .72594 m .53963 .727 L .54113 .72617 L F
.53586 .68971 m .54456 .67511 L .53816 .69994 L .743 .634 .739 r
F
.52279 .61668 m .55611 .63022 L .55002 .65387 L F
.53333 .65684 m .52957 .63033 L .53822 .62386 L .699 .548 .679 r
F
.52914 .61597 m .55611 .63022 L .52279 .61668 L .743 .634 .739 r
F
.55611 .63022 m .55835 .6413 L .55531 .64742 L F
.5541 .64576 m .55531 .64742 L .55339 .65127 L F
.55611 .63022 m .55531 .64742 L .5541 .64576 L F
.53333 .65684 m .53822 .62386 L .55608 .65379 L .699 .548 .679 r
F
.51786 .63848 m .52012 .70773 L .5238 .67581 L .609 .514 .722 r
F
.52012 .70773 m .52042 .71698 L .52131 .70619 L F
.52012 .70773 m .52131 .70619 L .5238 .67581 L F
.51575 .65346 m .51977 .70818 L .51786 .63848 L F
.51977 .70818 m .52042 .71698 L .52012 .70773 L F
.51977 .70818 m .52012 .70773 L .51786 .63848 L F
.52044 .62023 m .54484 .66341 L .52171 .60882 L .719 .599 .722 r
F
.52059 .62271 m .54484 .66341 L .52044 .62023 L F
.53018 .69198 m .52042 .71698 L .53049 .72409 L .683 .581 .735 r
F
.52044 .62023 m .52171 .60882 L .51525 .65698 L .719 .599 .722 r
F
.50996 .6944 m .52171 .60882 L .5091 .69879 L F
.51336 .67034 m .52171 .60882 L .50996 .6944 L F
.51041 .69207 m .51336 .67034 L .50996 .6944 L F
.50939 .69103 m .51723 .60442 L .51267 .61167 L .627 .537 .734 r
F
.51525 .65698 m .52171 .60882 L .51336 .67034 L .719 .599 .722 r
F
.51187 .60086 m .5133 .60982 L .51568 .60289 L .609 .514 .722 r
F
.51481 .60208 m .51568 .60289 L .51582 .60249 L F
.51187 .60086 m .51568 .60289 L .51481 .60208 L F
.45864 .53163 m .46432 .53047 L .46058 .53753 L 0 0 0 r
F
.46432 .53047 m .46506 .53116 L .46058 .53753 L F
.46206 .53566 m .46539 .53146 L .46449 .53375 L F
.45559 .53512 m .478 .53501 L .45627 .53589 L .455 .123 .313 r
F
.44628 .53746 m .43824 .54197 L .43844 .54176 L F
.43844 .54176 m .45864 .53163 L .43736 .54287 L 0 0 0 r
F
.45559 .53512 m .45627 .53589 L .44368 .5364 L .455 .123 .313 r
F
.44072 .53519 m .45559 .53512 L .44368 .5364 L F
.46449 .53375 m .47206 .52643 L .47043 .52907 L 0 0 0 r
F
.46432 .53047 m .46575 .53018 L .46506 .53116 L F
.46539 .53146 m .46663 .53053 L .46449 .53375 L F
.46449 .53375 m .46785 .5296 L .46922 .52917 L F
.45222 .53514 m .46953 .52912 L .46279 .53509 L .455 .123 .313 r
F
.47962 .52788 m .50192 .55612 L .47867 .52864 L .523 .324 .553 r
F
.51093 .55837 m .5152 .56256 L .50466 .55908 L F
.49648 .56585 m .48967 .54288 L .50018 .55424 L .543 .31 .512 r
F
.50326 .55757 m .50466 .55908 L .4986 .55708 L .523 .324 .553 r
F
.51093 .55837 m .50466 .55908 L .50326 .55757 L F
.50018 .55424 m .48541 .52851 L .50551 .53752 L .543 .31 .512 r
F
.48967 .54288 m .48541 .52851 L .50018 .55424 L F
.49541 .55603 m .49921 .55728 L .49361 .55617 L .65 .463 .618 r
F
.49921 .55728 m .50466 .55908 L .49361 .55617 L F
.48413 .55691 m .48468 .54484 L .48415 .55693 L .608 .314 .444 r
F
.48468 .54484 m .4847 .54483 L .48416 .55694 L F
.48413 .55691 m .48474 .55739 L .4815 .55712 L .65 .463 .618 r
F
.47621 .57687 m .46666 .54985 L .48215 .58129 L .68 .316 .35 r
F
.48061 .58033 m .4845 .58229 L .48074 .5807 L .732 .556 .654 r
F
.47621 .57687 m .48215 .58129 L .48022 .58048 L .68 .316 .35 r
F
.47991 .57848 m .48267 .58077 L .48061 .58033 L .732 .556 .654 r
F
.48267 .58077 m .4845 .58229 L .48061 .58033 L F
.48415 .55693 m .48416 .55694 L .48311 .58086 L .608 .314 .444 r
F
.48311 .58086 m .48311 .58086 L .48302 .58293 L F
.48415 .55693 m .48311 .58086 L .48311 .58086 L F
.48468 .54484 m .48416 .55694 L .48415 .55693 L F
.49361 .55617 m .50466 .55908 L .48474 .55739 L .65 .463 .618 r
F
.49361 .55617 m .48474 .55739 L .48413 .55691 L F
.48297 .58265 m .48413 .55691 L .48302 .58293 L .608 .314 .444 r
F
.48413 .55691 m .48415 .55693 L .48302 .58293 L F
.48474 .55739 m .49678 .56688 L .49169 .57193 L .65 .463 .618 r
F
.48302 .58293 m .48416 .55694 L .50072 .58018 L .608 .314 .444 r
F
.50052 .59398 m .48871 .58205 L .50072 .58018 L .784 .572 .613 r
F
.50052 .59398 m .50072 .58018 L .50224 .5941 L F
.48306 .58085 m .48285 .58046 L .48413 .55691 L .608 .314 .444 r
F
.48285 .58046 m .4815 .55712 L .48413 .55691 L F
.50224 .5941 m .50072 .58018 L .50314 .59416 L .784 .572 .613 r
F
.46648 .56072 m .46666 .54985 L .47621 .57687 L .68 .316 .35 r
F
.46429 .55709 m .47644 .54978 L .47892 .5703 L .627 .339 .461 r
F
.45778 .54627 m .47644 .54978 L .46429 .55709 L F
.46081 .5457 m .47644 .54978 L .45026 .54442 L .455 .123 .313 r
F
.46672 .54581 m .47773 .53759 L .46934 .54688 L F
.46685 .53755 m .47773 .53759 L .46672 .54581 L F
.46468 .54583 m .46058 .53753 L .48443 .55026 L .608 .314 .444 r
F
.46904 .52923 m .46785 .5296 L .46804 .52947 L 0 0 0 r
F
.46904 .52923 m .46804 .52947 L .47206 .52643 L F
.46922 .52917 m .46904 .52923 L .47206 .52643 L F
.46904 .52923 m .46909 .52921 L .46042 .53127 L F
.46432 .53047 m .46785 .5296 L .46042 .53127 L F
.46785 .5296 m .46904 .52923 L .46042 .53127 L F
.46042 .53127 m .46909 .52921 L .46628 .52963 L F
.46406 .53022 m .46396 .53014 L .46569 .52976 L F
.46396 .53014 m .46369 .52989 L .46569 .52976 L F
.46569 .52976 m .46369 .52989 L .46882 .52887 L F
.44387 .53465 m .46628 .52963 L .44072 .53519 L F
.4534 .53301 m .45864 .53163 L .44387 .53465 L F
.45864 .53163 m .46628 .52963 L .44387 .53465 L F
.44072 .53519 m .46628 .52963 L .45222 .53514 L .455 .123 .313 r
F
.46909 .52921 m .47104 .5286 L .46628 .52963 L 0 0 0 r
F
.46628 .52963 m .47104 .5286 L .45222 .53514 L .455 .123 .313 r
F
.46058 .53753 m .47886 .52848 L .47325 .53293 L 0 0 0 r
F
.51455 .59581 m .50072 .58018 L .51159 .5783 L .732 .552 .648 r
F
.52056 .59794 m .52011 .60169 L .52796 .60712 L .476 .562 .863 r
F
.52612 .60434 m .52796 .60712 L .52937 .60809 L F
.52056 .59794 m .52796 .60712 L .52612 .60434 L F
.5136 .58993 m .50468 .59102 L .52011 .60169 L F
.5136 .58993 m .52011 .60169 L .52056 .59794 L F
.47785 .52714 m .47789 .52709 L .47885 .5269 L 0 0 0 r
F
.47785 .52714 m .47885 .5269 L .47746 .52723 L F
.47116 .52845 m .48606 .52728 L .48554 .52827 L F
.47116 .52845 m .48554 .52827 L .48129 .5285 L F
.47096 .52862 m .47107 .5286 L .47104 .5286 L F
.47746 .52723 m .47885 .5269 L .47096 .52862 L F
.47209 .52838 m .47785 .52714 L .47732 .52797 L F
.47104 .5286 m .47885 .5269 L .47507 .52883 L .455 .123 .313 r
F
.47043 .52907 m .47507 .52883 L .46279 .53509 L F
.47104 .5286 m .47507 .52883 L .47043 .52907 L F
.48129 .5285 m .48554 .52827 L .48541 .52851 L 0 0 0 r
F
.46058 .53753 m .47043 .52907 L .47854 .52864 L F
.46953 .52912 m .47043 .52907 L .46279 .53509 L .455 .123 .313 r
F
.48474 .55739 m .50048 .55873 L .49678 .56688 L .65 .463 .618 r
F
.48416 .55694 m .49678 .56688 L .50072 .58018 L .608 .314 .444 r
F
.47644 .54978 m .49541 .55603 L .4815 .55712 L .65 .463 .618 r
F
.46058 .53753 m .46449 .53375 L .47043 .52907 L 0 0 0 r
F
.48443 .55026 m .47219 .54372 L .47773 .53759 L .608 .314 .444 r
F
.47845 .53074 m .50192 .55612 L .49348 .55402 L .523 .324 .553 r
F
.47845 .53074 m .49348 .55402 L .47773 .53759 L F
.48468 .54484 m .47773 .53759 L .48539 .52911 L .608 .314 .444 r
F
.48443 .55026 m .47773 .53759 L .48468 .54484 L F
.47773 .53759 m .49348 .55402 L .47644 .54978 L .523 .324 .553 r
F
.46934 .54688 m .47773 .53759 L .47644 .54978 L .455 .123 .313 r
F
.48539 .52911 m .46058 .53753 L .48541 .52851 L .608 .314 .444 r
F
.47219 .54372 m .46058 .53753 L .48539 .52911 L F
.46058 .53753 m .46206 .53566 L .46449 .53375 L 0 0 0 r
F
.50072 .58018 m .50289 .56083 L .52104 .57666 L .543 .31 .512 r
F
.50072 .58018 m .49678 .56688 L .50037 .56333 L F
.51093 .55837 m .4986 .55708 L .47644 .54978 L .523 .324 .553 r
F
.45188 .51883 m .50397 .59005 L .5136 .58993 L .476 .562 .863 r
F
.50397 .59005 m .50468 .59102 L .5136 .58993 L F
.49244 .58888 m .48871 .58205 L .50052 .59398 L .784 .572 .613 r
F
.49244 .58888 m .49841 .59384 L .49291 .58975 L .732 .556 .654 r
F
.48971 .58716 m .48302 .58293 L .48871 .58205 L .784 .572 .613 r
F
.50052 .59398 m .49841 .59384 L .49244 .58888 L .65 .463 .618 r
F
.43638 .54276 m .47436 .5738 L .43903 .55129 L .627 .339 .461 r
F
.45088 .54498 m .47892 .5703 L .47991 .57848 L F
.46636 .56803 m .46648 .56072 L .47621 .57687 L .68 .316 .35 r
F
.45088 .54498 m .45778 .54627 L .46429 .55709 L .627 .339 .461 r
F
.47436 .5738 m .47093 .56812 L .47991 .57848 L F
.46636 .56803 m .46429 .55709 L .46648 .56072 L .68 .316 .35 r
F
.46651 .5688 m .43736 .54287 L .45026 .54442 L F
.46651 .5688 m .45026 .54442 L .46429 .55709 L F
.43695 .54251 m .43674 .54255 L .44961 .53616 L 0 0 0 r
F
.43674 .54255 m .44396 .53837 L .44961 .53616 L F
.44368 .5364 m .44856 .53657 L .44628 .53746 L .455 .123 .313 r
F
.44072 .53519 m .44628 .53746 L .43599 .5415 L F
.44628 .53746 m .43811 .54194 L .43599 .5415 L F
.46651 .5688 m .4357 .54325 L .43736 .54287 L .68 .316 .35 r
F
.48197 .56977 m .45894 .55783 L .44141 .54876 L .483 .612 .904 r
F
.45894 .55783 m .45103 .55373 L .45004 .55321 L F
.45894 .55783 m .45004 .55321 L .44141 .54876 L F
.39193 .51667 m .41862 .53693 L .41122 .51661 L 0 .344 .809 r
F
.45103 .55373 m .44448 .55033 L .44141 .54876 L .483 .612 .904 r
F
.4267 .54407 m .43497 .54338 L .43327 .54413 L .462 0 .036 r
F
.43371 .54346 m .43259 .54358 L .43528 .54334 L .124 .673 .727 r
F
.43259 .54358 m .43436 .54343 L .43528 .54334 L F
.43436 .54343 m .43463 .54341 L .43528 .54334 L F
.43605 .54464 m .41466 .54489 L .43528 .54334 L .745 .291 .174 r
F
.4357 .54325 m .43844 .54176 L .43736 .54287 L 0 0 0 r
F
.43528 .54334 m .43594 .54301 L .4357 .54325 L F
.43594 .54301 m .43844 .54176 L .4357 .54325 L F
.43599 .5415 m .43811 .54194 L .43703 .54238 L .627 .339 .461 r
F
.43605 .54464 m .43528 .54334 L .43614 .5444 L .745 .291 .174 r
F
.43599 .5415 m .43703 .54238 L .43638 .54276 L .627 .339 .461 r
F
.43528 .54334 m .43497 .54338 L .43695 .54251 L 0 0 0 r
F
.43671 .5442 m .43528 .54334 L .4357 .54325 L .68 .316 .35 r
F
.43634 .54433 m .43528 .54334 L .43671 .5442 L F
.41862 .53693 m .44698 .55163 L .41122 .51661 L 0 .344 .809 r
F
.38107 .51747 m .41522 .53517 L .39193 .51667 L 0 .218 .637 r
F
.44536 .55079 m .42157 .53846 L .41522 .53517 L .483 .612 .904 r
F
.44365 .54991 m .41522 .53517 L .44141 .54876 L F
.44536 .55079 m .41522 .53517 L .44365 .54991 L F
.44342 .56124 m .44343 .56122 L .44327 .56091 L .897 .5 .256 r
F
.45192 .59029 m .46181 .60259 L .46508 .60995 L F
.46181 .60259 m .46909 .61165 L .46508 .60995 L F
.46508 .60995 m .46909 .61165 L .47255 .62111 L F
.4726 .62089 m .47108 .6065 L .47215 .6197 L .07 .081 .562 r
F
.46909 .61165 m .4726 .62089 L .47255 .62111 L .897 .5 .256 r
F
.47094 .6187 m .47255 .62111 L .47178 .61914 L F
.47255 .62111 m .47108 .6065 L .4726 .62089 L .437 .333 .639 r
F
.47248 .62075 m .47108 .6065 L .47255 .62111 L F
.47227 .62002 m .47108 .6065 L .47253 .62123 L F
.48149 .68807 m .47808 .70234 L .47938 .69725 L 0 0 .088 r
F
.48155 .68759 m .47808 .70234 L .48149 .68807 L F
.48461 .67434 m .47808 .70234 L .48485 .67352 L F
.47803 .6891 m .4781 .69015 L .4828 .67512 L .981 .833 .437 r
F
.48461 .67434 m .47856 .69704 L .47808 .70234 L 0 0 .088 r
F
.48201 .68331 m .47856 .69704 L .48461 .67434 L F
.47629 .66575 m .47753 .66777 L .47787 .67076 L .437 .333 .639 r
F
.47753 .66777 m .47755 .66779 L .47787 .67076 L F
.48051 .67976 m .47868 .67093 L .47888 .67155 L .787 .521 0 r
F
.48051 .67976 m .47882 .67167 L .47886 .67177 L F
.47648 .66606 m .47701 .67398 L .48252 .67507 L .981 .833 .437 r
F
.48254 .67474 m .48252 .67507 L .4828 .67512 L F
.47648 .66606 m .48252 .67507 L .48254 .67474 L F
.47701 .67398 m .48079 .68103 L .4828 .67512 L F
.48446 .64744 m .48546 .65859 L .48387 .65715 L .874 .745 .717 r
F
.48037 .63278 m .47781 .6547 L .48918 .65476 L .981 .833 .437 r
F
.48197 .64002 m .48037 .63278 L .4845 .6431 L .888 .491 .049 r
F
.48197 .64002 m .4845 .6431 L .48417 .64452 L F
.48499 .66926 m .48304 .67024 L .48549 .66788 L .964 .935 .627 r
F
.47781 .6547 m .4828 .67512 L .48918 .65476 L .981 .833 .437 r
F
.48197 .64002 m .48417 .64452 L .48399 .64035 L .888 .491 .049 r
F
.48417 .64452 m .4845 .6431 L .48918 .65476 L F
.48417 .64452 m .4881 .65255 L .48426 .64116 L F
.48417 .64452 m .48426 .64116 L .48399 .64035 L F
.48429 .6404 m .48504 .62616 L .48384 .63928 L .437 .333 .639 r
F
.48429 .6404 m .48384 .63928 L .48375 .64031 L F
.49693 .66608 m .50939 .69103 L .5 .65363 L .701 .531 .655 r
F
.50181 .68097 m .49706 .67482 L .50452 .6922 L .175 .215 .665 r
F
.50107 .67868 m .49706 .67482 L .50181 .68097 L F
.49987 .67504 m .50939 .69103 L .49693 .66608 L .701 .531 .655 r
F
.50381 .68483 m .50939 .69103 L .49987 .67504 L F
.50181 .68097 m .50452 .6922 L .50381 .68483 L .175 .215 .665 r
F
.5058 .68976 m .50648 .69587 L .50768 .69443 L .47 .41 .709 r
F
.50381 .68483 m .50452 .6922 L .5058 .68976 L F
.50631 .69469 m .50731 .69351 L .49987 .67504 L .701 .531 .655 r
F
.49143 .65457 m .5 .65363 L .49356 .64142 L .598 .448 .65 r
F
.49239 .65692 m .5 .65363 L .49143 .65457 L F
.49653 .66712 m .49706 .67482 L .50132 .67893 L .175 .215 .665 r
F
.4944 .66188 m .49584 .66888 L .49653 .66712 L F
.49584 .66888 m .49706 .67482 L .49653 .66712 L F
.49148 .65892 m .49218 .65963 L .49095 .65753 L .598 .448 .65 r
F
.49148 .65892 m .49706 .67482 L .4944 .66188 L 0 0 .413 r
F
.49644 .66691 m .49239 .65692 L .49095 .65753 L .598 .448 .65 r
F
.49095 .65753 m .49239 .65692 L .49143 .65457 L F
.47184 .6152 m .48509 .62536 L .47108 .6065 L .437 .333 .639 r
F
.47386 .62013 m .48509 .62536 L .47184 .6152 L F
.46863 .61044 m .46752 .60167 L .46829 .60953 L .07 .081 .562 r
F
.46364 .5998 m .46471 .60032 L .46352 .59916 L F
.46471 .60032 m .46752 .60167 L .46352 .59916 L F
.46352 .59916 m .46752 .60167 L .46284 .59531 L F
.47108 .6065 m .46289 .59862 L .46284 .59531 L 0 .222 .744 r
F
.44911 .58514 m .44912 .58516 L .46996 .60543 L F
.47108 .6065 m .46996 .60542 L .46996 .60543 L F
.46284 .59531 m .45235 .58581 L .45354 .58665 L .679 .139 0 r
F
.47108 .6065 m .44606 .57846 L .45178 .58774 L 0 .222 .744 r
F
.44058 .57185 m .45481 .58685 L .44327 .56091 L .897 .5 .256 r
F
.44031 .57294 m .44606 .57846 L .44058 .57185 L F
.44606 .57846 m .45481 .58685 L .44058 .57185 L F
.4354 .56561 m .44031 .57294 L .44058 .57185 L F
.41873 .54942 m .42497 .55134 L .41831 .54836 L .403 0 0 r
F
.44447 .57668 m .42003 .54929 L .45178 .58774 L 0 .222 .744 r
F
.42003 .54929 m .41923 .54879 L .45178 .58774 L F
.42609 .55662 m .41977 .54926 L .42961 .56002 L .315 .407 .797 r
F
.40943 .54465 m .41002 .54476 L .40989 .54485 L .403 0 0 r
F
.40943 .54465 m .40989 .54485 L .40805 .54615 L F
.39484 .54209 m .40943 .54465 L .40805 .54615 L F
.40251 .54268 m .41002 .54476 L .39484 .54209 L F
.40698 .5424 m .39858 .54238 L .40108 .54257 L .264 .671 .967 r
F
.41373 .54222 m .4062 .5423 L .40698 .5424 L F
.4062 .5423 m .39858 .54238 L .40698 .5424 L F
.40251 .54268 m .40947 .54447 L .41002 .54476 L .403 0 0 r
F
.40314 .54273 m .40947 .54447 L .40251 .54268 L F
.43562 .57203 m .4086 .54575 L .43626 .57269 L 0 .222 .744 r
F
.43403 .57052 m .4086 .54575 L .43581 .57242 L F
.4086 .54575 m .40878 .54642 L .40957 .54732 L F
.45178 .58774 m .41923 .54879 L .409 .54275 L F
.42497 .55134 m .41824 .54819 L .41831 .54836 L .403 0 0 r
F
.41871 .54848 m .42607 .55168 L .41919 .54877 L .434 0 0 r
F
.41923 .54879 m .40924 .54272 L .409 .54275 L 0 .222 .744 r
F
.40989 .54485 m .41002 .54476 L .41128 .54543 L .403 0 0 r
F
.40989 .54485 m .41128 .54543 L .41873 .54942 L F
.40805 .54615 m .40989 .54485 L .41873 .54942 L F
.41373 .54222 m .3861 .53641 L .33533 .53391 L .264 .671 .967 r
F
.3861 .53641 m .33458 .53219 L .33533 .53391 L F
.34312 .52622 m .35621 .52985 L .35447 .52953 L .403 0 0 r
F
.34312 .52622 m .35304 .52926 L .35707 .52114 L F
.39442 .54124 m .37727 .54037 L .39858 .54238 L .264 .671 .967 r
F
.41373 .54222 m .33533 .53391 L .37727 .54037 L F
.37275 .53531 m .39858 .54238 L .39484 .54209 L .403 0 0 r
F
.35304 .52926 m .39353 .54169 L .38295 .53573 L F
.35304 .52926 m .38295 .53573 L .35707 .52114 L F
.39704 .53877 m .39036 .53733 L .39744 .53881 L .379 .639 .957 r
F
.4087 .54278 m .40502 .54316 L .40525 .54317 L .264 .671 .967 r
F
.40924 .54272 m .40502 .54316 L .4087 .54278 L F
.41373 .54222 m .40918 .54271 L .40924 .54272 L F
.40918 .54271 m .40502 .54316 L .40924 .54272 L F
.39353 .54169 m .41873 .54942 L .39415 .53815 L .403 0 0 r
F
.39353 .54169 m .39415 .53815 L .38295 .53573 L F
.3954 .53872 m .39613 .53901 L .39437 .53819 L F
.41734 .51563 m .41122 .51661 L .43127 .51744 L .12 .646 .876 r
F
.3723 .5129 m .40592 .51084 L .36361 .5084 L .483 .612 .904 r
F
.40592 .51084 m .43261 .50921 L .4113 .50896 L F
.40592 .51084 m .4113 .50896 L .36361 .5084 L F
.37647 .51506 m .38805 .51385 L .3723 .5129 L F
.38805 .51385 m .39581 .51304 L .3723 .5129 L F
.46064 .51895 m .45188 .51883 L .47137 .52043 L .182 .659 .931 r
F
.43952 .51604 m .44131 .51629 L .43261 .50921 L .571 .605 .848 r
F
.44131 .51629 m .45878 .5187 L .45228 .51634 L F
.44131 .51629 m .45228 .51634 L .43261 .50921 L F
.40087 .51252 m .43261 .50921 L .39241 .51167 L .483 .612 .904 r
F
.44161 .51701 m .43833 .51714 L .45188 .51883 L .15 .652 .908 r
F
.43833 .51714 m .43127 .51744 L .43753 .51786 L F
.43833 .51714 m .43753 .51786 L .45188 .51883 L F
.43893 .51627 m .45188 .51883 L .44131 .51629 L F
.439 .51654 m .43854 .51601 L .43876 .51676 L .571 .605 .848 r
F
.43854 .51601 m .43261 .50921 L .43837 .51628 L F
.43854 .51601 m .43837 .51628 L .43876 .51676 L F
.44014 .51356 m .44335 .51678 L .46579 .51903 L .182 .659 .931 r
F
.43895 .51636 m .43261 .50921 L .439 .51654 L .571 .605 .848 r
F
.41961 .5151 m .43127 .51744 L .43833 .51714 L .15 .652 .908 r
F
.43876 .51676 m .43833 .51714 L .44161 .51701 L F
.41961 .5151 m .43833 .51714 L .43876 .51676 L F
.439 .51654 m .45188 .51883 L .43893 .51627 L F
.42083 .51482 m .43261 .50921 L .39581 .51304 L .483 .612 .904 r
F
.41734 .51563 m .43127 .51744 L .41961 .5151 L .12 .646 .876 r
F
.39312 .51533 m .41122 .51661 L .39595 .51433 L .111 .652 .846 r
F
.39595 .51433 m .41122 .51661 L .41734 .51563 L .12 .646 .876 r
F
.42884 .5159 m .39581 .51304 L .37647 .51506 L .483 .612 .904 r
F
.43819 .51605 m .39581 .51304 L .42884 .5159 L F
.39581 .51304 m .40087 .51252 L .38508 .51212 L F
.40087 .51252 m .39241 .51167 L .38508 .51212 L F
.36179 .51542 m .36361 .5084 L .3533 .51544 L .379 .639 .957 r
F
.37281 .51317 m .3642 .5087 L .36163 .51604 L F
.3642 .5087 m .36361 .5084 L .36163 .51604 L F
.33806 .52631 m .33497 .52566 L .33658 .52712 L .264 .671 .967 r
F
.33658 .52712 m .34028 .52661 L .33806 .52631 L .338 .815 .885 r
F
.33752 .52623 m .33141 .52491 L .33806 .52631 L .379 .639 .957 r
F
.36056 .5191 m .35724 .52108 L .37374 .51801 L .217 .737 .848 r
F
.34323 .52233 m .36361 .5084 L .33255 .52433 L .379 .639 .957 r
F
.34635 .52266 m .34687 .51984 L .33877 .52538 L F
.34653 .52172 m .35724 .52108 L .36056 .5191 L .217 .737 .848 r
F
.34629 .52299 m .35724 .52108 L .34653 .52172 L .338 .815 .885 r
F
.37281 .51317 m .34687 .51984 L .34635 .52266 L .379 .639 .957 r
F
.37281 .51317 m .33877 .52538 L .33967 .52544 L F
.33627 .52728 m .33141 .52491 L .33317 .52896 L .264 .671 .967 r
F
.33497 .52566 m .33141 .52491 L .33734 .5278 L F
.3343 .52743 m .33658 .52712 L .33967 .52544 L .338 .815 .885 r
F
.33734 .5278 m .34312 .52622 L .33658 .52712 L .485 .894 .927 r
F
.33734 .5278 m .33469 .53199 L .34312 .52622 L F
.3861 .53641 m .33826 .52635 L .33458 .53219 L .264 .671 .967 r
F
.33826 .52635 m .33457 .53218 L .33458 .53219 L F
.34281 .52738 m .33752 .52623 L .34569 .52791 L .379 .639 .957 r
F
.33752 .52623 m .33806 .52631 L .34569 .52791 L F
.33806 .52631 m .34312 .52622 L .3432 .52353 L .338 .815 .885 r
F
.34028 .52661 m .34312 .52622 L .33806 .52631 L F
.37635 .51667 m .37374 .51801 L .38107 .51747 L .14 .68 .834 r
F
.37955 .51667 m .38107 .51747 L .39193 .51667 L F
.37635 .51667 m .38107 .51747 L .37955 .51667 L F
.39193 .51667 m .41522 .53517 L .41862 .53693 L 0 .344 .809 r
F
.36101 .5178 m .37374 .51801 L .37635 .51667 L .14 .68 .834 r
F
.36056 .5191 m .37374 .51801 L .36101 .5178 L .217 .737 .848 r
F
.33826 .52635 m .33806 .52631 L .33734 .5278 L .264 .671 .967 r
F
.33806 .52631 m .33658 .52712 L .33734 .5278 L F
.34629 .52299 m .34312 .52622 L .35724 .52108 L .338 .815 .885 r
F
.34318 .52414 m .34312 .52622 L .34629 .52299 L F
.34281 .52738 m .34569 .52791 L .38597 .5364 L .379 .639 .957 r
F
.38597 .5364 m .34569 .52791 L .3861 .53641 L F
.38829 .53688 m .3861 .53641 L .39758 .53882 L F
.38597 .5364 m .3861 .53641 L .38829 .53688 L F
.41873 .54942 m .41831 .54836 L .39666 .53869 L .403 0 0 r
F
.34281 .52738 m .39758 .53882 L .39744 .53881 L .379 .639 .957 r
F
.39437 .53819 m .39666 .53869 L .35724 .52108 L .403 0 0 r
F
.41873 .54942 m .39666 .53869 L .39437 .53819 L F
.38295 .53573 m .39415 .53815 L .35707 .52114 L F
.39407 .5385 m .34281 .52738 L .39036 .53733 L .379 .639 .957 r
F
.39132 .53683 m .39144 .53684 L .35724 .52108 L .403 0 0 r
F
.35707 .52114 m .3954 .53872 L .35724 .52108 L F
.41831 .54836 m .41824 .54819 L .35724 .52108 L F
.35724 .52108 m .39299 .53697 L .382 .53254 L .434 0 0 r
F
.39744 .53881 m .39758 .53882 L .41373 .54222 L .379 .639 .957 r
F
.39299 .53697 m .39704 .53877 L .382 .53254 L .434 0 0 r
F
.39704 .53877 m .4044 .54204 L .39659 .53873 L F
.3954 .53872 m .39437 .53819 L .39422 .53816 L .403 0 0 r
F
.3954 .53872 m .39144 .53684 L .39132 .53683 L F
.39506 .53859 m .39036 .53733 L .39704 .53877 L .379 .639 .957 r
F
.39704 .53877 m .39659 .53873 L .382 .53254 L .434 0 0 r
F
.39422 .53816 m .39437 .53819 L .39144 .53684 L .403 0 0 r
F
.4044 .54204 m .40364 .54194 L .382 .53254 L .434 0 0 r
F
.382 .53254 m .39616 .53869 L .39506 .53859 L F
.35724 .52108 m .39506 .53859 L .37374 .51801 L F
.42547 .55141 m .41466 .54489 L .4241 .54478 L .745 .291 .174 r
F
.4044 .54204 m .42607 .55168 L .40364 .54194 L .434 0 0 r
F
.41588 .54812 m .41873 .54942 L .41586 .5481 L .403 0 0 r
F
.41588 .54812 m .41586 .5481 L .39613 .53901 L F
.3954 .53872 m .41588 .54812 L .39613 .53901 L F
.40267 .5418 m .42607 .55168 L .40171 .54167 L .434 0 0 r
F
.40364 .54194 m .41871 .54848 L .40267 .5418 L F
.41871 .54848 m .41919 .54877 L .40267 .5418 L F
.39616 .53869 m .40364 .54194 L .39506 .53859 L F
.40364 .54194 m .40267 .5418 L .39506 .53859 L F
.41977 .54926 m .42003 .54929 L .42961 .56002 L .315 .407 .797 r
F
.42609 .55662 m .42961 .56002 L .44606 .57846 L F
.44606 .57846 m .44447 .57668 L .44493 .57738 L 0 .222 .744 r
F
.44606 .57846 m .44493 .57738 L .45178 .58774 L F
.44921 .58225 m .44606 .57846 L .47108 .6065 L .315 .407 .797 r
F
.46996 .60542 m .46285 .5985 L .46996 .60543 L 0 .222 .744 r
F
.46285 .5985 m .46285 .59851 L .46996 .60543 L F
.46996 .60543 m .46285 .59851 L .46289 .59862 L F
.48156 .62125 m .46265 .59846 L .46874 .60391 L .315 .407 .797 r
F
.46285 .5985 m .45579 .59163 L .46285 .59851 L 0 .222 .744 r
F
.45579 .59163 m .4558 .59165 L .46285 .59851 L F
.45606 .59196 m .4561 .59201 L .46289 .59862 L F
.46285 .59851 m .45582 .59168 L .46289 .59862 L F
.45582 .59168 m .45606 .59196 L .46289 .59862 L F
.46289 .59862 m .44394 .58017 L .44462 .58105 L F
.46265 .59846 m .44921 .58225 L .46371 .59833 L .315 .407 .797 r
F
.46265 .59846 m .46371 .59833 L .46874 .60391 L F
.47221 .61937 m .47386 .62013 L .47184 .6152 L .437 .333 .639 r
F
.48504 .62616 m .48509 .62536 L .47221 .61937 L F
.47236 .61945 m .47372 .6199 L .47143 .61547 L .897 .5 .256 r
F
.47284 .62154 m .47361 .62011 L .47236 .61945 L F
.47361 .62011 m .47372 .6199 L .47236 .61945 L F
.46433 .60354 m .46608 .60543 L .46378 .60147 L .83 .438 .308 r
F
.46608 .60543 m .46663 .60521 L .46378 .60147 L F
.45642 .5924 m .46665 .60521 L .45192 .59029 L .897 .5 .256 r
F
.46255 .5998 m .46665 .60521 L .45642 .5924 L F
.46665 .60521 m .46722 .60672 L .45192 .59029 L F
.46764 .60984 m .46807 .60895 L .46909 .61165 L F
.45192 .59029 m .46807 .60895 L .46764 .60984 L F
.45192 .59029 m .46722 .60672 L .46807 .60895 L F
.47248 .62072 m .47143 .61547 L .46208 .59734 L F
.47284 .62154 m .47143 .61547 L .47248 .62072 L F
.47242 .62178 m .47227 .62002 L .47253 .62123 L .437 .333 .639 r
F
.46284 .59531 m .45354 .58665 L .45827 .59054 L .679 .139 0 r
F
.46508 .60995 m .46208 .59734 L .44343 .56122 L .897 .5 .256 r
F
.47284 .62154 m .48037 .63278 L .47372 .6199 L F
.47391 .62027 m .48037 .63278 L .48197 .64002 L .888 .491 .049 r
F
.47973 .63454 m .48504 .62616 L .47963 .6233 L .437 .333 .639 r
F
.48014 .67982 m .48345 .64364 L .47973 .63454 L F
.4881 .65255 m .4884 .65247 L .48429 .6404 L .888 .491 .049 r
F
.48197 .64002 m .48504 .62616 L .47973 .63454 L .437 .333 .639 r
F
.48375 .64031 m .48504 .62616 L .48197 .64002 L F
.47448 .61128 m .46874 .60391 L .47108 .6065 L .315 .407 .797 r
F
.48156 .62125 m .46874 .60391 L .47448 .61128 L F
.48509 .62536 m .48156 .62125 L .47108 .6065 L F
.46265 .59846 m .47391 .62027 L .47204 .61694 L .888 .491 .049 r
F
.46508 .60995 m .47094 .6187 L .46208 .59734 L .897 .5 .256 r
F
.47094 .6187 m .47178 .61914 L .46208 .59734 L F
.46206 .59853 m .47204 .61694 L .4617 .59858 L .888 .491 .049 r
F
.46265 .59846 m .47204 .61694 L .46206 .59853 L F
.48156 .62125 m .46945 .60714 L .46928 .60645 L .315 .407 .797 r
F
.45579 .59163 m .44911 .58514 L .4558 .59165 L 0 .222 .744 r
F
.43361 .57007 m .43366 .57012 L .44912 .58516 L F
.44031 .57294 m .45642 .5924 L .45192 .59029 L .897 .5 .256 r
F
.44031 .57294 m .46508 .60995 L .45687 .59149 L F
.44606 .57846 m .45687 .59149 L .45481 .58685 L F
.44031 .57294 m .45687 .59149 L .44606 .57846 L F
.46508 .60995 m .45483 .58687 L .45481 .58685 L F
.46945 .60714 m .4525 .58739 L .46928 .60645 L .315 .407 .797 r
F
.4525 .58739 m .44767 .58152 L .46928 .60645 L F
.46928 .60645 m .42609 .55662 L .44921 .58225 L F
.46206 .59853 m .45808 .59118 L .4525 .58739 L F
.45481 .58685 m .44343 .56122 L .44342 .56124 L .897 .5 .256 r
F
.45483 .58687 m .44343 .56122 L .45481 .58685 L F
.44327 .56091 m .46265 .59846 L .46206 .59853 L .888 .491 .049 r
F
.45808 .59118 m .46206 .59853 L .4617 .59858 L F
.44327 .56091 m .46206 .59853 L .45808 .59118 L F
.4525 .58739 m .42609 .55662 L .44767 .58152 L .315 .407 .797 r
F
.42609 .55662 m .44606 .57846 L .44921 .58225 L F
.42607 .55168 m .44 .57005 L .43917 .56925 L .897 .5 .256 r
F
.42607 .55168 m .4354 .56561 L .44327 .56091 L F
.4354 .56561 m .44058 .57185 L .44327 .56091 L F
.42711 .55781 m .43163 .55552 L .41977 .54926 L .315 .407 .797 r
F
.426 .55291 m .42602 .55255 L .43163 .55552 L .434 0 0 r
F
.42602 .55255 m .42607 .55168 L .43163 .55552 L F
.43163 .55552 m .42607 .55168 L .44327 .56091 L F
.43163 .55552 m .44327 .56091 L .43323 .55471 L F
.40171 .54167 m .41833 .54849 L .426 .55291 L F
.41833 .54849 m .41958 .54901 L .42141 .55012 L F
.41833 .54849 m .42141 .55012 L .426 .55291 L F
.42497 .55134 m .42607 .55168 L .42488 .55115 L .403 0 0 r
F
.42009 .54929 m .42607 .55168 L .42602 .55255 L .434 0 0 r
F
.41958 .54901 m .42602 .55255 L .42141 .55012 L F
.44822 .56514 m .45931 .57295 L .46969 .58559 L .745 .291 .174 r
F
.43942 .55252 m .44958 .5661 L .44813 .56829 L .722 .458 .527 r
F
.44743 .56318 m .44327 .56091 L .45216 .56622 L 0 .218 .637 r
F
.44743 .56318 m .45216 .56622 L .45118 .56548 L F
.47684 .61575 m .47415 .61067 L .47525 .6139 L .315 .407 .797 r
F
.47415 .61067 m .46745 .598 L .47525 .6139 L F
.47525 .6139 m .46745 .598 L .46945 .60714 L F
.48436 .63776 m .48509 .62536 L .48429 .6404 L .598 .448 .65 r
F
.48436 .63776 m .49356 .64142 L .48509 .62536 L F
.48399 .64035 m .48429 .6404 L .48276 .63593 L .888 .491 .049 r
F
.4881 .65255 m .48429 .6404 L .48399 .64035 L F
.49221 .64674 m .49356 .64142 L .48436 .63776 L .598 .448 .65 r
F
.48424 .63983 m .48436 .63776 L .48426 .64006 L F
.46133 .72651 m .472 .7128 L .47342 .70569 L .527 .3 .513 r
F
.47312 .70606 m .47342 .70569 L .47241 .71073 L .981 .833 .437 r
F
.47312 .70606 m .47241 .71073 L .46965 .72456 L F
.47158 .70796 m .47312 .70606 L .46965 .72456 L F
.47423 .70162 m .47342 .70569 L .47311 .70607 L F
.47102 .71276 m .47669 .70448 L .48918 .65476 L F
.48201 .68331 m .48429 .6404 L .48014 .67982 L .437 .333 .639 r
F
.48429 .6404 m .48375 .64031 L .48014 .67982 L F
.48436 .63776 m .48429 .6404 L .48404 .64509 L .598 .448 .65 r
F
.48424 .63983 m .49221 .64674 L .48436 .63776 L F
.49006 .65518 m .49221 .64674 L .48424 .63983 L F
.49148 .65892 m .48918 .65476 L .49706 .67482 L 0 0 .413 r
F
.49025 .65568 m .48918 .65476 L .49148 .65892 L F
.48149 .68807 m .48085 .69776 L .49706 .67482 L 0 0 .088 r
F
.48085 .69776 m .4851 .69925 L .49706 .67482 L F
.48426 .69895 m .49564 .66989 L .49095 .65753 L .598 .448 .65 r
F
.47882 .73258 m .48754 .7001 L .48426 .69895 L F
.48669 .6998 m .48759 .70012 L .49706 .67482 L 0 0 .088 r
F
.48754 .7001 m .49564 .66989 L .48426 .69895 L .598 .448 .65 r
F
.49706 .67482 m .48759 .70012 L .49185 .69186 L .275 .088 .437 r
F
.47975 .73217 m .49471 .67418 L .47882 .73258 L .598 .448 .65 r
F
.49471 .67418 m .5 .65363 L .49453 .67405 L F
.49471 .67418 m .49453 .67405 L .47882 .73258 L F
.49031 .65583 m .49356 .64142 L .49006 .65518 L F
.48509 .62536 m .4783 .61346 L .47684 .61575 L .315 .407 .797 r
F
.4783 .61346 m .47035 .59952 L .47684 .61575 L F
.47021 .59942 m .47035 .59952 L .47006 .59898 L .888 .491 .049 r
F
.46278 .59437 m .46135 .59215 L .46269 .59285 L .679 .139 0 r
F
.46135 .59215 m .46016 .59031 L .46269 .59285 L F
.4631 .59551 m .46278 .59437 L .46269 .59285 L .787 .521 0 r
F
.4631 .59551 m .46269 .59285 L .46247 .58915 L F
.45808 .59118 m .46845 .59823 L .46713 .59362 L .888 .491 .049 r
F
.46277 .59063 m .46247 .58915 L .46286 .59065 L .787 .521 0 r
F
.46247 .58915 m .45734 .5805 L .46929 .58578 L .745 .291 .174 r
F
.47647 .60202 m .48388 .61193 L .467 .59132 L .722 .458 .527 r
F
.4714 .59647 m .46323 .58877 L .46969 .58559 L .957 .664 .437 r
F
.45808 .59118 m .46713 .59362 L .45961 .57985 L .888 .491 .049 r
F
.47035 .59952 m .46907 .59865 L .472 .6051 L .315 .407 .797 r
F
.47035 .59952 m .472 .6051 L .47684 .61575 L F
.46907 .59865 m .46708 .59729 L .47684 .61575 L F
.47701 .67398 m .47963 .6233 L .47629 .66575 L .437 .333 .639 r
F
.48014 .67982 m .47963 .6233 L .47701 .67398 L F
.47253 .62123 m .47248 .62075 L .47255 .62111 L F
.47255 .62111 m .4726 .62089 L .4727 .62181 L F
.47255 .62111 m .47284 .62154 L .47248 .62072 L .897 .5 .256 r
F
.47255 .62111 m .47248 .62072 L .47178 .61914 L F
.47629 .66575 m .47963 .6233 L .47221 .61937 L .437 .333 .639 r
F
.4617 .59858 m .47391 .62027 L .48197 .64002 L .888 .491 .049 r
F
.47824 .63239 m .47921 .62616 L .47021 .59942 L F
.46845 .59823 m .47021 .59942 L .47006 .59898 L F
.46845 .59823 m .47006 .59898 L .46713 .59362 L F
.466 .59188 m .46265 .58893 L .46708 .59729 L .315 .407 .797 r
F
.466 .59188 m .46708 .59729 L .46907 .59865 L F
.47035 .59952 m .46611 .59212 L .46907 .59865 L F
.47035 .59952 m .466 .59188 L .46611 .59212 L F
.4433 .55771 m .46774 .57692 L .46486 .57518 L .722 .458 .527 r
F
.4433 .55771 m .46738 .57339 L .46305 .57323 L F
.44743 .56318 m .46075 .57135 L .44894 .56196 L 0 .218 .637 r
F
.44958 .5661 m .45858 .58105 L .44813 .56829 L .722 .458 .527 r
F
.46969 .58559 m .45952 .5731 L .46738 .57339 L .68 .316 .35 r
F
.44327 .56091 m .45808 .59118 L .46075 .57135 L .888 .491 .049 r
F
.466 .59188 m .44894 .56196 L .46265 .58893 L .315 .407 .797 r
F
.48045 .58145 m .46651 .5688 L .48065 .58095 L .68 .316 .35 r
F
.46738 .57339 m .46651 .5688 L .48225 .58308 L F
.48074 .5807 m .48175 .58149 L .48115 .58178 L .732 .556 .654 r
F
.46651 .5688 m .46896 .57036 L .48296 .58294 L .68 .316 .35 r
F
.43903 .55129 m .47115 .57265 L .43942 .55252 L .627 .339 .461 r
F
.47115 .57265 m .47226 .57357 L .43942 .55252 L F
.43942 .55252 m .47991 .57848 L .48031 .58182 L .722 .458 .527 r
F
.43942 .55252 m .48031 .58182 L .4433 .55771 L F
.47436 .5738 m .47991 .57848 L .43903 .55129 L .627 .339 .461 r
F
.44894 .56196 m .44141 .54876 L .44816 .56151 L .315 .407 .797 r
F
.44894 .56196 m .44816 .56151 L .46265 .58893 L F
.44835 .56118 m .44141 .54876 L .44894 .56196 L .511 .482 .761 r
F
.44759 .55982 m .48197 .56977 L .44141 .54876 L F
.45078 .5618 m .48197 .56977 L .44759 .55982 L F
.46875 .57295 m .478 .58202 L .47888 .57924 L .182 .455 .88 r
F
.46651 .5688 m .46636 .56803 L .46896 .57036 L .68 .316 .35 r
F
.46497 .57212 m .48197 .56977 L .44835 .56118 L .511 .482 .761 r
F
.46497 .57212 m .478 .58202 L .46875 .57295 L 0 .344 .809 r
F
.48296 .58294 m .48215 .58129 L .48306 .58085 L .608 .314 .444 r
F
.48022 .58048 m .48215 .58129 L .48296 .58294 L .68 .316 .35 r
F
.47991 .57848 m .48074 .5807 L .48031 .58182 L .732 .556 .654 r
F
.48225 .58308 m .48045 .58145 L .48296 .58294 L .68 .316 .35 r
F
.48045 .58145 m .48065 .58095 L .48296 .58294 L F
.47888 .57924 m .478 .58202 L .48479 .58291 L .182 .455 .88 r
F
.48006 .58206 m .48092 .58051 L .46497 .57212 L .511 .482 .761 r
F
.48286 .58067 m .48288 .58094 L .47991 .57848 L .65 .463 .618 r
F
.47936 .57393 m .48265 .57701 L .47991 .57848 L F
.48265 .57701 m .48286 .58067 L .47991 .57848 L F
.47115 .57265 m .47991 .57848 L .47226 .57357 L .627 .339 .461 r
F
.49175 .58598 m .5145 .60173 L .50708 .59444 L .627 .537 .734 r
F
.50079 .594 m .5013 .59447 L .50052 .59398 L .65 .463 .618 r
F
.49796 .59043 m .49495 .59206 L .51047 .59941 L .368 .521 .878 r
F
.50474 .5953 m .5145 .60173 L .49175 .58598 L .627 .537 .734 r
F
.48756 .58341 m .49495 .59206 L .49796 .59043 L .368 .521 .878 r
F
.48446 .58075 m .50708 .59444 L .48197 .56977 L .627 .537 .734 r
F
.48661 .5823 m .50708 .59444 L .48446 .58075 L F
.48756 .58341 m .49796 .59043 L .48911 .58409 L .368 .521 .878 r
F
.48661 .5823 m .48756 .58341 L .48911 .58409 L F
.48087 .58048 m .48335 .57616 L .46875 .57295 L .511 .482 .761 r
F
.48093 .5805 m .48335 .57616 L .48087 .58048 L F
.4848 .58291 m .48335 .57616 L .48006 .58206 L F
.47928 .57795 m .48479 .58291 L .4848 .58291 L .182 .455 .88 r
F
.48453 .58106 m .4848 .58291 L .48661 .5823 L F
.48453 .58106 m .48446 .58075 L .4848 .58291 L .627 .537 .734 r
F
.48446 .58075 m .48197 .56977 L .48463 .58212 L F
.48446 .58075 m .48463 .58212 L .4848 .58291 L F
.48325 .57124 m .48661 .5823 L .50048 .58907 L .368 .521 .878 r
F
.48335 .57616 m .48197 .56977 L .46497 .57212 L .511 .482 .761 r
F
.43127 .51744 m .4536 .54361 L .45299 .53992 L .368 .521 .878 r
F
.37955 .51667 m .39193 .51667 L .37705 .51537 L .14 .68 .834 r
F
.39312 .51533 m .39193 .51667 L .41122 .51661 L .111 .652 .846 r
F
.393 .51533 m .39193 .51667 L .39312 .51533 L F
.36767 .53277 m .37281 .51317 L .33752 .52623 L .379 .639 .957 r
F
.37705 .51537 m .37281 .51317 L .37191 .51658 L F
.40774 .54108 m .39744 .53881 L .41373 .54222 L F
.41657 .54648 m .41466 .54489 L .41808 .54695 L .745 .291 .174 r
F
.41657 .54648 m .41808 .54695 L .42547 .55141 L F
.41923 .54879 m .41373 .54222 L .40924 .54272 L 0 .222 .744 r
F
.42003 .54929 m .41373 .54222 L .41923 .54879 L F
.43232 .55136 m .43942 .55252 L .42781 .54996 L .462 0 .036 r
F
.42519 .5501 m .43942 .55252 L .42524 .55032 L .643 .215 .214 r
F
.42781 .54996 m .43942 .55252 L .42499 .54909 L .462 0 .036 r
F
.42499 .54909 m .43942 .55252 L .42519 .5501 L .643 .215 .214 r
F
.44446 .55939 m .44141 .54876 L .41522 .54257 L .315 .407 .797 r
F
.44141 .54876 m .43025 .54634 L .42245 .54451 L .379 .639 .957 r
F
.44141 .54876 m .42245 .54451 L .42165 .5443 L F
.4207 .54404 m .41874 .54364 L .41795 .54341 L F
.44141 .54876 m .42165 .5443 L .4207 .54404 L F
.42165 .5443 m .41874 .54364 L .4207 .54404 L F
.43323 .55471 m .44327 .56091 L .44743 .56318 L 0 .218 .637 r
F
.46708 .59729 m .44816 .56151 L .4525 .58739 L .315 .407 .797 r
F
.44816 .56151 m .44141 .54876 L .44446 .55939 L F
.44816 .56151 m .44446 .55939 L .4525 .58739 L F
.44835 .56118 m .45078 .5618 L .44759 .55982 L .511 .482 .761 r
F
.44843 .56128 m .45003 .56259 L .44542 .55728 L 0 .344 .809 r
F
.45003 .56259 m .46075 .57135 L .45319 .56441 L F
.45003 .56259 m .45319 .56441 L .44542 .55728 L F
.44894 .56196 m .45003 .56259 L .43056 .54668 L F
.41977 .54926 m .41373 .54222 L .42003 .54929 L .315 .407 .797 r
F
.41958 .54901 m .42034 .54932 L .42009 .54929 L .434 0 0 r
F
.42034 .54932 m .42607 .55168 L .42009 .54929 L F
.41977 .54926 m .44446 .55939 L .41373 .54222 L .315 .407 .797 r
F
.44446 .55939 m .41522 .54257 L .41373 .54222 L F
.43025 .54634 m .41405 .54283 L .41378 .54271 L .379 .639 .957 r
F
.43025 .54634 m .41378 .54271 L .41255 .54218 L F
.42165 .5443 m .42245 .54451 L .41874 .54364 L F
.41795 .54341 m .41874 .54364 L .41255 .54218 L F
.42089 .54781 m .42181 .54767 L .41378 .54271 L .434 0 0 r
F
.41255 .54218 m .4001 .5397 L .40774 .54108 L .379 .639 .957 r
F
.39506 .53859 m .40267 .5418 L .40171 .54167 L .434 0 0 r
F
.39506 .53859 m .41632 .54843 L .40588 .54097 L F
.4001 .5397 m .39407 .5385 L .39814 .53927 L .379 .639 .957 r
F
.4001 .5397 m .39814 .53927 L .40774 .54108 L F
.44161 .56079 m .44075 .5592 L .41977 .54926 L .315 .407 .797 r
F
.44075 .5592 m .43359 .55493 L .41977 .54926 L F
.42141 .55012 m .42602 .55255 L .426 .55291 L .434 0 0 r
F
.41632 .54843 m .43163 .55552 L .41212 .54235 L F
.41632 .54843 m .41212 .54235 L .40856 .54156 L F
.43163 .55552 m .41378 .54271 L .41212 .54235 L F
.41378 .54271 m .42181 .54767 L .41405 .54283 L 0 .218 .637 r
F
.41632 .54843 m .40856 .54156 L .40588 .54097 L .434 0 0 r
F
.41405 .54283 m .39407 .5385 L .4001 .5397 L .379 .639 .957 r
F
.41378 .54271 m .4001 .5397 L .41255 .54218 L F
.41405 .54283 m .4001 .5397 L .41378 .54271 L F
.39407 .5385 m .39704 .53877 L .40774 .54108 L F
.39704 .53877 m .39744 .53881 L .40774 .54108 L F
.40588 .54097 m .40084 .53473 L .37374 .51801 L .434 0 0 r
F
.42161 .54408 m .40774 .54108 L .41373 .54222 L .379 .639 .957 r
F
.44141 .54876 m .41255 .54218 L .42161 .54408 L F
.41255 .54218 m .40774 .54108 L .41229 .54207 L F
.41255 .54218 m .41229 .54207 L .42161 .54408 L F
.44075 .5592 m .43982 .55748 L .43359 .55493 L .315 .407 .797 r
F
.4432 .56163 m .44446 .55939 L .43982 .55748 L F
.4432 .56163 m .43982 .55748 L .44161 .56079 L F
.4459 .56441 m .44446 .55939 L .43814 .57066 L F
.41466 .5431 m .43323 .55471 L .44743 .56318 L 0 .218 .637 r
F
.40856 .54156 m .40084 .53473 L .40588 .54097 L .434 0 0 r
F
.40856 .54156 m .41212 .54235 L .40084 .53473 L F
.41212 .54235 m .41378 .54271 L .40084 .53473 L F
.37374 .51801 m .41378 .54271 L .40321 .53607 L 0 .218 .637 r
F
.41378 .54271 m .41405 .54283 L .40321 .53607 L F
.39506 .53859 m .40588 .54097 L .37374 .51801 L .434 0 0 r
F
.39407 .5385 m .39273 .53808 L .39506 .53859 L .379 .639 .957 r
F
.39273 .53808 m .39036 .53733 L .39506 .53859 L F
.37635 .51667 m .37955 .51667 L .37652 .51636 L .14 .68 .834 r
F
.37374 .51801 m .40321 .53607 L .41522 .53517 L 0 .218 .637 r
F
.43025 .54634 m .41154 .53545 L .38812 .53721 L .379 .639 .957 r
F
.37374 .51801 m .41522 .53517 L .38107 .51747 L 0 .218 .637 r
F
.37705 .51537 m .37191 .51658 L .37527 .51867 L .379 .639 .957 r
F
.37652 .51636 m .37705 .51537 L .30513 .50911 L .14 .68 .834 r
F
.37955 .51667 m .37705 .51537 L .37652 .51636 L F
.43524 .54556 m .37705 .51537 L .43025 .54634 L .379 .639 .957 r
F
.40321 .53607 m .44743 .56318 L .41522 .53517 L 0 .218 .637 r
F
.38812 .53721 m .37705 .51537 L .36767 .53277 L .379 .639 .957 r
F
.41154 .53545 m .37705 .51537 L .38812 .53721 L F
.40321 .53607 m .41418 .54289 L .41466 .5431 L 0 .218 .637 r
F
.41418 .54289 m .43323 .55471 L .41466 .5431 L F
.44141 .54876 m .43524 .54556 L .43025 .54634 L .379 .639 .957 r
F
.43163 .55552 m .43323 .55471 L .42181 .54767 L .434 0 0 r
F
.43163 .55552 m .42181 .54767 L .42089 .54781 L F
.43037 .54663 m .43056 .54668 L .41862 .53693 L 0 .344 .809 r
F
.44894 .56196 m .43056 .54668 L .43037 .54663 L F
.41522 .53517 m .42928 .54634 L .41862 .53693 L F
.42928 .54634 m .44894 .56196 L .43037 .54663 L F
.42928 .54634 m .43037 .54663 L .41862 .53693 L F
.37527 .51867 m .37191 .51658 L .36767 .53277 L .379 .639 .957 r
F
.42181 .54767 m .43323 .55471 L .40321 .53607 L 0 .218 .637 r
F
.37464 .51412 m .36361 .5084 L .37705 .51537 L .483 .612 .904 r
F
.37447 .51401 m .37705 .51537 L .39301 .51532 L .111 .652 .846 r
F
.37464 .51412 m .37705 .51537 L .37679 .51523 L .483 .612 .904 r
F
.30513 .50911 m .37705 .51537 L .37447 .51401 L .111 .652 .846 r
F
.37679 .51523 m .37705 .51537 L .37915 .51646 L .483 .612 .904 r
F
.37705 .51537 m .39193 .51667 L .39301 .51532 L .111 .652 .846 r
F
.45427 .5554 m .45462 .55816 L .47928 .57795 L .182 .455 .88 r
F
.45462 .55816 m .45476 .55926 L .45671 .56074 L F
.45462 .55816 m .45671 .56074 L .47928 .57795 L F
.41122 .51661 m .44729 .54911 L .43127 .51744 L F
.45566 .55613 m .45114 .54575 L .44855 .54801 L .483 .612 .904 r
F
.44729 .54911 m .44936 .5473 L .43127 .51744 L .182 .455 .88 r
F
.45566 .55613 m .44855 .54801 L .45103 .55373 L .483 .612 .904 r
F
.44855 .54801 m .42026 .51576 L .44729 .54911 L F
.44855 .54801 m .44729 .54911 L .45103 .55373 L F
.48197 .56977 m .45772 .54002 L .45566 .55613 L F
.43127 .51744 m .45299 .53992 L .45188 .51883 L .368 .521 .878 r
F
.45772 .54002 m .45655 .53858 L .4536 .54361 L .483 .612 .904 r
F
.45655 .53858 m .45299 .53992 L .4536 .54361 L F
.45772 .54002 m .4536 .54361 L .45566 .55613 L F
.49175 .58598 m .50708 .59444 L .48661 .5823 L .627 .537 .734 r
F
.48479 .58291 m .49495 .59206 L .48756 .58341 L .182 .455 .88 r
F
.48479 .58291 m .48756 .58341 L .48661 .5823 L F
.49712 .59155 m .5145 .60173 L .48477 .58213 L .627 .537 .734 r
F
.49814 .59232 m .51107 .59976 L .49712 .59155 L F
.51107 .59976 m .5145 .60173 L .49712 .59155 L F
.5145 .60173 m .50468 .59102 L .48197 .56977 L .571 .605 .848 r
F
.46189 .53566 m .46206 .53566 L .46058 .53753 L 0 0 0 r
F
.45655 .53858 m .50326 .58947 L .46422 .53569 L .368 .521 .878 r
F
.50468 .59102 m .45655 .53858 L .48197 .56977 L .571 .605 .848 r
F
.51047 .59941 m .51107 .59976 L .50468 .59102 L .368 .521 .878 r
F
.50326 .58947 m .50468 .59102 L .46422 .53569 L F
.51047 .59941 m .50468 .59102 L .50326 .58947 L F
.45299 .53992 m .46422 .53569 L .45188 .51883 L F
.50468 .59102 m .5145 .60173 L .52937 .60809 L .476 .562 .863 r
F
.5145 .60173 m .51481 .60208 L .51582 .60249 L F
.5145 .60173 m .51582 .60249 L .52937 .60809 L F
.51568 .60289 m .45609 .53802 L .50468 .59102 L .571 .605 .848 r
F
.51462 .60185 m .50468 .59102 L .5145 .60173 L F
.51568 .60289 m .50468 .59102 L .51462 .60185 L F
.50468 .59102 m .45609 .53802 L .45655 .53858 L F
.45299 .53992 m .51047 .59941 L .50326 .58947 L .368 .521 .878 r
F
.45299 .53992 m .50326 .58947 L .45655 .53858 L F
.51047 .59941 m .51187 .60086 L .51107 .59976 L F
.45655 .53858 m .45182 .53277 L .45299 .53992 L .483 .612 .904 r
F
.48453 .58106 m .48661 .5823 L .48446 .58075 L .627 .537 .734 r
F
.47928 .57795 m .48661 .5823 L .4536 .54361 L .182 .455 .88 r
F
.45268 .54442 m .4536 .54361 L .43127 .51744 L F
.44936 .5473 m .45268 .54442 L .43127 .51744 L F
.45182 .53277 m .43819 .51605 L .45566 .55613 L .483 .612 .904 r
F
.47928 .57795 m .4536 .54361 L .45268 .54442 L .182 .455 .88 r
F
.45427 .5554 m .46637 .56168 L .45268 .54442 L F
.45427 .5554 m .45268 .54442 L .44936 .5473 L F
.44729 .54911 m .45427 .5554 L .44936 .5473 L F
.44855 .54801 m .43819 .51605 L .42026 .51576 L .483 .612 .904 r
F
.45114 .54575 m .43819 .51605 L .44855 .54801 L F
.43811 .54194 m .43824 .54197 L .43795 .54201 L .627 .339 .461 r
F
.43844 .54176 m .43824 .54197 L .43811 .54194 L .455 .123 .313 r
F
.41122 .51661 m .44698 .55163 L .45427 .5554 L .182 .455 .88 r
F
.45103 .55373 m .42026 .51576 L .37647 .51506 L .483 .612 .904 r
F
.45299 .53992 m .48431 .5796 L .48325 .57124 L .368 .521 .878 r
F
.4536 .54361 m .48431 .5796 L .45299 .53992 L F
.48431 .5796 m .48661 .5823 L .48325 .57124 L F
.47928 .57795 m .4848 .58291 L .48453 .58106 L .182 .455 .88 r
F
.48296 .58294 m .48297 .58265 L .48302 .58293 L .608 .314 .444 r
F
.48479 .58291 m .478 .58202 L .48494 .58613 L .182 .455 .88 r
F
.4848 .58292 m .48494 .58613 L .49495 .59206 L F
.48479 .58291 m .48494 .58613 L .4848 .58292 L F
.50548 .67375 m .50088 .65412 L .5 .65363 L .627 .537 .734 r
F
.50088 .65412 m .49245 .61817 L .49346 .62293 L F
.50088 .65412 m .49346 .62293 L .5 .65363 L F
.50939 .69103 m .50548 .67375 L .5 .65363 L F
.49495 .59206 m .50268 .66171 L .50424 .66826 L .47 .41 .709 r
F
.49495 .59206 m .50424 .66826 L .50415 .66381 L F
.50939 .69103 m .5119 .61289 L .50389 .65172 L .627 .537 .734 r
F
.48494 .58613 m .49163 .61469 L .49495 .59206 L .175 .215 .665 r
F
.49163 .61469 m .49888 .64558 L .49674 .61653 L F
.49163 .61469 m .49674 .61653 L .49495 .59206 L F
.47155 .6017 m .47035 .59952 L .48509 .62536 L .511 .482 .761 r
F
.47195 .60245 m .47155 .6017 L .48509 .62536 L F
.48379 .62411 m .48329 .62372 L .47195 .60245 L F
.48286 .69846 m .49068 .6568 L .48085 .69776 L .598 .448 .65 r
F
.49068 .6568 m .49356 .64142 L .49031 .65583 L F
.49068 .6568 m .49031 .65583 L .48085 .69776 L F
.48429 .6404 m .48918 .65476 L .49025 .65568 L 0 0 .413 r
F
.48831 .65056 m .49025 .65568 L .49038 .65579 L F
.48429 .6404 m .49025 .65568 L .48831 .65056 L F
.48228 .71117 m .49356 .64142 L .47989 .71432 L .598 .448 .65 r
F
.49574 .646 m .48687 .63011 L .48379 .62411 L .511 .482 .761 r
F
.48687 .63011 m .48329 .62372 L .48379 .62411 L F
.5 .65363 m .49163 .61469 L .48532 .61242 L F
.478 .58202 m .48611 .62152 L .48579 .61778 L .175 .215 .665 r
F
.48329 .62372 m .49148 .65892 L .48627 .6292 L 0 0 .413 r
F
.47153 .60207 m .48002 .62627 L .48329 .62372 L F
.48002 .62627 m .49148 .65892 L .48329 .62372 L F
.5 .65363 m .49574 .646 L .48509 .62536 L .511 .482 .761 r
F
.49574 .646 m .47195 .60245 L .48509 .62536 L F
.48687 .63011 m .48611 .62152 L .48329 .62372 L F
.48399 .64035 m .47035 .59952 L .47021 .59942 L .888 .491 .049 r
F
.47035 .59952 m .48276 .63593 L .47153 .60207 L 0 0 .413 r
F
.48236 .63547 m .48276 .63593 L .47035 .59952 L .888 .491 .049 r
F
.45045 .56493 m .47155 .6017 L .47195 .60245 L .511 .482 .761 r
F
.47247 .60379 m .47068 .60023 L .47195 .60245 L F
.47314 .60555 m .47153 .60207 L .47247 .60379 L F
.47153 .60207 m .47068 .60023 L .47247 .60379 L F
.48329 .62372 m .47247 .60379 L .47195 .60245 L F
.47153 .60207 m .48627 .6292 L .478 .58202 L 0 0 .413 r
F
.48329 .62372 m .47314 .60555 L .47247 .60379 L .511 .482 .761 r
F
.5 .65363 m .48803 .62003 L .48687 .63011 L F
.48803 .62003 m .48611 .62152 L .48687 .63011 L F
.49644 .66691 m .5 .65363 L .49239 .65692 L .598 .448 .65 r
F
.49148 .65892 m .4944 .66188 L .48611 .62152 L 0 0 .413 r
F
.48507 .62233 m .48611 .62152 L .478 .58202 L F
.49148 .65892 m .48611 .62152 L .48507 .62233 L F
.48803 .62003 m .48532 .61242 L .48611 .62152 L .511 .482 .761 r
F
.49693 .66608 m .5 .65363 L .49653 .66712 L .701 .531 .655 r
F
.48532 .61242 m .49653 .66712 L .49774 .66402 L .175 .215 .665 r
F
.478 .58202 m .48579 .61778 L .48532 .61242 L F
.48579 .61778 m .49653 .66712 L .48532 .61242 L F
.48477 .58213 m .48477 .58221 L .49237 .61785 L .627 .537 .734 r
F
.49245 .61817 m .49237 .61785 L .5 .65363 L F
.48477 .58213 m .49237 .61785 L .49245 .61817 L F
.48453 .58106 m .4848 .58291 L .49163 .61469 L F
.49237 .61785 m .49163 .61469 L .5 .65363 L F
.48453 .58106 m .49163 .61469 L .49237 .61785 L F
.50181 .68097 m .50381 .68483 L .50088 .65412 L .175 .215 .665 r
F
.49918 .64688 m .50088 .65412 L .49495 .59206 L F
.50181 .68097 m .50088 .65412 L .49918 .64688 L F
.50132 .67893 m .50168 .67919 L .49918 .64688 L F
.49888 .64558 m .49918 .64688 L .49495 .59206 L F
.50132 .67893 m .49918 .64688 L .49888 .64558 L F
.48834 .61351 m .50132 .67893 L .49888 .64558 L F
.478 .58202 m .48532 .61242 L .48834 .61351 L F
.48532 .61242 m .50132 .67893 L .48834 .61351 L F
.478 .58202 m .49888 .64558 L .48494 .58613 L F
.44743 .56318 m .44894 .56196 L .41522 .53517 L 0 .218 .637 r
F
.41862 .53693 m .44843 .56128 L .44542 .55728 L 0 .344 .809 r
F
.44835 .56118 m .44894 .56196 L .47035 .59952 L .511 .482 .761 r
F
.44835 .56118 m .47035 .59952 L .47155 .6017 L F
.46713 .59362 m .47006 .59898 L .46075 .57135 L .888 .491 .049 r
F
.47824 .63239 m .47021 .59942 L .46845 .59823 L F
.45045 .56493 m .45054 .565 L .47155 .6017 L .511 .482 .761 r
F
.45961 .57985 m .46713 .59362 L .46075 .57135 L .888 .491 .049 r
F
.46884 .59439 m .47035 .59952 L .47153 .60207 L 0 0 .413 r
F
.46075 .57135 m .47035 .59952 L .46884 .59439 L F
.4714 .59647 m .46969 .58559 L .4727 .59777 L .957 .664 .437 r
F
.46075 .57135 m .46884 .59439 L .478 .58202 L 0 0 .413 r
F
.46884 .59439 m .47153 .60207 L .47286 .59795 L F
.46884 .59439 m .47286 .59795 L .478 .58202 L F
.47153 .60207 m .48276 .63593 L .48366 .63723 L F
.48002 .62627 m .48366 .63723 L .48408 .63783 L F
.47153 .60207 m .48366 .63723 L .48002 .62627 L F
.47488 .60867 m .48336 .58998 L .46219 .57256 L .511 .482 .761 r
F
.47314 .60555 m .45045 .56493 L .47068 .60023 L F
.47006 .59898 m .47035 .59952 L .46075 .57135 L .888 .491 .049 r
F
.45045 .56493 m .44835 .56118 L .45054 .565 L .511 .482 .761 r
F
.45118 .56548 m .45216 .56622 L .46075 .57135 L 0 .218 .637 r
F
.44894 .56196 m .46075 .57135 L .45003 .56259 L 0 .344 .809 r
F
.47314 .60555 m .46219 .57256 L .44835 .56118 L .511 .482 .761 r
F
.47488 .60867 m .46219 .57256 L .47314 .60555 L F
.48336 .58998 m .48537 .58555 L .48283 .58388 L F
.46497 .57212 m .46075 .57135 L .478 .58202 L 0 .344 .809 r
F
.46005 .56888 m .46075 .57135 L .46497 .57212 L F
.44542 .55728 m .45319 .56441 L .45987 .56825 L F
.45319 .56441 m .46075 .57135 L .45987 .56825 L F
.48336 .58998 m .48283 .58388 L .44835 .56118 L .511 .482 .761 r
F
.48329 .62372 m .48532 .61242 L .47488 .60867 L F
.48611 .62152 m .48532 .61242 L .48329 .62372 L F
.48579 .61778 m .48856 .63341 L .48966 .63555 L .175 .215 .665 r
F
.48611 .62152 m .48856 .63341 L .48579 .61778 L F
.49163 .61469 m .48537 .58555 L .47488 .60867 L .511 .482 .761 r
F
.50088 .65412 m .48477 .58213 L .49245 .61817 L .627 .537 .734 r
F
.50548 .67375 m .50424 .66826 L .50088 .65412 L F
.49495 .59206 m .50088 .65412 L .50268 .66171 L .47 .41 .709 r
F
.50424 .66826 m .48477 .58213 L .50088 .65412 L .627 .537 .734 r
F
.50731 .69351 m .50792 .69277 L .50381 .68483 L .701 .531 .655 r
F
.50792 .69277 m .50939 .69103 L .50381 .68483 L F
.50268 .66171 m .50381 .68483 L .5058 .68976 L .47 .41 .709 r
F
.50088 .65412 m .50381 .68483 L .50268 .66171 L F
.50939 .69103 m .50389 .65172 L .50424 .66826 L .627 .537 .734 r
F
.50939 .69103 m .51267 .61167 L .51186 .61402 L F
.49993 .70516 m .49382 .72243 L .50304 .71499 L .543 .335 .549 r
F
.49993 .70516 m .50304 .71499 L .50721 .70739 L F
.4734 .78013 m .46745 .79695 L .47911 .77328 L F
.48296 .76873 m .46839 .79996 L .49141 .75877 L .692 .491 .61 r
F
.48163 .77293 m .49104 .75921 L .47302 .78046 L .875 .71 .674 r
F
.49465 .74579 m .4966 .74479 L .4962 .74521 L .803 .728 .781 r
F
.48783 .74992 m .4962 .74521 L .48629 .75591 L F
.47089 .78082 m .50779 .73478 L .50518 .71109 L .789 .613 .662 r
F
.47089 .78082 m .50518 .71109 L .48458 .74853 L F
.4622 .784 m .46461 .78656 L .4663 .78189 L .789 .547 .571 r
F
.45543 .78749 m .46443 .78658 L .4622 .784 L F
.46443 .78658 m .46461 .78656 L .4622 .784 L F
.4622 .784 m .45974 .78713 L .46592 .78832 L .61 .236 .308 r
F
.45974 .78713 m .46437 .79001 L .46592 .78832 L F
.4645 .79009 m .50779 .73478 L .46381 .78966 L .789 .613 .662 r
F
.49911 .72213 m .4734 .78013 L .50402 .72185 L .543 .335 .549 r
F
.49382 .72243 m .48458 .74853 L .49911 .72213 L F
.48458 .74853 m .4734 .78013 L .49911 .72213 L F
.49382 .72243 m .50402 .72185 L .511 .70855 L F
.48458 .74853 m .50518 .71109 L .50421 .70224 L .789 .613 .662 r
F
.49157 .72879 m .50791 .69416 L .50199 .70579 L F
.50791 .69416 m .50939 .69103 L .50768 .69443 L F
.50791 .69416 m .50768 .69443 L .50199 .70579 L F
.50839 .69579 m .5091 .69879 L .50939 .69103 L F
.5099 .69179 m .50882 .70025 L .51015 .69343 L .47 .41 .709 r
F
.49965 .71181 m .50794 .69413 L .49157 .72879 L .789 .613 .662 r
F
.50794 .69413 m .50939 .69103 L .50791 .69416 L F
.50794 .69413 m .50791 .69416 L .49157 .72879 L F
.50415 .66381 m .50802 .69403 L .50389 .65172 L .47 .41 .709 r
F
.50802 .69403 m .50882 .70025 L .50817 .69385 L F
.50802 .69403 m .50817 .69385 L .50389 .65172 L F
.50389 .65172 m .50817 .69385 L .5099 .69179 L F
.50817 .69385 m .50882 .70025 L .5099 .69179 L F
.49495 .59206 m .50415 .66381 L .50389 .65172 L F
.49495 .59206 m .50389 .65172 L .51187 .60086 L F
.49705 .63647 m .50331 .62401 L .48542 .585 L .627 .537 .734 r
F
.51047 .59941 m .49495 .59206 L .51187 .60086 L .368 .521 .878 r
F
.5145 .60173 m .51187 .60086 L .51481 .60208 L .476 .562 .863 r
F
.50468 .59102 m .51107 .59976 L .5145 .60173 L F
.51107 .59976 m .51187 .60086 L .5145 .60173 L F
.50389 .65172 m .51162 .61422 L .51187 .60086 L .47 .41 .709 r
F
.51186 .61402 m .51267 .61167 L .5119 .61289 L .627 .537 .734 r
F
.51475 .66072 m .51525 .65698 L .51191 .68126 L .719 .599 .722 r
F
.51475 .66072 m .51191 .68126 L .51203 .68045 L F
.51015 .69343 m .51208 .70636 L .51203 .68045 L .47 .41 .709 r
F
.51525 .65698 m .51336 .67034 L .50896 .70279 L .719 .599 .722 r
F
.51015 .69343 m .51203 .68045 L .5119 .61289 L .47 .41 .709 r
F
.51162 .61422 m .5119 .61289 L .51187 .60086 L F
.51015 .69343 m .5119 .61289 L .51162 .61422 L F
.51322 .61007 m .51723 .60442 L .51568 .60289 L .627 .537 .734 r
F
.51187 .60086 m .51267 .61167 L .5133 .60982 L .609 .514 .722 r
F
.51187 .60086 m .51455 .66215 L .51575 .65346 L F
.50336 .62645 m .51723 .60442 L .50331 .62401 L .627 .537 .734 r
F
.5133 .60982 m .51575 .65346 L .51786 .63848 L .609 .514 .722 r
F
.51267 .61167 m .51575 .65346 L .5133 .60982 L F
.50331 .62401 m .51322 .61007 L .5145 .60173 L .627 .537 .734 r
F
.51322 .61007 m .51568 .60289 L .5145 .60173 L F
.50331 .62401 m .51399 .60274 L .50269 .59494 L F
.51399 .60274 m .5145 .60173 L .51423 .60158 L F
.51399 .60274 m .51423 .60158 L .50269 .59494 L F
.50331 .62401 m .50269 .59494 L .48542 .585 L F
.50424 .66826 m .50389 .65172 L .50227 .65956 L F
.50424 .66826 m .5058 .68976 L .50528 .67262 L .47 .41 .709 r
F
.50268 .66171 m .50443 .67748 L .50424 .66826 L F
.50443 .67748 m .5058 .68976 L .50424 .66826 L F
.50415 .66381 m .50424 .66826 L .50528 .67262 L F
.49705 .63647 m .50336 .62645 L .50331 .62401 L .627 .537 .734 r
F
.50528 .67262 m .5058 .68976 L .50802 .69403 L .47 .41 .709 r
F
.48477 .58213 m .48453 .58106 L .48477 .58221 L .627 .537 .734 r
F
.48477 .58213 m .49175 .58598 L .48453 .58106 L F
.49175 .58598 m .48661 .5823 L .48453 .58106 L F
.48661 .5823 m .48911 .58409 L .50048 .58907 L .368 .521 .878 r
F
.48911 .58409 m .49796 .59043 L .50048 .58907 L F
.48477 .58213 m .50474 .5953 L .49175 .58598 L .627 .537 .734 r
F
.50048 .58907 m .49796 .59043 L .51047 .59941 L .368 .521 .878 r
F
.48092 .58051 m .48093 .5805 L .48087 .58048 L .511 .482 .761 r
F
.48092 .58051 m .46875 .57295 L .46497 .57212 L F
.47928 .57795 m .47888 .57924 L .48479 .58291 L .182 .455 .88 r
F
.48537 .58555 m .4848 .58291 L .48006 .58206 L .511 .482 .761 r
F
.41862 .53693 m .46497 .57212 L .44698 .55163 L 0 .344 .809 r
F
.46497 .57212 m .46875 .57295 L .44698 .55163 L F
.45476 .55926 m .46875 .57295 L .47928 .57795 L .182 .455 .88 r
F
.46875 .57295 m .47888 .57924 L .47928 .57795 L F
.45987 .56825 m .46005 .56888 L .46497 .57212 L 0 .344 .809 r
F
.48966 .63555 m .4944 .66188 L .49653 .66712 L .175 .215 .665 r
F
.48856 .63341 m .4944 .66188 L .48966 .63555 L F
.50132 .67893 m .50181 .68097 L .50168 .67919 L F
.46889 .7427 m .47021 .74657 L .48759 .70012 L 0 0 .088 r
F
.46889 .7427 m .48759 .70012 L .48669 .6998 L F
.48085 .69776 m .48008 .70951 L .4851 .69925 L F
.48085 .69776 m .49031 .65583 L .48134 .68954 L .598 .448 .65 r
F
.49031 .65583 m .49006 .65518 L .48134 .68954 L F
.48408 .63783 m .48424 .63983 L .49038 .65579 L 0 0 .413 r
F
.48424 .63983 m .48429 .6404 L .48831 .65056 L F
.48424 .63983 m .48831 .65056 L .49038 .65579 L F
.48276 .63593 m .48429 .6404 L .48424 .63983 L F
.48276 .63593 m .48424 .63983 L .48408 .63783 L F
.4839 .64569 m .48424 .63983 L .48404 .64509 L .598 .448 .65 r
F
.48424 .63983 m .48426 .64006 L .48404 .64509 L F
.48134 .68954 m .4839 .64569 L .48201 .68331 L F
.4839 .64569 m .48404 .64509 L .48201 .68331 L F
.48485 .67352 m .48155 .68759 L .48149 .68807 L 0 0 .088 r
F
.48918 .65476 m .48461 .67434 L .48485 .67352 L F
.48918 .65476 m .48201 .68331 L .48461 .67434 L F
.48257 .67418 m .48254 .67474 L .4828 .67512 L .981 .833 .437 r
F
.4881 .65255 m .48918 .65476 L .4884 .65247 L .888 .491 .049 r
F
.48134 .68954 m .49006 .65518 L .48424 .63983 L .598 .448 .65 r
F
.48399 .64035 m .48276 .63593 L .48236 .63547 L .888 .491 .049 r
F
.43814 .57066 m .4432 .56163 L .43163 .55552 L .315 .407 .797 r
F
.43814 .57066 m .43163 .55552 L .42711 .55781 L F
.46283 .59459 m .46284 .59531 L .46278 .59437 L .787 .521 0 r
F
.46945 .60714 m .46708 .59729 L .45808 .59118 L .315 .407 .797 r
F
.46945 .60714 m .45808 .59118 L .46206 .59853 L F
.46745 .598 m .46708 .59729 L .46945 .60714 L F
.45808 .59118 m .4617 .59858 L .46845 .59823 L .888 .491 .049 r
F
.4617 .59858 m .47824 .63239 L .47222 .61137 L F
.4617 .59858 m .47222 .61137 L .46845 .59823 L F
.48345 .64364 m .48375 .64031 L .48197 .64002 L .437 .333 .639 r
F
.36163 .51604 m .36179 .51542 L .34849 .51873 L .379 .639 .957 r
F
.36179 .51542 m .3533 .51544 L .34849 .51873 L F
.36163 .51604 m .34849 .51873 L .35227 .51845 L F
.29252 .51668 m .37635 .51667 L .30513 .50911 L .14 .68 .834 r
F
.37635 .51667 m .37652 .51636 L .30513 .50911 L F
.37864 .51619 m .37464 .51412 L .37915 .51646 L .483 .612 .904 r
F
.44536 .55079 m .37864 .51619 L .40384 .52927 L F
.37864 .51619 m .37915 .51646 L .40384 .52927 L F
.28143 .52561 m .34653 .52172 L .36056 .5191 L .217 .737 .848 r
F
.33752 .52623 m .34323 .52233 L .33141 .52491 L .379 .639 .957 r
F
.34323 .52233 m .33255 .52433 L .33141 .52491 L F
.27217 .53591 m .3343 .52743 L .3432 .52353 L .338 .815 .885 r
F
.33967 .52544 m .33877 .52538 L .33752 .52623 L .379 .639 .957 r
F
.3343 .52743 m .33967 .52544 L .3432 .52353 L .338 .815 .885 r
F
.31894 .50286 m .41734 .51563 L .33363 .49787 L .12 .646 .876 r
F
.41734 .51563 m .41961 .5151 L .33363 .49787 L F
.43819 .51605 m .43457 .51162 L .42083 .51482 L .483 .612 .904 r
F
.43457 .51162 m .43261 .50921 L .42083 .51482 L F
.43861 .51591 m .43952 .51604 L .43261 .50921 L .571 .605 .848 r
F
.43876 .51567 m .44131 .51629 L .44014 .51356 L .182 .659 .931 r
F
.44131 .51629 m .44335 .51678 L .44311 .51653 L F
.44131 .51629 m .44311 .51653 L .44014 .51356 L F
.43744 .51627 m .41961 .5151 L .44161 .51701 L .15 .652 .908 r
F
.52171 .60882 m .52035 .6073 L .51568 .60289 L .571 .605 .848 r
F
.51582 .60249 m .51608 .6071 L .51946 .604 L .609 .514 .722 r
F
.51608 .6071 m .51786 .63848 L .51931 .60725 L F
.51608 .6071 m .51931 .60725 L .51946 .604 L F
.52171 .60882 m .52159 .60735 L .52036 .6073 L .571 .605 .848 r
F
.54484 .66341 m .54225 .65213 L .52171 .60882 L .651 .623 .809 r
F
.54225 .65213 m .5297 .62267 L .52171 .60882 L F
.53996 .62086 m .54065 .62205 L .52914 .61597 L .666 .547 .71 r
F
.53996 .62086 m .52914 .61597 L .52889 .61543 L F
.52937 .60809 m .52842 .61968 L .52951 .62223 L .683 .581 .735 r
F
.52999 .62318 m .52177 .60767 L .52171 .60882 L .651 .623 .809 r
F
.52937 .60809 m .52951 .62223 L .53057 .62433 L .683 .581 .735 r
F
.56021 .63081 m .54065 .62205 L .53996 .62086 L .666 .547 .71 r
F
.53893 .61908 m .52193 .57651 L .54605 .571 L .699 .548 .679 r
F
.53313 .60905 m .52193 .57651 L .53893 .61908 L F
.53893 .61908 m .54605 .571 L .55196 .61979 L F
.53822 .62386 m .55531 .64742 L .55608 .65379 L F
.53577 .61003 m .53572 .63448 L .5482 .6138 L .683 .581 .735 r
F
.54225 .65213 m .54025 .64342 L .5297 .62267 L .651 .623 .809 r
F
.54025 .64342 m .52999 .62318 L .5297 .62267 L F
.51786 .63848 m .5238 .67581 L .52044 .62023 L .609 .514 .722 r
F
.52965 .68822 m .54484 .66341 L .52024 .62211 L .719 .599 .722 r
F
.53562 .68448 m .54142 .72557 L .54484 .66341 L .812 .687 .726 r
F
.5356 .69197 m .54142 .72557 L .53562 .68448 L F
.53011 .69179 m .52042 .71698 L .53018 .69198 L .683 .581 .735 r
F
.5238 .67581 m .52131 .70619 L .53011 .69179 L F
.52131 .70619 m .52042 .71698 L .53011 .69179 L F
.53508 .6852 m .53018 .69198 L .5356 .69229 L F
.53024 .69158 m .53031 .69146 L .53024 .69159 L .812 .687 .726 r
F
.53031 .69146 m .54484 .66341 L .53014 .69171 L F
.53018 .69166 m .53014 .69171 L .53011 .69179 L F
.53031 .69146 m .53014 .69171 L .53018 .69166 L F
.51455 .66215 m .51208 .70636 L .51674 .71229 L .609 .514 .722 r
F
.51237 .61215 m .51216 .67949 L .51455 .66215 L F
.51216 .67949 m .51208 .70636 L .51455 .66215 L F
.5119 .61289 m .51208 .70636 L .51237 .61215 L F
.52044 .62023 m .51575 .65346 L .5089 .70432 L .719 .599 .722 r
F
.51575 .65346 m .51525 .65698 L .51475 .66072 L F
.51575 .65346 m .51475 .66072 L .5089 .70432 L F
.51208 .70636 m .51087 .73425 L .51674 .71229 L .692 .491 .61 r
F
.50955 .72154 m .52967 .68839 L .50925 .72155 L .719 .599 .722 r
F
.52967 .68839 m .54484 .66341 L .52965 .68822 L F
.52967 .68839 m .52965 .68822 L .50925 .72155 L F
.52596 .61524 m .52177 .60767 L .52999 .62318 L .651 .623 .809 r
F
.51977 .70818 m .51674 .71229 L .52042 .71698 L .609 .514 .722 r
F
.51384 .72311 m .51975 .71175 L .50918 .72214 L .719 .599 .722 r
F
.51975 .71175 m .54484 .66341 L .51512 .71236 L F
.51975 .71175 m .51512 .71236 L .50918 .72214 L F
.52937 .60809 m .53057 .62433 L .53577 .61003 L .683 .581 .735 r
F
.53508 .6852 m .5356 .69229 L .53562 .68448 L F
.53018 .69198 m .53049 .72409 L .53275 .71003 L F
.53018 .69198 m .53275 .71003 L .5356 .69229 L F
.51087 .73425 m .51046 .73579 L .52042 .71698 L .692 .491 .61 r
F
.50619 .75174 m .53562 .68448 L .51378 .72337 L .812 .687 .726 r
F
.53562 .68448 m .54484 .66341 L .53024 .69158 L F
.53018 .69166 m .53018 .69198 L .53019 .69166 L .683 .581 .735 r
F
.53019 .69166 m .53018 .69198 L .53508 .6852 L F
.52392 .67473 m .52965 .68822 L .52555 .65943 L .719 .599 .722 r
F
.52392 .67473 m .52555 .65943 L .52024 .62211 L F
.51638 .65698 m .52392 .67473 L .52024 .62211 L F
.52907 .68916 m .52965 .68822 L .51638 .65698 L F
.52951 .62223 m .5238 .67581 L .53018 .69198 L .683 .581 .735 r
F
.53562 .68448 m .53024 .69158 L .51378 .72337 L .812 .687 .726 r
F
.53057 .62433 m .53508 .6852 L .53572 .63448 L .683 .581 .735 r
F
.53508 .6852 m .53562 .68448 L .53572 .63448 L F
.53057 .62433 m .53572 .63448 L .53577 .61003 L F
.53572 .63448 m .54025 .64342 L .5482 .6138 L F
.56026 .63082 m .54605 .571 L .57268 .56248 L .684 .561 .71 r
F
.55538 .62434 m .54605 .571 L .56026 .63082 L F
.55611 .63022 m .5622 .63344 L .55871 .6431 L .743 .634 .739 r
F
.56026 .63082 m .57268 .56248 L .58015 .63368 L .684 .561 .71 r
F
.56049 .63085 m .5618 .62248 L .5622 .63344 L .666 .547 .71 r
F
.56021 .63081 m .5622 .63344 L .55611 .63022 L F
.5482 .6138 m .54697 .64468 L .56918 .61842 L .722 .627 .751 r
F
.54484 .66341 m .55274 .65001 L .54465 .64574 L .651 .623 .809 r
F
.56186 .62707 m .565 .63638 L .56918 .61842 L .722 .627 .751 r
F
.54697 .64468 m .55922 .63904 L .56186 .62707 L F
.55922 .63904 m .565 .63638 L .56186 .62707 L F
.54184 .7178 m .54452 .70566 L .54484 .66341 L .728 .669 .792 r
F
.54767 .69951 m .55358 .65995 L .58171 .64862 L .794 .728 .79 r
F
.55608 .65379 m .55531 .64742 L .55835 .6413 L .684 .561 .71 r
F
.55358 .65995 m .55608 .65379 L .56069 .65286 L .794 .728 .79 r
F
.55358 .65995 m .56069 .65286 L .58171 .64862 L F
.55608 .65379 m .55835 .6413 L .55842 .64163 L .684 .561 .71 r
F
.54452 .70566 m .55922 .63904 L .55274 .65001 L .728 .669 .792 r
F
.54452 .70566 m .55274 .65001 L .54484 .66341 L F
.54112 .72619 m .54311 .72427 L .54142 .72557 L .814 .762 .804 r
F
.54452 .70566 m .54172 .72463 L .54233 .72447 L .722 .627 .751 r
F
.54142 .72557 m .54311 .72427 L .54172 .72463 L .728 .669 .792 r
F
.54452 .70566 m .54226 .72509 L .5438 .7236 L .722 .627 .751 r
F
.56108 .72766 m .63613 .62927 L .57952 .71964 L .819 .811 .843 r
F
.56108 .72766 m .60896 .64054 L .63613 .62927 L F
.56294 .70663 m .54979 .72136 L .56174 .72347 L .735 .656 .771 r
F
.5445 .72254 m .54678 .72083 L .54541 .72058 L .728 .669 .792 r
F
.54473 .72347 m .5462 .72211 L .54403 .72357 L .814 .762 .804 r
F
.54473 .72347 m .54362 .72827 L .54979 .72136 L .735 .656 .771 r
F
.54746 .72095 m .54979 .72136 L .56294 .70663 L F
.54473 .72347 m .54979 .72136 L .54746 .72095 L F
.55274 .65001 m .55922 .63904 L .54697 .64468 L .651 .623 .809 r
F
.55274 .65001 m .54373 .64168 L .54025 .64342 L F
.54697 .64468 m .5438 .7236 L .565 .63638 L .722 .627 .751 r
F
.5438 .7236 m .54391 .72359 L .565 .63638 L F
.54378 .7241 m .54541 .72058 L .565 .63638 L F
.54311 .72427 m .54746 .72095 L .54172 .72463 L .728 .669 .792 r
F
.54746 .72095 m .54678 .72083 L .54172 .72463 L F
.55958 .71314 m .55138 .71795 L .54746 .72095 L .814 .762 .804 r
F
.5462 .72211 m .54746 .72095 L .54403 .72357 L F
.55958 .71314 m .54746 .72095 L .5462 .72211 L F
.54172 .72463 m .5445 .72254 L .54512 .72053 L .728 .669 .792 r
F
.56759 .64085 m .54541 .72058 L .56294 .70663 L .735 .656 .771 r
F
.56918 .61842 m .565 .63638 L .56759 .64085 L F
.565 .63638 m .54541 .72058 L .56759 .64085 L F
.58171 .64862 m .57268 .56248 L .60109 .54985 L .688 .59 .741 r
F
.56695 .70606 m .60288 .67861 L .56711 .70553 L .728 .669 .792 r
F
.58171 .64862 m .60109 .54985 L .60896 .64054 L .688 .59 .741 r
F
.56918 .61842 m .56294 .70663 L .59192 .62257 L .735 .656 .771 r
F
.56294 .70663 m .56174 .72347 L .56695 .70606 L F
.56294 .70663 m .56695 .70606 L .59192 .62257 L F
.57952 .71964 m .6612 .61515 L .59526 .70965 L .852 .894 .866 r
F
.57952 .71964 m .63613 .62927 L .6612 .61515 L F
.58773 .69093 m .56122 .73085 L .58444 .73387 L .731 .671 .792 r
F
.56857 .70583 m .58739 .69096 L .56695 .70606 L .814 .762 .804 r
F
.57588 .70014 m .58739 .69096 L .56857 .70583 L F
.58739 .69096 m .60288 .67861 L .58663 .69103 L F
.58739 .69096 m .58663 .69103 L .56695 .70606 L F
.58783 .6896 m .60288 .67861 L .59185 .63705 L .728 .669 .792 r
F
.58783 .6896 m .59185 .63705 L .58896 .62618 L F
.54541 .72058 m .54746 .72095 L .56294 .70663 L .735 .656 .771 r
F
.54541 .72058 m .58783 .6896 L .58896 .62618 L .728 .669 .792 r
F
.54678 .72083 m .60288 .67861 L .54541 .72058 L F
.56857 .70583 m .56122 .73085 L .58773 .69093 L .731 .671 .792 r
F
.58773 .69093 m .58444 .73387 L .58557 .73049 L F
.59291 .69048 m .58776 .71856 L .60288 .67861 L .814 .762 .804 r
F
.59291 .69048 m .58557 .73049 L .59909 .68995 L .731 .671 .792 r
F
.58773 .69093 m .58557 .73049 L .59291 .69048 L F
.52741 .76848 m .53401 .76457 L .56122 .73085 L .92 .85 .758 r
F
.52741 .76848 m .58086 .73679 L .58776 .71856 L .814 .762 .804 r
F
.56831 .70587 m .56122 .73085 L .56857 .70583 L .735 .656 .771 r
F
.56174 .72347 m .56122 .73085 L .59192 .62257 L F
.56174 .72347 m .54362 .72827 L .56122 .73085 L F
.54979 .72136 m .54362 .72827 L .56174 .72347 L F
.54378 .7241 m .54362 .72827 L .54473 .72347 L .722 .627 .751 r
F
.54403 .72357 m .54473 .72347 L .54541 .72058 L F
.54378 .7241 m .54473 .72347 L .54403 .72357 L F
.49011 .8061 m .49058 .80589 L .54135 .72755 L .896 .772 .717 r
F
.49024 .80604 m .53985 .72887 L .54112 .72619 L .92 .842 .75 r
F
.54119 .72592 m .54112 .72619 L .54142 .72557 L F
.49024 .80604 m .54112 .72619 L .54119 .72592 L F
.54379 .72398 m .54121 .72585 L .54362 .72827 L .722 .627 .751 r
F
.54121 .72585 m .54081 .72738 L .54362 .72827 L F
.53521 .75919 m .56793 .72023 L .53985 .72887 L .814 .762 .804 r
F
.56793 .72023 m .58157 .70399 L .55018 .72271 L F
.56793 .72023 m .55018 .72271 L .53985 .72887 L F
.58157 .70399 m .60288 .67861 L .56879 .7058 L F
.58157 .70399 m .56879 .7058 L .53985 .72887 L F
.59192 .62257 m .56831 .70587 L .59294 .62276 L .735 .656 .771 r
F
.56831 .70587 m .56857 .70583 L .59294 .62276 L F
.58157 .70399 m .58776 .71856 L .59291 .69048 L .814 .762 .804 r
F
.52741 .76848 m .57383 .73008 L .58157 .70399 L F
.57383 .73008 m .58776 .71856 L .58157 .70399 L F
.59294 .62276 m .56857 .70583 L .58773 .69093 L .731 .671 .792 r
F
.56879 .7058 m .57588 .70014 L .56857 .70583 L .814 .762 .804 r
F
.60896 .64054 m .6301 .53254 L .63613 .62927 L .712 .634 .768 r
F
.60896 .64054 m .60109 .54985 L .6301 .53254 L F
.59294 .62276 m .58773 .69093 L .61981 .62787 L .731 .671 .792 r
F
.58773 .69093 m .59909 .68995 L .61981 .62787 L F
.55958 .71314 m .56879 .7058 L .55138 .71795 L .814 .762 .804 r
F
.56879 .7058 m .56695 .70606 L .55138 .71795 L F
.54746 .72095 m .56695 .70606 L .54678 .72083 L .728 .669 .792 r
F
.56695 .70606 m .56711 .70553 L .54678 .72083 L F
.52193 .57651 m .52297 .56391 L .54605 .571 L .494 .321 .575 r
F
.53283 .57165 m .5482 .6138 L .56918 .61842 L .568 .612 .856 r
F
.51969 .56197 m .52023 .55025 L .52307 .5627 L .494 .321 .575 r
F
.54469 .56615 m .53527 .53254 L .54567 .56618 L .474 .357 .64 r
F
.52326 .56352 m .54567 .56618 L .5328 .56572 L .666 .547 .71 r
F
.52326 .56352 m .5328 .56572 L .52297 .56391 L F
.52297 .56391 m .53002 .56521 L .54605 .571 L .494 .321 .575 r
F
.5152 .56256 m .52326 .56352 L .52194 .56533 L .666 .547 .71 r
F
.51969 .56197 m .51305 .51877 L .52023 .55025 L .494 .321 .575 r
F
.53195 .54155 m .54567 .56618 L .5152 .56256 L .55 .438 .679 r
F
.52156 .56188 m .5482 .6138 L .53283 .57165 L .568 .612 .856 r
F
.47507 .52883 m .47885 .5269 L .47867 .52864 L .455 .123 .313 r
F
.47325 .53293 m .47867 .52864 L .48541 .52851 L 0 0 0 r
F
.47867 .52864 m .47886 .52848 L .48129 .5285 L F
.47867 .52864 m .48129 .5285 L .48541 .52851 L F
.47885 .5269 m .47962 .52788 L .47867 .52864 L .523 .324 .553 r
F
.50048 .55873 m .50466 .55908 L .50289 .56083 L .65 .463 .618 r
F
.50048 .55873 m .50289 .56083 L .49678 .56688 L F
.48468 .54484 m .48541 .52851 L .4847 .54483 L .608 .314 .444 r
F
.4847 .54483 m .48541 .52851 L .48967 .54288 L F
.52008 .59652 m .51159 .5783 L .52193 .57651 L .732 .552 .648 r
F
.52008 .59652 m .52193 .57651 L .52441 .594 L F
.47116 .52845 m .47952 .52453 L .47785 .52714 L 0 0 0 r
F
.47789 .52709 m .48117 .52366 L .47885 .5269 L F
.4798 .52409 m .48117 .52366 L .47789 .52709 L F
.47116 .52845 m .48413 .51732 L .47952 .52453 L F
.47885 .5269 m .47975 .52778 L .47962 .52788 L .523 .324 .553 r
F
.48541 .52851 m .48621 .52727 L .48623 .52725 L 0 0 0 r
F
.51142 .52213 m .51447 .52501 L .5152 .56256 L .55 .438 .679 r
F
.51447 .52501 m .5213 .55491 L .5152 .56256 L F
.47885 .5269 m .48447 .52607 L .47943 .52747 L .523 .324 .553 r
F
.50551 .53752 m .49859 .52217 L .50669 .52701 L .543 .31 .512 r
F
.50326 .55757 m .50551 .53752 L .51444 .55873 L F
.51093 .55837 m .51142 .52213 L .5152 .56256 L .523 .324 .553 r
F
.50613 .5229 m .51142 .52213 L .51093 .55837 L F
.51077 .56519 m .51816 .56757 L .52193 .57651 L .543 .31 .512 r
F
.5152 .56256 m .51862 .56772 L .51575 .57205 L .666 .547 .71 r
F
.52104 .57666 m .51616 .57142 L .52193 .57651 L .543 .31 .512 r
F
.51616 .57142 m .51647 .57097 L .52193 .57651 L F
.50811 .56538 m .5152 .56256 L .51575 .57205 L .65 .463 .618 r
F
.50326 .55757 m .50018 .55424 L .50551 .53752 L .543 .31 .512 r
F
.52074 .5961 m .51645 .53961 L .47379 .52414 L .571 .605 .848 r
F
.52083 .59519 m .52937 .60809 L .52086 .59488 L .476 .562 .863 r
F
.46953 .52912 m .47104 .5286 L .47043 .52907 L .455 .123 .313 r
F
.46315 .52938 m .47179 .52664 L .46369 .52989 L 0 0 0 r
F
.47179 .52664 m .47093 .52728 L .46369 .52989 L F
.46369 .52989 m .47093 .52728 L .46882 .52887 L F
.45188 .51883 m .52612 .60434 L .47137 .52043 L .476 .562 .863 r
F
.52182 .56883 m .5482 .6138 L .52156 .56188 L .568 .612 .856 r
F
.52193 .57651 m .5199 .56813 L .52051 .56729 L .494 .321 .575 r
F
.52058 .57955 m .52937 .60809 L .5482 .6138 L .538 .59 .855 r
F
.52086 .59488 m .52002 .58436 L .52074 .5961 L .651 .623 .809 r
F
.51891 .57039 m .51645 .53961 L .51882 .57086 L F
.52035 .56713 m .51645 .53961 L .52086 .59488 L F
.52058 .57955 m .5482 .6138 L .52182 .56883 L .538 .59 .855 r
F
.52156 .56188 m .51645 .53961 L .52228 .58072 L .651 .623 .809 r
F
.53666 .51403 m .5428 .51206 L .51447 .52501 L .55 .438 .679 r
F
.51447 .52501 m .53195 .54155 L .5213 .55491 L F
.52307 .5627 m .5267 .51896 L .54372 .56269 L .494 .321 .575 r
F
.5328 .56572 m .54567 .56618 L .54522 .56801 L .666 .547 .71 r
F
.52307 .5627 m .51305 .51877 L .52694 .51598 L .494 .321 .575 r
F
.54605 .571 m .54522 .56801 L .54567 .56618 L .474 .357 .64 r
F
.54605 .571 m .54567 .56618 L .54609 .56694 L F
.54605 .571 m .54675 .4919 L .57268 .56248 L F
.51928 .55193 m .58209 .60029 L .51645 .53961 L .651 .623 .809 r
F
.54189 .57328 m .58209 .60029 L .51928 .55193 L F
.55744 .59742 m .58209 .60029 L .52095 .55921 L F
.57615 .60999 m .56918 .61842 L .58819 .61807 L .577 .626 .864 r
F
.5765 .60977 m .58819 .61807 L .58689 .6165 L F
.55744 .59742 m .57615 .60999 L .5765 .60977 L F
.57615 .60999 m .58819 .61807 L .5765 .60977 L F
.58928 .61805 m .58819 .61807 L .59294 .62276 L F
.58819 .61807 m .56918 .61842 L .59192 .62257 L F
.58819 .61807 m .59192 .62257 L .59294 .62276 L F
.57976 .60789 m .58616 .61562 L .58209 .60029 L .728 .669 .792 r
F
.57966 .60778 m .57986 .60716 L .57964 .60779 L F
.57986 .60716 m .58209 .60029 L .57984 .60717 L F
.57986 .60716 m .57984 .60717 L .57964 .60779 L F
.57964 .60779 m .57984 .60717 L .5765 .60977 L F
.57984 .60717 m .58209 .60029 L .57794 .60733 L F
.57984 .60717 m .57794 .60733 L .5765 .60977 L F
.58928 .61805 m .59145 .62009 L .58398 .60681 L .577 .626 .864 r
F
.57966 .60778 m .57976 .60789 L .58209 .60029 L .728 .669 .792 r
F
.57429 .60834 m .58209 .60029 L .55744 .59742 L .651 .623 .809 r
F
.57659 .60961 m .58209 .60029 L .57467 .60794 L F
.58313 .60688 m .58398 .60681 L .53989 .52837 L .577 .626 .864 r
F
.58928 .61805 m .58398 .60681 L .58313 .60688 L F
.5267 .51896 m .53527 .53254 L .54372 .56269 L .494 .321 .575 r
F
.53527 .53254 m .53547 .532 L .54567 .56618 L .474 .357 .64 r
F
.51704 .52514 m .58076 .60709 L .53989 .52837 L .577 .626 .864 r
F
.58076 .60709 m .58928 .61805 L .58313 .60688 L F
.58076 .60709 m .58313 .60688 L .53989 .52837 L F
.55744 .59742 m .5675 .61543 L .57615 .60999 L F
.5675 .61543 m .56918 .61842 L .57615 .60999 L F
.53283 .57165 m .56918 .61842 L .55744 .59742 L .568 .612 .856 r
F
.56347 .63184 m .57372 .61447 L .55829 .62482 L .651 .623 .809 r
F
.57372 .61447 m .57659 .60961 L .5724 .61309 L F
.57372 .61447 m .5724 .61309 L .55829 .62482 L F
.52095 .55921 m .54189 .57328 L .51928 .55193 L F
.52137 .55691 m .53283 .57165 L .52467 .53879 L .568 .612 .856 r
F
.53283 .57165 m .55744 .59742 L .52467 .53879 L F
.57659 .60961 m .57467 .60794 L .55829 .62482 L .651 .623 .809 r
F
.54609 .56694 m .54567 .56618 L .54611 .56439 L .474 .357 .64 r
F
.51704 .52514 m .55744 .59742 L .58928 .61805 L .577 .626 .864 r
F
.5445 .72254 m .58896 .62618 L .58616 .61562 L .728 .669 .792 r
F
.5445 .72254 m .58616 .61562 L .57976 .60789 L F
.54172 .72463 m .57966 .60778 L .542 .72272 L F
.57966 .60778 m .57964 .60779 L .542 .72272 L F
.5439 .71693 m .57964 .60779 L .56291 .63279 L F
.57964 .60779 m .5765 .60977 L .56291 .63279 L F
.58689 .6165 m .58819 .61807 L .58928 .61805 L .577 .626 .864 r
F
.54316 .72019 m .54512 .72053 L .57976 .60789 L .728 .669 .792 r
F
.54316 .72019 m .57976 .60789 L .57966 .60778 L F
.57105 .61167 m .57429 .60834 L .55744 .59742 L .651 .623 .809 r
F
.58928 .61805 m .59294 .62276 L .59145 .62009 L .577 .626 .864 r
F
.54142 .72557 m .54172 .72463 L .542 .72272 L .728 .669 .792 r
F
.54142 .72557 m .55922 .63904 L .54184 .7178 L F
.54484 .66341 m .54465 .64574 L .54115 .64735 L .651 .623 .809 r
F
.54107 .72585 m .54142 .72557 L .53468 .68663 L .812 .687 .726 r
F
.54121 .72585 m .54119 .72592 L .54142 .72557 L .92 .842 .75 r
F
.54121 .72585 m .54142 .72557 L .54109 .72594 L F
.54641 .64416 m .53963 .727 L .54158 .72559 L .722 .627 .751 r
F
.5482 .6138 m .54594 .64373 L .54641 .64416 L F
.54594 .64373 m .53963 .727 L .54641 .64416 L F
.54697 .64468 m .54158 .72559 L .54452 .70566 L F
.5482 .6138 m .54641 .64416 L .54697 .64468 L F
.54641 .64416 m .54158 .72559 L .54697 .64468 L F
.5482 .6138 m .54373 .64168 L .54594 .64373 L F
.54025 .64342 m .54373 .64168 L .5482 .6138 L .683 .581 .735 r
F
.56261 .63227 m .55829 .62482 L .54278 .64081 L .651 .623 .809 r
F
.54373 .64168 m .54278 .64081 L .54025 .64342 L F
.56261 .63227 m .54278 .64081 L .54373 .64168 L F
.53881 .63714 m .57105 .61167 L .52095 .55921 L F
.54025 .64342 m .54278 .64081 L .53881 .63714 L F
.54278 .64081 m .57105 .61167 L .53881 .63714 L F
.51142 .52213 m .53666 .51403 L .51447 .52501 L .55 .438 .679 r
F
.48777 .52516 m .50691 .49794 L .49859 .52217 L 0 0 0 r
F
.50105 .52364 m .50613 .5229 L .50669 .52701 L .523 .324 .553 r
F
.49473 .52263 m .52137 .55691 L .51704 .52514 L .568 .612 .856 r
F
.52137 .55691 m .52467 .53879 L .51704 .52514 L F
.52002 .58436 m .51891 .57039 L .51992 .58527 L .651 .623 .809 r
F
.51891 .57039 m .51882 .57086 L .51992 .58527 L F
.52002 .58436 m .51992 .58527 L .52074 .5961 L F
.47302 .52057 m .52058 .57955 L .49473 .52263 L .538 .59 .855 r
F
.52086 .59488 m .52937 .60809 L .52058 .57955 L F
.52228 .58072 m .52035 .56713 L .52086 .59488 L .651 .623 .809 r
F
.52058 .57955 m .52182 .56883 L .49473 .52263 L .538 .59 .855 r
F
.47302 .52057 m .52086 .59488 L .52058 .57955 L F
.52337 .56981 m .52156 .56188 L .52228 .58072 L .651 .623 .809 r
F
.49473 .52263 m .51381 .55516 L .52156 .56188 L .568 .612 .856 r
F
.52137 .55691 m .52156 .56188 L .53283 .57165 L F
.49473 .52263 m .52156 .56188 L .52137 .55691 L F
.52612 .60434 m .52937 .60809 L .47137 .52043 L .476 .562 .863 r
F
.52372 .57133 m .52337 .56981 L .52075 .59628 L .651 .623 .809 r
F
.52337 .56981 m .52074 .5961 L .52075 .59628 L F
.47137 .52043 m .52083 .59519 L .47302 .52057 L .476 .562 .863 r
F
.52083 .59519 m .52086 .59488 L .47302 .52057 L F
.52075 .59628 m .52074 .5961 L .47245 .52365 L .571 .605 .848 r
F
.52074 .5961 m .47379 .52414 L .47245 .52365 L F
.51381 .55516 m .52182 .56883 L .52156 .56188 L .568 .612 .856 r
F
.53932 .63937 m .52596 .61524 L .52999 .62318 L .651 .623 .809 r
F
.52256 .60528 m .5238 .67581 L .52937 .60809 L .609 .514 .722 r
F
.53932 .63937 m .52372 .57133 L .52267 .59088 L .651 .623 .809 r
F
.51982 .60414 m .52103 .60633 L .52256 .60528 L .609 .514 .722 r
F
.52171 .60882 m .52036 .6073 L .52035 .6073 L .571 .605 .848 r
F
.51966 .60726 m .52044 .62023 L .52213 .60832 L .609 .514 .722 r
F
.52159 .60735 m .52213 .60832 L .52226 .60738 L F
.52177 .60767 m .52159 .60735 L .52171 .60882 L .651 .623 .809 r
F
.51966 .60726 m .52213 .60832 L .52159 .60735 L .609 .514 .722 r
F
.51966 .60726 m .52226 .60738 L .52256 .60528 L F
.52372 .57133 m .52075 .59628 L .52159 .60735 L .651 .623 .809 r
F
.52372 .57133 m .52159 .60735 L .52177 .60767 L F
.52044 .62023 m .5238 .67581 L .52256 .60528 L .609 .514 .722 r
F
.52341 .61 m .52267 .59088 L .5218 .60704 L .651 .623 .809 r
F
.53932 .63937 m .52267 .59088 L .52341 .61 L F
.56347 .63184 m .55829 .62482 L .56261 .63227 L F
.54172 .72463 m .54512 .72053 L .54316 .72019 L .728 .669 .792 r
F
.54541 .72058 m .54473 .72347 L .54746 .72095 L .735 .656 .771 r
F
.542 .72272 m .5439 .71693 L .55922 .63904 L .728 .669 .792 r
F
.5439 .71693 m .56291 .63279 L .55922 .63904 L F
.54697 .64468 m .56347 .63184 L .54373 .64168 L .651 .623 .809 r
F
.55922 .63904 m .56347 .63184 L .54697 .64468 L F
.54703 .72315 m .55958 .71314 L .5462 .72211 L .814 .762 .804 r
F
.54703 .72315 m .5462 .72211 L .54473 .72347 L F
.60678 .69801 m .69652 .58265 L .6127 .68522 L .669 .902 .562 r
F
.6127 .68522 m .69652 .58265 L .70283 .56733 L 0 0 0 r
F
.60678 .69801 m .68204 .59912 L .69652 .58265 L .669 .902 .562 r
F
.59526 .70965 m .68204 .59912 L .60678 .69801 L .865 .987 .838 r
F
.59526 .70965 m .6612 .61515 L .68204 .59912 L F
.61697 .67946 m .58444 .73387 L .61365 .73979 L .711 .673 .811 r
F
.61981 .62787 m .59909 .68995 L .61697 .67946 L F
.59909 .68995 m .58444 .73387 L .61697 .67946 L F
.5438 .7236 m .54226 .72509 L .54379 .72398 L .722 .627 .751 r
F
.53985 .72887 m .54703 .72315 L .54311 .72427 L .814 .762 .804 r
F
.5438 .7236 m .54378 .7241 L .54391 .72359 L .722 .627 .751 r
F
.54703 .72315 m .54403 .72357 L .54311 .72427 L .814 .762 .804 r
F
.54233 .72447 m .54158 .72559 L .54226 .72509 L .722 .627 .751 r
F
.54172 .72463 m .54158 .72559 L .54233 .72447 L F
.53985 .72887 m .54311 .72427 L .54112 .72619 L .814 .762 .804 r
F
.54115 .64735 m .54465 .64574 L .54025 .64342 L .651 .623 .809 r
F
.54594 .64373 m .53275 .71003 L .541 .70894 L .722 .627 .751 r
F
.54373 .64168 m .53275 .71003 L .54594 .64373 L F
.54025 .64342 m .54268 .6482 L .54373 .64168 L .683 .581 .735 r
F
.52596 .61524 m .5218 .60704 L .52177 .60767 L .651 .623 .809 r
F
.53932 .63937 m .5218 .60704 L .52596 .61524 L F
.54015 .72016 m .53049 .72409 L .53963 .727 L .722 .627 .751 r
F
.541 .70894 m .53883 .71207 L .54015 .72016 L F
.53883 .71207 m .53049 .72409 L .54015 .72016 L F
.53275 .71003 m .53049 .72409 L .541 .70894 L F
.52951 .62223 m .53018 .69166 L .53057 .62433 L .683 .581 .735 r
F
.53018 .69166 m .53019 .69166 L .53057 .62433 L F
.53057 .62433 m .53019 .69166 L .53508 .6852 L F
.52606 .69966 m .53024 .69158 L .52593 .69984 L .812 .687 .726 r
F
.53024 .69158 m .53024 .69159 L .52593 .69984 L F
.53031 .69146 m .53011 .69179 L .52593 .69984 L F
.53572 .63448 m .5356 .69229 L .54268 .6482 L .683 .581 .735 r
F
.54025 .64342 m .53932 .63937 L .52999 .62318 L .651 .623 .809 r
F
.52842 .61968 m .5238 .67581 L .52951 .62223 L .683 .581 .735 r
F
.51946 .604 m .51966 .60726 L .52103 .60633 L .609 .514 .722 r
F
.51946 .604 m .52103 .60633 L .51982 .60414 L F
.51786 .63848 m .52044 .62023 L .51946 .604 L F
.52035 .6073 m .43952 .51604 L .43861 .51591 L .571 .605 .848 r
F
.52036 .6073 m .43952 .51604 L .52035 .6073 L F
.52036 .6073 m .52075 .59628 L .43952 .51604 L F
.52159 .60735 m .52075 .59628 L .52036 .6073 L F
.44335 .51678 m .45188 .51883 L .46064 .51895 L .182 .659 .931 r
F
.44889 .51733 m .46064 .51895 L .46579 .51903 L F
.44335 .51678 m .46064 .51895 L .44889 .51733 L F
.44007 .51658 m .45878 .5187 L .43952 .51604 L .571 .605 .848 r
F
.52075 .59628 m .45885 .51878 L .44007 .51658 L F
.45885 .51878 m .45878 .5187 L .44007 .51658 L F
.33363 .49787 m .40837 .51285 L .43744 .51627 L .15 .652 .908 r
F
.40837 .51285 m .41961 .5151 L .43744 .51627 L F
.5133 .60982 m .51786 .63848 L .51582 .60249 L .609 .514 .722 r
F
.52035 .6073 m .4391 .51646 L .51568 .60289 L .571 .605 .848 r
F
.43893 .51627 m .43261 .50921 L .43895 .51636 L F
.43744 .51627 m .43893 .51627 L .3489 .49409 L .15 .652 .908 r
F
.43893 .51627 m .44131 .51629 L .43876 .51567 L F
.43893 .51627 m .43876 .51567 L .3489 .49409 L F
.4391 .51646 m .43893 .51627 L .43906 .51649 L .571 .605 .848 r
F
.43893 .51627 m .43895 .51636 L .43906 .51649 L F
.4391 .51646 m .43906 .51649 L .51568 .60289 L F
.3489 .49409 m .43876 .51567 L .44014 .51356 L .182 .659 .931 r
F
.43744 .51627 m .439 .51654 L .43893 .51627 L .15 .652 .908 r
F
.43906 .51649 m .43895 .51636 L .439 .51654 L .571 .605 .848 r
F
.51568 .60289 m .43906 .51649 L .45609 .53802 L F
.43906 .51649 m .43876 .51676 L .45609 .53802 L F
.33363 .49787 m .43744 .51627 L .3489 .49409 L .15 .652 .908 r
F
.52075 .59628 m .47245 .52365 L .45878 .5187 L .571 .605 .848 r
F
.46579 .51903 m .46064 .51895 L .47302 .52057 L .182 .659 .931 r
F
.46064 .51895 m .47137 .52043 L .47302 .52057 L F
.39581 .51304 m .38508 .51212 L .3723 .5129 L .483 .612 .904 r
F
.30513 .50911 m .39312 .51533 L .31894 .50286 L .111 .652 .846 r
F
.39312 .51533 m .39595 .51433 L .31894 .50286 L F
.31894 .50286 m .39595 .51433 L .41734 .51563 L .12 .646 .876 r
F
.39301 .51532 m .393 .51533 L .39312 .51533 L .111 .652 .846 r
F
.35227 .51845 m .34849 .51873 L .34687 .51984 L .379 .639 .957 r
F
.29252 .51668 m .36101 .5178 L .37635 .51667 L .14 .68 .834 r
F
.28143 .52561 m .36056 .5191 L .29252 .51668 L .217 .737 .848 r
F
.36056 .5191 m .36101 .5178 L .29252 .51668 L F
.27217 .53591 m .34629 .52299 L .28143 .52561 L .338 .815 .885 r
F
.34629 .52299 m .34653 .52172 L .28143 .52561 L F
.3432 .52353 m .34318 .52414 L .34629 .52299 L F
.33734 .5278 m .33627 .52728 L .33457 .53218 L .264 .671 .967 r
F
.33627 .52728 m .33317 .52896 L .33457 .53218 L F
.26503 .54756 m .33734 .5278 L .27217 .53591 L .485 .894 .927 r
F
.33734 .5278 m .33658 .52712 L .27217 .53591 L F
.26503 .54756 m .33221 .53369 L .33469 .53199 L F
.26503 .54756 m .33469 .53199 L .33734 .5278 L F
.49564 .66989 m .49644 .66691 L .49218 .65963 L .598 .448 .65 r
F
.49564 .66989 m .49218 .65963 L .49148 .65892 L F
.49774 .66402 m .49653 .66712 L .50132 .67893 L .175 .215 .665 r
F
.49185 .69186 m .48765 .70205 L .48476 .71505 L .275 .088 .437 r
F
.48395 .71871 m .48844 .69847 L .48798 .70025 L .701 .531 .655 r
F
.47406 .75794 m .48798 .70025 L .47858 .73672 L F
.48759 .70012 m .47923 .72247 L .49185 .69186 L .275 .088 .437 r
F
.48395 .71871 m .49693 .66608 L .48844 .69847 L .701 .531 .655 r
F
.49693 .66608 m .49653 .66712 L .48844 .69847 L F
.5058 .68976 m .50768 .69443 L .50802 .69403 L .47 .41 .709 r
F
.50452 .6922 m .50582 .69733 L .50648 .69587 L .543 .335 .549 r
F
.50452 .6922 m .48584 .74082 L .49157 .72879 L F
.50452 .6922 m .49777 .70866 L .4989 .70682 L F
.48305 .72234 m .50631 .69469 L .49693 .66608 L .701 .531 .655 r
F
.50132 .67893 m .50107 .67868 L .50181 .68097 L .175 .215 .665 r
F
.49038 .65579 m .49025 .65568 L .49148 .65892 L 0 0 .413 r
F
.47824 .63239 m .48197 .64002 L .47921 .62616 L .888 .491 .049 r
F
.48197 .64002 m .48399 .64035 L .47921 .62616 L F
.4525 .58739 m .4459 .56441 L .43814 .57066 L .315 .407 .797 r
F
.42157 .53846 m .40384 .52927 L .41522 .53517 L .483 .612 .904 r
F
.44698 .55163 m .45476 .55926 L .45427 .5554 L .182 .455 .88 r
F
.45103 .55373 m .44536 .55079 L .44448 .55033 L .483 .612 .904 r
F
.45427 .5554 m .47928 .57795 L .46637 .56168 L .182 .455 .88 r
F
.48542 .585 m .49814 .59232 L .48477 .58213 L .627 .537 .734 r
F
.50227 .65956 m .5119 .61289 L .49705 .63647 L F
.50389 .65172 m .51015 .69343 L .51162 .61422 L .47 .41 .709 r
F
.51203 .68045 m .51191 .68126 L .50896 .70279 L .719 .599 .722 r
F
.50721 .70739 m .50304 .71499 L .511 .70855 L .543 .335 .549 r
F
.4734 .78013 m .47911 .77328 L .511 .70855 L F
.50996 .70239 m .508 .70595 L .51208 .70636 L F
.50925 .72155 m .52907 .68916 L .51638 .65698 L .719 .599 .722 r
F
.52606 .69966 m .52593 .69984 L .52533 .70099 L .812 .687 .726 r
F
.52544 .70085 m .52533 .70099 L .51386 .72309 L F
.52606 .69966 m .52533 .70099 L .52544 .70085 L F
.51378 .72337 m .52545 .70083 L .51386 .72309 L F
.52545 .70083 m .52606 .69966 L .52544 .70085 L F
.52545 .70083 m .52544 .70085 L .51386 .72309 L F
.50925 .72155 m .52044 .62023 L .5089 .70432 L .719 .599 .722 r
F
.52024 .62211 m .52059 .62271 L .52044 .62023 L F
.53468 .68663 m .5356 .69197 L .53562 .68448 L .812 .687 .726 r
F
.5175 .74941 m .53307 .73514 L .53963 .727 L .896 .772 .717 r
F
.5175 .74941 m .51763 .7487 L .50033 .76515 L .812 .687 .726 r
F
.48913 .78728 m .49575 .78335 L .53049 .72409 L .808 .634 .665 r
F
.50437 .7559 m .54107 .72585 L .53468 .68663 L .812 .687 .726 r
F
.44998 .86024 m .46494 .84253 L .47238 .82223 L .793 .955 .624 r
F
.46985 .83858 m .47324 .83682 L .48307 .82417 L F
.44998 .86024 m .46509 .84503 L .46936 .83924 L F
.44998 .86024 m .46936 .83924 L .46884 .83968 L F
.46509 .84503 m .47324 .83682 L .46985 .83858 L F
.4806 .8213 m .47024 .83805 L .48328 .8239 L 0 0 0 r
F
.4837 .82108 m .48328 .8239 L .48603 .82092 L F
.4806 .8213 m .48328 .8239 L .4837 .82108 L F
.47324 .83682 m .48286 .82678 L .48328 .8239 L .88 .959 .848 r
F
.48603 .82092 m .4831 .82511 L .48868 .82073 L 0 0 0 r
F
.48868 .82073 m .47906 .83219 L .50222 .81881 L .171 0 .048 r
F
.50242 .82583 m .49808 .82911 L .50246 .8258 L .059 0 0 r
F
.49808 .82911 m .45352 .86272 L .4981 .82909 L F
.49808 .82911 m .4981 .82909 L .50246 .8258 L F
.51117 .81924 m .45358 .86362 L .52273 .81979 L 0 0 0 r
F
.45358 .86362 m .44376 .87119 L .45475 .86404 L F
.45358 .86362 m .45475 .86404 L .52273 .81979 L F
.4831 .84058 m .45386 .86333 L .51117 .81924 L F
.45386 .86333 m .44376 .87119 L .45405 .86326 L F
.45386 .86333 m .45405 .86326 L .51117 .81924 L F
.45333 .86354 m .45286 .86371 L .45352 .86272 L .602 .166 .184 r
F
.45333 .86354 m .45352 .86272 L .45304 .86343 L F
.45304 .86343 m .45352 .86272 L .50242 .82583 L .059 0 0 r
F
.45304 .86343 m .50242 .82583 L .50221 .82603 L F
.50493 .82398 m .50804 .82159 L .5077 .82188 L F
.45304 .86343 m .50503 .82388 L .50493 .82398 L F
.50503 .82388 m .50804 .82159 L .50493 .82398 L F
.44975 .86116 m .46482 .84555 L .44998 .86024 L 0 0 0 r
F
.46482 .84555 m .47324 .83682 L .46509 .84503 L F
.46482 .84555 m .46509 .84503 L .44998 .86024 L F
.48727 .8322 m .44376 .87119 L .50737 .82169 L F
.50674 .82134 m .50737 .82169 L .51056 .81921 L F
.48727 .8322 m .50737 .82169 L .50674 .82134 L F
.48223 .91889 m .382 .91584 L .35889 .96686 L .789 .867 .907 r
F
.46719 .88476 m .382 .91584 L .48223 .91889 L .614 .953 .914 r
F
.4576 .88826 m .41469 .89284 L .382 .91584 L F
.45446 .88661 m .40234 .89416 L .4576 .88826 L F
.44376 .87119 m .43739 .87762 L .45371 .87034 L .603 .144 .136 r
F
.45371 .87034 m .42511 .8836 L .46719 .88476 L .105 0 0 r
F
.42511 .8836 m .40234 .89416 L .41451 .89239 L F
.42511 .8836 m .41451 .89239 L .46719 .88476 L F
.41469 .89284 m .40234 .89416 L .38605 .91152 L .614 .953 .914 r
F
.41469 .89284 m .38605 .91152 L .382 .91584 L F
.43985 .88027 m .41762 .89771 L .43967 .87685 L .105 0 0 r
F
.44906 .87387 m .43395 .88532 L .45077 .87171 L F
.43395 .88532 m .41762 .89771 L .43361 .88516 L F
.43395 .88532 m .43361 .88516 L .45077 .87171 L F
.45077 .87171 m .43985 .88027 L .43967 .87685 L F
.43967 .87685 m .41762 .89771 L .40234 .89416 L F
.45371 .87034 m .44906 .87387 L .45077 .87171 L F
.43868 .87704 m .44136 .87971 L .45371 .87034 L .603 .144 .136 r
F
.43739 .87762 m .43793 .87791 L .43868 .87704 L F
.43793 .87791 m .44136 .87971 L .43868 .87704 L F
.41762 .89771 m .4169 .89805 L .40234 .89416 L .105 0 0 r
F
.43739 .87762 m .4171 .8981 L .44136 .87971 L .603 .144 .136 r
F
.44376 .87119 m .43396 .90412 L .4189 .89628 L F
.4379 .888 m .43648 .88868 L .43848 .88563 L .602 .166 .184 r
F
.43693 .89196 m .43648 .88868 L .4379 .888 L F
.48223 .91889 m .35889 .96686 L .4992 .97237 L .789 .867 .907 r
F
.47633 .96509 m .45315 .95204 L .42827 .90119 L .67 .241 .222 r
F
.4441 .92249 m .43352 .90816 L .43438 .9095 L F
.44034 .91768 m .43438 .9095 L .43647 .91273 L F
.4441 .92249 m .43438 .9095 L .44034 .91768 L F
.44409 .92222 m .43352 .90816 L .4441 .92249 L F
.44088 .89321 m .44586 .93854 L .43414 .92307 L .727 .29 .212 r
F
.44411 .92287 m .44435 .92503 L .4441 .92249 L .571 .188 .277 r
F
.44435 .92503 m .44459 .92692 L .4441 .92249 L F
.44435 .92503 m .44586 .93854 L .44459 .92692 L F
.44435 .92503 m .4609 .94594 L .44586 .93854 L F
.44411 .92287 m .44774 .92785 L .44435 .92503 L F
.44774 .92785 m .4609 .94594 L .44435 .92503 L F
.44412 .92314 m .44454 .92336 L .44061 .91856 L .67 .241 .222 r
F
.47633 .96509 m .44454 .92336 L .44412 .92314 L F
.47633 .96509 m .44932 .92918 L .44454 .92336 L F
.44932 .92918 m .44409 .92222 L .4441 .92249 L F
.44932 .92918 m .43647 .91273 L .44061 .91856 L F
.48695 .9605 m .47633 .96509 L .46393 .94893 L .417 .229 .516 r
F
.461 .93889 m .46393 .94893 L .44774 .92785 L F
.48695 .9605 m .46393 .94893 L .461 .93889 L F
.43352 .90816 m .43304 .9079 L .43647 .91273 L .67 .241 .222 r
F
.43352 .90816 m .42827 .90119 L .43304 .9079 L F
.43647 .91272 m .42827 .90119 L .42829 .90116 L .602 .166 .184 r
F
.43647 .91273 m .42827 .90119 L .43647 .91272 L F
.4379 .888 m .43396 .90412 L .43928 .88626 L .727 .29 .212 r
F
.43897 .90672 m .42829 .90116 L .43648 .88868 L .602 .166 .184 r
F
.43699 .88916 m .43396 .90412 L .4379 .888 L .727 .29 .212 r
F
.44061 .91856 m .43693 .89196 L .43941 .88812 L .602 .166 .184 r
F
.44024 .89001 m .43941 .88812 L .4402 .8869 L F
.44061 .91856 m .43941 .88812 L .44024 .89001 L F
.43693 .89196 m .4379 .888 L .4391 .88742 L F
.43941 .88812 m .4391 .88742 L .4402 .8869 L F
.43693 .89196 m .4391 .88742 L .43941 .88812 L F
.45777 .93019 m .45773 .93075 L .45369 .9207 L .239 .058 .423 r
F
.45133 .91876 m .46455 .94773 L .4609 .94594 L .571 .188 .277 r
F
.44223 .91129 m .4402 .8869 L .44263 .90952 L .602 .166 .184 r
F
.44049 .90986 m .4402 .8869 L .44223 .91129 L F
.43937 .87951 m .43699 .88916 L .43879 .88438 L .727 .29 .212 r
F
.4405 .87737 m .43879 .88438 L .44376 .87119 L F
.43937 .87951 m .43879 .88438 L .4405 .87737 L F
.43699 .88916 m .43928 .88626 L .44376 .87119 L F
.47073 .85788 m .4456 .8701 L .45371 .87034 L .704 .98 .791 r
F
.4576 .86294 m .4456 .8701 L .47073 .85788 L F
.4456 .8701 m .44463 .87112 L .45371 .87034 L F
.45868 .86148 m .45475 .86404 L .49104 .843 L F
.45475 .86404 m .44584 .86983 L .4576 .86294 L F
.44584 .86983 m .4456 .8701 L .4576 .86294 L F
.45475 .86404 m .4576 .86294 L .49104 .843 L F
.44858 .88289 m .44274 .88568 L .45134 .86802 L .602 .166 .184 r
F
.44274 .88568 m .4379 .888 L .45134 .86802 L F
.45134 .86802 m .4379 .888 L .45183 .86539 L F
.44858 .88289 m .45183 .86539 L .45258 .86496 L F
.44265 .90973 m .44329 .91538 L .44088 .89321 L .571 .188 .277 r
F
.444 .92184 m .44401 .92191 L .44088 .89321 L F
.44401 .92191 m .4441 .92249 L .44088 .89321 L F
.44411 .92287 m .4441 .92255 L .44401 .92191 L F
.4441 .92255 m .4441 .92249 L .44401 .92191 L F
.44287 .91182 m .444 .92184 L .44329 .91538 L F
.45369 .9207 m .46455 .94773 L .45133 .91876 L F
.44299 .90791 m .44159 .89986 L .44751 .88766 L .602 .166 .184 r
F
.44263 .90952 m .44235 .90691 L .44299 .90791 L F
.44235 .90691 m .44159 .89986 L .44299 .90791 L F
.44156 .89958 m .4402 .8869 L .44225 .88592 L F
.44228 .91133 m .45286 .86371 L .45333 .86354 L F
.44061 .91856 m .44223 .91129 L .44228 .91133 L F
.44223 .91129 m .45286 .86371 L .44228 .91133 L F
.44287 .91182 m .44329 .91538 L .44265 .90973 L .571 .188 .277 r
F
.444 .92184 m .44411 .92287 L .44401 .92191 L F
.44287 .91182 m .4609 .94594 L .44411 .92287 L F
.44172 .89631 m .4434 .89614 L .44195 .89175 L .602 .166 .184 r
F
.4379 .888 m .43848 .88563 L .45286 .86371 L F
.43937 .87951 m .4406 .89065 L .43835 .88484 L .727 .29 .212 r
F
.44061 .91856 m .42829 .90116 L .43897 .90672 L .602 .166 .184 r
F
.43835 .88484 m .44088 .89321 L .43371 .9092 L .727 .29 .212 r
F
.4406 .89065 m .44088 .89321 L .43835 .88484 L F
.44088 .89321 m .43414 .92307 L .42996 .91756 L F
.44061 .91856 m .44049 .90986 L .44223 .91129 L .602 .166 .184 r
F
.44061 .91856 m .44265 .90973 L .44154 .89996 L F
.44026 .88796 m .44287 .91182 L .44021 .8872 L .571 .188 .277 r
F
.4403 .88882 m .44138 .8985 L .44026 .88796 L F
.44138 .8985 m .44287 .91182 L .44026 .88796 L F
.44184 .89935 m .4434 .89614 L .44172 .89631 L .602 .166 .184 r
F
.44287 .91182 m .44088 .89321 L .44021 .8872 L .571 .188 .277 r
F
.44138 .8985 m .44172 .89631 L .44201 .90412 L F
.44265 .90973 m .4448 .90042 L .44184 .89935 L .602 .166 .184 r
F
.4448 .90042 m .44797 .88672 L .4434 .89614 L F
.4448 .90042 m .4434 .89614 L .44184 .89935 L F
.44195 .89175 m .44797 .88672 L .44226 .88559 L F
.4434 .89614 m .44797 .88672 L .44195 .89175 L F
.44773 .88667 m .44274 .88568 L .44858 .88289 L F
.44797 .88672 m .45062 .87525 L .44226 .88559 L F
.45062 .87525 m .45306 .86469 L .44803 .87443 L F
.45062 .87525 m .44803 .87443 L .44226 .88559 L F
.45306 .86469 m .45333 .86354 L .45268 .86484 L F
.45306 .86469 m .45268 .86484 L .44788 .87439 L F
.44803 .87443 m .44788 .87439 L .44226 .88559 L F
.45306 .86469 m .44788 .87439 L .44803 .87443 L F
.44226 .88559 m .45268 .86484 L .44557 .87483 L F
.44729 .87186 m .43937 .87951 L .44727 .87175 L 0 0 0 r
F
.43947 .87939 m .43967 .87923 L .44547 .87363 L .171 0 .048 r
F
.43947 .87939 m .44547 .87363 L .44545 .87362 L F
.44584 .86983 m .44376 .87119 L .4456 .8701 L .704 .98 .791 r
F
.4456 .8701 m .44376 .87119 L .44463 .87112 L F
.44681 .86846 m .43937 .87951 L .44376 .87119 L 0 0 0 r
F
.45268 .86484 m .45333 .86354 L .45234 .86497 L .602 .166 .184 r
F
.44727 .87175 m .43937 .87951 L .44681 .86846 L 0 0 0 r
F
.44487 .87344 m .43947 .87939 L .44545 .87362 L .171 0 .048 r
F
.44244 .88203 m .44557 .87483 L .44318 .87821 L .602 .166 .184 r
F
.44226 .88559 m .44557 .87483 L .44244 .88203 L F
.44284 .88911 m .44233 .89243 L .44247 .88519 L .234 0 .201 r
F
.44266 .88482 m .44247 .88519 L .44254 .8819 L F
.44284 .88911 m .44247 .88519 L .44266 .88482 L F
.4427 .88474 m .44254 .8819 L .4426 .8818 L F
.44284 .88911 m .44266 .88482 L .4427 .88474 L F
.44266 .88482 m .44254 .8819 L .4427 .88474 L F
.4426 .8818 m .44254 .8819 L .44256 .88054 L F
.44244 .88203 m .44318 .87821 L .44252 .88055 L .602 .166 .184 r
F
.44266 .88171 m .44256 .88054 L .44263 .88052 L .234 0 .201 r
F
.44273 .88468 m .4426 .8818 L .44266 .88171 L F
.4427 .88474 m .4426 .8818 L .44273 .88468 L F
.4426 .8818 m .44256 .88054 L .44266 .88171 L F
.45268 .86484 m .45234 .86497 L .44618 .87385 L .602 .166 .184 r
F
.45268 .86484 m .44618 .87385 L .44625 .87387 L F
.45268 .86484 m .44319 .87817 L .44318 .87821 L F
.45258 .86496 m .45183 .86539 L .45286 .86371 L F
.44455 .87334 m .43947 .87939 L .44487 .87344 L .171 0 .048 r
F
.43947 .87939 m .43937 .87951 L .43967 .87923 L F
.45333 .86354 m .45304 .86343 L .44933 .86931 L .602 .166 .184 r
F
.44008 .88684 m .4403 .88882 L .43937 .87951 L .571 .188 .277 r
F
.4403 .88882 m .44021 .8872 L .43937 .87951 L F
.44116 .88537 m .44008 .88684 L .44213 .88065 L .171 0 .048 r
F
.44286 .87933 m .44232 .88007 L .44279 .87864 L F
.44289 .87922 m .44279 .87864 L .44455 .87334 L F
.44286 .87933 m .44279 .87864 L .44289 .87922 L F
.44252 .88055 m .44232 .88007 L .44286 .87933 L F
.44233 .89243 m .44195 .89175 L .44252 .88055 L .234 0 .201 r
F
.44252 .88055 m .44318 .87821 L .44259 .87903 L .602 .166 .184 r
F
.44256 .88054 m .44252 .88055 L .44259 .87903 L .234 0 .201 r
F
.44233 .89243 m .44252 .88055 L .44256 .88054 L F
.44294 .87821 m .44213 .88065 L .43947 .87939 L .171 0 .048 r
F
.4478 .9024 m .45927 .93343 L .44255 .89283 L .239 .058 .423 r
F
.44326 .90609 m .45133 .91876 L .44342 .91226 L .571 .188 .277 r
F
.44326 .90609 m .44342 .91226 L .44287 .91182 L F
.44265 .90973 m .44184 .89935 L .44201 .90412 L .602 .166 .184 r
F
.44201 .90412 m .44326 .90609 L .44287 .91182 L .571 .188 .277 r
F
.44233 .89243 m .44172 .89631 L .44195 .89175 L .234 0 .201 r
F
.44172 .89631 m .45133 .91876 L .44201 .90412 L .571 .188 .277 r
F
.44153 .89094 m .44224 .89298 L .44172 .89631 L F
.44224 .89298 m .45133 .91876 L .44172 .89631 L F
.45133 .91876 m .4609 .94594 L .44287 .91182 L F
.45778 .92999 m .45369 .9207 L .44233 .89243 L .239 .058 .423 r
F
.45778 .92999 m .44233 .89243 L .4424 .89257 L F
.44021 .88717 m .45369 .9207 L .44022 .88723 L .571 .188 .277 r
F
.44022 .88723 m .45369 .9207 L .45133 .91876 L F
.44359 .91908 m .44172 .89631 L .44233 .89243 L .234 0 .201 r
F
.44295 .89357 m .44233 .89243 L .44284 .88911 L F
.45778 .92999 m .4424 .89257 L .44251 .89277 L .239 .058 .423 r
F
.45927 .93343 m .45812 .93081 L .44324 .89455 L F
.44324 .89452 m .44324 .89455 L .44008 .88684 L F
.45927 .93343 m .44324 .89455 L .44324 .89452 L F
.4424 .89257 m .4415 .89038 L .44251 .89277 L F
.4424 .89257 m .44233 .89243 L .4415 .89038 L F
.49104 .843 m .4576 .86294 L .47073 .85788 L .704 .98 .791 r
F
.5133 .8267 m .45868 .86148 L .49104 .843 L F
.52273 .81979 m .50675 .83019 L .5133 .8267 L F
.50675 .83019 m .45868 .86148 L .5133 .8267 L F
.44535 .87664 m .45304 .86343 L .47687 .84531 L .059 0 0 r
F
.51158 .81876 m .51089 .81888 L .51117 .81924 L .857 .826 .816 r
F
.51089 .81888 m .50942 .81916 L .51056 .81921 L F
.51089 .81888 m .51056 .81921 L .51117 .81924 L F
.55431 .76812 m .50222 .81881 L .50942 .81916 L F
.52982 .77766 m .50222 .81881 L .54555 .77404 L .897 .854 .792 r
F
.511 .79739 m .56506 .76086 L .53053 .777 L .88 .959 .848 r
F
.56506 .76086 m .56934 .75796 L .56299 .76108 L F
.56506 .76086 m .56299 .76108 L .53053 .777 L F
.56779 .76057 m .5593 .77026 L .57364 .75585 L F
.56582 .76078 m .55688 .77301 L .56779 .76057 L .857 .826 .816 r
F
.51108 .81869 m .51273 .818 L .54067 .78949 L .88 .959 .848 r
F
.51203 .81867 m .51117 .81924 L .51281 .81799 L .059 0 0 r
F
.51203 .81867 m .51287 .81794 L .51089 .81888 L F
.53073 .77631 m .56299 .76108 L .58045 .73787 L .814 .762 .804 r
F
.53053 .777 m .56299 .76108 L .53073 .77631 L F
.56299 .76108 m .57754 .74348 L .58045 .73787 L F
.57754 .74348 m .57991 .73928 L .58045 .73787 L F
.51089 .81888 m .51287 .81794 L .51108 .81869 L .88 .959 .848 r
F
.5077 .82188 m .50804 .82159 L .51281 .81799 L .059 0 0 r
F
.51281 .81799 m .50242 .82583 L .51287 .81794 L F
.50242 .82583 m .50246 .8258 L .51287 .81794 L F
.51273 .818 m .51287 .81794 L .5129 .8179 L .88 .959 .848 r
F
.51273 .818 m .5129 .8179 L .54191 .78827 L F
.51273 .818 m .54191 .78827 L .54067 .78949 L F
.55379 .77654 m .51117 .81924 L .53393 .8042 L .857 .826 .816 r
F
.57754 .74348 m .57364 .75585 L .57899 .74173 L .814 .762 .804 r
F
.56299 .76108 m .56934 .75796 L .57754 .74348 L F
.56934 .75796 m .57364 .75585 L .57754 .74348 L F
.57754 .74348 m .5147 .81513 L .55379 .77654 L .857 .826 .816 r
F
.58444 .73387 m .58014 .73888 L .57754 .74348 L F
.58014 .73888 m .5147 .81513 L .57754 .74348 L F
.5147 .81513 m .51117 .81924 L .55379 .77654 L F
.55742 .7724 m .55725 .7726 L .57364 .75585 L .88 .959 .848 r
F
.5593 .77026 m .55742 .7724 L .57364 .75585 L F
.5658 .76078 m .57364 .75585 L .56934 .75796 L F
.58021 .73876 m .50942 .81916 L .51089 .81888 L .857 .826 .816 r
F
.58033 .73853 m .50942 .81916 L .58021 .73876 L F
.58444 .73387 m .51089 .81888 L .5147 .81513 L F
.54555 .77404 m .50222 .81881 L .55431 .76812 L F
.53393 .8042 m .51117 .81924 L .52273 .81979 L F
.46386 .86054 m .47687 .84531 L .51117 .81924 L .059 0 0 r
F
.46386 .86054 m .51117 .81924 L .51203 .81867 L F
.44535 .87664 m .47687 .84531 L .46386 .86054 L F
.44392 .87788 m .44568 .87509 L .44535 .87664 L F
.44568 .87509 m .45304 .86343 L .44535 .87664 L F
.44933 .86931 m .45304 .86343 L .44259 .87903 L .602 .166 .184 r
F
.44625 .87387 m .44618 .87385 L .44319 .87817 L F
.4432 .87812 m .45304 .86343 L .44392 .87788 L .059 0 0 r
F
.47717 .84125 m .44727 .87175 L .44681 .86846 L 0 0 0 r
F
.47233 .84713 m .44727 .87175 L .47717 .84125 L F
.50221 .82603 m .50242 .82583 L .50804 .82159 L .059 0 0 r
F
.51056 .81921 m .4831 .84058 L .51117 .81924 L 0 0 0 r
F
.50222 .81881 m .48727 .8322 L .51056 .81921 L F
.44392 .87788 m .51203 .81867 L .50006 .82427 L .059 0 0 r
F
.48765 .83299 m .50006 .82427 L .49287 .82763 L F
.44392 .87788 m .50006 .82427 L .48765 .83299 L F
.49008 .82969 m .47233 .84713 L .47717 .84125 L 0 0 0 r
F
.44392 .87788 m .49287 .82763 L .44715 .87345 L .059 0 0 r
F
.51203 .81867 m .51089 .81888 L .49318 .82732 L F
.4944 .8261 m .49348 .82702 L .49008 .82969 L 0 0 0 r
F
.51203 .81867 m .49318 .82732 L .49287 .82763 L .059 0 0 r
F
.49631 .82451 m .49472 .82605 L .49348 .82702 L 0 0 0 r
F
.49631 .82451 m .49348 .82702 L .4944 .8261 L F
.49472 .82605 m .48884 .8309 L .49008 .82969 L F
.47324 .83682 m .4742 .83637 L .47892 .83225 L .88 .959 .848 r
F
.50222 .81881 m .49631 .82451 L .49008 .82969 L 0 0 0 r
F
.4742 .83637 m .49607 .82594 L .47906 .83219 L .88 .959 .848 r
F
.4742 .83637 m .47906 .83219 L .47892 .83225 L F
.48868 .82073 m .48251 .82911 L .48025 .83117 L .171 0 .048 r
F
.48868 .82073 m .48025 .83117 L .47906 .83219 L F
.49607 .82594 m .50106 .82357 L .49305 .82671 L .88 .959 .848 r
F
.49607 .82594 m .49305 .82671 L .47906 .83219 L F
.47906 .83219 m .47906 .83219 L .47892 .83225 L F
.49607 .82594 m .47906 .83219 L .47906 .83219 L F
.47699 .83506 m .47702 .83502 L .4742 .83637 L .059 0 0 r
F
.49318 .82732 m .4701 .84983 L .48884 .8309 L 0 0 0 r
F
.49472 .82605 m .48723 .83329 L .49318 .82732 L F
.48723 .83329 m .4701 .84983 L .49318 .82732 L F
.49287 .82763 m .47702 .83502 L .47699 .83506 L .059 0 0 r
F
.49287 .82763 m .49318 .82732 L .47702 .83502 L F
.44729 .87186 m .44727 .87175 L .49008 .82969 L 0 0 0 r
F
.4651 .84883 m .49287 .82763 L .4742 .83637 L .059 0 0 r
F
.4701 .84983 m .44729 .87186 L .47209 .84742 L 0 0 0 r
F
.4701 .84983 m .47209 .84742 L .48884 .8309 L F
.47595 .84121 m .4745 .84558 L .48723 .83329 L .171 0 .048 r
F
.48723 .83329 m .49287 .82763 L .4651 .84883 L .059 0 0 r
F
.47232 .84022 m .4651 .84883 L .47702 .83799 L .171 0 .048 r
F
.4651 .84883 m .45349 .86268 L .4706 .84497 L F
.45349 .86268 m .44769 .86992 L .4706 .84497 L F
.45349 .86268 m .44455 .87334 L .44769 .86992 L F
.4651 .84883 m .4706 .84497 L .47702 .83799 L F
.44455 .87334 m .44487 .87344 L .47082 .84481 L F
.4706 .84497 m .47082 .84481 L .47702 .83799 L F
.44455 .87334 m .47082 .84481 L .4706 .84497 L F
.46422 .84946 m .4742 .83637 L .47324 .83682 L .059 0 0 r
F
.44545 .87362 m .44547 .87363 L .4745 .84558 L .171 0 .048 r
F
.47702 .83799 m .44487 .87344 L .4745 .84558 L F
.44487 .87344 m .44545 .87362 L .4745 .84558 L F
.45617 .86441 m .48723 .83329 L .46933 .84587 L .059 0 0 r
F
.45617 .86441 m .46933 .84587 L .4651 .84883 L F
.44715 .87345 m .45617 .86441 L .4651 .84883 L F
.47885 .83244 m .47232 .84022 L .47702 .83799 L .171 0 .048 r
F
.47885 .83244 m .44524 .87982 L .44489 .87655 L F
.4651 .84883 m .44489 .87655 L .44455 .87334 L F
.47885 .83244 m .44489 .87655 L .4651 .84883 L F
.44524 .87982 m .44252 .88055 L .44455 .87334 L F
.44392 .87788 m .4651 .84883 L .46422 .84946 L .059 0 0 r
F
.4651 .84883 m .4742 .83637 L .46422 .84946 L F
.44318 .87821 m .44319 .87817 L .44259 .87903 L .602 .166 .184 r
F
.44259 .87903 m .4432 .87812 L .44392 .87788 L .059 0 0 r
F
.44259 .87903 m .44392 .87788 L .46422 .84946 L F
.44259 .87903 m .46422 .84946 L .46391 .84967 L F
.47885 .83244 m .47595 .84121 L .50222 .81881 L .171 0 .048 r
F
.47595 .84121 m .48723 .83329 L .50222 .81881 L F
.47906 .83219 m .47974 .83192 L .50222 .81881 L F
.56757 .76059 m .57364 .75585 L .5658 .76078 L .88 .959 .848 r
F
.57754 .74348 m .56506 .76086 L .58534 .73405 L .857 .826 .816 r
F
.56506 .76086 m .52273 .81979 L .56582 .76078 L F
.5658 .76078 m .56934 .75796 L .56506 .76086 L .88 .959 .848 r
F
.56506 .76086 m .56582 .76078 L .58534 .73405 L .857 .826 .816 r
F
.4831 .82511 m .48251 .82911 L .48868 .82073 L 0 0 0 r
F
.50443 .80122 m .52982 .77766 L .49964 .80284 L .88 .959 .848 r
F
.52982 .77766 m .53053 .777 L .52862 .77794 L F
.52862 .77794 m .58045 .73787 L .58086 .73679 L .814 .762 .804 r
F
.53401 .76457 m .50443 .80122 L .53073 .77631 L .897 .854 .792 r
F
.50443 .80122 m .48868 .82073 L .52676 .7805 L F
.50443 .80122 m .52676 .7805 L .53073 .77631 L F
.48286 .82678 m .5658 .76078 L .511 .79739 L .88 .959 .848 r
F
.5658 .76078 m .56506 .76086 L .511 .79739 L F
.47971 .83163 m .51108 .81869 L .5593 .77026 L F
.47892 .83225 m .47907 .83218 L .47971 .83163 L F
.47907 .83218 m .51108 .81869 L .47971 .83163 L F
.49472 .82605 m .49572 .82522 L .47892 .83225 L F
.51089 .81888 m .51108 .81869 L .47892 .83225 L F
.47892 .83225 m .5593 .77026 L .56779 .76057 L F
.47906 .83219 m .47885 .83244 L .47974 .83192 L .171 0 .048 r
F
.48025 .83117 m .44524 .87982 L .47885 .83244 L F
.47892 .83225 m .48247 .82938 L .4796 .83019 L .88 .959 .848 r
F
.48228 .82943 m .44524 .87982 L .48025 .83117 L .171 0 .048 r
F
.44648 .87765 m .44758 .87663 L .46557 .85217 L 0 0 0 r
F
.44648 .87765 m .46557 .85217 L .46529 .85231 L F
.46094 .85663 m .44866 .87068 L .46391 .84967 L F
.45252 .86816 m .44866 .87068 L .46094 .85663 L F
.46391 .84967 m .46422 .84946 L .47324 .83682 L .059 0 0 r
F
.46592 .84981 m .46391 .84967 L .47096 .84088 L 0 0 0 r
F
.44479 .87922 m .44648 .87765 L .44741 .87632 L F
.44756 .87536 m .44741 .87632 L .46515 .85087 L F
.44479 .87922 m .44741 .87632 L .44756 .87536 L F
.44479 .87922 m .46515 .85087 L .45546 .86413 L F
.44672 .87609 m .44479 .87922 L .45546 .86413 L F
.44387 .88249 m .44284 .88911 L .44263 .88052 L .234 0 .201 r
F
.44616 .88868 m .44284 .88911 L .44387 .88249 L F
.45007 .89925 m .44478 .89182 L .44616 .88868 L F
.44478 .89182 m .44284 .88911 L .44616 .88868 L F
.46094 .85663 m .46391 .84967 L .46592 .84981 L 0 0 0 r
F
.44743 .89644 m .44284 .88911 L .45007 .89925 L .234 0 .201 r
F
.44923 .90251 m .44284 .88911 L .45134 .90269 L F
.44387 .88249 m .44263 .88052 L .4431 .88039 L F
.44387 .88248 m .44326 .88083 L .44342 .88229 L F
.44326 .88083 m .4431 .88039 L .44321 .88106 L F
.44326 .88083 m .44321 .88106 L .44342 .88229 L F
.44524 .87982 m .44116 .88537 L .44146 .88429 L .171 0 .048 r
F
.44365 .88024 m .44146 .88429 L .44252 .88055 L F
.44524 .87982 m .44146 .88429 L .44365 .88024 L F
.44263 .88052 m .44256 .88054 L .44259 .87903 L .234 0 .201 r
F
.443 .8821 m .44259 .87903 L .44249 .88188 L F
.44318 .88218 m .44309 .88169 L .443 .8821 L F
.44309 .88169 m .44259 .87903 L .443 .8821 L F
.44116 .88537 m .44213 .88065 L .44252 .88055 L .171 0 .048 r
F
.443 .8821 m .44008 .88684 L .44329 .88223 L 0 0 0 r
F
.4431 .88039 m .44263 .88052 L .44259 .87903 L .234 0 .201 r
F
.44111 .88536 m .44116 .88537 L .44342 .88229 L 0 0 0 r
F
.44111 .88536 m .44342 .88229 L .4434 .88228 L F
.44342 .88229 m .44502 .89208 L .44516 .89232 L .234 0 .201 r
F
.44341 .88228 m .44502 .89208 L .44342 .88229 L F
.44329 .88223 m .44111 .88536 L .4434 .88227 L 0 0 0 r
F
.44111 .88536 m .4434 .88228 L .4434 .88227 L F
.44341 .88228 m .44318 .88218 L .44502 .89208 L .234 0 .201 r
F
.45134 .90269 m .44743 .89644 L .45007 .89925 L F
.4487 .90247 m .45727 .91263 L .4626 .93053 L .239 .058 .423 r
F
.4487 .90247 m .4619 .9291 L .46046 .93007 L F
.4619 .9291 m .4626 .93053 L .46152 .9303 L F
.4619 .9291 m .46152 .9303 L .46046 .93007 L F
.61854 .88105 m .48223 .91889 L .4992 .97237 L .746 .711 .819 r
F
.50297 .95356 m .46101 .93187 L .46152 .9303 L .417 .229 .516 r
F
.44923 .90251 m .44295 .89357 L .44284 .88911 L .234 0 .201 r
F
.4487 .90247 m .4611 .93159 L .4478 .9024 L .239 .058 .423 r
F
.45994 .93523 m .461 .93889 L .45773 .93075 L F
.50297 .95356 m .48695 .9605 L .45951 .93656 L .417 .229 .516 r
F
.50297 .95356 m .45951 .93656 L .46101 .93187 L F
.45951 .93656 m .44774 .92785 L .44412 .92314 L F
.48695 .9605 m .45924 .93742 L .45951 .93656 L F
.45924 .93742 m .44774 .92785 L .45951 .93656 L F
.4478 .9024 m .46098 .93196 L .45927 .93343 L .239 .058 .423 r
F
.46098 .93196 m .46714 .94577 L .4601 .93473 L F
.46098 .93196 m .4601 .93473 L .45927 .93343 L F
.4611 .93159 m .46714 .94577 L .46098 .93196 L F
.4611 .93159 m .46098 .93196 L .4478 .9024 L F
.45927 .93343 m .46714 .94577 L .46455 .94773 L F
.45812 .93081 m .45778 .93003 L .45778 .92999 L F
.45994 .93523 m .45773 .93075 L .45777 .93019 L F
.45994 .93523 m .45369 .9207 L .45812 .93081 L F
.45927 .93343 m .45994 .93523 L .45812 .93081 L F
.46101 .93187 m .45951 .93656 L .44412 .92314 L .417 .229 .516 r
F
.47529 .93376 m .46152 .9303 L .47426 .93303 L F
.50297 .95356 m .4761 .93848 L .47529 .93376 L F
.4761 .93848 m .46152 .9303 L .47529 .93376 L F
.58272 .84836 m .48223 .91889 L .61854 .88105 L .792 .82 .874 r
F
.58272 .84836 m .46719 .88476 L .48223 .91889 L F
.45134 .90269 m .44387 .88248 L .4454 .89273 L .234 0 .201 r
F
.44349 .88385 m .44318 .88218 L .44286 .8852 L F
.4478 .9024 m .44295 .89357 L .44923 .90251 L F
.44284 .88911 m .4427 .88474 L .44273 .88468 L F
.44231 .88755 m .4487 .90247 L .4478 .9024 L .239 .058 .423 r
F
.4421 .88697 m .44243 .88774 L .44231 .88755 L F
.44243 .88774 m .4487 .90247 L .44231 .88755 L F
.44349 .88385 m .44286 .8852 L .44256 .88797 L .234 0 .201 r
F
.44243 .88774 m .44256 .88797 L .44255 .88804 L .239 .058 .423 r
F
.44256 .88797 m .45134 .90269 L .44255 .88804 L F
.44255 .88804 m .45134 .90269 L .4487 .90247 L F
.44202 .88728 m .44501 .8951 L .44137 .88996 L F
.44501 .8951 m .44418 .89539 L .44137 .88996 L F
.44208 .88705 m .44223 .88745 L .44202 .88728 L F
.44223 .88745 m .4478 .9024 L .44202 .88728 L F
.44289 .88268 m .44237 .88529 L .44034 .88685 L 0 0 0 r
F
.44237 .88529 m .44204 .88696 L .44159 .88693 L F
.44237 .88529 m .44159 .88693 L .44034 .88685 L F
.44231 .88755 m .4478 .9024 L .44223 .88745 L .239 .058 .423 r
F
.44229 .8875 m .44223 .88745 L .44208 .88705 L F
.44231 .88755 m .44223 .88745 L .44229 .8875 L F
.44501 .8951 m .4478 .9024 L .44418 .89539 L F
.4478 .9024 m .44255 .89283 L .44137 .88996 L F
.44649 .89999 m .44349 .88385 L .44213 .89204 L .234 0 .201 r
F
.44528 .87973 m .44524 .87982 L .44758 .87663 L 0 0 0 r
F
.44648 .87765 m .44599 .87835 L .44758 .87663 L F
.44599 .87835 m .44528 .87973 L .44758 .87663 L F
.48251 .82911 m .48228 .82943 L .48025 .83117 L .171 0 .048 r
F
.47906 .83219 m .48025 .83117 L .47885 .83244 L F
.46667 .84929 m .44648 .87765 L .46848 .84802 L 0 0 0 r
F
.4796 .83019 m .48247 .82938 L .48286 .82678 L .88 .959 .848 r
F
.47324 .83682 m .47892 .83225 L .4796 .83019 L F
.46515 .85087 m .44648 .87765 L .48049 .82988 L 0 0 0 r
F
.55008 .8284 m .45371 .87034 L .46719 .88476 L .823 .941 .903 r
F
.52273 .81979 m .45371 .87034 L .55008 .8284 L .704 .98 .791 r
F
.44639 .88448 m .44778 .87464 L .45737 .865 L 0 0 0 r
F
.4451 .88676 m .4457 .88406 L .44639 .88448 L F
.4457 .88406 m .44778 .87464 L .44639 .88448 L F
.44778 .87464 m .45024 .87128 L .45737 .865 L F
.44811 .87316 m .44956 .87009 L .45737 .865 L F
.44453 .88652 m .44789 .87361 L .4451 .88676 L F
.44789 .87361 m .44866 .87068 L .44811 .87316 L F
.44789 .87361 m .44811 .87316 L .4451 .88676 L F
.4434 .88788 m .4439 .88625 L .44392 .88812 L F
.44387 .88248 m .44342 .88229 L .44649 .89999 L .234 0 .201 r
F
.4439 .88625 m .44752 .87441 L .44453 .88652 L 0 0 0 r
F
.44752 .87441 m .44866 .87068 L .44789 .87361 L F
.44752 .87441 m .44789 .87361 L .44453 .88652 L F
.44321 .88106 m .44341 .88228 L .44342 .88229 L .234 0 .201 r
F
.4431 .88039 m .44318 .88218 L .44341 .88228 L F
.44506 .87902 m .44389 .88099 L .44599 .87835 L 0 0 0 r
F
.44479 .87922 m .44389 .88099 L .44506 .87902 L F
.44479 .87922 m .443 .8821 L .44389 .88099 L F
.44289 .88268 m .44291 .88258 L .44643 .87671 L F
.44289 .88268 m .44643 .87671 L .44636 .87686 L F
.44318 .88218 m .44229 .88751 L .44263 .88733 L .234 0 .201 r
F
.44289 .88268 m .44034 .88685 L .44291 .88258 L 0 0 0 r
F
.44111 .88536 m .44008 .88684 L .44116 .88537 L F
.443 .8821 m .44034 .88685 L .441 .88534 L F
.44291 .88258 m .44034 .88685 L .443 .8821 L F
.44318 .88218 m .44249 .88188 L .44229 .88751 L .234 0 .201 r
F
.44599 .87835 m .44329 .88223 L .44528 .87973 L 0 0 0 r
F
.44329 .88223 m .4434 .88227 L .44528 .87973 L F
.4434 .88227 m .44524 .87982 L .44528 .87973 L F
.4434 .88228 m .44524 .87982 L .4434 .88227 L F
.4431 .88039 m .44259 .87903 L .44318 .88218 L .234 0 .201 r
F
.443 .8821 m .44329 .88223 L .44599 .87835 L 0 0 0 r
F
.4434 .88228 m .44342 .88229 L .44524 .87982 L F
.44479 .87922 m .44599 .87835 L .44624 .87787 L F
.44607 .87746 m .44237 .88529 L .44289 .88268 L F
.44607 .87746 m .44289 .88268 L .44636 .87686 L F
.44349 .88385 m .44256 .88797 L .44275 .88828 L .234 0 .201 r
F
.4431 .88039 m .44321 .88108 L .44321 .88106 L F
.44321 .88108 m .44341 .88228 L .44321 .88106 L F
.44752 .87441 m .44259 .87903 L .44866 .87068 L 0 0 0 r
F
.44624 .87787 m .44599 .87835 L .44648 .87765 L F
.44375 .88673 m .44325 .88342 L .44752 .87441 L F
.44672 .87609 m .44291 .88258 L .443 .8821 L F
.44643 .87671 m .44291 .88258 L .44672 .87609 L F
.44325 .88342 m .44259 .87903 L .44752 .87441 L F
.44778 .87464 m .44811 .87316 L .45024 .87128 L F
.4607 .85347 m .44672 .87609 L .46526 .85028 L F
.44672 .87609 m .45546 .86413 L .46526 .85028 L F
.44934 .87185 m .44643 .87671 L .44672 .87609 L F
.44636 .87686 m .44643 .87671 L .44934 .87185 L F
.44779 .88991 m .44973 .89294 L .44467 .88898 L 0 0 .542 r
F
.44425 .88827 m .44467 .88898 L .44307 .88773 L F
.44779 .88991 m .44467 .88898 L .44425 .88827 L F
.44419 .88638 m .44453 .88652 L .44413 .88807 L 0 0 0 r
F
.44263 .88733 m .44229 .88751 L .44213 .89204 L .234 0 .201 r
F
.44973 .89294 m .4446 .89047 L .44243 .88743 L 0 0 .542 r
F
.44229 .88751 m .44237 .88529 L .44375 .88673 L 0 0 0 r
F
.44307 .88773 m .44243 .88743 L .4421 .88697 L 0 0 .542 r
F
.44973 .89294 m .44243 .88743 L .44307 .88773 L F
.44419 .88638 m .44413 .88807 L .4441 .8882 L 0 0 0 r
F
.444 .88816 m .4441 .8882 L .44393 .88884 L F
.44419 .88638 m .4441 .8882 L .444 .88816 L F
.4439 .88625 m .44419 .88638 L .44393 .88884 L F
.44393 .88884 m .44453 .88652 L .4451 .88676 L F
.44425 .88827 m .44687 .88362 L .44353 .88706 L F
.44237 .88529 m .44325 .88342 L .44375 .88673 L F
.44736 .87546 m .44204 .88696 L .44237 .88529 L F
.44771 .87479 m .44728 .87571 L .44736 .87546 L F
.44728 .87571 m .44204 .88696 L .44736 .87546 L F
.44771 .87479 m .44237 .88529 L .44607 .87746 L F
.44237 .88529 m .44259 .87903 L .44325 .88342 L F
.44771 .87479 m .4421 .88697 L .44204 .88696 L F
.44794 .87645 m .4421 .88697 L .44771 .87479 L F
.44549 .87996 m .44193 .88621 L .44316 .88477 L .999 .845 .541 r
F
.4455 .87984 m .44193 .88621 L .44549 .87996 L F
.44468 .88068 m .44193 .88621 L .44579 .87932 L F
.44252 .88055 m .44213 .88065 L .44232 .88007 L .171 0 .048 r
F
.43947 .87939 m .44213 .88065 L .43937 .87951 L F
.44455 .87334 m .44294 .87821 L .43947 .87939 L F
.44213 .88065 m .44008 .88684 L .43955 .88135 L F
.44213 .88065 m .43955 .88135 L .43937 .87951 L F
.44337 .88102 m .44012 .87792 L .44155 .88447 L .999 .845 .541 r
F
.44811 .87316 m .44866 .87068 L .44956 .87009 L 0 0 0 r
F
.44714 .86642 m .44586 .87692 L .44975 .86116 L .847 .753 .239 r
F
.44719 .86607 m .44975 .86116 L .44985 .8605 L F
.44697 .86781 m .44135 .8761 L .44596 .87614 L .999 .845 .541 r
F
.44135 .8761 m .44103 .87658 L .4416 .87653 L F
.44135 .8761 m .4416 .87653 L .44596 .87614 L F
.48913 .78728 m .47949 .80581 L .48064 .80638 L .808 .634 .665 r
F
.47949 .80581 m .4744 .81558 L .47788 .81044 L F
.47788 .81044 m .48064 .80638 L .47855 .80917 L .92 .842 .75 r
F
.47949 .80581 m .47788 .81044 L .48064 .80638 L .808 .634 .665 r
F
.43641 .84551 m .45651 .82264 L .44887 .82071 L .953 .819 .675 r
F
.47106 .80849 m .45803 .81975 L .47138 .80955 L .761 .416 .4 r
F
.46839 .79996 m .46525 .80595 L .47106 .80849 L F
.46525 .80595 m .45803 .81975 L .47106 .80849 L F
.44887 .82071 m .46525 .80595 L .46293 .80494 L .875 .71 .674 r
F
.44887 .82071 m .46293 .80494 L .45878 .80625 L F
.46745 .79695 m .45931 .80422 L .45878 .80625 L .761 .416 .4 r
F
.45651 .82264 m .46405 .80824 L .44887 .82071 L .953 .819 .675 r
F
.48054 .79354 m .47138 .80955 L .48913 .78728 L .808 .634 .665 r
F
.47969 .79416 m .48589 .78921 L .47602 .79625 L .953 .819 .675 r
F
.48483 .79042 m .48589 .78921 L .47969 .79416 L F
.48589 .78921 m .47987 .79278 L .47602 .79625 L F
.47969 .79416 m .47602 .79625 L .47944 .79433 L F
.51046 .73579 m .47944 .79433 L .50673 .74774 L .808 .634 .665 r
F
.47944 .79433 m .47138 .80955 L .48054 .79354 L F
.47944 .79433 m .48054 .79354 L .50673 .74774 L F
.47944 .79433 m .47602 .79625 L .47677 .79588 L .953 .819 .675 r
F
.48341 .79203 m .47969 .79416 L .47944 .79433 L F
.48244 .79313 m .48158 .79355 L .44887 .82071 L F
.48341 .79203 m .4758 .79645 L .44887 .82071 L F
.46293 .80494 m .45878 .80625 L .45584 .8175 L .761 .416 .4 r
F
.46745 .79695 m .45878 .80625 L .46293 .80494 L F
.46396 .80539 m .45195 .82439 L .45803 .81975 L F
.46745 .79695 m .46293 .80494 L .46396 .80539 L F
.46293 .80494 m .45195 .82439 L .46396 .80539 L F
.46745 .79695 m .45803 .81975 L .46839 .79996 L F
.46293 .80494 m .47602 .79625 L .46043 .80385 L .875 .71 .674 r
F
.46525 .80595 m .46822 .80328 L .46293 .80494 L F
.46822 .80328 m .47602 .79625 L .46293 .80494 L F
.45878 .80625 m .46293 .80494 L .46043 .80385 L F
.4734 .78013 m .46645 .79131 L .46745 .79695 L .543 .335 .549 r
F
.48458 .74853 m .46988 .78321 L .4734 .78013 L F
.46988 .78321 m .46645 .79131 L .4734 .78013 L F
.44887 .82071 m .45833 .80691 L .4618 .79473 L .875 .71 .674 r
F
.46224 .79305 m .4618 .79473 L .46233 .79285 L F
.44887 .82071 m .4618 .79473 L .46224 .79305 L F
.4287 .82728 m .43641 .84551 L .44887 .82071 L .902 .603 .47 r
F
.41638 .84226 m .41605 .84217 L .41542 .84349 L .61 .236 .308 r
F
.42996 .84509 m .43641 .84551 L .42068 .84315 L .933 .558 .257 r
F
.42702 .83061 m .43641 .84551 L .4287 .82728 L .902 .603 .47 r
F
.42524 .831 m .43073 .81158 L .41605 .84217 L .61 .236 .308 r
F
.42524 .831 m .41605 .84217 L .41638 .84226 L F
.42297 .83863 m .41542 .84349 L .41859 .8473 L .761 .416 .4 r
F
.42498 .83304 m .41542 .84349 L .42472 .83517 L .61 .236 .308 r
F
.40056 .82661 m .40053 .827 L .40297 .8297 L .356 0 0 r
F
.40056 .82661 m .40297 .8297 L .40193 .82816 L F
.39506 .83146 m .40307 .82986 L .40119 .82794 L .846 .586 .546 r
F
.41389 .84267 m .41387 .84253 L .39282 .83898 L .933 .558 .257 r
F
.41387 .84253 m .41381 .84212 L .41335 .84205 L F
.41387 .84253 m .41335 .84205 L .39282 .83898 L F
.43258 .86012 m .47124 .82309 L .43641 .84551 L .989 .892 .598 r
F
.43214 .85905 m .42476 .844 L .43065 .8616 L .761 .416 .4 r
F
.42996 .84509 m .43219 .85936 L .43641 .84551 L .933 .558 .257 r
F
.43219 .85936 m .43241 .85978 L .43641 .84551 L F
.43241 .85978 m .43258 .86012 L .43258 .86012 L F
.43241 .85978 m .43258 .86012 L .43641 .84551 L F
.43641 .84551 m .47124 .82309 L .47405 .81773 L .953 .819 .675 r
F
.47138 .80955 m .4673 .81849 L .47405 .81773 L .892 .593 .474 r
F
.4744 .81558 m .47405 .81773 L .4754 .81758 L F
.47138 .80955 m .47405 .81773 L .4744 .81558 L F
.47124 .82309 m .47375 .8196 L .47383 .81916 L .92 .842 .75 r
F
.43641 .84551 m .47405 .81773 L .47201 .81796 L .953 .819 .675 r
F
.43633 .85697 m .47124 .82309 L .43258 .86012 L .989 .892 .598 r
F
.43516 .85818 m .43267 .86029 L .43741 .8623 L .892 .593 .474 r
F
.43557 .86467 m .44998 .86024 L .45116 .84455 L .989 .892 .598 r
F
.44555 .86605 m .44086 .8763 L .44674 .8666 L .892 .593 .474 r
F
.44086 .8763 m .44097 .87647 L .44674 .8666 L F
.44086 .8763 m .44012 .87792 L .44097 .87647 L F
.44599 .86606 m .44674 .8666 L .44703 .86611 L F
.44555 .86605 m .44674 .8666 L .44599 .86606 L F
.4471 .8661 m .44998 .86024 L .43557 .86467 L .847 .753 .239 r
F
.44719 .86607 m .44998 .86024 L .4471 .8661 L F
.44717 .86611 m .43557 .86467 L .44555 .86605 L F
.44714 .86642 m .44975 .86116 L .44719 .86607 L F
.47096 .84088 m .46391 .84967 L .47324 .83682 L 0 0 0 r
F
.46478 .85061 m .47079 .84096 L .44975 .86116 L F
.46526 .85028 m .46639 .84838 L .46478 .85061 L F
.46639 .84838 m .47079 .84096 L .46478 .85061 L F
.45737 .865 m .45252 .86816 L .46094 .85663 L F
.4607 .85347 m .44794 .87645 L .44771 .87479 L F
.44921 .87227 m .44468 .88068 L .44579 .87932 L .999 .845 .541 r
F
.4607 .85347 m .45087 .8696 L .44934 .87185 L 0 0 0 r
F
.47079 .84096 m .46794 .84232 L .44975 .86116 L F
.45087 .8696 m .44607 .87746 L .44934 .87185 L F
.44807 .87385 m .44468 .88068 L .44921 .87227 L .999 .845 .541 r
F
.44607 .87746 m .44636 .87686 L .44934 .87185 L 0 0 0 r
F
.45459 .86526 m .44373 .88413 L .45574 .86242 L F
.44373 .88413 m .44377 .88396 L .45574 .86242 L F
.45713 .86036 m .45574 .86242 L .4607 .85347 L F
.45459 .86526 m .45574 .86242 L .45713 .86036 L F
.4562 .86214 m .46113 .85569 L .45903 .8567 L F
.46113 .85569 m .46478 .85061 L .4607 .85347 L F
.45903 .8567 m .4607 .85347 L .44975 .86116 L F
.46113 .85569 m .4607 .85347 L .45903 .8567 L F
.448 .87689 m .44798 .87674 L .45459 .86526 L F
.448 .87689 m .45459 .86526 L .45403 .86634 L F
.45275 .8688 m .448 .87689 L .45403 .86634 L F
.45737 .865 m .46094 .85663 L .46592 .84981 L F
.46592 .84981 m .47324 .83682 L .46526 .85028 L F
.45546 .86413 m .46515 .85087 L .48603 .82092 L F
.45624 .86538 m .46526 .85028 L .44631 .87511 L F
.45403 .86634 m .45459 .86526 L .46142 .85339 L F
.46238 .85237 m .45275 .8688 L .46142 .85339 L F
.45275 .8688 m .45403 .86634 L .46142 .85339 L F
.44631 .87511 m .4562 .86214 L .44975 .86116 L F
.4562 .86214 m .45903 .8567 L .44975 .86116 L F
.46113 .85569 m .46526 .85028 L .46478 .85061 L F
.44807 .87385 m .44155 .88447 L .44468 .88068 L .999 .845 .541 r
F
.44465 .8786 m .44155 .88447 L .44807 .87385 L F
.44921 .87227 m .44316 .88477 L .45206 .86948 L F
.44579 .87932 m .4455 .87984 L .44549 .87996 L F
.448 .87689 m .4421 .88697 L .44798 .87674 L 0 0 0 r
F
.47079 .84096 m .47324 .83682 L .46794 .84232 L F
.48248 .82477 m .48307 .82417 L .48328 .8239 L .793 .955 .624 r
F
.4806 .8213 m .47284 .83453 L .47024 .83805 L 0 0 0 r
F
.44998 .86024 m .48307 .82417 L .46786 .83957 L .793 .955 .624 r
F
.47024 .83805 m .4607 .85347 L .48603 .82092 L 0 0 0 r
F
.4607 .85347 m .46526 .85028 L .48603 .82092 L F
.47284 .83453 m .46238 .85237 L .47024 .83805 L F
.46238 .85237 m .46142 .85339 L .47024 .83805 L F
.46142 .85339 m .45459 .86526 L .45994 .85495 L F
.44316 .88477 m .44366 .88427 L .47185 .83553 L .999 .845 .541 r
F
.47174 .83565 m .47185 .83553 L .48023 .82105 L F
.44316 .88477 m .47185 .83553 L .47174 .83565 L F
.44998 .86024 m .46786 .83957 L .46494 .84253 L .793 .955 .624 r
F
.47024 .83805 m .46142 .85339 L .4607 .85347 L 0 0 0 r
F
.46142 .85339 m .45994 .85495 L .4607 .85347 L F
.46494 .84253 m .47435 .82075 L .47238 .82223 L .793 .955 .624 r
F
.47124 .82309 m .47453 .82014 L .4736 .81982 L .92 .842 .75 r
F
.47453 .82014 m .47467 .82002 L .4745 .81998 L F
.47453 .82014 m .4745 .81998 L .4736 .81982 L F
.47435 .82075 m .47467 .82002 L .47124 .82309 L .793 .955 .624 r
F
.4745 .81998 m .44921 .87227 L .45804 .85849 L .999 .845 .541 r
F
.47314 .82355 m .45804 .85849 L .46245 .85161 L F
.4745 .81998 m .45804 .85849 L .47314 .82355 L F
.47554 .81784 m .4745 .81998 L .48023 .82105 L F
.499 .80221 m .49024 .80604 L .47467 .82002 L .793 .955 .624 r
F
.4745 .81998 m .46245 .85161 L .47621 .8203 L .999 .845 .541 r
F
.499 .80221 m .47467 .82002 L .47435 .82075 L .793 .955 .624 r
F
.4745 .81998 m .45654 .85006 L .4623 .8452 L .999 .845 .541 r
F
.47554 .81784 m .47444 .81969 L .4745 .81998 L F
.4754 .81758 m .47419 .81966 L .47554 .81784 L .892 .593 .474 r
F
.47467 .82002 m .47495 .81976 L .4736 .81982 L .92 .842 .75 r
F
.47495 .81976 m .47385 .81961 L .4736 .81982 L F
.47419 .81966 m .44012 .87792 L .47444 .81969 L .892 .593 .474 r
F
.47419 .81966 m .47444 .81969 L .47554 .81784 L F
.45116 .84455 m .44998 .86024 L .47124 .82309 L .989 .892 .598 r
F
.46871 .82575 m .47124 .82309 L .46952 .82476 L F
.43267 .86029 m .43075 .86191 L .43395 .86275 L .892 .593 .474 r
F
.43267 .86029 m .43395 .86275 L .44565 .86582 L F
.43133 .86117 m .43075 .86191 L .43267 .86029 L F
.43258 .86012 m .43267 .86029 L .458 .83882 L F
.43133 .86117 m .43267 .86029 L .43258 .86012 L F
.43219 .85937 m .43103 .86142 L .43237 .8597 L .761 .416 .4 r
F
.46871 .82575 m .46952 .82476 L .43241 .86078 L .989 .892 .598 r
F
.43516 .85818 m .43741 .8623 L .43864 .86071 L .892 .593 .474 r
F
.458 .83882 m .43516 .85818 L .44565 .86582 L F
.43772 .8583 m .46871 .82575 L .43241 .86078 L .989 .892 .598 r
F
.44338 .85286 m .47124 .82309 L .43772 .8583 L F
.43641 .84551 m .47525 .81545 L .46923 .81776 L .953 .819 .675 r
F
.47138 .80955 m .46322 .82006 L .4673 .81849 L .892 .593 .474 r
F
.45195 .82439 m .46322 .82006 L .47138 .80955 L .761 .416 .4 r
F
.45648 .82267 m .47788 .81044 L .48483 .79042 L .953 .819 .675 r
F
.43641 .84551 m .46927 .81772 L .45648 .82267 L F
.46927 .81772 m .47788 .81044 L .45648 .82267 L F
.4673 .81849 m .43241 .85978 L .458 .83882 L .892 .593 .474 r
F
.46322 .82006 m .43241 .85978 L .4673 .81849 L F
.43241 .85978 m .43133 .86117 L .43258 .86012 L F
.43258 .86012 m .43633 .85697 L .43258 .86012 L .989 .892 .598 r
F
.43628 .85702 m .43633 .85697 L .43258 .86012 L F
.43241 .85978 m .43258 .86012 L .458 .83882 L .892 .593 .474 r
F
.39848 .84305 m .41409 .84406 L .39282 .83898 L .933 .558 .257 r
F
.41374 .84163 m .41378 .84189 L .41542 .84349 L .356 0 0 r
F
.40407 .83531 m .40914 .83745 L .40627 .83459 L .902 .603 .47 r
F
.39282 .83898 m .41335 .84205 L .40407 .83531 L F
.40627 .83459 m .40351 .8305 L .39506 .83146 L F
.40351 .8305 m .40307 .82986 L .39506 .83146 L F
.40053 .827 m .40486 .83318 L .40621 .8345 L .356 0 0 r
F
.40308 .82986 m .40621 .8345 L .41378 .84189 L F
.40053 .827 m .40621 .8345 L .40308 .82986 L F
.40053 .827 m .41378 .84189 L .41374 .84163 L F
.40193 .82816 m .40297 .8297 L .40352 .83031 L F
.40193 .82816 m .40352 .83031 L .40625 .83308 L F
.40193 .82816 m .41374 .84163 L .41373 .84157 L F
.43811 .8079 m .43073 .81158 L .42524 .831 L .61 .236 .308 r
F
.43073 .81158 m .40639 .83323 L .41542 .84349 L F
.427 .82784 m .41225 .82803 L .40307 .82986 L .902 .603 .47 r
F
.40625 .83308 m .40352 .83031 L .41374 .84163 L .356 0 0 r
F
.427 .82784 m .40307 .82986 L .40351 .8305 L .902 .603 .47 r
F
.40486 .83318 m .41479 .8431 L .41542 .84349 L .356 0 0 r
F
.41373 .84157 m .41374 .84163 L .41542 .84349 L F
.41335 .84205 m .41381 .84212 L .40407 .83531 L .902 .603 .47 r
F
.427 .82784 m .42702 .83061 L .4287 .82728 L F
.42619 .82929 m .42702 .83061 L .427 .82784 L F
.42367 .8436 m .43641 .84551 L .42702 .83061 L F
.42472 .83517 m .42702 .83061 L .42557 .8283 L F
.42367 .8436 m .42702 .83061 L .42472 .83517 L F
.43462 .82631 m .42472 .83517 L .44469 .82467 L .761 .416 .4 r
F
.42472 .83517 m .41542 .84349 L .42297 .83863 L F
.41102 .8223 m .4528 .79832 L .40571 .82279 L .846 .586 .546 r
F
.40571 .82279 m .4528 .79832 L .4042 .82292 L F
.45974 .78713 m .42524 .831 L .46437 .79001 L .61 .236 .308 r
F
.42524 .831 m .41542 .84349 L .42498 .83304 L F
.42524 .831 m .42498 .83304 L .46437 .79001 L F
.40627 .83459 m .42367 .8436 L .42557 .8283 L .902 .603 .47 r
F
.42472 .83517 m .42297 .83863 L .44469 .82467 L .761 .416 .4 r
F
.41381 .84212 m .42367 .8436 L .40914 .83745 L .902 .603 .47 r
F
.41381 .84212 m .40914 .83745 L .40407 .83531 L F
.39282 .83898 m .40407 .83531 L .39506 .83146 L F
.40407 .83531 m .40627 .83459 L .40158 .83328 L F
.40407 .83531 m .40158 .83328 L .39506 .83146 L F
.40486 .83318 m .40036 .83396 L .40956 .83987 L .356 0 0 r
F
.40036 .83396 m .40095 .83456 L .40956 .83987 L F
.39901 .82919 m .40169 .82766 L .39913 .82621 L .846 .586 .546 r
F
.40053 .827 m .40042 .82874 L .40486 .83318 L .356 0 0 r
F
.41409 .84406 m .41389 .84267 L .39282 .83898 L .933 .558 .257 r
F
.40041 .82876 m .3703 .81906 L .3774 .82263 L .356 0 0 r
F
.40024 .83138 m .3774 .82263 L .39036 .82914 L F
.39657 .82283 m .35252 .81295 L .39913 .8262 L .149 0 0 r
F
.40041 .82876 m .3774 .82263 L .40024 .83138 L .356 0 0 r
F
.38921 .82869 m .39848 .84305 L .37651 .82365 L .036 .354 .828 r
F
.38921 .82869 m .40969 .84351 L .39848 .84305 L F
.3958 .83171 m .40969 .84351 L .38921 .82869 L F
.40095 .83456 m .40969 .84351 L .3958 .83171 L F
.39203 .82998 m .37752 .8244 L .40006 .83402 L .356 0 0 r
F
.3703 .81906 m .37367 .82155 L .39203 .82998 L F
.37367 .82155 m .37752 .8244 L .39203 .82998 L F
.40024 .83138 m .39036 .82914 L .39281 .83011 L F
.40024 .83138 m .39203 .82998 L .40008 .83368 L F
.40053 .827 m .3708 .81845 L .40041 .82876 L F
.3532 .81336 m .39282 .83898 L .3492 .81182 L 0 .082 .565 r
F
.37267 .82082 m .38687 .83362 L .3532 .81336 L F
.38687 .83362 m .39282 .83898 L .3532 .81336 L F
.39339 .81976 m .35204 .81266 L .39657 .82283 L .149 0 0 r
F
.35204 .81266 m .34859 .81207 L .35252 .81295 L F
.35204 .81266 m .35252 .81295 L .39657 .82283 L F
.3708 .81845 m .34859 .81207 L .40041 .82876 L .356 0 0 r
F
.39927 .8333 m .3958 .83171 L .38553 .82298 L .036 .354 .828 r
F
.40095 .83456 m .3958 .83171 L .39927 .8333 L F
.37706 .81214 m .35042 .81135 L .35623 .81209 L .149 0 0 r
F
.38551 .81217 m .36503 .81211 L .39304 .81943 L F
.35107 .81208 m .3532 .81336 L .3492 .81182 L 0 .082 .565 r
F
.35274 .81164 m .35497 .81316 L .35657 .81344 L .718 .185 0 r
F
.36503 .81211 m .35107 .81208 L .39613 .82023 L .149 0 0 r
F
.35107 .81208 m .34859 .81207 L .35204 .81266 L F
.35107 .81208 m .35204 .81266 L .39613 .82023 L F
.36955 .81034 m .35326 .809 L .35846 .80969 L F
.36448 .81019 m .35846 .80969 L .36164 .81011 L F
.36955 .81034 m .35846 .80969 L .36448 .81019 L F
.34841 .80732 m .32123 .8063 L .34475 .80834 L .181 .715 .778 r
F
.36932 .80086 m .32773 .80491 L .37663 .80652 L F
.35803 .8073 m .35109 .80658 L .35746 .8074 L F
.35326 .809 m .3341 .80752 L .37706 .81214 L .149 0 0 r
F
.3341 .80752 m .34425 .80892 L .37706 .81214 L F
.35109 .80658 m .34605 .80651 L .34841 .80732 L .181 .715 .778 r
F
.34646 .80069 m .33748 .80323 L .35995 .80177 L .571 .935 .92 r
F
.38587 .78952 m .34646 .80069 L .35995 .80177 L F
.34311 .79417 m .36506 .81395 L .33797 .8042 L 0 .082 .565 r
F
.33386 .80172 m .33797 .8042 L .33301 .80241 L F
.34311 .79417 m .33797 .8042 L .33386 .80172 L F
.39913 .82621 m .34859 .81207 L .40053 .827 L .356 0 0 r
F
.36448 .81019 m .39837 .80903 L .37124 .81038 L .736 .315 .248 r
F
.37916 .8102 m .37124 .81038 L .39465 .81219 L .181 .715 .778 r
F
.39481 .80923 m .3776 .81023 L .37601 .81027 L .736 .315 .248 r
F
.39481 .80923 m .39675 .80922 L .37817 .81022 L F
.39481 .80923 m .37817 .81022 L .3776 .81023 L F
.38276 .81127 m .37124 .81038 L .39205 .81218 L .149 0 0 r
F
.37124 .81038 m .36955 .81034 L .39205 .81218 L F
.39205 .81218 m .36955 .81034 L .37706 .81214 L F
.36955 .81034 m .36164 .81011 L .37706 .81214 L F
.39465 .81219 m .38276 .81127 L .39205 .81218 L F
.39881 .80911 m .39817 .80927 L .38131 .81014 L .736 .315 .248 r
F
.39881 .80911 m .38131 .81014 L .37817 .81022 L F
.39526 .81118 m .38459 .81007 L .39465 .81219 L .181 .715 .778 r
F
.38459 .81007 m .37963 .81018 L .39465 .81219 L F
.40335 .80886 m .39817 .80927 L .39881 .80911 L .736 .315 .248 r
F
.39837 .80903 m .39828 .80914 L .39675 .80922 L F
.39837 .80903 m .39675 .80922 L .39481 .80923 L F
.36448 .81019 m .40209 .81333 L .40335 .80886 L F
.36 .78342 m .38921 .82869 L .34311 .79417 L .036 .354 .828 r
F
.38921 .82869 m .37651 .82365 L .34311 .79417 L F
.39281 .83011 m .39036 .82914 L .39203 .82998 L .356 0 0 r
F
.37754 .8106 m .40095 .83456 L .38553 .82298 L .036 .354 .828 r
F
.40008 .83368 m .39203 .82998 L .40006 .83402 L .356 0 0 r
F
.38553 .82298 m .3958 .83171 L .38921 .82869 L .036 .354 .828 r
F
.40486 .83318 m .40956 .83987 L .41387 .84253 L .356 0 0 r
F
.41381 .84212 m .41387 .84253 L .41479 .8431 L F
.40486 .83318 m .41387 .84253 L .41381 .84212 L F
.42476 .844 m .41859 .8473 L .43075 .86191 L .761 .416 .4 r
F
.40914 .83745 m .42367 .8436 L .40627 .83459 L .902 .603 .47 r
F
.42297 .83863 m .42068 .84315 L .42476 .844 L .761 .416 .4 r
F
.42068 .84315 m .41859 .8473 L .42476 .844 L F
.41542 .84349 m .4209 .84792 L .43075 .86191 L .45 0 0 r
F
.4209 .84792 m .4306 .8613 L .43075 .86191 L F
.39848 .84305 m .42938 .85397 L .41564 .84416 L .933 .558 .257 r
F
.41771 .84564 m .41565 .84418 L .41797 .84585 L .45 0 0 r
F
.41423 .84286 m .41564 .84416 L .41771 .84564 L F
.41564 .84416 m .41565 .84418 L .41771 .84564 L F
.43917 .84701 m .43065 .8616 L .43103 .86142 L .761 .416 .4 r
F
.42388 .85202 m .43219 .85936 L .42938 .85397 L .933 .558 .257 r
F
.42758 .85714 m .43219 .85936 L .42388 .85202 L F
.43103 .86142 m .43133 .86117 L .43241 .85978 L .761 .416 .4 r
F
.43103 .86142 m .43241 .85978 L .43237 .8597 L F
.42758 .85714 m .43241 .86078 L .43219 .85937 L .933 .558 .257 r
F
.43219 .85936 m .43219 .85937 L .43219 .85936 L F
.42758 .85714 m .43219 .85937 L .43219 .85936 L F
.43237 .8597 m .43241 .85978 L .46322 .82006 L .761 .416 .4 r
F
.42889 .85894 m .43241 .86078 L .42758 .85714 L .933 .558 .257 r
F
.44565 .86582 m .43075 .86191 L .43209 .86419 L .892 .593 .474 r
F
.44565 .86582 m .43209 .86419 L .44555 .86605 L F
.43103 .86142 m .43075 .86191 L .43133 .86117 L .761 .416 .4 r
F
.43103 .86142 m .43065 .8616 L .43075 .86191 L F
.4306 .8613 m .43119 .8621 L .43075 .86191 L .45 0 0 r
F
.44555 .86605 m .43209 .86419 L .44012 .87792 L .892 .593 .474 r
F
.43354 .8653 m .43557 .86467 L .43288 .86408 L .989 .892 .598 r
F
.45648 .86211 m .4421 .88697 L .45593 .86337 L .999 .845 .541 r
F
.44454 .88227 m .45624 .86538 L .44631 .87511 L 0 0 0 r
F
.44341 .88685 m .44548 .88339 L .44454 .88227 L F
.44548 .88339 m .45624 .86538 L .44454 .88227 L F
.4623 .8452 m .44465 .8786 L .44807 .87385 L .999 .845 .541 r
F
.44327 .8883 m .4423 .88751 L .44375 .88673 L 0 0 0 r
F
.44348 .88698 m .46526 .85028 L .44341 .88685 L F
.44708 .86611 m .44012 .87792 L .44842 .86567 L .999 .845 .541 r
F
.44555 .86605 m .43557 .86467 L .43322 .86539 L .847 .753 .239 r
F
.43375 .86703 m .43334 .86576 L .44012 .87792 L 0 .006 .567 r
F
.4427 .87546 m .44717 .86611 L .43387 .86608 L .847 .753 .239 r
F
.44555 .86605 m .43322 .86539 L .43337 .86555 L F
.43283 .86413 m .43354 .8653 L .43288 .86408 L .989 .892 .598 r
F
.43282 .86415 m .43291 .86429 L .43283 .86413 L F
.43291 .86429 m .43354 .8653 L .43283 .86413 L F
.43322 .86539 m .43354 .8653 L .43282 .86415 L F
.43182 .86303 m .43182 .86303 L .43182 .86303 L .933 .558 .257 r
F
.43075 .86191 m .43277 .86491 L .43209 .86419 L 0 .006 .567 r
F
.43075 .86191 m .4317 .8629 L .43301 .86517 L F
.4317 .8629 m .43181 .86301 L .43182 .86303 L F
.4317 .8629 m .43182 .86303 L .43301 .86517 L F
.43182 .86303 m .43873 .85783 L .43241 .86078 L .989 .892 .598 r
F
.43182 .86303 m .43873 .85783 L .43182 .86303 L F
.43282 .86415 m .43873 .85783 L .43182 .86303 L F
.4291 .85905 m .43182 .86303 L .43241 .86078 L .933 .558 .257 r
F
.43288 .86408 m .43557 .86467 L .43864 .86071 L .989 .892 .598 r
F
.43288 .86408 m .43864 .86071 L .43705 .85963 L F
.44717 .86611 m .43337 .86555 L .43387 .86608 L .847 .753 .239 r
F
.44596 .87614 m .44103 .87658 L .44337 .88102 L .999 .845 .541 r
F
.44348 .87382 m .44343 .87782 L .44586 .87692 L .847 .753 .239 r
F
.44343 .87782 m .44403 .88023 L .44586 .87692 L F
.44468 .88068 m .44155 .88447 L .44193 .88621 L .999 .845 .541 r
F
.44339 .88138 m .44372 .88415 L .44586 .87692 L .847 .753 .239 r
F
.44335 .8854 m .4434 .88675 L .44383 .88506 L F
.44372 .88415 m .44383 .88506 L .44586 .87692 L F
.44335 .8854 m .44383 .88506 L .44372 .88415 L F
.44103 .87658 m .44012 .87792 L .44337 .88102 L .999 .845 .541 r
F
.43311 .86527 m .4427 .87546 L .44058 .87826 L 0 .006 .567 r
F
.44343 .87782 m .44339 .88138 L .44403 .88023 L .847 .753 .239 r
F
.44687 .88362 m .46592 .84981 L .44349 .88698 L 0 0 0 r
F
.44341 .88685 m .44408 .88799 L .44344 .88766 L 0 0 .542 r
F
.44353 .88706 m .44349 .88698 L .4433 .88729 L 0 0 0 r
F
.44687 .88362 m .44349 .88698 L .44353 .88706 L F
.44316 .88477 m .44193 .88621 L .4421 .88697 L .999 .845 .541 r
F
.44373 .88413 m .4421 .88697 L .44377 .88396 L 0 0 0 r
F
.44316 .88477 m .4421 .88697 L .44366 .88427 L .999 .845 .541 r
F
.44253 .88537 m .44344 .88766 L .4421 .88697 L 0 0 .542 r
F
.44324 .88279 m .44341 .88685 L .44253 .88537 L F
.44341 .88685 m .44344 .88766 L .44253 .88537 L F
.44333 .88705 m .44344 .88673 L .44383 .88513 L .847 .753 .239 r
F
.44383 .88506 m .44383 .88513 L .44586 .87692 L F
.44333 .88705 m .44383 .88513 L .44383 .88506 L F
.46592 .84981 m .46526 .85028 L .4433 .88729 L 0 0 0 r
F
.44331 .88066 m .44331 .8807 L .44012 .87792 L 0 .006 .567 r
F
.4427 .87546 m .44326 .88026 L .44058 .87826 L F
.44012 .87792 m .44324 .88279 L .4421 .88697 L 0 0 .542 r
F
.44329 .88141 m .44333 .88718 L .44339 .88138 L .847 .753 .239 r
F
.44309 .88691 m .44333 .88718 L .44329 .88141 L F
.44339 .88138 m .44335 .8854 L .44372 .88415 L F
.51359 .90923 m .4801 .91677 L .47338 .9068 L .334 .327 .702 r
F
.47431 .8985 m .47324 .90679 L .46846 .89691 L F
.51359 .90923 m .47324 .90679 L .47431 .8985 L F
.46643 .89931 m .46674 .89696 L .47292 .90612 L 0 .006 .567 r
F
.46058 .89318 m .4663 .89669 L .46643 .89931 L F
.4663 .89669 m .46674 .89696 L .46643 .89931 L F
.44324 .88279 m .46855 .90314 L .47079 .92585 L 0 0 .542 r
F
.46855 .90314 m .47323 .9069 L .47172 .91866 L F
.46855 .90314 m .47172 .91866 L .47079 .92585 L F
.47444 .93168 m .47491 .93283 L .45347 .90286 L F
.45347 .90286 m .47491 .93283 L .4487 .90247 L .239 .058 .423 r
F
.47504 .93316 m .47431 .93135 L .47172 .91866 L .334 .327 .702 r
F
.51359 .90923 m .50297 .95356 L .47529 .93376 L F
.47504 .93316 m .47529 .93376 L .47472 .93336 L F
.51359 .90923 m .47529 .93376 L .47504 .93316 L F
.47491 .93283 m .47444 .93297 L .4487 .90247 L .239 .058 .423 r
F
.47079 .92585 m .47431 .93135 L .47103 .92699 L 0 0 .542 r
F
.47431 .93135 m .47444 .93168 L .47103 .92699 L F
.51359 .90923 m .47623 .93242 L .47172 .91866 L .334 .327 .702 r
F
.47623 .93242 m .47504 .93316 L .47496 .93281 L F
.47623 .93242 m .47496 .93281 L .47172 .91866 L F
.47338 .9068 m .47827 .91718 L .47324 .90679 L F
.4801 .91677 m .47827 .91718 L .47338 .9068 L F
.4427 .87546 m .44339 .88138 L .44343 .87782 L .847 .753 .239 r
F
.4428 .87525 m .44343 .87782 L .44348 .87382 L F
.4427 .87546 m .44343 .87782 L .4428 .87525 L F
.43274 .86395 m .44228 .87316 L .43279 .86404 L 0 .006 .567 r
F
.46846 .89691 m .46858 .89968 L .46635 .89633 L .334 .327 .702 r
F
.44348 .87382 m .44586 .87692 L .44709 .86685 L .847 .753 .239 r
F
.44697 .86678 m .44709 .86685 L .44714 .86642 L F
.44348 .87382 m .44709 .86685 L .44697 .86678 L F
.43075 .86191 m .43081 .86194 L .43107 .86222 L 0 .006 .567 r
F
.43075 .86191 m .43301 .86517 L .43277 .86491 L F
.43181 .86301 m .44058 .87826 L .44012 .87792 L F
.43075 .86191 m .43164 .86276 L .43181 .86301 L F
.39848 .84305 m .43182 .86303 L .43119 .8621 L .933 .558 .257 r
F
.42889 .85894 m .43119 .8621 L .4291 .85905 L F
.39848 .84305 m .43119 .8621 L .42889 .85894 L F
.42212 .8496 m .42905 .85501 L .4306 .8613 L .45 0 0 r
F
.4209 .84792 m .42905 .85501 L .42212 .8496 L F
.4209 .84792 m .42889 .85437 L .42905 .85501 L F
.43219 .85936 m .43241 .86078 L .43258 .86012 L .933 .558 .257 r
F
.43241 .86078 m .43628 .85702 L .43258 .86012 L .989 .892 .598 r
F
.42889 .85437 m .43408 .86342 L .43202 .86248 L .45 0 0 r
F
.42889 .85437 m .43202 .86248 L .43042 .85954 L F
.42889 .85437 m .43119 .8621 L .4306 .8613 L F
.42996 .84509 m .42476 .844 L .43214 .85905 L .761 .416 .4 r
F
.42457 .84474 m .43219 .85936 L .42996 .84509 L .933 .558 .257 r
F
.43864 .86071 m .43741 .8623 L .44565 .86582 L .892 .593 .474 r
F
.45195 .82439 m .43219 .85937 L .46322 .82006 L .761 .416 .4 r
F
.43219 .85937 m .43237 .8597 L .46322 .82006 L F
.43917 .84701 m .42996 .84509 L .43214 .85905 L F
.44348 .87382 m .44714 .86642 L .44719 .86607 L .847 .753 .239 r
F
.4623 .8452 m .44697 .86781 L .44596 .87614 L .999 .845 .541 r
F
.42889 .85437 m .44319 .86593 L .43408 .86342 L .45 0 0 r
F
.44319 .86593 m .44424 .86678 L .44472 .86825 L F
.44424 .86678 m .44585 .86876 L .44472 .86825 L F
.44319 .86593 m .44472 .86825 L .43408 .86342 L F
.46719 .88476 m .45446 .88661 L .4576 .88826 L .614 .953 .914 r
F
.46639 .89644 m .46639 .89644 L .44229 .8732 L 0 .006 .567 r
F
.4652 .89978 m .47324 .90679 L .46506 .90024 L 0 0 .542 r
F
.4652 .89978 m .46506 .90024 L .44324 .88279 L F
.44331 .8807 m .4652 .89978 L .44324 .88279 L F
.47324 .90679 m .47323 .9069 L .44324 .88279 L F
.46858 .89968 m .46635 .89638 L .46635 .89633 L .334 .327 .702 r
F
.44256 .87428 m .46645 .89652 L .46058 .89318 L 0 .006 .567 r
F
.46645 .89652 m .46726 .89728 L .46674 .89696 L F
.46645 .89652 m .46674 .89696 L .46058 .89318 L F
.44229 .8732 m .46726 .89728 L .44256 .87428 L F
.432 .86311 m .46726 .89728 L .43222 .86345 L F
.46635 .89638 m .46634 .89636 L .46635 .89633 L .334 .327 .702 r
F
.46635 .89633 m .46634 .89636 L .46629 .89632 L 0 0 .446 r
F
.46565 .89544 m .46635 .89633 L .46628 .89629 L .041 .256 .754 r
F
.43705 .85963 m .43864 .86071 L .45116 .84455 L .989 .892 .598 r
F
.44921 .87227 m .45206 .86948 L .46245 .85161 L .999 .845 .541 r
F
.4623 .8452 m .44807 .87385 L .44921 .87227 L F
.45654 .85006 m .44708 .86611 L .4623 .8452 L F
.44708 .86611 m .44842 .86567 L .4623 .8452 L F
.44717 .86611 m .44719 .86607 L .4471 .8661 L .847 .753 .239 r
F
.44998 .86024 m .47238 .82223 L .47107 .82339 L .793 .955 .624 r
F
.458 .83882 m .44555 .86605 L .46938 .82788 L .892 .593 .474 r
F
.44985 .8605 m .44975 .86116 L .44998 .86024 L .847 .753 .239 r
F
.44555 .86605 m .44703 .86611 L .46938 .82788 L .892 .593 .474 r
F
.43873 .85783 m .44338 .85286 L .43772 .8583 L .989 .892 .598 r
F
.44435 .8415 m .45903 .87808 L .44163 .86357 L .041 .256 .754 r
F
.43408 .86342 m .44585 .86876 L .43593 .86692 L 0 .006 .567 r
F
.45903 .87808 m .4645 .89171 L .44585 .86876 L .041 .256 .754 r
F
.45903 .87808 m .44585 .86876 L .44456 .86702 L F
.44585 .86876 m .44624 .86928 L .43593 .86692 L 0 .006 .567 r
F
.44319 .86593 m .44318 .86597 L .44424 .86678 L .45 0 0 r
F
.42666 .85257 m .44256 .86546 L .44319 .86593 L F
.44256 .86546 m .44318 .86597 L .44319 .86593 L F
.42666 .85257 m .42486 .85135 L .44243 .86537 L F
.44256 .86546 m .44243 .86537 L .44318 .86597 L F
.42666 .85257 m .44243 .86537 L .44256 .86546 L F
.4394 .86295 m .43891 .8627 L .44318 .86597 L F
.45584 .8175 m .42476 .844 L .43917 .84701 L .761 .416 .4 r
F
.42642 .84486 m .42996 .84509 L .41864 .84284 L .933 .558 .257 r
F
.42996 .84509 m .42068 .84315 L .41864 .84284 L F
.44163 .86357 m .4415 .86468 L .42791 .84275 L .041 .256 .754 r
F
.43593 .86692 m .44624 .86928 L .46639 .89643 L 0 .006 .567 r
F
.44228 .87316 m .44229 .8732 L .43279 .86404 L F
.43182 .86303 m .43182 .86303 L .43182 .86303 L .989 .892 .598 r
F
.43181 .86301 m .44263 .87489 L .43311 .86527 L 0 .006 .567 r
F
.44263 .87489 m .4427 .87546 L .43311 .86527 L F
.43279 .86404 m .44229 .8732 L .44256 .87428 L F
.43181 .86301 m .44256 .87428 L .44263 .87489 L F
.43107 .86222 m .43408 .86342 L .43593 .86692 L F
.43081 .86194 m .43408 .86342 L .43107 .86222 L F
.44012 .87792 m .44331 .8807 L .44324 .88279 L 0 0 .542 r
F
.46058 .89318 m .45535 .89101 L .44012 .87792 L 0 .006 .567 r
F
.43396 .90412 m .42996 .91756 L .4189 .89628 L .603 .144 .136 r
F
.43336 .90381 m .43243 .90757 L .43396 .90412 L .727 .29 .212 r
F
.43699 .88916 m .43336 .90381 L .43396 .90412 L F
.43243 .90757 m .42996 .91756 L .43287 .90781 L F
.43243 .90757 m .43287 .90781 L .43396 .90412 L F
.43937 .87951 m .43371 .9092 L .43243 .90757 L F
.4393 .88256 m .4427 .87546 L .43102 .86607 L .847 .753 .239 r
F
.43209 .86419 m .43334 .86576 L .43375 .86703 L 0 .006 .567 r
F
.4427 .87546 m .43387 .86608 L .43102 .86607 L .847 .753 .239 r
F
.4415 .86468 m .4393 .88256 L .43223 .85784 L .041 .256 .754 r
F
.43891 .8627 m .43888 .86269 L .44318 .86597 L .45 0 0 r
F
.41797 .84585 m .41831 .84662 L .43888 .86269 L F
.41797 .84585 m .43888 .86269 L .4394 .86295 L F
.43387 .86608 m .43278 .86553 L .43102 .86607 L .847 .753 .239 r
F
.43337 .86555 m .43278 .86553 L .43387 .86608 L F
.43277 .86491 m .43334 .86576 L .43209 .86419 L 0 .006 .567 r
F
.43102 .86607 m .43282 .86415 L .43182 .86303 L .989 .892 .598 r
F
.43337 .86555 m .43322 .86539 L .43278 .86553 L .847 .753 .239 r
F
.43277 .86491 m .43301 .86517 L .43334 .86576 L 0 .006 .567 r
F
.43222 .86345 m .43274 .86395 L .43279 .86404 L F
.43102 .86607 m .43322 .86539 L .43282 .86415 L .989 .892 .598 r
F
.39848 .84305 m .43102 .86607 L .43182 .86303 L .933 .558 .257 r
F
.39848 .84305 m .43182 .86303 L .43182 .86303 L F
.43181 .86301 m .432 .86311 L .43222 .86345 L 0 .006 .567 r
F
.43164 .86276 m .432 .86311 L .43181 .86301 L F
.43042 .85954 m .43202 .86248 L .43119 .8621 L .45 0 0 r
F
.39848 .84305 m .42758 .85714 L .42388 .85202 L .933 .558 .257 r
F
.39848 .84305 m .42889 .85894 L .42758 .85714 L F
.41304 .84364 m .43102 .86607 L .39848 .84305 L .661 .246 0 r
F
.41698 .84645 m .43102 .86607 L .41304 .84364 L F
.41698 .84645 m .4393 .88256 L .43102 .86607 L F
.41931 .84663 m .4152 .84364 L .42486 .85135 L .45 0 0 r
F
.41627 .84417 m .41423 .84286 L .4152 .84364 L F
.41627 .84417 m .4152 .84364 L .41931 .84663 L F
.41542 .84349 m .41479 .8431 L .41627 .84417 L F
.41409 .84406 m .41564 .84416 L .41389 .84267 L .933 .558 .257 r
F
.41479 .8431 m .41387 .84253 L .41627 .84417 L .45 0 0 r
F
.41387 .84253 m .41423 .84286 L .41627 .84417 L F
.41564 .84416 m .42642 .84486 L .41404 .84269 L .933 .558 .257 r
F
.41564 .84416 m .41404 .84269 L .41389 .84267 L F
.41387 .84253 m .41005 .84018 L .41423 .84286 L .45 0 0 r
F
.41005 .84018 m .41807 .84671 L .41856 .84682 L F
.41669 .84638 m .4393 .88256 L .41698 .84645 L .661 .246 0 r
F
.43223 .85784 m .4393 .88256 L .41669 .84638 L .041 .256 .754 r
F
.41005 .84018 m .40095 .83456 L .42923 .85579 L .45 0 0 r
F
.40095 .83456 m .42635 .85364 L .42923 .85579 L F
.41423 .84286 m .41005 .84018 L .41831 .84662 L F
.41502 .84372 m .41698 .84645 L .41304 .84364 L .661 .246 0 r
F
.41502 .84372 m .41669 .84638 L .41698 .84645 L F
.41856 .84682 m .42324 .85091 L .42968 .8555 L .45 0 0 r
F
.41807 .84671 m .42324 .85091 L .41856 .84682 L F
.4645 .89171 m .46635 .89633 L .4438 .86644 L .041 .256 .754 r
F
.44424 .86678 m .4438 .86644 L .44163 .86357 L F
.4645 .89171 m .4438 .86644 L .44424 .86678 L F
.44456 .86702 m .44585 .86876 L .44424 .86678 L F
.4438 .86644 m .46399 .89321 L .4415 .86468 L F
.46399 .89321 m .46565 .89544 L .4415 .86468 L F
.44228 .87316 m .4661 .89616 L .44229 .8732 L 0 .006 .567 r
F
.4661 .89616 m .4661 .89616 L .44229 .8732 L F
.4393 .88256 m .44309 .88691 L .44329 .88141 L .847 .753 .239 r
F
.4393 .88256 m .44339 .88138 L .4427 .87546 L F
.44263 .87489 m .45654 .89017 L .4427 .87546 L 0 .006 .567 r
F
.45535 .89101 m .45495 .89084 L .44331 .8807 L F
.45535 .89101 m .44331 .8807 L .44331 .88066 L F
.4427 .87546 m .45654 .89017 L .44326 .88026 L F
.44263 .87489 m .46058 .89318 L .45654 .89017 L F
.44256 .87428 m .46058 .89318 L .44263 .87489 L F
.44324 .88279 m .44779 .88991 L .44408 .88799 L 0 0 .542 r
F
.44324 .88279 m .44408 .88799 L .44341 .88685 L F
.4415 .86468 m .46565 .89544 L .4393 .88256 L .041 .256 .754 r
F
.44424 .86678 m .44777 .86963 L .44585 .86876 L .45 0 0 r
F
.44031 .86381 m .42923 .85579 L .44777 .86963 L F
.42968 .8555 m .42934 .85571 L .44031 .86381 L F
.42934 .85571 m .42923 .85579 L .44031 .86381 L F
.42324 .85091 m .42923 .85579 L .42968 .8555 L F
.4415 .86468 m .43223 .85784 L .42791 .84275 L .041 .256 .754 r
F
.41931 .84663 m .42486 .85135 L .42666 .85257 L .45 0 0 r
F
.41564 .84416 m .42938 .85397 L .42457 .84474 L .933 .558 .257 r
F
.41565 .84418 m .41831 .84662 L .41797 .84585 L .45 0 0 r
F
.42642 .84486 m .41864 .84284 L .41381 .84212 L .933 .558 .257 r
F
.42642 .84486 m .41381 .84212 L .41389 .84267 L F
.45584 .8175 m .42297 .83863 L .42476 .844 L .761 .416 .4 r
F
.42791 .84275 m .43223 .85784 L .41502 .84372 L .041 .256 .754 r
F
.43223 .85784 m .41669 .84638 L .41502 .84372 L F
.44585 .86876 m .44777 .86963 L .44624 .86928 L 0 .006 .567 r
F
.45903 .87808 m .44424 .86678 L .44163 .86357 L .041 .256 .754 r
F
.44424 .86678 m .44318 .86597 L .44777 .86963 L .45 0 0 r
F
.46635 .89633 m .46629 .89632 L .46628 .89629 L 0 0 .446 r
F
.47444 .81969 m .45654 .85006 L .4745 .81998 L .999 .845 .541 r
F
.46884 .83968 m .46936 .83924 L .46985 .83858 L .793 .955 .624 r
F
.47621 .8203 m .46245 .85161 L .48023 .82105 L .999 .845 .541 r
F
.48023 .82105 m .47185 .83553 L .4806 .8213 L F
.47185 .83553 m .47268 .83469 L .4806 .8213 L F
.45648 .86211 m .45593 .86337 L .4806 .8213 L F
.50212 .79944 m .49922 .80298 L .5006 .80152 L .92 .85 .758 r
F
.49922 .80298 m .50443 .80122 L .52524 .77543 L F
.46494 .84253 m .49964 .80284 L .50695 .7928 L .793 .955 .624 r
F
.46786 .83957 m .49964 .80284 L .46494 .84253 L F
.48049 .82988 m .46667 .84929 L .48228 .82943 L 0 0 0 r
F
.46667 .84929 m .46848 .84802 L .48228 .82943 L F
.47963 .8301 m .46515 .85087 L .48049 .82988 L F
.46529 .85231 m .46557 .85217 L .48228 .82943 L F
.46786 .83957 m .48248 .82477 L .49964 .80284 L .793 .955 .624 r
F
.47185 .83553 m .45648 .86211 L .47268 .83469 L .999 .845 .541 r
F
.46494 .84253 m .499 .80221 L .47435 .82075 L .793 .955 .624 r
F
.55008 .8284 m .46719 .88476 L .58272 .84836 L .823 .941 .903 r
F
.48648 .83719 m .46635 .89633 L .44435 .8415 L .402 .463 .809 r
F
.48648 .83719 m .51359 .90923 L .46635 .89633 L F
.46639 .89643 m .44777 .86963 L .46726 .89728 L 0 .006 .567 r
F
.46399 .89321 m .46635 .89633 L .46565 .89544 L .041 .256 .754 r
F
.44624 .86928 m .44777 .86963 L .46639 .89643 L 0 .006 .567 r
F
.47292 .90612 m .47324 .90679 L .45495 .89084 L F
.47292 .90612 m .45495 .89084 L .45535 .89101 L F
.46058 .89318 m .47292 .90612 L .45535 .89101 L F
.46937 .91918 m .46526 .89979 L .46634 .89636 L .334 .327 .702 r
F
.46937 .91918 m .46634 .89636 L .46635 .89638 L F
.46164 .91156 m .47079 .92585 L .45347 .90286 L 0 0 .542 r
F
.47079 .92585 m .47103 .92699 L .45347 .90286 L F
.45824 .92141 m .4478 .9024 L .44923 .90251 L .234 0 .201 r
F
.45727 .91263 m .47444 .93297 L .47019 .93429 L .239 .058 .423 r
F
.47827 .91718 m .47172 .91866 L .47324 .90679 L .334 .327 .702 r
F
.47431 .93135 m .47511 .90842 L .47819 .93742 L 0 0 .542 r
F
.47079 .92585 m .4721 .92056 L .47431 .93135 L F
.4721 .92056 m .47511 .90842 L .47431 .93135 L F
.47323 .9069 m .47511 .90842 L .47079 .92585 L F
.45727 .91263 m .47397 .94061 L .46714 .94577 L .239 .058 .423 r
F
.47172 .91866 m .47463 .93291 L .45836 .92166 L .334 .327 .702 r
F
.47463 .93291 m .47472 .93336 L .47426 .93303 L F
.47463 .93291 m .47426 .93303 L .45836 .92166 L F
.47019 .93429 m .47819 .93742 L .47397 .94061 L .239 .058 .423 r
F
.47444 .93297 m .47819 .93742 L .47019 .93429 L F
.45836 .92166 m .44923 .90251 L .45134 .90269 L .234 0 .201 r
F
.45833 .92156 m .45134 .90269 L .4457 .89475 L F
.45134 .90269 m .4454 .89273 L .4457 .89475 L F
.44516 .89232 m .44502 .89208 L .44649 .89999 L F
.44232 .88749 m .45347 .90286 L .45134 .90269 L .239 .058 .423 r
F
.44232 .88749 m .45134 .90269 L .44243 .88774 L F
.44243 .88743 m .45347 .90286 L .44232 .88749 L F
.44973 .89294 m .45207 .8966 L .4446 .89047 L 0 0 .542 r
F
.45207 .8966 m .46164 .91156 L .44983 .89694 L F
.45207 .8966 m .44983 .89694 L .4446 .89047 L F
.46346 .89486 m .44986 .89341 L .45624 .89118 L 0 0 .446 r
F
.4661 .89616 m .46639 .89644 L .4661 .89616 L 0 .006 .567 r
F
.46628 .89629 m .46061 .8953 L .46346 .89486 L 0 0 .446 r
F
.46061 .8953 m .44986 .89341 L .46346 .89486 L F
.46164 .91156 m .45347 .90286 L .4446 .89047 L 0 0 .542 r
F
.44251 .89277 m .4415 .89038 L .44139 .89002 L .239 .058 .423 r
F
.45836 .92166 m .44295 .89357 L .45824 .92141 L .234 0 .201 r
F
.45836 .92166 m .45833 .92156 L .44649 .89999 L F
.45833 .92156 m .4457 .89475 L .44649 .89999 L F
.46629 .89632 m .45836 .92166 L .44213 .89204 L 0 0 .446 r
F
.46634 .89636 m .45836 .92166 L .46629 .89632 L F
.46565 .89544 m .46628 .89629 L .4393 .88256 L .041 .256 .754 r
F
.44318 .86597 m .43888 .86269 L .44777 .86963 L .45 0 0 r
F
.44163 .86357 m .4438 .86644 L .4415 .86468 L .041 .256 .754 r
F
.44435 .8415 m .44163 .86357 L .42791 .84275 L F
.46858 .89968 m .46937 .91918 L .46635 .89638 L .334 .327 .702 r
F
.46639 .89644 m .46726 .89728 L .46639 .89644 L 0 .006 .567 r
F
.47324 .90679 m .46937 .91918 L .46846 .89691 L .334 .327 .702 r
F
.47172 .91866 m .46937 .91918 L .47324 .90679 L F
.47324 .90679 m .47511 .90842 L .47323 .9069 L 0 0 .542 r
F
.47491 .93283 m .47819 .93742 L .47444 .93297 L .239 .058 .423 r
F
.47504 .93316 m .47472 .93336 L .47431 .93135 L .334 .327 .702 r
F
.47431 .93135 m .47508 .93255 L .47444 .93168 L 0 0 .542 r
F
.47508 .93255 m .47519 .93323 L .47491 .93283 L F
.47508 .93255 m .47491 .93283 L .47444 .93168 L F
.46629 .89632 m .44986 .89341 L .46628 .89629 L 0 0 .446 r
F
.47292 .90612 m .46726 .89728 L .47511 .90842 L 0 .006 .567 r
F
.46674 .89696 m .46726 .89728 L .47292 .90612 L F
.40042 .82874 m .40008 .83368 L .40486 .83318 L .356 0 0 r
F
.40008 .83368 m .40006 .83402 L .40036 .83396 L F
.40008 .83368 m .40036 .83396 L .40486 .83318 L F
.40627 .83459 m .427 .82784 L .40351 .8305 L .902 .603 .47 r
F
.37407 .79944 m .41138 .78797 L .37396 .79895 L .502 .096 .203 r
F
.36 .78342 m .41502 .84372 L .40969 .84351 L .036 .354 .828 r
F
.36 .78342 m .40969 .84351 L .37754 .8106 L F
.40095 .83456 m .40006 .83402 L .42635 .85364 L .45 0 0 r
F
.40036 .83396 m .40006 .83402 L .40095 .83456 L .356 0 0 r
F
.47375 .8196 m .47419 .81966 L .4754 .81758 L .892 .593 .474 r
F
.47405 .81773 m .47405 .81776 L .4754 .81758 L F
.47124 .82309 m .47383 .81916 L .47384 .81909 L .92 .842 .75 r
F
.47124 .82309 m .47384 .81909 L .47405 .81773 L F
.4672 .81869 m .47375 .8196 L .47376 .81959 L .892 .593 .474 r
F
.47405 .81776 m .47376 .81959 L .4754 .81758 L F
.4672 .81869 m .47376 .81959 L .47405 .81776 L F
.47405 .81773 m .51438 .75659 L .47788 .81044 L .92 .842 .75 r
F
.47384 .81909 m .51438 .75659 L .47405 .81773 L F
.47384 .81909 m .51665 .75399 L .50066 .77774 L F
.47383 .81916 m .51665 .75399 L .47384 .81909 L F
.4673 .81849 m .4672 .81869 L .47405 .81776 L .892 .593 .474 r
F
.4673 .81849 m .47405 .81776 L .47405 .81773 L F
.4672 .81869 m .458 .83882 L .47375 .8196 L F
.47375 .8196 m .54119 .72592 L .54121 .72585 L .92 .842 .75 r
F
.47124 .82309 m .47376 .8196 L .47375 .8196 L F
.47376 .8196 m .54119 .72592 L .47375 .8196 L F
.47376 .8196 m .49024 .80604 L .54119 .72592 L F
.4736 .81982 m .47385 .81961 L .47376 .8196 L F
.47385 .81961 m .49024 .80604 L .47376 .8196 L F
.47107 .82339 m .47238 .82223 L .47124 .82309 L .793 .955 .624 r
F
.458 .83882 m .46938 .82788 L .47419 .81966 L .892 .593 .474 r
F
.458 .83882 m .47419 .81966 L .47375 .8196 L F
.47495 .81976 m .49024 .80604 L .47385 .81961 L .92 .842 .75 r
F
.4433 .88729 m .44348 .88698 L .44341 .88685 L 0 0 0 r
F
.47383 .81916 m .54121 .72585 L .51665 .75399 L .92 .842 .75 r
F
.47375 .8196 m .54121 .72585 L .47383 .81916 L F
.47201 .81796 m .47405 .81773 L .47525 .81545 L .953 .819 .675 r
F
.40119 .82794 m .41225 .82803 L .43259 .80992 L .846 .586 .546 r
F
.40307 .82986 m .41225 .82803 L .40119 .82794 L F
.44682 .80356 m .43811 .8079 L .42524 .831 L .61 .236 .308 r
F
.42557 .8283 m .42619 .82929 L .427 .82784 L .902 .603 .47 r
F
.46347 .79098 m .42498 .83304 L .46036 .80328 L .61 .236 .308 r
F
.42498 .83304 m .42472 .83517 L .46036 .80328 L F
.46347 .79098 m .46036 .80328 L .46745 .79695 L F
.45833 .80691 m .48163 .77293 L .46422 .79085 L .875 .71 .674 r
F
.45878 .80625 m .43462 .82631 L .45584 .8175 L .761 .416 .4 r
F
.45931 .80422 m .45611 .80709 L .45878 .80625 L F
.45611 .80709 m .43462 .82631 L .45878 .80625 L F
.49141 .75877 m .46839 .79996 L .47677 .79588 L .692 .491 .61 r
F
.46043 .80385 m .47602 .79625 L .49104 .75921 L .875 .71 .674 r
F
.45651 .82264 m .48244 .79313 L .46405 .80824 L .953 .819 .675 r
F
.46923 .81776 m .47525 .81545 L .47788 .81044 L F
.44335 .8854 m .44333 .88705 L .4434 .88675 L .847 .753 .239 r
F
.44333 .88705 m .44333 .88718 L .44344 .88673 L F
.44779 .88991 m .44307 .88773 L .4421 .88697 L 0 0 .542 r
F
.44327 .8883 m .4434 .88788 L .44393 .88884 L 0 0 0 r
F
.4434 .88788 m .44392 .88812 L .44393 .88884 L F
.44213 .89204 m .44327 .8883 L .44393 .88884 L F
.44213 .89204 m .44425 .88827 L .4433 .88729 L F
.44425 .88827 m .44353 .88706 L .4433 .88729 L F
.44213 .89204 m .44229 .88751 L .4423 .88751 L F
.44275 .88828 m .44256 .88797 L .44213 .89204 L .234 0 .201 r
F
.44213 .89204 m .4423 .88751 L .44327 .8883 L 0 0 0 r
F
.4421 .88697 m .44243 .88743 L .44232 .88749 L .239 .058 .423 r
F
.4421 .88697 m .44231 .88755 L .44208 .88705 L F
.441 .88534 m .44034 .88685 L .44008 .88684 L 0 0 0 r
F
.4421 .88697 m .44137 .88996 L .44034 .88685 L .239 .058 .423 r
F
.4393 .88256 m .44213 .89204 L .44333 .88718 L .847 .753 .239 r
F
.45624 .89118 m .44213 .89204 L .4393 .88256 L 0 0 .446 r
F
.44986 .89341 m .44213 .89204 L .45624 .89118 L F
.47292 .90612 m .47511 .90842 L .47324 .90679 L 0 .006 .567 r
F
.46937 .91918 m .45836 .92166 L .46526 .89979 L .334 .327 .702 r
F
.47508 .93255 m .47819 .93742 L .47519 .93323 L 0 0 .542 r
F
.45778 .93003 m .45369 .9207 L .45778 .92999 L .239 .058 .423 r
F
.46152 .9303 m .44412 .92314 L .44377 .92034 L .417 .229 .516 r
F
.46046 .93007 m .4626 .93053 L .46714 .94577 L .239 .058 .423 r
F
.46101 .93187 m .44412 .92314 L .46152 .9303 L .417 .229 .516 r
F
.47426 .93303 m .45791 .92827 L .45838 .92168 L F
.46152 .9303 m .45791 .92827 L .47426 .93303 L F
.50106 .82357 m .51089 .81888 L .49572 .82522 L .88 .959 .848 r
F
.50106 .82357 m .49572 .82522 L .49472 .82605 L F
.50062 .81265 m .56757 .76059 L .5658 .76078 L F
.48286 .82678 m .49862 .81447 L .50062 .81265 L F
.49862 .81447 m .56757 .76059 L .50062 .81265 L F
.48247 .82938 m .57364 .75585 L .48286 .82678 L F
.56873 .7595 m .59308 .75789 L .61365 .73979 L .857 .826 .816 r
F
.56582 .76078 m .56779 .76057 L .56873 .7595 L F
.56779 .76057 m .59308 .75789 L .56873 .7595 L F
.54067 .78949 m .54191 .78827 L .55725 .7726 L .88 .959 .848 r
F
.54067 .78949 m .55725 .7726 L .55742 .7724 L F
.58444 .73387 m .57754 .74348 L .58534 .73405 L .857 .826 .816 r
F
.57754 .74348 m .57899 .74173 L .57991 .73928 L .814 .762 .804 r
F
.58444 .73387 m .58033 .73853 L .58021 .73876 L .857 .826 .816 r
F
.5147 .81513 m .51089 .81888 L .51158 .81876 L F
.51108 .81869 m .54067 .78949 L .55742 .7724 L .88 .959 .848 r
F
.51108 .81869 m .55742 .7724 L .5593 .77026 L F
.58534 .73405 m .56582 .76078 L .56873 .7595 L .857 .826 .816 r
F
.59018 .73503 m .56873 .7595 L .61365 .73979 L F
.58534 .73405 m .56873 .7595 L .59018 .73503 L F
.56779 .76057 m .52273 .81979 L .59308 .75789 L F
.55688 .77301 m .52273 .81979 L .56779 .76057 L F
.58444 .73387 m .54555 .77404 L .55431 .76812 L F
.44359 .91908 m .44233 .89243 L .44295 .89357 L .234 0 .201 r
F
.45836 .92166 m .44359 .91908 L .44295 .89357 L F
.44034 .88685 m .44137 .88996 L .44008 .88684 L .239 .058 .423 r
F
.44201 .90412 m .44184 .89935 L .44154 .89996 L .602 .166 .184 r
F
.44154 .89996 m .44184 .89935 L .44172 .89631 L F
.44359 .91908 m .44154 .89996 L .44172 .89631 L .234 0 .201 r
F
.44008 .88684 m .44153 .89094 L .44172 .89631 L .571 .188 .277 r
F
.44008 .88684 m .44172 .89631 L .44138 .8985 L F
.44359 .91908 m .44061 .91856 L .44154 .89996 L .234 0 .201 r
F
.44139 .89002 m .4415 .89038 L .44008 .88684 L .239 .058 .423 r
F
.45791 .92827 m .44377 .92034 L .45838 .92168 L .417 .229 .516 r
F
.44377 .92034 m .44061 .91856 L .44359 .91908 L F
.44377 .92034 m .44359 .91908 L .45838 .92168 L F
.45838 .92168 m .44359 .91908 L .45836 .92166 L F
.44359 .91908 m .44061 .91856 L .44359 .91908 L F
.44359 .91908 m .44359 .91908 L .45836 .92166 L F
.44008 .88684 m .44021 .88717 L .44022 .88723 L .571 .188 .277 r
F
.45994 .93523 m .46455 .94773 L .461 .93889 L .239 .058 .423 r
F
.44377 .92034 m .44412 .92314 L .44061 .91856 L .417 .229 .516 r
F
.43243 .90757 m .43371 .9092 L .42996 .91756 L .727 .29 .212 r
F
.44061 .91856 m .43647 .91273 L .43647 .91272 L .602 .166 .184 r
F
.4189 .89628 m .42996 .91756 L .4171 .8981 L .603 .144 .136 r
F
.41762 .89771 m .4171 .8981 L .4169 .89805 L .105 0 0 r
F
.4831 .82511 m .47963 .8301 L .48251 .82911 L 0 0 0 r
F
.47963 .8301 m .48228 .82943 L .48251 .82911 L F
.48328 .8239 m .53053 .777 L .49182 .81291 L .88 .959 .848 r
F
.48286 .82678 m .53053 .777 L .48328 .8239 L F
.48248 .82477 m .48328 .8239 L .49964 .80284 L .793 .955 .624 r
F
.54121 .72585 m .54109 .72594 L .51665 .75399 L .92 .842 .75 r
F
.50066 .77774 m .51665 .75399 L .51438 .75659 L F
.5175 .74941 m .51033 .76337 L .53307 .73514 L .896 .772 .717 r
F
.53307 .73514 m .53878 .7286 L .51763 .7487 L .812 .687 .726 r
F
.53307 .73514 m .51763 .7487 L .5175 .74941 L F
.51835 .74481 m .48814 .79634 L .5175 .74941 L .896 .772 .717 r
F
.48814 .79634 m .49466 .78665 L .5175 .74941 L F
.5175 .74941 m .49466 .78665 L .51033 .76337 L F
.51763 .7487 m .53878 .7286 L .51835 .74481 L .812 .687 .726 r
F
.499 .80221 m .51046 .78864 L .49122 .80561 L .793 .955 .624 r
F
.50475 .79368 m .50783 .79245 L .52741 .76848 L .92 .85 .758 r
F
.53589 .74128 m .49177 .80513 L .50475 .79368 L F
.53984 .72889 m .53977 .729 L .53984 .72894 L .896 .772 .717 r
F
.53865 .73573 m .53521 .75919 L .53887 .73528 L .814 .762 .804 r
F
.52741 .76848 m .50212 .79944 L .52524 .77543 L .92 .85 .758 r
F
.50212 .79944 m .5006 .80152 L .52524 .77543 L F
.53589 .74128 m .51554 .77551 L .52741 .76848 L F
.49182 .81291 m .50443 .80122 L .49964 .80284 L .88 .959 .848 r
F
.53073 .77631 m .52982 .77766 L .58092 .73751 L .897 .854 .792 r
F
.52982 .77766 m .54555 .77404 L .58092 .73751 L F
.53073 .77631 m .52676 .7805 L .52982 .77766 L F
.52741 .76848 m .52524 .77543 L .53401 .76457 L .92 .85 .758 r
F
.48913 .78728 m .48064 .80638 L .49575 .78335 L .808 .634 .665 r
F
.48064 .80638 m .48814 .79634 L .49575 .78335 L F
.50673 .74774 m .48054 .79354 L .48913 .78728 L F
.48341 .79203 m .48483 .79042 L .47969 .79416 L .953 .819 .675 r
F
.40169 .82766 m .41102 .8223 L .39982 .82598 L .846 .586 .546 r
F
.40053 .827 m .39982 .82598 L .39913 .82621 L F
.40169 .82766 m .39982 .82598 L .40053 .827 L F
.41102 .8223 m .40571 .82279 L .39913 .82621 L F
.39913 .82621 m .40571 .82279 L .39915 .82548 L F
.40571 .82279 m .4042 .82292 L .39915 .82548 L F
.40419 .82292 m .40407 .82294 L .39915 .82548 L F
.4042 .82292 m .39915 .82548 L .39915 .82548 L F
.40419 .82292 m .39915 .82548 L .4042 .82292 L F
.42266 .79321 m .42266 .79322 L .40292 .82304 L .363 0 .14 r
F
.42266 .79321 m .40292 .82304 L .40292 .82304 L F
.45543 .78749 m .40946 .82026 L .4622 .784 L .61 .236 .308 r
F
.40946 .82026 m .41026 .8199 L .4622 .784 L F
.39915 .82548 m .39915 .82548 L .39901 .82555 L .846 .586 .546 r
F
.39657 .82283 m .39913 .8262 L .39916 .82532 L .149 0 0 r
F
.35252 .81295 m .34859 .81207 L .3532 .81336 L F
.37267 .82082 m .39848 .84305 L .39282 .83898 L 0 .082 .565 r
F
.37446 .82214 m .39848 .84305 L .37267 .82082 L F
.36601 .81452 m .39848 .84305 L .36506 .81395 L F
.35027 .80049 m .39848 .84305 L .35312 .80319 L F
.3703 .81906 m .34859 .81207 L .37752 .8244 L .356 0 0 r
F
.36506 .81395 m .37267 .82082 L .3532 .81336 L 0 .082 .565 r
F
.36506 .81395 m .3532 .81336 L .35107 .81208 L F
.36506 .81395 m .37446 .82214 L .37267 .82082 L F
.35312 .80319 m .36601 .81452 L .36506 .81395 L F
.35042 .81135 m .34676 .8117 L .34959 .81167 L .149 0 0 r
F
.32123 .8063 m .32163 .80656 L .34475 .80834 L .181 .715 .778 r
F
.33301 .80241 m .35274 .81164 L .3313 .8047 L .718 .185 0 r
F
.3341 .80752 m .32163 .80656 L .34425 .80892 L .149 0 0 r
F
.32163 .80656 m .32164 .80669 L .34425 .80892 L F
.35274 .81164 m .35038 .81134 L .3313 .8047 L .718 .185 0 r
F
.35038 .81134 m .34572 .81075 L .3313 .8047 L F
.33854 .80579 m .34819 .81169 L .34263 .80691 L F
.34819 .81169 m .35008 .81167 L .34263 .80691 L F
.35623 .81209 m .35042 .81135 L .34859 .81207 L .149 0 0 r
F
.34263 .80691 m .35008 .81167 L .35274 .81164 L .718 .185 0 r
F
.33301 .80241 m .33854 .80579 L .34263 .80691 L F
.36506 .81395 m .34819 .81169 L .33301 .80241 L 0 .082 .565 r
F
.34959 .81167 m .34676 .8117 L .34859 .81207 L .149 0 0 r
F
.34311 .79417 m .35027 .80049 L .35312 .80319 L 0 .082 .565 r
F
.33321 .80915 m .33316 .80928 L .33446 .80931 L .149 0 0 r
F
.33321 .80915 m .33446 .80931 L .33485 .80933 L F
.33304 .809 m .33574 .80957 L .33433 .80907 L .764 .294 .128 r
F
.34191 .80953 m .33326 .80901 L .33485 .80933 L .149 0 0 r
F
.32019 .80564 m .32101 .80617 L .33114 .80631 L .181 .715 .778 r
F
.3313 .8047 m .34572 .81075 L .32877 .80809 L .718 .185 0 r
F
.33149 .8089 m .33316 .80928 L .33326 .80901 L .149 0 0 r
F
.32164 .80669 m .33149 .8089 L .33326 .80901 L F
.33062 .80871 m .32927 .80857 L .33316 .80928 L F
.32877 .80809 m .33433 .80907 L .32883 .80853 L .764 .294 .128 r
F
.32877 .80809 m .33098 .80887 L .33304 .809 L F
.32877 .80809 m .33304 .809 L .33433 .80907 L F
.33485 .80933 m .33316 .80928 L .34859 .81207 L .149 0 0 r
F
.34572 .81075 m .33098 .80887 L .32877 .80809 L .718 .185 0 r
F
.39339 .81976 m .39657 .82283 L .39926 .82343 L .149 0 0 r
F
.39968 .82075 m .39816 .82076 L .39924 .82338 L .363 0 .14 r
F
.396 .82228 m .40054 .82326 L .396 .82228 L .764 .294 .128 r
F
.39304 .81943 m .40049 .82074 L .39564 .8201 L F
.39304 .81943 m .40054 .82326 L .40049 .82074 L F
.396 .82228 m .40054 .82326 L .39304 .81943 L F
.39603 .82231 m .39916 .82532 L .40054 .82326 L F
.39916 .82532 m .40407 .82294 L .3996 .82467 L .846 .586 .546 r
F
.39915 .82548 m .40407 .82294 L .39916 .82532 L F
.26001 .75739 m .32877 .80809 L .32883 .80853 L 0 .243 .707 r
F
.26001 .75739 m .32883 .80853 L .3236 .80703 L F
.26001 .75739 m .3236 .80703 L .25718 .76715 L F
.25718 .76715 m .26459 .77171 L .27024 .77499 L .434 0 0 r
F
.3236 .80703 m .32164 .80676 L .25718 .76715 L 0 .243 .707 r
F
.39603 .82231 m .40054 .82326 L .396 .82228 L .764 .294 .128 r
F
.40332 .823 m .40278 .82305 L .3996 .82467 L .846 .586 .546 r
F
.42417 .79093 m .40438 .80518 L .40081 .82323 L .363 0 .14 r
F
.40438 .80518 m .40136 .81595 L .40081 .82323 L F
.42417 .79093 m .40081 .82323 L .40261 .82307 L F
.40407 .82294 m .40332 .823 L .3996 .82467 L .846 .586 .546 r
F
.3996 .82467 m .40278 .82305 L .40054 .82326 L F
.40295 .82304 m .42266 .79321 L .40292 .82304 L .363 0 .14 r
F
.47021 .74657 m .4646 .77994 L .46461 .78094 L .275 .088 .437 r
F
.44198 .78884 m .45543 .78749 L .46697 .77188 L .789 .547 .571 r
F
.44198 .78884 m .46697 .77188 L .46718 .76854 L F
.46669 .77632 m .46461 .78094 L .46653 .77872 L .543 .335 .549 r
F
.46686 .77203 m .46634 .7818 L .46697 .77188 L .789 .547 .571 r
F
.46461 .78094 m .45543 .78749 L .4622 .784 L .61 .236 .308 r
F
.45543 .78749 m .46529 .78234 L .46686 .77203 L .789 .547 .571 r
F
.46529 .78234 m .46634 .7818 L .46686 .77203 L F
.47692 .74069 m .47079 .74606 L .46639 .77513 L .275 .088 .437 r
F
.47443 .7591 m .46669 .77632 L .47125 .77328 L .543 .335 .549 r
F
.46669 .77632 m .46653 .77872 L .47125 .77328 L F
.4789 .73914 m .48305 .72234 L .48201 .72528 L .701 .531 .655 r
F
.48305 .72234 m .48395 .71871 L .48373 .71945 L F
.48305 .72234 m .48373 .71945 L .48201 .72528 L F
.47858 .73672 m .47975 .73217 L .47882 .73258 L .598 .448 .65 r
F
.48476 .71505 m .46639 .77513 L .47443 .7591 L .275 .088 .437 r
F
.46639 .77513 m .46669 .77632 L .47443 .7591 L F
.47125 .77328 m .46653 .77872 L .46607 .78591 L .543 .335 .549 r
F
.45543 .78749 m .4663 .78189 L .46634 .7818 L .789 .547 .571 r
F
.46381 .78966 m .47089 .78082 L .48458 .74853 L .789 .613 .662 r
F
.47354 .7686 m .48458 .74853 L .50421 .70224 L F
.46381 .78966 m .48458 .74853 L .47354 .7686 L F
.50918 .72214 m .50955 .72154 L .50925 .72155 L .719 .599 .722 r
F
.50182 .70573 m .50669 .69424 L .49993 .70516 L .701 .531 .655 r
F
.50907 .7128 m .47911 .77328 L .48296 .76873 L .692 .491 .61 r
F
.50907 .71248 m .47911 .77328 L .50907 .7128 L F
.49104 .75921 m .49197 .75785 L .48662 .76427 L .875 .71 .674 r
F
.49197 .75785 m .50779 .73478 L .48662 .76427 L F
.50911 .7139 m .48296 .76873 L .49141 .75877 L .692 .491 .61 r
F
.50907 .7128 m .48296 .76873 L .50911 .7139 L F
.50911 .7139 m .47677 .79588 L .50932 .73705 L F
.50918 .72214 m .50925 .72155 L .50912 .71526 L .719 .599 .722 r
F
.50199 .70579 m .50768 .69443 L .50182 .70573 L .701 .531 .655 r
F
.50768 .69443 m .50766 .69439 L .50182 .70573 L F
.50808 .69451 m .5078 .69474 L .50826 .69586 L .47 .41 .709 r
F
.50802 .69403 m .50798 .69408 L .50808 .69451 L F
.50421 .70224 m .50518 .71109 L .50839 .69579 L .789 .613 .662 r
F
.50421 .70224 m .50839 .69579 L .50798 .69408 L F
.50182 .70573 m .50766 .69439 L .50669 .69424 L .701 .531 .655 r
F
.50766 .69439 m .50731 .69351 L .50669 .69424 L F
.47354 .7686 m .50798 .69408 L .48789 .73692 L .789 .613 .662 r
F
.50798 .69408 m .50794 .69413 L .48789 .73692 L F
.50518 .71109 m .5089 .70432 L .5091 .69879 L F
.50518 .71109 m .5091 .69879 L .50839 .69579 L F
.50896 .70279 m .51041 .69207 L .5091 .69879 L .719 .599 .722 r
F
.5089 .70432 m .51475 .66072 L .50896 .70279 L F
.49777 .70866 m .47443 .7591 L .47125 .77328 L .543 .335 .549 r
F
.46381 .78966 m .47354 .7686 L .46455 .78673 L .789 .613 .662 r
F
.47354 .7686 m .48789 .73692 L .46455 .78673 L F
.47302 .78046 m .47073 .78247 L .46422 .79085 L .875 .71 .674 r
F
.46422 .79085 m .47073 .78247 L .4645 .79009 L F
.47073 .78247 m .46988 .78321 L .4645 .79009 L F
.48789 .73692 m .49965 .71181 L .49157 .72879 L .789 .613 .662 r
F
.48789 .73692 m .49157 .72879 L .4866 .73923 L F
.49777 .70866 m .47664 .76015 L .4989 .70682 L .543 .335 .549 r
F
.47664 .76015 m .47764 .75805 L .4989 .70682 L F
.4989 .70682 m .47764 .75805 L .48584 .74082 L F
.46455 .78673 m .48789 .73692 L .4866 .73923 L .789 .613 .662 r
F
.46455 .78673 m .4866 .73923 L .46634 .7818 L F
.49539 .7125 m .50669 .69424 L .48305 .72234 L .701 .531 .655 r
F
.49539 .7125 m .47443 .7591 L .49777 .70866 L .543 .335 .549 r
F
.48305 .72234 m .47443 .7591 L .49539 .7125 L .275 .088 .437 r
F
.48373 .71945 m .48395 .71871 L .48457 .71586 L .701 .531 .655 r
F
.48476 .71505 m .47923 .72247 L .478 .73717 L .275 .088 .437 r
F
.48765 .70205 m .47923 .72247 L .48476 .71505 L F
.48008 .70951 m .48147 .7124 L .48669 .6998 L 0 0 .088 r
F
.48008 .70951 m .48669 .6998 L .4851 .69925 L F
.4734 .72316 m .47974 .71471 L .48008 .70951 L F
.47974 .71471 m .48147 .7124 L .48008 .70951 L F
.44524 .76073 m .46434 .73478 L .44625 .75902 L .647 .417 .556 r
F
.46434 .73478 m .45967 .74092 L .44625 .75902 L F
.47923 .72247 m .47072 .7452 L .478 .73717 L .275 .088 .437 r
F
.47158 .70796 m .4781 .69015 L .47803 .6891 L .981 .833 .437 r
F
.47938 .69725 m .47808 .70234 L .47801 .70318 L 0 0 .088 r
F
.44625 .75902 m .45967 .74092 L .44612 .75885 L .527 .3 .513 r
F
.45967 .74092 m .45944 .74103 L .44612 .75885 L F
.44115 .75245 m .41898 .78094 L .41202 .78738 L .846 .987 .712 r
F
.42014 .77764 m .43203 .77185 L .44625 .75902 L F
.42014 .77764 m .44625 .75902 L .44518 .75764 L F
.45676 .74536 m .46817 .74084 L .46939 .73806 L .647 .417 .556 r
F
.45676 .74536 m .46939 .73806 L .47201 .72446 L F
.47801 .70318 m .47157 .72487 L .4734 .72316 L 0 0 .088 r
F
.46778 .73025 m .47201 .72446 L .46828 .72946 L .647 .417 .556 r
F
.47201 .72446 m .4719 .72456 L .46828 .72946 L F
.44455 .76189 m .43371 .77227 L .44439 .76215 L 0 0 0 r
F
.44389 .76299 m .46778 .73025 L .44497 .76118 L .647 .417 .556 r
F
.46778 .73025 m .46828 .72946 L .44497 .76118 L F
.47856 .69704 m .47157 .72487 L .47801 .70318 L 0 0 .088 r
F
.47677 .79588 m .47944 .79433 L .51046 .73579 L .692 .491 .61 r
F
.47677 .79588 m .51046 .73579 L .51087 .73425 L F
.51378 .72337 m .51386 .72309 L .51384 .72311 L .812 .687 .726 r
F
.50673 .74774 m .5024 .75746 L .50471 .75472 L .808 .634 .665 r
F
.53878 .7286 m .54142 .72557 L .50437 .7559 L .812 .687 .726 r
F
.5024 .75746 m .48913 .78728 L .51541 .74714 L .808 .634 .665 r
F
.47677 .79588 m .47602 .79625 L .4758 .79645 L .953 .819 .675 r
F
.48163 .77293 m .47302 .78046 L .46422 .79085 L .875 .71 .674 r
F
.43462 .82631 m .44469 .82467 L .45584 .8175 L .761 .416 .4 r
F
.4622 .784 m .41026 .8199 L .44682 .80356 L .61 .236 .308 r
F
.41046 .81659 m .4042 .82292 L .44244 .78879 L .363 0 .14 r
F
.4042 .82292 m .4052 .82242 L .44244 .78879 L F
.41046 .81659 m .44244 .78879 L .44198 .78884 L F
.48244 .79313 m .48341 .79203 L .48158 .79355 L .953 .819 .675 r
F
.46447 .78664 m .46455 .78673 L .46461 .78656 L .789 .547 .571 r
F
.45486 .77164 m .41046 .81659 L .45824 .77453 L .363 0 .14 r
F
.46741 .76835 m .46651 .76856 L .45824 .77453 L .789 .547 .571 r
F
.46741 .76835 m .45824 .77453 L .45599 .77651 L F
.44198 .78884 m .46741 .76835 L .45599 .77651 L F
.47072 .7452 m .47021 .74657 L .47692 .74069 L .275 .088 .437 r
F
.46785 .74814 m .46997 .74588 L .46767 .748 L .726 .492 .572 r
F
.46889 .7427 m .46767 .748 L .46997 .74588 L 0 0 .088 r
F
.46785 .74814 m .46751 .74786 L .45268 .76277 L .726 .492 .572 r
F
.47102 .71276 m .46965 .72456 L .47669 .70448 L .981 .833 .437 r
F
.46965 .72456 m .47157 .72487 L .47669 .70448 L F
.44439 .76215 m .43371 .77227 L .44389 .76299 L 0 0 0 r
F
.44711 .7453 m .43674 .76438 L .44145 .76062 L .846 .987 .712 r
F
.4734 .72316 m .46889 .7427 L .48147 .7124 L 0 0 .088 r
F
.44497 .76118 m .44844 .75646 L .44524 .76073 L .647 .417 .556 r
F
.44455 .76189 m .4379 .76655 L .43371 .77227 L 0 0 0 r
F
.44625 .75902 m .4379 .76655 L .44455 .76189 L F
.448 .75924 m .43371 .77227 L .43065 .77646 L F
.44712 .75857 m .46117 .74881 L .45676 .74536 L .647 .417 .556 r
F
.42266 .79321 m .42417 .79093 L .42266 .79322 L .363 0 .14 r
F
.42402 .78304 m .41661 .78657 L .4095 .79533 L 0 0 0 r
F
.43065 .77646 m .41666 .78613 L .42402 .78304 L F
.41666 .78613 m .41605 .78684 L .42402 .78304 L F
.47701 .67398 m .47803 .6891 L .48079 .68103 L .981 .833 .437 r
F
.47158 .70796 m .47102 .71276 L .47378 .70394 L F
.47422 .65469 m .47057 .62578 L .47167 .64345 L .07 .081 .562 r
F
.47057 .62578 m .47009 .62667 L .47183 .64603 L F
.47151 .64276 m .47161 .6454 L .47199 .64485 L .958 .74 .565 r
F
.43554 .57195 m .43361 .57007 L .43556 .57196 L 0 .222 .744 r
F
.44394 .58017 m .43403 .57052 L .44462 .58105 L F
.43403 .57052 m .43581 .57242 L .44462 .58105 L F
.43022 .56646 m .43733 .57403 L .43684 .57365 L .83 .438 .308 r
F
.44079 .57736 m .43581 .57242 L .43733 .57403 L 0 .222 .744 r
F
.43947 .57599 m .43581 .57242 L .44079 .57736 L F
.43733 .57403 m .4375 .57421 L .43684 .57365 L .83 .438 .308 r
F
.43022 .56646 m .44751 .58525 L .44565 .58237 L F
.44462 .58105 m .43947 .57599 L .44079 .57736 L 0 .222 .744 r
F
.47161 .6454 m .47336 .69232 L .47584 .67123 L .958 .74 .565 r
F
.3936 .79378 m .4111 .78823 L .39354 .79356 L .502 .096 .203 r
F
.42014 .77764 m .41202 .78738 L .43203 .77185 L .846 .987 .712 r
F
.44711 .7453 m .42014 .77764 L .43674 .76438 L F
.39722 .78631 m .38587 .78952 L .38804 .7905 L .571 .935 .92 r
F
.33221 .53369 m .33779 .53429 L .34254 .53503 L .269 0 0 r
F
.33221 .53369 m .35144 .5364 L .33469 .53199 L F
.37727 .54037 m .34601 .53879 L .39083 .54246 L .264 .671 .967 r
F
.34349 .54272 m .34336 .54263 L .34293 .54265 L .317 .806 .849 r
F
.32526 .54356 m .34336 .54263 L .35272 .54246 L .024 0 0 r
F
.34336 .54263 m .33725 .53835 L .33915 .5427 L .264 .671 .967 r
F
.32526 .54356 m .35272 .54246 L .33221 .53369 L .024 0 0 r
F
.40124 .54408 m .35702 .54305 L .39923 .54479 L .164 .683 .886 r
F
.36504 .54273 m .36747 .54308 L .39406 .54314 L .264 .671 .967 r
F
.36504 .54273 m .39406 .54314 L .39122 .54302 L F
.39923 .54479 m .38657 .54819 L .3894 .54786 L .164 .683 .886 r
F
.38657 .54819 m .3962 .54759 L .39736 .54702 L F
.3962 .54759 m .39761 .54751 L .39736 .54702 L F
.38657 .54819 m .37768 .55058 L .39761 .54751 L F
.39471 .54839 m .38824 .5494 L .39183 .54891 L .124 .673 .727 r
F
.38824 .5494 m .38659 .54965 L .39232 .54887 L F
.36504 .54273 m .34383 .54296 L .36747 .54308 L .264 .671 .967 r
F
.34383 .54296 m .3459 .54302 L .36747 .54308 L F
.35702 .54305 m .3459 .54302 L .36275 .54514 L .164 .683 .886 r
F
.3229 .55573 m .36599 .54555 L .32526 .54356 L .317 .806 .849 r
F
.20267 .72012 m .21436 .73354 L .21785 .73733 L .585 .101 0 r
F
.21436 .73354 m .26156 .78774 L .21785 .73733 L F
.3229 .55573 m .36474 .54764 L .36599 .54555 L .317 .806 .849 r
F
.32548 .56989 m .37323 .54896 L .3229 .55573 L .615 .938 .956 r
F
.37323 .54896 m .36474 .54764 L .3229 .55573 L F
.37039 .5502 m .3759 .54993 L .37323 .54896 L F
.37768 .55058 m .37592 .55105 L .37859 .55063 L .164 .683 .886 r
F
.36565 .55228 m .37859 .55063 L .37039 .5502 L .615 .938 .956 r
F
.32548 .56989 m .38979 .55037 L .38907 .54929 L F
.38685 .54962 m .38659 .54965 L .38677 .54963 L .124 .673 .727 r
F
.32548 .56989 m .38907 .54929 L .36565 .55228 L .615 .938 .956 r
F
.50722 .52231 m .50772 .51778 L .50863 .52153 L .543 .31 .512 r
F
.51059 .52157 m .51098 .52036 L .51142 .52213 L .21 0 .352 r
F
.51098 .52036 m .51108 .52021 L .51142 .52213 L F
.53419 .5123 m .5428 .51206 L .53666 .51403 L .285 .208 .591 r
F
.54658 .51196 m .52778 .50586 L .54675 .4919 L .474 .357 .64 r
F
.52962 .51243 m .52778 .50586 L .54658 .51196 L F
.5082 .51974 m .50772 .51778 L .52694 .51598 L .494 .321 .575 r
F
.51184 .51901 m .53666 .51403 L .51142 .52213 L .285 .208 .591 r
F
.51611 .48954 m .51973 .48342 L .51809 .48811 L 0 0 0 r
F
.51595 .48853 m .51768 .48993 L .5146 .49852 L .285 .208 .591 r
F
.50723 .49893 m .51595 .48853 L .51239 .51497 L .21 0 .352 r
F
.50772 .51778 m .52114 .48088 L .52778 .50586 L 0 0 0 r
F
.53041 .46983 m .53298 .46576 L .52801 .49832 L .285 .208 .591 r
F
.52114 .48088 m .52888 .48806 L .52778 .50586 L 0 0 0 r
F
.52778 .50586 m .52888 .48806 L .53059 .46953 L 0 0 .006 r
F
.52888 .48806 m .53047 .46912 L .53059 .46953 L F
.53011 .46795 m .53098 .45384 L .53059 .46953 L F
.53557 .43101 m .53331 .43438 L .53257 .41465 L 0 0 .337 r
F
.53381 .45844 m .5357 .4321 L .53456 .4462 L .716 .629 .065 r
F
.55234 .479 m .56369 .42803 L .53381 .45844 L .917 .885 .786 r
F
.56369 .42803 m .53625 .42532 L .53381 .45844 L .95 .803 .662 r
F
.54675 .4919 m .53489 .44118 L .53557 .43101 L 0 0 .337 r
F
.53489 .44118 m .53331 .43438 L .53557 .43101 L F
.53366 .45976 m .53456 .4462 L .53298 .46576 L .716 .629 .065 r
F
.53381 .45844 m .53456 .4462 L .53366 .45976 L F
.51809 .48811 m .51973 .48342 L .51975 .48453 L 0 0 0 r
F
.51809 .48811 m .51975 .48453 L .51942 .48538 L F
.51973 .48342 m .52118 .47986 L .51975 .48471 L F
.51975 .48471 m .52118 .47986 L .52423 .47238 L F
.51595 .48853 m .52059 .48232 L .51768 .48993 L .285 .208 .591 r
F
.51942 .48538 m .51975 .48453 L .51975 .48471 L 0 0 0 r
F
.52138 .47938 m .52059 .48232 L .51595 .48853 L .716 .629 .065 r
F
.49859 .52217 m .50691 .49794 L .50772 .51778 L 0 0 0 r
F
.50772 .51778 m .51062 .50948 L .51975 .48471 L F
.51062 .50948 m .51924 .48575 L .51975 .48471 L F
.50691 .49794 m .50874 .50362 L .50772 .51778 L F
0 g
.4233 .57001 m
.43281 .56968 L
s
.34498 .60251 m .42178 .57092 L .40207 .55975 L .808 .85 .881 r
F
0 g
.41316 .57036 m
.4233 .57001 L
s
.40343 .59446 m
.41949 .60638 L
s
.36069 .61998 m .42178 .57092 L .34498 .60251 L .807 .772 .821 r
F
0 g
.38101 .57784 m
.40343 .59446 L
s
.39423 .57102 m
.41316 .57036 L
s
.39227 .57109 m
.39423 .57102 L
s
.53692 .48168 m
.54348 .47789 L
s
.54411 .47752 m
.55136 .47333 L
s
.55136 .47333 m
.57613 .45898 L
s
.57613 .45898 m
.57756 .45816 L
s
.57756 .45816 m
.58041 .45651 L
s
.58785 .44718 m
.59173 .43973 L
s
.58775 .45258 m
.58868 .45212 L
s
.53723 .48291 m
.54373 .47895 L
s
.54439 .47855 m
.54474 .47834 L
s
.54431 .47859 m
.54439 .47855 L
s
.54474 .47834 m
.56965 .46317 L
s
.56965 .46317 m
.57627 .45914 L
s
.27159 .63797 m .36069 .61998 L .34498 .60251 L .856 .772 .768 r
F
.27929 .65441 m .36069 .61998 L .27159 .63797 L .846 .718 .723 r
F
0 g
.35406 .64134 m
.35415 .64135 L
s
.35415 .64135 m
.38888 .64416 L
s
.38888 .64416 m
.46028 .64994 L
s
.46028 .64994 m
.47181 .65087 L
s
.68624 .54515 m .71703 .42158 L .7004 .42403 L .275 .239 .636 r
F
.69962 .55456 m .71703 .42158 L .68624 .54515 L 0 0 .335 r
F
0 g
.69896 .50992 m
.69927 .50998 L
s
.67246 .50442 m
.69896 .50992 L
s
.64099 .66183 m
.64297 .66034 L
s
.62674 .67256 m
.62699 .67237 L
s
.62634 .67286 m
.62674 .67256 L
s
.62739 .67207 m
.64099 .66183 L
s
.62699 .67237 m
.62739 .67207 L
s
.64297 .66034 m
.64316 .66019 L
s
.6444 .65926 m
.65278 .65295 L
s
.64316 .66019 m
.6444 .65926 L
s
.30638 .644 m
.3088 .64372 L
s
.65278 .65295 m
.65286 .65039 L
s
.65286 .65039 m
.65291 .6491 L
s
.65291 .6491 m
.65317 .64158 L
s
.65317 .64158 m
.65321 .64034 L
s
.65321 .64034 m
.65328 .63823 L
s
.66129 .6064 m
.66131 .60637 L
s
.66131 .60637 m
.66151 .60608 L
s
.63913 .65783 m
.6446 .65588 L
s
.6384 .65809 m
.63913 .65783 L
s
.63761 .65838 m
.6384 .65809 L
s
.64883 .65436 m
.65278 .65295 L
s
.64706 .65499 m
.64883 .65436 L
s
.64474 .65583 m
.64706 .65499 L
s
.6446 .65588 m
.64474 .65583 L
s
.67656 .57927 m
.6766 .57921 L
s
.7004 .42403 m .65781 .33192 L .67266 .43358 L .384 .446 .801 r
F
.67266 .43358 m .65781 .33192 L .63291 .36204 L .602 .583 .804 r
F
0 g
.67182 .46036 m
.6799 .42321 L
s
.34723 .74043 m
.38192 .75 L
s
.38192 .75 m
.38322 .75035 L
s
.38322 .75035 m
.38325 .75036 L
s
.33116 .75562 m
.37042 .75832 L
s
.59936 .39544 m .55357 .38378 L .56369 .42803 L .82 .702 .735 r
F
0 g
.5926 .45019 m
.67702 .40862 L
s
.58868 .45212 m
.5926 .45019 L
s
.58694 .48689 m
.67778 .41035 L
s
.57814 .4943 m
.58694 .48689 L
s
.59936 .39544 m .57603 .33825 L .55357 .38378 L .82 .702 .735 r
F
0 g
.59173 .43973 m
.60063 .42266 L
s
.63291 .36204 m .57603 .33825 L .59936 .39544 L .72 .645 .774 r
F
.34498 .60251 m .40207 .55975 L .33298 .58565 L .808 .85 .881 r
F
.26518 .6215 m .34498 .60251 L .33298 .58565 L .858 .827 .816 r
F
.27159 .63797 m .34498 .60251 L .26518 .6215 L .856 .772 .768 r
F
0 g
.31718 .60645 m
.32756 .62209 L
s
.53331 .46712 m
.5354 .46448 L
s
.5354 .46448 m
.53922 .45967 L
s
.54053 .45801 m
.55793 .43605 L
s
.57837 .41025 m
.58341 .40388 L
s
.58341 .40388 m
.58391 .40324 L
s
.58709 .3872 m
.58818 .36687 L
s
.59008 .39562 m
.59013 .39555 L
s
.58928 .39659 m
.59008 .39562 L
s
.49946 .50243 m
.50483 .4961 L
s
.50483 .4961 m
.52256 .47524 L
s
.52256 .47524 m
.52268 .4751 L
s
.53352 .46234 m
.53665 .45866 L
s
.53334 .46255 m
.53352 .46234 L
s
.53665 .45866 m
.53848 .4565 L
s
.57246 .41651 m
.57961 .4081 L
s
.57961 .4081 m
.58064 .40688 L
s
.69962 .55456 m .72232 .42764 L .71703 .42158 L 0 0 .335 r
F
.70283 .56733 m .72232 .42764 L .69962 .55456 L .88 .814 .334 r
F
0 g
.6322 .56628 m
.70466 .52073 L
s
.6766 .57921 m
.70319 .53506 L
s
.56369 .42803 m .55357 .38378 L .53625 .42532 L .95 .803 .662 r
F
0 g
.55784 .43372 m
.57246 .41651 L
s
.53994 .45479 m
.55784 .43372 L
s
.55793 .43605 m
.57837 .41025 L
s
.33298 .58565 m .40207 .55975 L .38979 .55037 L .764 .922 .941 r
F
0 g
.39188 .5634 m
.39835 .56056 L
s
.39835 .56056 m
.40243 .55876 L
s
.52489 .50046 m
.52677 .49968 L
s
.5147 .47534 m
.53098 .45384 L
s
.50661 .48603 m
.5147 .47534 L
s
.49163 .50583 m
.50661 .48603 L
s
.48686 .51213 m
.49163 .50583 L
s
.47321 .52059 m
.47442 .52027 L
s
.63291 .36204 m .59281 .2914 L .57603 .33825 L .72 .645 .774 r
F
0 g
.60063 .42266 m
.60248 .41911 L
s
.65781 .33192 m .59281 .2914 L .63291 .36204 L .603 .603 .825 r
F
.21266 .68526 m .31246 .71583 L .30487 .7015 L .916 .639 .5 r
F
.21392 .69345 m .31246 .71583 L .21266 .68526 L .909 .613 .472 r
F
.21392 .69345 m .31883 .72923 L .31246 .71583 L F
0 g
.50659 .49642 m
.52232 .47602 L
s
.21125 .67654 m .30487 .7015 L .29648 .68638 L .924 .669 .532 r
F
.21266 .68526 m .30487 .7015 L .21125 .67654 L .916 .639 .5 r
F
0 g
.30331 .68871 m
.3358 .68787 L
s
.29725 .68887 m
.30331 .68871 L
s
.29032 .68905 m
.29725 .68887 L
s
.21494 .70105 m .31883 .72923 L .21392 .69345 L .902 .59 .446 r
F
0 g
.29787 .6958 m
.29984 .69635 L
s
.28961 .69348 m
.29205 .69417 L
s
.29205 .69417 m
.29787 .6958 L
s
.21494 .70105 m .32367 .74159 L .31883 .72923 L .902 .59 .446 r
F
0 g
.49408 .50694 m
.49461 .50656 L
s
.49193 .50843 m
.49408 .50694 L
s
.49034 .50955 m
.49193 .50843 L
s
.48723 .51172 m
.49034 .50955 L
s
.48684 .51199 m
.48723 .51172 L
s
.48358 .51427 m
.48684 .51199 L
s
.48348 .51434 m
.48358 .51427 L
s
.21125 .67654 m .29648 .68638 L .20979 .66739 L .924 .669 .532 r
F
.20979 .66739 m .29648 .68638 L .28778 .67062 L .933 .703 .567 r
F
.7004 .42403 m .67087 .31028 L .65781 .33192 L .384 .446 .801 r
F
.71703 .42158 m .67087 .31028 L .7004 .42403 L 0 0 .552 r
F
.21566 .708 m .32367 .74159 L .21494 .70105 L .896 .571 .423 r
F
.21566 .708 m .3268 .75283 L .32367 .74159 L F
0 g
.31273 .72541 m
.35893 .72672 L
s
.65638 .64504 m
.66051 .636 L
s
.66051 .636 m
.66362 .62918 L
s
.66624 .62344 m
.66887 .61768 L
s
.66887 .61768 m
.66932 .61669 L
s
.66544 .6252 m
.66624 .62344 L
s
.66362 .62918 m
.66544 .6252 L
s
.65631 .64519 m
.65638 .64504 L
s
.65278 .65295 m
.65631 .64519 L
s
.64964 .64554 m
.64983 .64598 L
s
.6504 .64733 m
.65196 .65102 L
s
.64983 .64598 m
.6504 .64733 L
s
.64858 .64303 m
.64956 .64536 L
s
.64857 .64301 m
.64858 .64303 L
s
.64956 .64536 m
.64964 .64554 L
s
.65196 .65102 m
.65197 .65106 L
s
.65197 .65106 m
.65278 .65295 L
s
.62396 .67268 m
.62448 .67233 L
s
.62111 .67464 m
.62396 .67268 L
s
.61708 .67739 m
.62111 .67464 L
s
.62448 .67233 m
.63552 .66476 L
s
.63552 .66476 m
.63676 .66392 L
s
.63676 .66392 m
.6387 .66259 L
s
.6387 .66259 m
.64428 .65877 L
s
.64428 .65877 m
.64941 .65525 L
s
.64941 .65525 m
.64948 .6552 L
s
.64948 .6552 m
.65278 .65295 L
s
.52049 .48015 m
.52093 .47898 L
s
.53496 .4422 m
.53507 .44192 L
s
.53676 .43749 m
.54116 .42594 L
s
.54135 .42546 m
.54281 .42163 L
s
.53095 .45272 m
.53107 .45241 L
s
.52093 .47898 m
.53095 .45272 L
s
.53107 .45241 m
.53119 .4521 L
s
.53213 .44963 m
.53486 .44246 L
s
.54281 .42163 m
.56066 .37483 L
s
.56066 .37483 m
.56525 .36278 L
s
.51887 .4844 m
.52049 .48015 L
s
.53867 .4479 m
.54176 .43824 L
s
.54176 .43824 m
.5547 .39765 L
s
.5547 .39765 m
.5551 .39639 L
s
.5551 .39639 m
.56446 .36702 L
s
.56446 .36702 m
.56745 .35766 L
s
.56895 .35259 m
.56975 .34911 L
s
.55357 .38378 m
.57603 .33825 L
s
.20839 .65787 m .28778 .67062 L .27929 .65441 L .94 .74 .605 r
F
.20979 .66739 m .28778 .67062 L .20839 .65787 L .933 .703 .567 r
F
0 g
.28274 .65713 m
.35508 .67893 L
s
.33298 .58565 m .38979 .55037 L .32548 .56989 L .764 .922 .941 r
F
0 g
.34081 .58232 m
.35257 .57844 L
s
.33127 .56026 m
.33209 .56049 L
s
.3437 .5637 m
.34875 .5651 L
s
.36224 .54788 m
.36387 .55155 L
s
.36462 .55326 m
.36955 .56439 L
s
.36955 .56439 m
.37092 .56747 L
s
.26054 .60528 m .33298 .58565 L .32548 .56989 L .847 .882 .866 r
F
.26518 .6215 m .33298 .58565 L .26054 .60528 L .858 .827 .816 r
F
0 g
.32021 .59494 m
.41503 .61001 L
s
.32401 .58786 m
.34081 .58232 L
s
.21603 .71423 m .3268 .75283 L .21566 .708 L .891 .553 .4 r
F
0 g
.31173 .72538 m
.31273 .72541 L
s
.21603 .71423 m .32814 .76286 L .3268 .75283 L .891 .553 .4 r
F
0 g
.30812 .72528 m
.30831 .72529 L
s
.30831 .72529 m
.31173 .72538 L
s
.29984 .69635 m
.37475 .71734 L
s
.30718 .72939 m
.3098 .73011 L
s
.3098 .73011 m
.31034 .73026 L
s
.31034 .73026 m
.34723 .74043 L
s
.70283 .56733 m .71728 .44197 L .72232 .42764 L .88 .814 .334 r
F
0 g
.70858 .5261 m
.71123 .52171 L
s
.70978 .51751 m
.7121 .51605 L
s
.71051 .51231 m
.71276 .51278 L
s
.69652 .58265 m .71728 .44197 L .70283 .56733 L .974 .901 .684 r
F
0 g
.71427 .51309 m
.71618 .51349 L
s
.71276 .51278 m
.71427 .51309 L
s
.71383 .51497 m
.71618 .51349 L
s
.7121 .51605 m
.71383 .51497 L
s
.71324 .51836 m
.71618 .51349 L
s
.71123 .52171 m
.71324 .51836 L
s
1 Mabswid
.71618 .51349 Mdot
.5 Mabswid
.71618 .49303 m
.71618 .49145 L
s
.71618 .51349 m
.71618 .49393 L
s
.71618 .49393 m
.71618 .49303 L
s
1 Mabswid
.71618 .51349 Mdot
.5 Mabswid
.71347 .50887 m
.71398 .50974 L
s
.71212 .50656 m
.71347 .50887 L
s
.71146 .50545 m
.71212 .50656 L
s
.71398 .50974 m
.71416 .51004 L
s
.71416 .51004 m
.71618 .51349 L
s
1 Mabswid
.71618 .51349 Mdot
.5 Mabswid
.70962 .52804 m
.71399 .51835 L
s
.71399 .51835 m
.71418 .51792 L
s
.71418 .51792 m
.71618 .51349 L
s
1 Mabswid
.71618 .51349 Mdot
.71618 .51349 Mdot
.71618 .51349 Mdot
.5 Mabswid
.52232 .47602 m
.53098 .45384 L
s
.53625 .42532 m
.55357 .38378 L
s
.20718 .64809 m .27929 .65441 L .27159 .63797 L .946 .78 .644 r
F
.20839 .65787 m .27929 .65441 L .20718 .64809 L .94 .74 .605 r
F
0 g
.27374 .64777 m
.30638 .644 L
s
.26887 .65295 m
.28274 .65713 L
s
.26862 .65287 m
.26887 .65295 L
s
.21602 .71971 m .32814 .76286 L .21603 .71423 L .887 .536 .376 r
F
.21602 .71971 m .32771 .77165 L .32814 .76286 L F
0 g
.31652 .75461 m
.31675 .75463 L
s
.31675 .75463 m
.33116 .75562 L
s
.51009 .49343 m
.51082 .49278 L
s
.50921 .4942 m
.51009 .49343 L
s
.51618 .48801 m
.51667 .48757 L
s
.51667 .48757 m
.51688 .48739 L
s
.51523 .48886 m
.51618 .48801 L
s
.51082 .49278 m
.51523 .48886 L
s
.49678 .51138 m
.49712 .50918 L
s
.4874 .51558 m
.49717 .50504 L
s
.48198 .52142 m
.4874 .51558 L
s
.32788 .76165 m
.3747 .77467 L
s
.25158 .69858 m
.25386 .70011 L
s
.25386 .70011 m
.25513 .70097 L
s
.25513 .70097 m
.25565 .70132 L
s
.25565 .70132 m
.26007 .7043 L
s
.21583 .69145 m
.2228 .69457 L
s
.2228 .69457 m
.23316 .69919 L
s
.23316 .69919 m
.24234 .70329 L
s
.24234 .70329 m
.24257 .70339 L
s
.24257 .70339 m
.24258 .7034 L
s
.65781 .33192 m .59684 .25012 L .59281 .2914 L .603 .603 .825 r
F
0 g
.57603 .33825 m
.59281 .2914 L
s
.67087 .31028 m .59684 .25012 L .65781 .33192 L .301 .502 .887 r
F
0 g
.59013 .39555 m
.65488 .31648 L
s
.60248 .41911 m
.65553 .31738 L
s
.24562 .67087 m
.24921 .67313 L
s
.24921 .67313 m
.25197 .67486 L
s
.22097 .67202 m
.23099 .67524 L
s
.23099 .67524 m
.23287 .67584 L
s
.23287 .67584 m
.23816 .67754 L
s
.68204 .59912 m .70361 .46267 L .69652 .58265 L .896 .83 .774 r
F
0 g
.66151 .60608 m
.68654 .57063 L
s
.69652 .58265 m .70361 .46267 L .71728 .44197 L .974 .901 .684 r
F
0 g
.70944 .52844 m
.70962 .52804 L
s
.70362 .54134 m
.70513 .53801 L
s
.70513 .53801 m
.70944 .52844 L
s
.71619 .47993 m
.71619 .47159 L
s
.71618 .49145 m
.71619 .47993 L
s
.21563 .72441 m .32771 .77165 L .21602 .71971 L .883 .519 .349 r
F
.21563 .72441 m .32563 .77916 L .32771 .77165 L F
0 g
.315 .75807 m
.32788 .76165 L
s
.31498 .75806 m
.315 .75807 L
s
.71703 .42158 m .67237 .30147 L .67087 .31028 L 0 0 .552 r
F
.72232 .42764 m .67237 .30147 L .71703 .42158 L .973 .664 .313 r
F
.20718 .64809 m .27159 .63797 L .20627 .63815 L .946 .78 .644 r
F
0 g
.27049 .64814 m
.27374 .64777 L
s
.20627 .63815 m .27159 .63797 L .26518 .6215 L .949 .823 .685 r
F
0 g
1 Mabswid
.53098 .45384 Mdot
.5 Mabswid
.53403 .45369 m
.53507 .45364 L
s
.53507 .45364 m
.53778 .45351 L
s
.53181 .4538 m
.53395 .45369 L
s
1 Mabswid
.53098 .45384 Mdot
.5 Mabswid
.52961 .4688 m
.53098 .45384 L
s
1 Mabswid
.53098 .45384 Mdot
.5 Mabswid
.53456 .4462 m
.53495 .4414 L
s
.53572 .43183 m
.53625 .42532 L
s
.24837 .71749 m
.24963 .7184 L
s
.24963 .7184 m
.25317 .72096 L
s
.25317 .72096 m
.25595 .72297 L
s
.25595 .72297 m
.2567 .72351 L
s
.23562 .71936 m
.23656 .71987 L
s
.23656 .71987 m
.24044 .72199 L
s
.24044 .72199 m
.24426 .72407 L
s
.25803 .58954 m .32548 .56989 L .3229 .55573 L .811 .929 .911 r
F
.26054 .60528 m .32548 .56989 L .25803 .58954 L .847 .882 .866 r
F
0 g
.30642 .5811 m
.30646 .58135 L
s
.29207 .58713 m
.29237 .58723 L
s
.27979 .60017 m
.28286 .5994 L
s
.51823 .48789 m
.51825 .48847 L
s
.5048 .52376 m
.50709 .51735 L
s
.50709 .51735 m
.50823 .51414 L
s
.50823 .51414 m
.50987 .50953 L
s
.50987 .50953 m
.5105 .50777 L
s
.5105 .50777 m
.51797 .4868 L
s
.21489 .72829 m .32563 .77916 L .21563 .72441 L .88 .5 .318 r
F
0 g
.24697 .72555 m
.24738 .72577 L
s
.24426 .72407 m
.24697 .72555 L
s
.21489 .72829 m .32209 .7854 L .32563 .77916 L .88 .5 .318 r
F
0 g
.3138 .77565 m
.31433 .7757 L
s
.31433 .7757 m
.31626 .7759 L
s
.31626 .7759 m
.36227 .78068 L
s
.24202 .64111 m
.24453 .64246 L
s
.20577 .62815 m .26518 .6215 L .26054 .60528 L .948 .866 .724 r
F
.20627 .63815 m .26518 .6215 L .20577 .62815 L .949 .823 .685 r
F
0 g
.36966 .54849 m
.37384 .54776 L
s
.36678 .54899 m
.36966 .54849 L
s
.68204 .59912 m .68324 .48676 L .70361 .46267 L .896 .83 .774 r
F
0 g
.69727 .55544 m
.70061 .54803 L
s
.70061 .54803 m
.70362 .54134 L
s
.69247 .56223 m
.693 .56148 L
s
.6938 .56035 m
.6968 .55609 L
s
.693 .56148 m
.6938 .56035 L
s
.6968 .55609 m
.69727 .55544 L
s
.68898 .5736 m
.68934 .57281 L
s
.6876 .57663 m
.68898 .5736 L
s
.68934 .57281 m
.69659 .55693 L
s
.69659 .55693 m
.69727 .55544 L
s
.67479 .6047 m
.68215 .58857 L
s
.6612 .61515 m .68324 .48676 L .68204 .59912 L .818 .755 .794 r
F
.67087 .31028 m .58741 .22224 L .59684 .25012 L .301 .502 .887 r
F
0 g
.59281 .2914 m
.59684 .25012 L
s
.48638 .52184 m
.49323 .51808 L
s
.49972 .51452 m
.51135 .50814 L
s
.49323 .51808 m
.49972 .51452 L
s
.51135 .50814 m
.52323 .50162 L
s
.52323 .50162 m
.52677 .49968 L
s
.67237 .30147 m .58741 .22224 L .67087 .31028 L .748 .231 0 r
F
0 g
.56975 .34911 m
.59426 .24243 L
s
.58818 .36687 m
.59483 .24308 L
s
.52778 .50586 m .53331 .43438 L .54675 .4919 L 0 0 .006 r
F
0 g
.52677 .49968 m
.52808 .48541 L
s
.53098 .45384 m
.53104 .43615 L
s
.53098 .45384 m
.53331 .43438 L
s
.72232 .42764 m .66503 .30732 L .67237 .30147 L .973 .664 .313 r
F
0 g
.68653 .40477 m
.70938 .40048 L
s
.71728 .44197 m .66503 .30732 L .72232 .42764 L .924 .715 .602 r
F
0 g
.71287 .39982 m
.7162 .39919 L
s
.71141 .40009 m
.71188 .40001 L
s
.71223 .39994 m
.71287 .39982 L
s
.71188 .40001 m
.71223 .39994 L
s
.71465 .40219 m
.7162 .39919 L
s
.71349 .40443 m
.71465 .40219 L
s
.7162 .40567 m
.7162 .39919 L
s
.7162 .41508 m
.7162 .41502 L
s
.71619 .44362 m
.71619 .43917 L
s
.7162 .41502 m
.7162 .41097 L
s
.7162 .41097 m
.7162 .40567 L
s
.66589 .49621 m
.70732 .41631 L
s
.71295 .40547 m
.71349 .40443 L
s
.71285 .40566 m
.71295 .40547 L
s
.6612 .61515 m .65809 .51095 L .68324 .48676 L .818 .755 .794 r
F
.63613 .62927 m .65809 .51095 L .6612 .61515 L .756 .689 .788 r
F
0 g
.52877 .51783 m
.52908 .51404 L
s
.52908 .51404 m
.53032 .49866 L
s
.53032 .49866 m
.53089 .49161 L
s
.52806 .5267 m
.52877 .51783 L
s
.32664 .78224 m
.35125 .78899 L
s
.31258 .77838 m
.32664 .78224 L
s
.31121 .778 m
.31258 .77838 L
s
.31119 .778 m
.31121 .778 L
s
.24754 .73558 m
.24793 .7359 L
s
.24793 .7359 m
.2482 .73611 L
s
.2482 .73611 m
.24928 .73696 L
s
.24928 .73696 m
.24948 .73712 L
s
.2248 .72776 m
.22663 .72895 L
s
.22663 .72895 m
.23116 .73189 L
s
.23116 .73189 m
.2353 .73457 L
s
.2353 .73457 m
.2393 .73716 L
s
.2393 .73716 m
.24312 .73963 L
s
.24312 .73963 m
.24438 .74045 L
s
.21856 .72372 m
.2248 .72776 L
s
.25803 .58954 m .3229 .55573 L .25788 .57454 L .811 .929 .911 r
F
0 g
.28935 .58613 m
.29207 .58713 L
s
.25788 .57454 m .3229 .55573 L .32526 .54356 L .741 .955 .944 r
F
0 g
.30187 .55212 m
.30219 .55417 L
s
.31714 .55635 m
.33127 .56026 L
s
.3167 .55623 m
.31714 .55635 L
s
.30187 .55212 m
.30485 .55295 L
s
.30431 .56768 m
.30642 .5811 L
s
.20579 .6182 m .26054 .60528 L .25803 .58954 L .94 .909 .761 r
F
.20577 .62815 m .26054 .60528 L .20579 .6182 L .948 .866 .724 r
F
0 g
.25572 .60618 m
.27979 .60017 L
s
.25571 .60619 m
.25572 .60618 L
s
.25611 .61201 m
.32613 .63564 L
s
.25384 .61125 m
.25611 .61201 L
s
1 Mabswid
.69727 .55544 Mdot
.5 Mabswid
.69698 .5536 m
.69727 .55544 L
s
.69257 .52563 m
.69698 .5536 L
s
.6916 .51951 m
.69257 .52563 L
s
.6897 .50743 m
.6916 .51951 L
s
1 Mabswid
.69727 .55544 Mdot
.5 Mabswid
.69675 .55522 m
.69727 .55544 L
s
.68941 .55208 m
.69675 .55522 L
s
.68735 .55121 m
.68941 .55208 L
s
.68505 .55022 m
.68735 .55121 L
s
1 Mabswid
.69727 .55544 Mdot
.5 Mabswid
.69663 .55588 m
.69727 .55544 L
s
.68625 .56302 m
.69663 .55588 L
s
.68227 .56577 m
.68625 .56302 L
s
.67143 .57323 m
.68227 .56577 L
s
.66995 .57425 m
.67143 .57323 L
s
1 Mabswid
.69727 .55544 Mdot
.69727 .55544 Mdot
.69727 .55544 Mdot
.52677 .49968 Mdot
.5 Mabswid
.52677 .49968 m
.52837 .49801 L
s
.53046 .49582 m
.53425 .49185 L
s
1 Mabswid
.52677 .49968 Mdot
.52677 .49968 Mdot
.52677 .49968 Mdot
.5 Mabswid
.52677 .49968 m
.52817 .5 L
s
1 Mabswid
.52677 .49968 Mdot
.5 Mabswid
.52677 .49968 m
.52761 .50285 L
s
1 Mabswid
.52677 .49968 Mdot
.5 Mabswid
.30619 .7886 m
.34378 .79374 L
s
.30515 .78846 m
.30619 .7886 L
s
.30202 .78803 m
.30515 .78846 L
s
.30166 .78798 m
.30202 .78803 L
s
.63613 .62927 m .6301 .53254 L .65809 .51095 L .756 .689 .788 r
F
0 g
.63086 .60118 m
.63786 .59635 L
s
.63786 .59635 m
.64305 .59278 L
s
.64305 .59278 m
.66268 .57926 L
s
.62581 .61792 m
.63086 .60118 L
s
.63086 .60118 m
.63255 .60517 L
s
1 Mabswid
.7162 .39919 Mdot
.5 Mabswid
.70997 .38877 m
.7162 .39919 L
s
1 Mabswid
.7162 .39919 Mdot
.5 Mabswid
.71167 .39781 m
.71383 .39847 L
s
.71383 .39847 m
.7162 .39919 L
s
1 Mabswid
.7162 .39919 Mdot
.5 Mabswid
.71379 .40298 m
.71497 .40112 L
s
.71497 .40112 m
.7162 .39919 L
s
1 Mabswid
.7162 .39919 Mdot
.7162 .39919 Mdot
.7162 .39919 Mdot
.5 Mabswid
.31821 .54935 m
.33336 .54677 L
s
.30187 .55212 m
.30943 .55084 L
s
.5655 .47414 m .53257 .41465 L .53026 .39097 L 0 .149 .673 r
F
0 g
.53968 .45341 m
.54025 .45339 L
s
.54025 .45339 m
.55365 .45273 L
s
.53104 .43615 m
.53115 .39949 L
s
.54675 .4919 m .53257 .41465 L .5655 .47414 L 0 0 .337 r
F
0 g
.53257 .41465 m
.53331 .43438 L
s
.55637 .4526 m
.5576 .45254 L
s
.53998 .48585 m
.54323 .48244 L
s
.53425 .49185 m
.53998 .48585 L
s
.54323 .48244 m
.54478 .48082 L
s
.20641 .60839 m .25803 .58954 L .25788 .57454 L .922 .949 .794 r
F
.20579 .6182 m .25803 .58954 L .20641 .60839 L .94 .909 .761 r
F
0 g
.22162 .61459 m
.22163 .61459 L
s
.67237 .30147 m .5693 .21309 L .58741 .22224 L .748 .231 0 r
F
0 g
.59045 .23122 m
.59684 .25012 L
s
.71728 .44197 m .65226 .32663 L .66503 .30732 L .924 .715 .602 r
F
0 g
.67216 .36193 m
.68236 .39993 L
s
.70361 .46267 m .65226 .32663 L .71728 .44197 L .846 .698 .698 r
F
0 g
.70478 .38007 m
.70997 .38877 L
s
.70444 .39561 m
.71167 .39781 L
s
.70336 .39528 m
.70444 .39561 L
s
.70919 .4102 m
.71379 .40298 L
s
.7079 .41221 m
.70919 .4102 L
s
.57268 .56248 m .54675 .4919 L .5655 .47414 L .493 .42 .702 r
F
0 g
.54478 .48082 m
.55079 .47453 L
s
.55079 .47453 m
.56083 .46402 L
s
.56835 .50922 m
.57818 .51147 L
s
.62598 .57894 m
.63086 .60118 L
s
.62458 .59793 m
.63086 .60118 L
s
.58837 .61461 m
.59067 .61389 L
s
.6116 .60727 m
.61916 .60488 L
s
.61916 .60488 m
.63086 .60118 L
s
.59067 .61389 m
.6116 .60727 L
s
.66503 .30732 m .5693 .21309 L .67237 .30147 L .834 .525 .466 r
F
.26022 .56048 m .32526 .54356 L .33221 .53369 L .629 .945 .951 r
F
.25788 .57454 m .32526 .54356 L .26022 .56048 L .741 .955 .944 r
F
0 g
.28985 .54813 m
.29173 .54875 L
s
.55185 .54965 m
.56181 .54472 L
s
1 Mabswid
.53115 .39949 Mdot
.5 Mabswid
.53115 .39949 m
.53132 .39943 L
s
.53109 .39856 m
.53115 .39949 L
s
1 Mabswid
.53115 .39949 Mdot
.5 Mabswid
.53115 .39949 m
.53163 .4001 L
s
1 Mabswid
.53115 .39949 Mdot
.70361 .46267 m .63678 .35561 L .65226 .32663 L .846 .698 .698 r
F
0 g
.5 Mabswid
.67987 .33838 m
.67993 .33848 L
s
.68324 .48676 m .63678 .35561 L .70361 .46267 L .775 .67 .747 r
F
0 g
.67993 .33848 m
.70478 .38007 L
s
.68724 .44462 m
.68788 .44361 L
s
.31114 .79261 m
.32995 .79763 L
s
.30585 .79119 m
.31114 .79261 L
s
.32995 .79763 m
.33049 .79778 L
s
.22335 .73058 m
.22498 .73202 L
s
.22498 .73202 m
.23192 .73818 L
s
.23192 .73818 m
.23849 .744 L
s
.23849 .744 m
.23919 .74462 L
s
.21656 .73225 m
.21802 .73338 L
s
.21892 .73407 m
.21937 .73442 L
s
.23186 .74411 m
.23647 .74768 L
s
.23647 .74768 m
.23893 .74958 L
s
.23893 .74958 m
.23982 .75027 L
s
.21937 .73442 m
.23071 .74321 L
s
.23071 .74321 m
.23186 .74411 L
s
.20641 .60839 m .25788 .57454 L .20769 .59884 L .922 .949 .794 r
F
.20769 .59884 m .25788 .57454 L .26022 .56048 L .889 .981 .817 r
F
0 g
.25314 .57291 m
.28935 .58613 L
s
.25537 .5673 m
.27269 .56164 L
s
.57268 .56248 m .5655 .47414 L .60109 .54985 L .493 .42 .702 r
F
0 g
.5701 .54062 m
.571 .54018 L
s
.56181 .54472 m
.5701 .54062 L
s
.5655 .47414 m .53026 .39097 L .58416 .45099 L 0 .149 .673 r
F
.60109 .54985 m .5655 .47414 L .58416 .45099 L .548 .497 .751 r
F
0 g
.57205 .45184 m
.57249 .45182 L
s
.56816 .45635 m
.57249 .45182 L
s
.58416 .45099 m .53026 .39097 L .52724 .36101 L .35 .439 .812 r
F
0 g
.56912 .44755 m
.57249 .45182 L
s
.53026 .39097 m
.53257 .41465 L
s
.52102 1.03998 m .34706 1.13644 L .55116 1.11243 L .766 .637 .719 r
F
.52102 1.03998 m .34296 1.04384 L .34706 1.13644 L F
.4992 .97237 m .34296 1.04384 L .52102 1.03998 L .788 .736 .804 r
F
.69295 .97561 m .52102 1.03998 L .55116 1.11243 L .658 .534 .702 r
F
.65574 .92493 m .52102 1.03998 L .69295 .97561 L .702 .619 .761 r
F
.65574 .92493 m .4992 .97237 L .52102 1.03998 L F
.60109 .54985 m .58416 .45099 L .6301 .53254 L .548 .497 .751 r
F
0 g
.571 .54018 m
.59607 .52777 L
s
.62582 .52494 m
.63491 .52882 L
s
.68324 .48676 m .62001 .38909 L .63678 .35561 L .775 .67 .747 r
F
0 g
.68365 .45025 m
.68724 .44462 L
s
.65809 .51095 m .62001 .38909 L .68324 .48676 L .702 .63 .773 r
F
0 g
.68127 .45398 m
.68358 .45036 L
s
.68358 .45036 m
.68365 .45025 L
s
.68287 .46409 m
.68379 .46996 L
s
.68277 .46348 m
.68284 .46391 L
s
.68284 .46391 m
.68287 .46409 L
s
.68127 .45398 m
.68277 .46348 L
s
.68291 .45677 m
.68369 .45811 L
s
.68252 .4561 m
.68291 .45677 L
s
.68127 .45398 m
.68248 .45605 L
s
.68248 .45605 m
.68252 .4561 L
s
.6301 .53254 m .60242 .4221 L .65809 .51095 L .624 .572 .775 r
F
.6301 .53254 m .58416 .45099 L .60242 .4221 L F
0 g
.60154 .52507 m
.61292 .51944 L
s
.61006 .51878 m
.61292 .51944 L
s
.61292 .51944 m
.61522 .52988 L
s
.61292 .51944 m
.6157 .52062 L
s
.65809 .51095 m .60242 .4221 L .62001 .38909 L .702 .63 .773 r
F
.19057 .63127 m .21266 .68526 L .21125 .67654 L .866 .626 .093 r
F
.19057 .63127 m .21392 .69345 L .21266 .68526 L .861 .618 .083 r
F
.69295 .97561 m .55116 1.11243 L .72848 1.02657 L .658 .534 .702 r
F
.55116 1.11243 m .38037 1.22797 L .5904 1.17769 L .734 .547 .64 r
F
.55116 1.11243 m .34706 1.13644 L .38037 1.22797 L F
.72848 1.02657 m .55116 1.11243 L .5904 1.17769 L .603 .442 .637 r
F
.19057 .63127 m .21494 .70105 L .21392 .69345 L .863 .62 .086 r
F
0 g
1 Mabswid
.61292 .51944 Mdot
.5 Mabswid
.57249 .45182 m
.57518 .45632 L
s
.60509 .50634 m
.61292 .51944 L
s
.67612 .45891 m
.68127 .45398 L
s
.67142 .46341 m
.67612 .45891 L
s
.61292 .51944 m
.6207 .51199 L
s
.66685 .46779 m
.67142 .46341 L
s
.66677 .46787 m
.66685 .46779 L
s
1 Mabswid
.61292 .51944 Mdot
.61292 .51944 Mdot
.61292 .51944 Mdot
.61292 .51944 Mdot
.61292 .51944 Mdot
.66503 .30732 m .54969 .22352 L .5693 .21309 L .834 .525 .466 r
F
0 g
.5 Mabswid
.5693 .21309 m
.58741 .22224 L
s
.65535 .30029 m
.65776 .31171 L
s
.65462 .2968 m
.65463 .29686 L
s
.65568 .30053 m
.65968 .31542 L
s
.19057 .63127 m .21125 .67654 L .20979 .66739 L .875 .643 .116 r
F
.19057 .63127 m .21566 .708 L .21494 .70105 L .87 .632 .101 r
F
0 g
.21444 .66992 m
.21506 .67012 L
s
.21506 .67012 m
.22097 .67202 L
s
1 Mabswid
.57249 .45182 Mdot
.5 Mabswid
.57249 .45182 m
.57444 .44804 L
s
1 Mabswid
.57249 .45182 Mdot
.57249 .45182 Mdot
.57249 .45182 Mdot
.5 Mabswid
.67604 .45387 m
.68127 .45398 L
s
.67291 .45381 m
.67604 .45387 L
s
.67279 .45381 m
.67291 .45381 L
s
.67226 .4538 m
.67279 .45381 L
s
.57249 .45182 m
.57348 .45184 L
s
1 Mabswid
.57249 .45182 Mdot
.57249 .45182 Mdot
.5 Mabswid
.56687 1.18333 m
.56811 1.18624 L
s
.4078 .893 m
.40903 .8946 L
s
.44959 .94726 m
.45292 .95158 L
s
.43247 .92503 m
.43529 .92869 L
s
.43529 .92869 m
.44959 .94726 L
s
.41033 .89629 m
.43247 .92503 L
s
.50409 .99156 m
.51713 .98821 L
s
.19057 .63127 m .20979 .66739 L .20839 .65787 L .887 .669 .15 r
F
.26022 .56048 m .33221 .53369 L .26503 .54756 L .629 .945 .951 r
F
0 g
.27911 .54456 m
.27962 .54473 L
s
.19057 .63127 m .21603 .71423 L .21566 .708 L .881 .649 .126 r
F
0 g
.21563 .69384 m
.24837 .71749 L
s
.2127 .69006 m
.2128 .6901 L
s
.21308 .69023 m
.21404 .69065 L
s
.2128 .6901 m
.21308 .69023 L
s
.2127 .69006 m
.2127 .69006 L
s
.21232 .66924 m
.21444 .66992 L
s
.2123 .67211 m
.21432 .67347 L
s
.21394 .69262 m
.21563 .69384 L
s
.21404 .69065 m
.21583 .69145 L
s
.21432 .67347 m
.21489 .67385 L
s
.21489 .67385 m
.25158 .69858 L
s
1 Mabswid
.68127 .45398 Mdot
.5 Mabswid
.66503 .43286 m
.68127 .45398 L
s
.65511 .41996 m
.66503 .43286 L
s
.63847 .39833 m
.65511 .41996 L
s
.63778 .39743 m
.63847 .39833 L
s
1 Mabswid
.68127 .45398 Mdot
.68127 .45398 Mdot
.68127 .45398 Mdot
.68127 .45398 Mdot
.68127 .45398 Mdot
.65226 .32663 m .54969 .22352 L .66503 .30732 L .778 .57 .618 r
F
0 g
.5 Mabswid
.6544 .29574 m
.65759 .30108 L
s
.65864 .30284 m
.65867 .3029 L
s
.65759 .30108 m
.65864 .30284 L
s
.6544 .29574 m
.65512 .29845 L
s
.65512 .29845 m
.65526 .29897 L
s
.65526 .29897 m
.65531 .29914 L
s
.6544 .29574 m
.65459 .29668 L
s
.65459 .29668 m
.65462 .2968 L
s
.19057 .63127 m .20839 .65787 L .20718 .64809 L .899 .701 .192 r
F
.19057 .63127 m .21602 .71971 L .21603 .71423 L .895 .67 .156 r
F
0 g
.21569 .7085 m
.23562 .71936 L
s
.21102 .64444 m
.21177 .64452 L
s
.20942 .66831 m
.20949 .66833 L
s
.20928 .66826 m
.20942 .66831 L
s
.20949 .66833 m
.21008 .66852 L
s
.21103 .66882 m
.21232 .66924 L
s
.21008 .66852 m
.21103 .66882 L
s
.20942 .67017 m
.20954 .67025 L
s
.20961 .6703 m
.21023 .67072 L
s
.21114 .67133 m
.2123 .67211 L
s
.21023 .67072 m
.21114 .67133 L
s
.20954 .67025 m
.20961 .6703 L
s
.21197 .64973 m
.24562 .67087 L
s
.21195 .64971 m
.21197 .64973 L
s
.21179 .64452 m
.22964 .6465 L
s
.21177 .64452 m
.21179 .64452 L
s
.21291 .69188 m
.21315 .69205 L
s
.21361 .69238 m
.21394 .69262 L
s
.21315 .69205 m
.21361 .69238 L
s
.21285 .69183 m
.21291 .69188 L
s
.21284 .69183 m
.21285 .69183 L
s
.31951 .79871 m
.32078 .79894 L
s
.3149 .79787 m
.31951 .79871 L
s
.32078 .79894 m
.32131 .79904 L
s
.4992 .97237 m .35889 .96686 L .34296 1.04384 L .788 .736 .804 r
F
0 g
.47777 .96447 m
.48499 .98888 L
s
.45337 .95217 m
.48471 .99285 L
s
.49194 1.00735 m
.56135 1.17036 L
s
.4511 .99435 m
.45115 .99435 L
s
.35215 .99 m
.35408 .99009 L
s
.61854 .88105 m .4992 .97237 L .65574 .92493 L .746 .711 .819 r
F
.58416 .45099 m .52724 .36101 L .60242 .4221 L .35 .439 .812 r
F
.20966 .58965 m .26022 .56048 L .26503 .54756 L .835 .999 .825 r
F
.20769 .59884 m .26022 .56048 L .20966 .58965 L .889 .981 .817 r
F
0 g
1 Mabswid
.6544 .29574 Mdot
.6544 .29574 Mdot
.5 Mabswid
.6458 .29683 m
.6544 .29574 L
s
.6442 .29703 m
.6458 .29683 L
s
1 Mabswid
.6544 .29574 Mdot
.5 Mabswid
.65085 .30237 m
.6544 .29574 L
s
.64972 .30449 m
.65085 .30237 L
s
1 Mabswid
.6544 .29574 Mdot
.6544 .29574 Mdot
.6544 .29574 Mdot
.5 Mabswid
.58383 .93625 m
.62558 .95414 L
s
.51221 .90557 m
.58383 .93625 L
s
.62257 .94369 m
.62295 .94414 L
s
.55684 .86559 m
.55742 .86627 L
s
.55272 .8607 m
.55684 .86559 L
s
.19057 .63127 m .20718 .64809 L .20627 .63815 L .907 .736 .238 r
F
.19057 .63127 m .21563 .72441 L .21602 .71971 L .908 .69 .186 r
F
0 g
.20819 .64413 m
.20874 .64419 L
s
.20846 .64752 m
.20895 .64783 L
s
.20874 .64419 m
.21077 .64441 L
s
.20895 .64783 m
.21097 .6491 L
s
.21462 .70792 m
.21468 .70795 L
s
.21468 .70795 m
.21471 .70797 L
s
.21491 .70808 m
.21569 .7085 L
s
.21471 .70797 m
.21491 .70808 L
s
.20901 .70487 m
.2106 .70573 L
s
.20909 .70517 m
.21082 .70654 L
s
.21123 .64926 m
.21195 .64971 L
s
.21097 .6491 m
.21123 .64926 L
s
.21077 .64441 m
.21102 .64444 L
s
.21463 .70955 m
.21463 .70955 L
s
.21481 .70969 m
.21547 .71022 L
s
.21463 .70955 m
.21481 .70969 L
s
.21547 .71022 m
.24754 .73558 L
s
.60242 .4221 m .52724 .36101 L .52513 .32501 L .559 .555 .806 r
F
0 g
.52724 .36101 m
.53026 .39097 L
s
.20707 .69261 m
.20763 .69934 L
s
.19057 .63127 m .20627 .63815 L .20577 .62815 L .91 .77 .282 r
F
.19057 .63127 m .21489 .72829 L .21563 .72441 L .92 .707 .214 r
F
0 g
.21433 .72098 m
.21856 .72372 L
s
.21421 .72091 m
.21433 .72098 L
s
.21413 .72085 m
.21418 .72088 L
s
.21418 .72088 m
.21421 .72091 L
s
.21403 .72232 m
.22335 .73058 L
s
.21394 .72224 m
.214 .7223 L
s
.214 .7223 m
.21403 .72232 L
s
.2139 .72221 m
.21394 .72224 L
s
.20603 .64599 m
.20694 .64657 L
s
.20694 .64657 m
.20846 .64752 L
s
.2061 .64389 m
.20668 .64396 L
s
.20668 .64396 m
.20819 .64413 L
s
.21137 .72823 m
.21144 .72828 L
s
.21168 .72846 m
.21656 .73225 L
s
.21144 .72828 m
.21168 .72846 L
s
.76428 .82487 m .65574 .92493 L .69295 .97561 L .576 .523 .759 r
F
.72606 .79405 m .65574 .92493 L .76428 .82487 L .642 .603 .795 r
F
.72606 .79405 m .61854 .88105 L .65574 .92493 L F
0 g
.65246 .94532 m
.69155 .91749 L
s
.60242 .4221 m .52513 .32501 L .62001 .38909 L .559 .555 .806 r
F
.65226 .32663 m .53459 .24998 L .54969 .22352 L .778 .57 .618 r
F
0 g
1 Mabswid
.54969 .22352 Mdot
.54969 .22352 Mdot
.54969 .22352 Mdot
.5 Mabswid
.54969 .22352 m
.6544 .29574 L
s
.54969 .22352 m
.5693 .21309 L
s
.63678 .35561 m .53459 .24998 L .65226 .32663 L .727 .586 .697 r
F
.79805 .85877 m .69295 .97561 L .72848 1.02657 L .496 .427 .709 r
F
.76428 .82487 m .69295 .97561 L .79805 .85877 L .576 .523 .759 r
F
0 g
.69155 .91749 m
.69316 .91634 L
s
.19057 .63127 m .20577 .62815 L .20579 .6182 L .904 .799 .32 r
F
.21233 .58089 m .26503 .54756 L .27217 .53591 L .754 .993 .811 r
F
0 g
.26693 .54051 m
.27546 .54335 L
s
.20966 .58965 m .26503 .54756 L .21233 .58089 L .835 .999 .825 r
F
0 g
.25583 .54819 m
.25592 .548 L
s
.22046 .58659 m
.22128 .58607 L
s
.22128 .58607 m
.2214 .58599 L
s
.35783 .99517 m
.55849 1.1775 L
s
.35215 .99 m
.35379 .99149 L
s
.56531 1.1837 m
.56811 1.18624 L
s
.68645 .76898 m .61854 .88105 L .72606 .79405 L .701 .674 .821 r
F
.68645 .76898 m .58272 .84836 L .61854 .88105 L F
0 g
.55742 .86627 m
.62257 .94369 L
s
.34296 1.04384 m
.34706 1.13644 L
s
.62001 .38909 m .52513 .32501 L .52667 .28611 L .665 .587 .757 r
F
0 g
.52509 .31213 m
.52594 .30905 L
s
.54766 .30927 m
.58711 .30427 L
s
.52513 .32501 m
.52724 .36101 L
s
.52533 .3156 m
.52544 .31721 L
s
.52509 .31213 m
.52531 .31529 L
s
.52531 .31529 m
.52533 .3156 L
s
.72848 1.02657 m .5904 1.17769 L .75924 1.07026 L .603 .442 .637 r
F
.5904 1.17769 m .44196 1.29786 L .634 1.22302 L .679 .435 .546 r
F
0 g
.56811 1.18624 m
.57442 1.18278 L
s
.55539 1.18907 m
.56811 1.18624 L
s
.5904 1.17769 m .38037 1.22797 L .44196 1.29786 L .679 .435 .546 r
F
0 g
.34706 1.13644 m
.38037 1.22797 L
s
.75924 1.07026 m .5904 1.17769 L .634 1.22302 L .511 .309 .542 r
F
0 g
.57926 1.18012 m
.63442 1.14985 L
s
.49458 .99913 m
.7075 1.08982 L
s
.64608 .97526 m
.71177 1.07418 L
s
.30444 .79954 m
.30578 .79993 L
s
.25632 .78662 m
.25778 .78694 L
s
.25778 .78694 m
.25843 .78708 L
s
.25843 .78708 m
.26068 .78757 L
s
.26068 .78757 m
.2616 .78778 L
s
.21104 .72929 m
.21929 .7376 L
s
.21096 .72921 m
.21104 .72929 L
s
.21929 .7376 m
.22731 .74568 L
s
.22731 .74568 m
.22849 .74688 L
s
.20225 .72494 m
.2031 .72574 L
s
.62001 .38909 m .52667 .28611 L .63678 .35561 L .665 .587 .757 r
F
0 g
.61511 .36865 m
.61553 .36849 L
s
.61137 .37002 m
.61511 .36865 L
s
.61553 .36849 m
.61566 .36824 L
s
.61553 .36849 m
.61598 .36908 L
s
.61598 .36908 m
.62226 .37724 L
s
.61488 .36975 m
.61553 .36849 L
s
.61198 .37537 m
.61488 .36975 L
s
.61553 .36849 m
.61573 .36855 L
s
.61573 .36855 m
.61933 .36965 L
s
.61566 .36824 m
.61898 .36204 L
s
.62603 .34883 m
.62752 .34604 L
s
.53147 .28914 m
.54062 .2562 L
s
.40809 .54616 m
.41857 .5526 L
s
.3383 .5258 m
.33957 .52599 L
s
.63678 .35561 m .52667 .28611 L .53459 .24998 L .727 .586 .697 r
F
0 g
.52513 .32501 m
.52667 .28611 L
s
.52509 .31213 m
.52816 .31174 L
s
.53459 .24998 m
.54969 .22352 L
s
1 Mabswid
.52509 .31213 Mdot
.52509 .31213 Mdot
.5 Mabswid
.57707 .34452 m
.61163 .36606 L
s
.52509 .31213 m
.57707 .34452 L
s
.61163 .36606 m
.61553 .36849 L
s
1 Mabswid
.52509 .31213 Mdot
.19057 .63127 m .20579 .6182 L .20641 .60839 L .887 .822 .348 r
F
0 g
.5 Mabswid
.20483 .62108 m
.2051 .62122 L
s
.2051 .62122 m
.20616 .62179 L
s
.20508 .61864 m
.22162 .61459 L
s
.20618 .6218 m
.24202 .64111 L
s
.20616 .62179 m
.20618 .6218 L
s
1 Mabswid
.61553 .36849 Mdot
.61553 .36849 Mdot
.61553 .36849 Mdot
.61553 .36849 Mdot
.61553 .36849 Mdot
.61553 .36849 Mdot
.5 Mabswid
.34296 1.04384 m
.35889 .96686 L
s
.52667 .28611 m
.53459 .24998 L
s
.29965 .51777 m
.30068 .51802 L
s
.28764 .53181 m
.28842 .53163 L
s
.19057 .63127 m .20641 .60839 L .20769 .59884 L .857 .834 .362 r
F
.64819 .75098 m .58272 .84836 L .68645 .76898 L .757 .736 .833 r
F
.64819 .75098 m .55008 .8284 L .58272 .84836 L F
.79805 .85877 m .72848 1.02657 L .82402 .89209 L .496 .427 .709 r
F
.82402 .89209 m .72848 1.02657 L .75924 1.07026 L .376 .293 .634 r
F
.21233 .58089 m .27217 .53591 L .21569 .57267 L .754 .993 .811 r
F
0 g
.22525 .57374 m
.22593 .57363 L
s
.22593 .57363 m
.22849 .57321 L
s
.21569 .57267 m .27217 .53591 L .28143 .52561 L .644 .957 .768 r
F
0 g
.2602 .53828 m
.26261 .53908 L
s
.25857 .54197 m
.2602 .53828 L
s
.26992 .53599 m
.27856 .53395 L
s
.2602 .53828 m
.26546 .53704 L
s
.27856 .53395 m
.28764 .53181 L
s
1 Mabswid
.38037 1.22797 Mdot
.5 Mabswid
.35311 .9981 m
.38037 1.22797 L
s
.35215 .99 m
.35286 .99599 L
s
1 Mabswid
.38037 1.22797 Mdot
.38037 1.22797 Mdot
.5 Mabswid
.20225 .72494 m
.2029 .72466 L
s
1 Mabswid
.35215 .99 Mdot
.35215 .99 Mdot
.35215 .99 Mdot
.5 Mabswid
.40646 .89534 m
.4078 .893 L
s
.3921 .92037 m
.40646 .89534 L
s
.36312 .97088 m
.3921 .92037 L
s
.35436 .98615 m
.36312 .97088 L
s
.35424 .98637 m
.35436 .98615 L
s
.35215 .99 m
.35424 .98637 L
s
.19057 .63127 m .20769 .59884 L .20966 .58965 L .812 .831 .359 r
F
0 g
.20747 .5971 m
.2342 .60508 L
s
.20818 .59438 m
.22046 .58659 L
s
.50227 .86505 m
.50244 .865 L
s
.50244 .865 m
.52464 .85823 L
s
.49751 .8665 m
.50227 .86505 L
s
.43614 .88557 m
.43801 .88499 L
s
.49756 .86665 m
.51852 .86019 L
s
.51852 .86019 m
.5342 .85536 L
s
.5342 .85536 m
.53677 .85457 L
s
.53677 .85457 m
.54111 .85323 L
s
.49676 .83761 m
.5015 .839 L
s
.51555 .84315 m
.51697 .84356 L
s
.51697 .84356 m
.53711 .8495 L
s
.5015 .839 m
.51555 .84315 L
s
.55651 .85324 m
.72879 .87345 L
s
.72879 .87345 m
.72915 .87349 L
s
.55517 .85308 m
.55651 .85324 L
s
.55322 .85285 m
.55517 .85308 L
s
.61056 .81298 m
.61947 .80765 L
s
.56052 .84286 m
.60575 .81585 L
s
.60575 .81585 m
.61056 .81298 L
s
.31712 .809 m
.32509 .80887 L
s
.25724 .53994 m
.2602 .53828 L
s
.31712 .809 m
.32566 .80923 L
s
.25806 .7871 m
.25818 .78713 L
s
.25818 .78713 m
.26091 .78789 L
s
.26091 .78789 m
.26206 .78821 L
s
.30072 .79894 m
.30697 .80068 L
s
.30697 .80068 m
.3102 .80158 L
s
.25632 .78662 m
.25806 .7871 L
s
.19057 .63127 m .20966 .58965 L .21233 .58089 L .749 .811 .336 r
F
0 g
.20504 .59638 m
.20587 .59585 L
s
.20504 .59638 m
.20557 .59654 L
s
.20475 .59844 m
.20504 .59638 L
s
.35889 .96686 m
.382 .91584 L
s
.67442 .81636 m
.71663 .84966 L
s
.67107 .81372 m
.67442 .81636 L
s
.6589 .80411 m
.67107 .81372 L
s
.71663 .84966 m
.7173 .85019 L
s
.50216 .82934 m
.5069 .82812 L
s
.49993 .82991 m
.50216 .82934 L
s
.49875 .83021 m
.49993 .82991 L
s
.65456 .79069 m
.65539 .79052 L
s
.61365 .73979 m .55008 .8284 L .64819 .75098 L .81 .786 .831 r
F
0 g
.62056 .78505 m
.62708 .78714 L
s
.62888 .79673 m
.63473 .79523 L
s
.62208 .79848 m
.62888 .79673 L
s
.61365 .73979 m .52273 .81979 L .55008 .8284 L .81 .786 .831 r
F
0 g
.54276 .81889 m
.59794 .80469 L
s
.59794 .80469 m
.62208 .79848 L
s
.58565 .77384 m
.59675 .77741 L
s
.5069 .82812 m
.54276 .81889 L
s
.21969 .56506 m .28143 .52561 L .29252 .51668 L .508 .886 .695 r
F
.21569 .57267 m .28143 .52561 L .21969 .56506 L .644 .957 .768 r
F
0 g
.26963 .52968 m
.27231 .52724 L
s
.26405 .53477 m
.26963 .52968 L
s
.26073 .5378 m
.26405 .53477 L
s
.25101 .54345 m
.25724 .53994 L
s
.22665 .56455 m
.22812 .56341 L
s
1 Mabswid
.20504 .59638 Mdot
.20504 .59638 Mdot
.20504 .59638 Mdot
.20504 .59638 Mdot
.20504 .59638 Mdot
.19057 .63127 m .21233 .58089 L .21569 .57267 L .668 .769 .29 r
F
0 g
.5 Mabswid
.44688 .56032 m
.45172 .5672 L
s
.48229 .63456 m
.48255 .6369 L
s
.48255 .6369 m
.48375 .64819 L
s
1 Mabswid
.20225 .72494 Mdot
.20225 .72494 Mdot
.5 Mabswid
.24421 .7728 m
.25632 .78662 L
s
.22767 .75394 m
.24421 .7728 L
s
.22065 .74592 m
.22767 .75394 L
s
.20225 .72494 m
.20314 .72596 L
s
1 Mabswid
.20225 .72494 Mdot
.5 Mabswid
.19953 .72064 m
.20225 .72494 L
s
1 Mabswid
.20225 .72494 Mdot
.20225 .72494 Mdot
.5 Mabswid
.47251 .71923 m
.47365 .71658 L
s
.46894 .72747 m
.47251 .71923 L
s
.46796 .72974 m
.46894 .72747 L
s
1 Mabswid
.25632 .78662 Mdot
.25632 .78662 Mdot
.5 Mabswid
.28345 .7966 m
.29101 .79939 L
s
.27943 .79513 m
.28345 .7966 L
s
.26186 .78866 m
.26294 .78905 L
s
.29475 .80077 m
.31473 .80812 L
s
.31473 .80812 m
.31712 .809 L
s
.29101 .79939 m
.29475 .80077 L
s
.25632 .78662 m
.25853 .78743 L
s
.25853 .78743 m
.26186 .78866 L
s
1 Mabswid
.25632 .78662 Mdot
.5 Mabswid
.24665 .77726 m
.25293 .78333 L
s
.25293 .78333 m
.25345 .78383 L
s
.25345 .78383 m
.25632 .78662 L
s
1 Mabswid
.25632 .78662 Mdot
.25632 .78662 Mdot
.5 Mabswid
.22136 .746 m
.22834 .7541 L
s
.23591 .7629 m
.24139 .76927 L
s
.22834 .7541 m
.23591 .7629 L
s
.24139 .76927 m
.25632 .78662 L
s
.20269 .7243 m
.20288 .72453 L
s
.2024 .72397 m
.20269 .7243 L
s
.20189 .72337 m
.2024 .72397 L
s
.20185 .72333 m
.20189 .72337 L
s
.20151 .72293 m
.20185 .72333 L
s
.2015 .72292 m
.20151 .72293 L
s
.19953 .72064 m
.2015 .72292 L
s
1 Mabswid
.25632 .78662 Mdot
.5 Mabswid
.41394 .5032 m
.41671 .50856 L
s
.71336 .65848 m .68645 .76898 L .72606 .79405 L .553 .583 .839 r
F
.68122 .64493 m .68645 .76898 L .71336 .65848 L .625 .632 .838 r
F
.68122 .64493 m .64819 .75098 L .68645 .76898 L F
0 g
.68317 .73305 m
.68647 .72796 L
s
.65631 .77446 m
.66795 .75652 L
s
.64952 .63493 m .64819 .75098 L .68122 .64493 L .676 .661 .828 r
F
0 g
.66795 .75652 m
.68317 .73305 L
s
.64952 .63493 m .61365 .73979 L .64819 .75098 L .676 .661 .828 r
F
.634 1.22302 m .5174 1.32674 L .67083 1.23792 L .547 .222 .368 r
F
.634 1.22302 m .44196 1.29786 L .5174 1.32674 L F
0 g
.38037 1.22797 m
.44196 1.29786 L
s
.7799 1.09958 m .634 1.22302 L .67083 1.23792 L .277 .01 .317 r
F
.75924 1.07026 m .634 1.22302 L .7799 1.09958 L .511 .309 .542 r
F
.82402 .89209 m .75924 1.07026 L .83845 .92094 L .376 .293 .634 r
F
.83845 .92094 m .75924 1.07026 L .7799 1.09958 L .137 .043 .476 r
F
0 g
.64465 .95885 m
.80214 .97194 L
s
.76923 .90128 m
.80419 .94721 L
s
.74125 1.08132 m
.7804 1.03071 L
s
.5582 .71507 m
.5599 .67625 L
s
.55798 .72015 m
.5582 .71507 L
s
.44034 .88956 m
.44115 .88877 L
s
.44028 .88961 m
.44034 .88956 L
s
.43491 .89479 m
.43798 .89183 L
s
.43798 .89183 m
.44028 .88961 L
s
.43296 .89667 m
.43491 .89479 L
s
.42828 .90118 m
.43296 .89667 L
s
.48866 .84298 m
.50792 .82441 L
s
.50792 .82441 m
.5168 .81585 L
s
.5168 .81585 m
.52535 .80762 L
s
.52535 .80762 m
.52653 .80647 L
s
.52653 .80647 m
.52863 .80445 L
s
.52863 .80445 m
.54397 .78967 L
s
.54397 .78967 m
.55267 .78128 L
s
.74389 .67558 m .72606 .79405 L .76428 .82487 L .452 .508 .826 r
F
.71336 .65848 m .72606 .79405 L .74389 .67558 L .553 .583 .839 r
F
.21969 .56506 m .29252 .51668 L .22426 .55813 L .508 .886 .695 r
F
.22426 .55813 m .29252 .51668 L .30513 .50911 L 0 0 0 r
F
0 g
.27231 .52724 m
.27575 .52411 L
s
.29089 .51562 m
.29231 .51597 L
s
.29231 .51597 m
.29333 .51622 L
s
.29338 .51623 m
.29965 .51777 L
s
.58045 .73787 m
.58605 .72307 L
s
.58605 .72307 m
.58776 .71856 L
s
.57899 .74173 m
.57991 .73928 L
s
.5428 .78736 m
.55725 .7726 L
s
.54191 .78827 m
.5428 .78736 L
s
.19057 .63127 m .21569 .57267 L .21969 .56506 L 0 0 0 r
F
0 g
.21668 .57237 m
.22665 .56455 L
s
.2122 .57588 m
.21447 .5755 L
s
.21447 .5755 m
.21451 .5755 L
s
.21514 .57539 m
.22525 .57374 L
s
.2122 .57588 m
.21531 .57344 L
s
.21531 .57344 m
.21574 .5731 L
s
.21637 .57261 m
.21668 .57237 L
s
.21006 .58199 m
.2122 .57588 L
s
.20725 .59005 m
.21006 .58199 L
s
.20504 .59638 m
.20725 .59005 L
s
.61981 .62787 m .61365 .73979 L .64952 .63493 L .711 .673 .811 r
F
0 g
.48153 .82377 m
.49258 .81544 L
s
.49258 .81544 m
.51074 .80174 L
s
.51074 .80174 m
.52343 .79217 L
s
.52343 .79217 m
.52866 .78822 L
s
.52866 .78822 m
.53818 .78104 L
s
.58207 .7554 m
.63135 .7342 L
s
.63135 .7342 m
.66308 .72055 L
s
.66308 .72055 m
.67821 .71404 L
s
.67821 .71404 m
.68432 .71141 L
s
.68432 .71141 m
.68825 .70972 L
s
.57605 .75799 m
.58207 .7554 L
s
.56709 .76184 m
.57605 .75799 L
s
.56598 .76232 m
.56709 .76184 L
s
.57875 .73315 m
.5944 .70762 L
s
.57329 .74207 m
.57875 .73315 L
s
.5944 .70762 m
.59613 .7048 L
s
.57137 .7452 m
.57329 .74207 L
s
.41759 .7844 m
.42042 .78232 L
s
.4128 .78792 m
.41759 .7844 L
s
.39889 .50476 m
.41394 .5032 L
s
.32251 .51164 m
.32314 .51159 L
s
.32314 .51159 m
.32865 .51115 L
s
.41899 .50905 m
.43261 .50921 L
s
1 Mabswid
.2122 .57588 Mdot
.2122 .57588 Mdot
.2122 .57588 Mdot
.2122 .57588 Mdot
.2122 .57588 Mdot
.5 Mabswid
.50466 .70231 m
.50881 .67828 L
s
.50412 .70545 m
.50466 .70231 L
s
.50881 .67828 m
.50906 .6768 L
s
.50378 .70739 m
.50412 .70545 L
s
.50286 .71275 m
.50378 .70739 L
s
.52327 .61986 m
.52622 .61161 L
s
.52165 .62441 m
.52327 .61986 L
s
.52622 .61161 m
.52699 .60945 L
s
.4996 .59851 m
.50479 .61394 L
s
.49751 .59229 m
.4996 .59851 L
s
.49446 .58325 m
.49751 .59229 L
s
.49428 .5827 m
.49446 .58325 L
s
.49423 .58255 m
.49428 .5827 L
s
.49422 .58252 m
.49423 .58255 L
s
.77033 .69564 m .76428 .82487 L .79805 .85877 L .305 .392 .788 r
F
.74389 .67558 m .76428 .82487 L .77033 .69564 L .452 .508 .826 r
F
0 g
.65539 .79052 m
.76913 .76759 L
s
.76913 .76759 m
.7692 .76758 L
s
.4078 .893 m
.41513 .89091 L
s
.43614 .88557 m
.4374 .88516 L
s
.50063 .74821 m
.50244 .74334 L
s
.49492 .76359 m
.49764 .75627 L
s
.49764 .75627 m
.50063 .74821 L
s
.50244 .74334 m
.50975 .72361 L
s
.50975 .72361 m
.51199 .71758 L
s
.48455 .79156 m
.49492 .76359 L
s
.48021 .80324 m
.48455 .79156 L
s
.47492 .81751 m
.47857 .80767 L
s
.47857 .80767 m
.48021 .80324 L
s
.47408 .81976 m
.47421 .81941 L
s
.19057 .63127 m .21969 .56506 L .22426 .55813 L 0 0 0 r
F
0 g
.46537 .78804 m
.46609 .78691 L
s
.46118 .79462 m
.46537 .78804 L
s
.4608 .79522 m
.46118 .79462 L
s
.46609 .78691 m
.46854 .78306 L
s
.46854 .78306 m
.47612 .77117 L
s
.47612 .77117 m
.47663 .77037 L
s
.51476 .71486 m
.52621 .70005 L
s
.47895 .81575 m
.48039 .81362 L
s
.48039 .81362 m
.4861 .80521 L
s
.4861 .80521 m
.4888 .80123 L
s
.47333 .82403 m
.47895 .81575 L
s
.47294 .82461 m
.47333 .82403 L
s
.57626 .70853 m
.58396 .70186 L
s
.58396 .70186 m
.59602 .69143 L
s
.59602 .69143 m
.59786 .68984 L
s
.53303 .74594 m
.5513 .73013 L
s
.5513 .73013 m
.5675 .71611 L
s
.5675 .71611 m
.57626 .70853 L
s
.52968 .74884 m
.53303 .74594 L
s
.52966 .74886 m
.52968 .74884 L
s
.52797 .73091 m
.53844 .7038 L
s
.53844 .7038 m
.54409 .68917 L
s
.31712 .809 m
.3241 .80831 L
s
.22426 .55813 m .30513 .50911 L .22932 .55193 L 0 0 0 r
F
.22932 .55193 m .30513 .50911 L .31894 .50286 L F
0 g
.2996 .51345 m
.32251 .51164 L
s
.2863 .51449 m
.2971 .51364 L
s
.2863 .51449 m
.29089 .51562 L
s
.27577 .52409 m
.28552 .5152 L
s
.27575 .52411 m
.27577 .52409 L
s
.28552 .5152 m
.2863 .51449 L
s
.23123 .55459 m
.23323 .55347 L
s
.23323 .55347 m
.23494 .5525 L
s
.57233 .63542 m
.57318 .63409 L
s
.52667 .70591 m
.53395 .67385 L
s
.53395 .67385 m
.53435 .67211 L
s
.53435 .67211 m
.53666 .66193 L
s
.5171 .74798 m
.52667 .70591 L
s
.51583 .75359 m
.5171 .74798 L
s
.47623 .83824 m
.48157 .83124 L
s
.43991 .88591 m
.43993 .88589 L
s
.43993 .88589 m
.44019 .88555 L
s
.43584 .89126 m
.43627 .8907 L
s
.43627 .8907 m
.43991 .88591 L
s
.43507 .89226 m
.43584 .89126 L
s
.43228 .89593 m
.43507 .89226 L
s
.42828 .90118 m
.43228 .89593 L
s
.48157 .83124 m
.48805 .82274 L
s
.48805 .82274 m
.49012 .82001 L
s
.49012 .82001 m
.49307 .81614 L
s
.49307 .81614 m
.49387 .81509 L
s
.49387 .81509 m
.49887 .80853 L
s
.44047 .9141 m
.44237 .91075 L
s
.44036 .9143 m
.44047 .9141 L
s
.43933 .9161 m
.44036 .9143 L
s
.43883 .91699 m
.43912 .91647 L
s
.48405 .83744 m
.49107 .82509 L
s
.49107 .82509 m
.49667 .81524 L
s
.49667 .81524 m
.49803 .81285 L
s
.49803 .81285 m
.50126 .80717 L
s
1 Mabswid
.19953 .72064 Mdot
.19953 .72064 Mdot
.5 Mabswid
.21165 .73529 m
.21578 .74028 L
s
.20257 .7243 m
.20291 .72471 L
s
.2022 .72386 m
.20257 .7243 L
s
.20197 .72358 m
.2022 .72386 L
s
.20151 .72302 m
.20197 .72358 L
s
.20148 .72298 m
.20151 .72302 L
s
.20118 .72263 m
.20148 .72298 L
s
.20117 .72262 m
.20118 .72263 L
s
.19953 .72064 m
.20117 .72262 L
s
1 Mabswid
.19953 .72064 Mdot
.5 Mabswid
.19912 .71522 m
.19914 .71548 L
s
.19914 .71548 m
.19924 .71671 L
s
.19924 .71671 m
.19924 .71674 L
s
.19924 .71674 m
.19929 .7174 L
s
.19929 .7174 m
.19929 .71741 L
s
.19929 .71741 m
.19953 .72064 L
s
1 Mabswid
.19953 .72064 Mdot
.19953 .72064 Mdot
.5 Mabswid
.382 .91584 m
.40234 .89416 L
s
1 Mabswid
.2863 .51449 Mdot
.2863 .51449 Mdot
.2863 .51449 Mdot
.2863 .51449 Mdot
.2863 .51449 Mdot
.5 Mabswid
.2492 .5407 m
.2863 .51449 L
s
1 Mabswid
.2863 .51449 Mdot
.5 Mabswid
.46109 .81209 m
.46859 .79562 L
s
.46009 .8143 m
.46109 .81209 L
s
.45838 .81804 m
.46009 .8143 L
s
.46859 .79562 m
.46976 .79303 L
s
.46043 .78392 m
.46701 .77822 L
s
.45791 .7861 m
.46043 .78392 L
s
.46701 .77822 m
.46898 .77651 L
s
.62624 .66271 m
.63038 .65828 L
s
.62468 .66438 m
.62624 .66271 L
s
.61892 .67054 m
.62468 .66438 L
s
.61145 .6447 m
.6117 .64815 L
s
.19057 .63127 m .22426 .55813 L .22932 .55193 L 0 0 0 r
F
0 g
.22528 .55794 m
.22587 .55761 L
s
.22679 .55709 m
.23123 .55459 L
s
.21781 .56712 m
.22033 .56319 L
s
.2122 .57588 m
.21781 .56712 L
s
.43098 .51606 m
.43241 .51714 L
s
.42994 .51528 m
.43098 .51606 L
s
.43241 .51714 m
.45065 .5309 L
s
.41394 .5032 m
.42274 .50984 L
s
.43841 .88314 m
.43916 .88234 L
s
.43818 .88338 m
.43841 .88314 L
s
.43614 .88557 m
.43818 .88338 L
s
.78999 .71749 m .79805 .85877 L .82402 .89209 L .064 .199 .695 r
F
.77033 .69564 m .79805 .85877 L .78999 .71749 L .305 .392 .788 r
F
0 g
.77594 .80667 m
.77618 .80602 L
s
.7587 .85256 m
.77594 .80667 L
s
1 Mabswid
.31712 .809 Mdot
.5 Mabswid
.34333 .818 m
.37795 .82989 L
s
.34271 .81779 m
.34333 .818 L
s
.33335 .81457 m
.34271 .81779 L
s
.33195 .81409 m
.33335 .81457 L
s
.32133 .81045 m
.33195 .81409 L
s
.31712 .809 m
.32133 .81045 L
s
.3774 .82368 m
.38223 .82486 L
s
.36536 .82075 m
.37375 .8228 L
s
.36514 .8207 m
.36536 .82075 L
s
.35725 .81878 m
.36145 .8198 L
s
.35359 .81788 m
.35725 .81878 L
s
.35077 .8172 m
.35359 .81788 L
s
.34435 .81563 m
.35077 .8172 L
s
.33829 .81416 m
.34435 .81563 L
s
.33414 .81315 m
.33829 .81416 L
s
.33287 .81284 m
.33414 .81315 L
s
.33122 .81244 m
.33287 .81284 L
s
.31901 .80946 m
.33122 .81244 L
s
.31712 .809 m
.31901 .80946 L
s
1 Mabswid
.31712 .809 Mdot
.31712 .809 Mdot
.31712 .809 Mdot
.31712 .809 Mdot
.5 Mabswid
.34115 .81366 m
.3487 .81512 L
s
.33751 .81295 m
.34115 .81366 L
s
.32836 .81118 m
.32905 .81131 L
s
.33701 .81285 m
.33751 .81295 L
s
.33537 .81254 m
.33701 .81285 L
s
.31712 .809 m
.32836 .81118 L
s
1 Mabswid
.31712 .809 Mdot
.5 Mabswid
.30455 .80171 m
.30552 .80227 L
s
.30552 .80227 m
.30955 .80461 L
s
.30955 .80461 m
.31016 .80496 L
s
.31016 .80496 m
.31277 .80648 L
s
.31277 .80648 m
.31609 .8084 L
s
.31609 .8084 m
.31618 .80845 L
s
.31618 .80845 m
.31712 .809 L
s
1 Mabswid
.31712 .809 Mdot
.31712 .809 Mdot
.5 Mabswid
.28461 .79404 m
.30156 .80184 L
s
.30156 .80184 m
.31467 .80787 L
s
.31467 .80787 m
.31712 .809 L
s
1 Mabswid
.31712 .809 Mdot
.5 Mabswid
.31556 .80609 m
.31567 .8063 L
s
.31567 .8063 m
.31574 .80643 L
s
.31574 .80643 m
.31622 .80733 L
s
.31622 .80733 m
.31692 .80862 L
s
.31692 .80862 m
.31712 .809 L
s
.22932 .55193 m .31894 .50286 L .23475 .54651 L 0 0 0 r
F
0 g
.24299 .54508 m
.24704 .54222 L
s
.19057 .63127 m .22932 .55193 L .23475 .54651 L 0 0 .033 r
F
0 g
.23114 .55345 m
.24299 .54508 L
s
.22033 .56319 m
.22279 .55934 L
s
.22279 .55934 m
.22528 .55794 L
s
.22558 .55738 m
.22722 .55622 L
s
.22279 .55934 m
.22558 .55738 L
s
.70639 .697 m
.70658 .6967 L
s
.69462 .66916 m
.69629 .67677 L
s
.23475 .54651 m .31894 .50286 L .33363 .49787 L 0 0 0 r
F
0 g
.2863 .51449 m
.2966 .50987 L
s
.26524 .5283 m
.2863 .51449 L
s
1 Mabswid
.22279 .55934 Mdot
.22279 .55934 Mdot
.22279 .55934 Mdot
.22279 .55934 Mdot
.22279 .55934 Mdot
.19057 .63127 m .20267 .72012 L .20292 .72478 L 0 0 .15 r
F
0 g
.5 Mabswid
.199 .71357 m
.19912 .71522 L
s
.19895 .71295 m
.199 .71357 L
s
.53989 .52837 m .59294 .62276 L .61981 .62787 L .564 .633 .878 r
F
0 g
.58652 .61696 m
.58985 .62951 L
s
.58616 .61562 m
.58652 .61696 L
s
.57318 .63409 m
.57917 .62476 L
s
.5599 .67625 m
.56203 .62744 L
s
.20301 .71463 m .26156 .78774 L .20267 .72012 L 0 0 .528 r
F
0 g
.24528 .77594 m
.25093 .77854 L
s
.25093 .77854 m
.2553 .78055 L
s
.25796 .78178 m
.25826 .78191 L
s
.22596 .75258 m
.24528 .77594 L
s
.21578 .74028 m
.22596 .75258 L
s
.24528 .77594 m
.24665 .77726 L
s
1 Mabswid
.24528 .77594 Mdot
.24528 .77594 Mdot
.5 Mabswid
.25436 .77988 m
.25675 .78093 L
s
.24528 .77594 m
.25436 .77988 L
s
.29663 .79826 m
.30455 .80171 L
s
.27459 .78868 m
.29663 .79826 L
s
.26568 .78481 m
.27459 .78868 L
s
.25755 .78127 m
.25818 .78155 L
s
1 Mabswid
.24528 .77594 Mdot
.24528 .77594 Mdot
.24528 .77594 Mdot
.5 Mabswid
.21808 .73781 m
.24528 .77594 L
s
1 Mabswid
.24528 .77594 Mdot
.23475 .54651 m .33363 .49787 L .24045 .54193 L 0 0 0 r
F
.19057 .63127 m .23475 .54651 L .24045 .54193 L 0 0 .113 r
F
.19057 .63127 m .27625 .56787 L .27266 .57617 L .022 0 .223 r
F
.19057 .63127 m .27882 .56031 L .27625 .56787 L .027 0 .231 r
F
.19057 .63127 m .28033 .55356 L .27882 .56031 L .037 0 .247 r
F
.19057 .63127 m .28074 .54769 L .28033 .55356 L .051 0 .267 r
F
.19057 .63127 m .28006 .54274 L .28074 .54769 L .067 0 .288 r
F
0 g
.5 Mabswid
.22279 .55934 m
.2248 .55751 L
s
.19057 .63127 m .27835 .53875 L .28006 .54274 L .082 0 .308 r
F
.19057 .63127 m .27568 .53573 L .27835 .53875 L .095 0 .323 r
F
.19057 .63127 m .27215 .5337 L .27568 .53573 L .103 0 .332 r
F
.19057 .63127 m .26789 .53267 L .27215 .5337 L .105 0 .334 r
F
.19057 .63127 m .26302 .53262 L .26789 .53267 L .097 0 .326 r
F
.24045 .54193 m .33363 .49787 L .3489 .49409 L .031 0 0 r
F
.24045 .54193 m .3489 .49409 L .24626 .53822 L F
.3489 .49409 m .47302 .52057 L .36447 .4915 L .182 .659 .931 r
F
.26773 .52974 m .3489 .49409 L .36447 .4915 L .126 0 0 r
F
.24626 .53822 m .25812 .53313 L .26773 .52974 L F
.25812 .53313 m .3489 .49409 L .26773 .52974 L F
.24626 .53822 m .36447 .4915 L .25206 .53542 L F
.25206 .53542 m .34401 .50285 L .2577 .53354 L .205 0 0 r
F
.36447 .4915 m .47302 .52057 L .49473 .52263 L .198 .66 .942 r
F
.36447 .4915 m .49473 .52263 L .38004 .49009 L F
.34401 .50285 m .38004 .49009 L .35722 .49819 L .205 0 0 r
F
.34401 .50285 m .35722 .49819 L .2577 .53354 L F
.19057 .63127 m .2577 .53354 L .26302 .53262 L .079 0 .308 r
F
0 g
.25854 .53269 m
.26524 .5283 L
s
.2578 .53318 m
.25854 .53269 L
s
.19057 .63127 m .25206 .53542 L .2577 .53354 L .048 0 .278 r
F
0 g
.25646 .54514 m
.25844 .54255 L
s
.2248 .55751 m
.22631 .55614 L
s
.19057 .63127 m .24626 .53822 L .25206 .53542 L .003 0 .236 r
F
.19057 .63127 m .24045 .54193 L .24626 .53822 L 0 0 .181 r
F
0 g
.23966 .54507 m
.23985 .54494 L
s
.24455 .54755 m
.24807 .54209 L
s
.22767 .5549 m
.22866 .554 L
s
.22866 .554 m
.2295 .55323 L
s
.22631 .55614 m
.22767 .5549 L
s
.2295 .55323 m
.22968 .55307 L
s
.23075 .5521 m
.23088 .55198 L
s
.23088 .55198 m
.23543 .54784 L
s
.23017 .55262 m
.23075 .5521 L
s
.22968 .55307 m
.23017 .55262 L
s
.23825 .54599 m
.23877 .54565 L
s
.23794 .54619 m
.23825 .54599 L
s
.23745 .54651 m
.2375 .54648 L
s
.23543 .54784 m
.23745 .54651 L
s
.2375 .54648 m
.23772 .54633 L
s
.23772 .54633 m
.23794 .54619 L
s
.23877 .54565 m
.23891 .54556 L
s
.23951 .54516 m
.23966 .54507 L
s
.23891 .54556 m
.23951 .54516 L
s
.19057 .63127 m .20301 .71463 L .20267 .72012 L 0 0 .24 r
F
.19057 .63127 m .204 .70835 L .20301 .71463 L 0 0 .318 r
F
0 g
.19878 .71076 m
.19895 .71295 L
s
.20133 .71432 m
.20202 .71529 L
s
.20017 .71271 m
.20117 .7141 L
s
.20117 .7141 m
.20133 .71432 L
s
.1988 .71078 m
.20017 .71271 L
s
.19878 .71076 m
.1988 .71078 L
s
.19057 .63127 m .20571 .7013 L .204 .70835 L 0 0 .38 r
F
.19057 .63127 m .20818 .69352 L .20571 .7013 L 0 0 .423 r
F
.19057 .63127 m .21144 .68508 L .20818 .69352 L 0 0 .447 r
F
.19057 .63127 m .21547 .67604 L .21144 .68508 L 0 0 .455 r
F
.19057 .63127 m .22022 .6665 L .21547 .67604 L 0 0 .449 r
F
.19057 .63127 m .22561 .65653 L .22022 .6665 L .021 0 .434 r
F
.19057 .63127 m .23152 .64626 L .22561 .65653 L .044 0 .409 r
F
.19057 .63127 m .23781 .63581 L .23152 .64626 L .056 0 .38 r
F
.19057 .63127 m .24429 .62529 L .23781 .63581 L .058 0 .346 r
F
.19057 .63127 m .25077 .61483 L .24429 .62529 L .054 0 .312 r
F
.19057 .63127 m .25704 .60457 L .25077 .61483 L .046 0 .281 r
F
.19057 .63127 m .2629 .59463 L .25704 .60457 L .036 0 .254 r
F
.19057 .63127 m .26817 .58512 L .2629 .59463 L .028 0 .234 r
F
.19057 .63127 m .27266 .57617 L .26817 .58512 L .023 0 .224 r
F
0 g
.19057 .63127 m
.2122 .57588 L
s
.19057 .63127 m
.20504 .59638 L
s
.19057 .63127 m
.20225 .72494 L
s
.19057 .63127 m
.19953 .72064 L
s
.19057 .63127 m
.22279 .55934 L
s
1 Mabswid
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.2645 .56234 L
s
1 Mabswid
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.26441 .54938 L
s
1 Mabswid
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.25646 .54514 L
s
1 Mabswid
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.24455 .54755 L
s
1 Mabswid
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.23543 .54784 L
s
1 Mabswid
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.19878 .71076 L
s
1 Mabswid
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.20142 .69563 L
s
1 Mabswid
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.20832 .67591 L
s
1 Mabswid
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.21936 .65275 L
s
1 Mabswid
.19057 .63127 Mdot
.5 Mabswid
.19057 .63127 m
.23313 .62782 L
s
1 Mabswid
.19057 .63127 Mdot
.19057 .63127 Mdot
.56302 .53268 m .61981 .62787 L .64952 .63493 L .528 .63 .895 r
F
.53989 .52837 m .61981 .62787 L .56302 .53268 L .564 .633 .878 r
F
0 g
.5 Mabswid
.56338 .59662 m
.5634 .59604 L
s
.56344 .59507 m
.56356 .59243 L
s
.5634 .59604 m
.56344 .59507 L
s
.56203 .62744 m
.56338 .59662 L
s
.42097 .82831 m
.42347 .82666 L
s
.44231 .90736 m
.44362 .90374 L
s
.44362 .90374 m
.44475 .90061 L
s
.44475 .90061 m
.44558 .89833 L
s
.44026 .91304 m
.44231 .90736 L
s
.43988 .91408 m
.44026 .91304 L
s
.43917 .91604 m
.43988 .91408 L
s
.43883 .91699 m
.43905 .91637 L
s
.45454 .9231 m
.45467 .92235 L
s
.46883 .839 m
.46895 .83833 L
s
.41683 .84295 m
.42054 .83525 L
s
.39591 .81476 m
.40554 .81269 L
s
.39487 .81499 m
.39591 .81476 L
s
.46677 .5216 m
.47049 .52295 L
s
.46274 .52013 m
.46677 .5216 L
s
.45878 .5187 m
.46274 .52013 L
s
.47049 .52295 m
.47379 .52414 L
s
1 Mabswid
.19878 .71076 Mdot
.19878 .71076 Mdot
.5 Mabswid
.19878 .71076 m
.20159 .7137 L
s
.20159 .7137 m
.20225 .7144 L
s
.2062 .71854 m
.20944 .72193 L
s
1 Mabswid
.19878 .71076 Mdot
.5 Mabswid
.2 .70378 m
.20142 .69563 L
s
.19878 .71076 m
.2 .70378 L
s
1 Mabswid
.19878 .71076 Mdot
.19878 .71076 Mdot
.5 Mabswid
.42703 .50342 m
.44144 .50366 L
s
.32577 .49968 m
.3323 .49994 L
s
.3323 .49994 m
.33382 .5 L
s
.34442 .50042 m
.34916 .50061 L
s
.34916 .50061 m
.35021 .50066 L
s
.35028 .50066 m
.36797 .50137 L
s
.34212 .50033 m
.34442 .50042 L
s
.36797 .50137 m
.36895 .50141 L
s
.31981 .49944 m
.32577 .49968 L
s
.53655 .55463 m
.53693 .55588 L
s
.49968 .53238 m
.51344 .54476 L
s
.51344 .54476 m
.51612 .54718 L
s
.43648 .88868 m
.43748 .88715 L
s
.42829 .90116 m
.43648 .88868 L
s
.7799 1.09958 m .67083 1.23792 L .78333 1.10948 L .277 .01 .317 r
F
.83743 .942 m .7799 1.09958 L .78333 1.10948 L 0 0 0 r
F
.83845 .92094 m .7799 1.09958 L .83743 .942 L .137 .043 .476 r
F
0 g
.30169 .50758 m
.31056 .5036 L
s
.2966 .50987 m
.30169 .50758 L
s
.31056 .5036 m
.31981 .49944 L
s
.31981 .49944 m
.32604 .50071 L
s
.32604 .50071 m
.32637 .50078 L
s
.32637 .50078 m
.32784 .50108 L
s
.336 .50275 m
.33892 .50335 L
s
.58591 .53848 m .64952 .63493 L .68122 .64493 L .46 .61 .912 r
F
.56302 .53268 m .64952 .63493 L .58591 .53848 L .528 .63 .895 r
F
0 g
.60886 .60841 m
.61145 .6447 L
s
.60882 .60781 m
.60886 .60841 L
s
.59328 .6028 m
.59619 .59828 L
s
.57917 .62476 m
.59328 .6028 L
s
.78999 .71749 m .82402 .89209 L .80346 .76068 L .064 .199 .695 r
F
.80017 .73965 m .82402 .89209 L .83845 .92094 L 0 0 .448 r
F
.79844 .76062 m .83509 .90748 L .83743 .942 L .856 .6 .063 r
F
.83509 .90748 m .83845 .92094 L .83836 .92269 L F
.83509 .90748 m .83836 .92269 L .83743 .942 L F
.79783 .73456 m .80346 .76068 L .80017 .73965 L .064 .199 .695 r
F
.78999 .71749 m .80346 .76068 L .79783 .73456 L F
.204 .70835 m .25834 .78223 L .20301 .71463 L 0 .08 .631 r
F
0 g
.24507 .77434 m
.24528 .77594 L
s
.204 .70835 m .25675 .77541 L .25834 .78223 L 0 .08 .631 r
F
0 g
.24434 .76885 m
.24507 .77434 L
s
1 Mabswid
.23543 .54784 Mdot
.5 Mabswid
.23543 .54784 m
.23848 .54609 L
s
.23848 .54609 m
.23856 .54604 L
s
.23856 .54604 m
.23888 .54586 L
s
.23888 .54586 m
.2392 .54567 L
s
.2392 .54567 m
.23962 .54543 L
s
.23962 .54543 m
.2404 .54498 L
s
.2404 .54498 m
.24049 .54494 L
s
.24049 .54494 m
.24119 .54453 L
s
.24119 .54453 m
.24142 .5444 L
s
.2615 .53288 m
.26347 .53175 L
s
.26347 .53175 m
.26467 .53106 L
s
.26519 .53077 m
.26533 .53069 L
s
.27716 .5239 m
.31981 .49944 L
s
.26994 .52804 m
.27716 .5239 L
s
.23543 .54784 m
.24807 .54209 L
s
1 Mabswid
.23543 .54784 Mdot
.23543 .54784 Mdot
.23543 .54784 Mdot
.23543 .54784 Mdot
.58591 .53848 m .68122 .64493 L .60778 .54611 L .46 .61 .912 r
F
0 g
.5 Mabswid
.59619 .59828 m
.59748 .59627 L
s
.60778 .54611 m .68122 .64493 L .71336 .65848 L .34 .56 .918 r
F
.67083 1.23792 m .5174 1.32674 L .58102 1.30335 L 0 0 0 r
F
.67083 1.23792 m .58102 1.30335 L .68599 1.21767 L F
0 g
.66319 1.23958 m
.67171 1.23993 L
s
.38037 1.22797 m
.65934 1.23942 L
s
.57226 1.18839 m
.66376 1.23581 L
s
.44196 1.29786 m
.5174 1.32674 L
s
.38037 1.22797 m
.55436 1.31292 L
s
.55463 1.31305 m
.56292 1.3171 L
s
.78333 1.10948 m .67083 1.23792 L .68599 1.21767 L .58 .856 .522 r
F
0 g
.66876 1.2384 m
.67171 1.23993 L
s
.66655 1.23726 m
.66876 1.2384 L
s
1 Mabswid
.31981 .49944 Mdot
.31981 .49944 Mdot
.31981 .49944 Mdot
.31981 .49944 Mdot
.5 Mabswid
.24807 .54209 m
.25389 .53863 L
s
.25389 .53863 m
.25393 .53861 L
s
.25393 .53861 m
.25405 .53854 L
s
.25405 .53854 m
.25424 .53842 L
s
.25424 .53842 m
.25425 .53842 L
s
.28262 .52155 m
.31981 .49944 L
s
1 Mabswid
.31981 .49944 Mdot
.31981 .49944 Mdot
.5 Mabswid
.40234 .89416 m
.4171 .8981 L
s
.38612 .49164 m .49473 .52263 L .51704 .52514 L .185 .65 .938 r
F
.38576 .49171 m .49473 .52263 L .38612 .49164 L F
.38004 .49009 m .51704 .52514 L .39534 .48988 L F
.2577 .53354 m .39437 .49019 L .26302 .53262 L .272 0 0 r
F
.39437 .49019 m .39534 .48988 L .39441 .49018 L F
.39437 .49019 m .39441 .49018 L .26302 .53262 L F
.38004 .49009 m .38576 .49171 L .38612 .49164 L .185 .65 .938 r
F
0 g
.47278 .51784 m
.47923 .5375 L
s
.47264 .51741 m
.47265 .51745 L
s
.47272 .51765 m
.47278 .51784 L
s
.47265 .51745 m
.47272 .51765 L
s
.47811 .51296 m
.47959 .51429 L
s
.48394 .51821 m
.48415 .5184 L
s
.48433 .51855 m
.48453 .51874 L
s
.48415 .5184 m
.48433 .51855 L
s
.48453 .51874 m
.49968 .53238 L
s
.38659 .49842 m
.38699 .49849 L
s
.20571 .7013 m .25675 .77541 L .204 .70835 L 0 .166 .705 r
F
0 g
.21157 .72416 m
.21841 .73134 L
s
.24352 .76275 m
.24388 .7654 L
s
.24388 .7654 m
.24434 .76885 L
s
.5987 .56935 m
.5988 .5695 L
s
.5988 .5695 m
.599 .56979 L
s
.599 .56979 m
.60033 .57175 L
s
.57501 .55475 m
.57578 .5554 L
s
.57578 .5554 m
.57634 .55586 L
s
.62753 .5558 m .71336 .65848 L .74389 .67558 L .134 .453 .884 r
F
.60778 .54611 m .71336 .65848 L .62753 .5558 L .34 .56 .918 r
F
0 g
.68651 .63208 m
.688 .6389 L
s
.688 .6389 m
.69462 .66916 L
s
.63038 .65828 m
.6658 .62039 L
s
.37004 .82566 m
.37029 .8251 L
s
.37029 .8251 m
.37045 .82474 L
s
.37045 .82474 m
.37051 .82461 L
s
.30616 .80213 m
.31015 .80319 L
s
.31015 .80319 m
.31961 .8057 L
s
.30455 .80171 m
.30616 .80213 L
s
1 Mabswid
.20142 .69563 Mdot
.5 Mabswid
.20142 .69563 m
.20402 .69948 L
s
.20402 .69948 m
.20439 .70003 L
s
1 Mabswid
.20142 .69563 Mdot
.5 Mabswid
.20142 .69563 m
.20476 .69772 L
s
.20476 .69772 m
.20481 .69775 L
s
1 Mabswid
.20142 .69563 Mdot
.5 Mabswid
.20347 .68978 m
.206 .68253 L
s
.20142 .69563 m
.20347 .68978 L
s
.20608 .6823 m
.20832 .67591 L
s
.206 .68253 m
.20608 .6823 L
s
1 Mabswid
.20142 .69563 Mdot
.20142 .69563 Mdot
.25206 .53542 m .36447 .4915 L .38004 .49009 L .205 0 0 r
F
0 g
.5 Mabswid
.37512 .49641 m
.38659 .49842 L
s
.37162 .4958 m
.37489 .49637 L
s
.26399 .53263 m
.26517 .53193 L
s
.26789 .53031 m
.2695 .52935 L
s
.27338 .52704 m
.28262 .52155 L
s
.27096 .52848 m
.27338 .52704 L
s
.26995 .52908 m
.27096 .52848 L
s
.31981 .49944 m
.33992 .4958 L
s
.39534 .48988 m .51704 .52514 L .53989 .52837 L .132 .621 .914 r
F
0 g
.44745 .50376 m
.46827 .5041 L
s
.46827 .5041 m
.47648 .51149 L
s
.46827 .5041 m
.47014 .5098 L
s
.20571 .7013 m .25718 .76715 L .25675 .77541 L 0 .166 .705 r
F
0 g
.4534 .91535 m
.45363 .91692 L
s
.45285 .9116 m
.4534 .91535 L
s
.45439 .92209 m
.45454 .9231 L
s
.46596 .90795 m
.4661 .90831 L
s
1 Mabswid
.4078 .893 Mdot
.4078 .893 Mdot
.4078 .893 Mdot
.5 Mabswid
.4078 .893 m
.41009 .89575 L
s
.44413 .93647 m
.44586 .93854 L
s
.44381 .93609 m
.44413 .93647 L
s
.43253 .92259 m
.43283 .92295 L
s
.41724 .9043 m
.43253 .92259 L
s
.43283 .92295 m
.44381 .93609 L
s
.41061 .89637 m
.41724 .9043 L
s
.20818 .69352 m .25718 .76715 L .20571 .7013 L .004 .235 .744 r
F
0 g
.23233 .74593 m
.24273 .75683 L
s
.21841 .73134 m
.23233 .74593 L
s
.24273 .75683 m
.24306 .75929 L
s
.24306 .75929 m
.24352 .76275 L
s
.23248 .74164 m
.24273 .75683 L
s
.22387 .7289 m
.23248 .74164 L
s
.21436 .71481 m
.22387 .7289 L
s
1 Mabswid
.46827 .5041 Mdot
.46827 .5041 Mdot
.46827 .5041 Mdot
.46827 .5041 Mdot
.46827 .5041 Mdot
.5 Mabswid
.43724 .50104 m
.46827 .5041 L
s
1 Mabswid
.46827 .5041 Mdot
.24807 .54209 Mdot
.5 Mabswid
.24807 .54209 m
.25535 .53876 L
s
.25535 .53876 m
.2554 .53874 L
s
.2554 .53874 m
.25552 .53868 L
s
.25552 .53868 m
.25568 .53861 L
s
.24807 .54209 m
.25844 .54255 L
s
1 Mabswid
.24807 .54209 Mdot
.24807 .54209 Mdot
.24807 .54209 Mdot
.24807 .54209 Mdot
.2577 .53354 m .38004 .49009 L .39534 .48988 L .272 0 0 r
F
0 g
.5 Mabswid
.26841 .53279 m
.28268 .52627 L
s
.28719 .52421 m
.2979 .51931 L
s
.36502 .49464 m
.36533 .4947 L
s
.36533 .4947 m
.36584 .49479 L
s
.64388 .56759 m .74389 .67558 L .77033 .69564 L 0 .24 .739 r
F
.62753 .5558 m .74389 .67558 L .65037 .57459 L .134 .453 .884 r
F
.65541 .58135 m .75599 .68138 L .78999 .71749 L .58 .075 0 r
F
.75599 .68138 m .77033 .69564 L .77269 .69826 L F
.75599 .68138 m .77269 .69826 L .78999 .71749 L F
.64234 .56648 m .65037 .57459 L .64388 .56759 L .134 .453 .884 r
F
.62753 .5558 m .65037 .57459 L .64234 .56648 L F
0 g
.6805 .60467 m
.6805 .60466 L
s
.6805 .60466 m
.68051 .60468 L
s
.66785 .6182 m
.66943 .6165 L
s
.6658 .62039 m
.66785 .6182 L
s
.68048 .60465 m
.6805 .60466 L
s
1 Mabswid
.43614 .88557 Mdot
.5 Mabswid
.43614 .88557 m
.43674 .8888 L
s
.43674 .8888 m
.43688 .88959 L
s
1 Mabswid
.43614 .88557 Mdot
.5 Mabswid
.4403 .88892 m
.44036 .88896 L
s
.43742 .8866 m
.43793 .88701 L
s
.43992 .88861 m
.4403 .88892 L
s
.43793 .88701 m
.43992 .88861 L
s
.4371 .88634 m
.43742 .8866 L
s
.43614 .88557 m
.4371 .88634 L
s
.4407 .88924 m
.44148 .88986 L
s
.4761 .9177 m
.47864 .91975 L
s
.44036 .88896 m
.4407 .88924 L
s
1 Mabswid
.43614 .88557 Mdot
.5 Mabswid
.43979 .88656 m
.44055 .88676 L
s
.4369 .88578 m
.43979 .88656 L
s
.43643 .88565 m
.4369 .88578 L
s
.43614 .88557 m
.43643 .88565 L
s
1 Mabswid
.43614 .88557 Mdot
.43614 .88557 Mdot
.43614 .88557 Mdot
.80017 .73965 m .83845 .92094 L .79844 .76062 L 0 0 .448 r
F
0 g
.5 Mabswid
.81241 .7976 m
.81333 .79919 L
s
.81333 .79919 m
.81422 .80073 L
s
.81422 .80073 m
.8166 .80487 L
s
.82589 .94412 m
.82813 .89871 L
s
.82891 .88291 m
.82964 .8681 L
s
.8206 .8367 m
.82141 .83625 L
s
.757 .872 m
.81541 .83958 L
s
.82026 .83689 m
.8206 .8367 L
s
.39534 .48988 m .53989 .52837 L .41002 .49095 L .132 .621 .914 r
F
.41002 .49095 m .53989 .52837 L .56302 .53268 L .028 .56 .855 r
F
0 g
.45172 .50233 m
.46827 .5041 L
s
.41553 .4989 m
.41574 .49892 L
s
1 Mabswid
.30455 .80171 Mdot
.30455 .80171 Mdot
.5 Mabswid
.31562 .80576 m
.31853 .80682 L
s
.36758 .82476 m
.37004 .82566 L
s
.36388 .8234 m
.36758 .82476 L
s
.3477 .81748 m
.36388 .8234 L
s
.33912 .81435 m
.3477 .81748 L
s
.32752 .81011 m
.33435 .8126 L
s
.32509 .80922 m
.32752 .81011 L
s
.33435 .8126 m
.33912 .81435 L
s
.31853 .80682 m
.32509 .80922 L
s
.30759 .80282 m
.31562 .80576 L
s
.30455 .80171 m
.30759 .80282 L
s
1 Mabswid
.30455 .80171 Mdot
.5 Mabswid
.3063 .7977 m
.30833 .79309 L
s
.30455 .80171 m
.3063 .7977 L
s
1 Mabswid
.30455 .80171 Mdot
.30455 .80171 Mdot
.5 Mabswid
.28781 .78956 m
.30455 .80171 L
s
.26911 .77598 m
.28781 .78956 L
s
.24273 .75683 m
.24779 .7605 L
s
.24779 .7605 m
.25222 .76372 L
s
1 Mabswid
.30455 .80171 Mdot
.24273 .75683 Mdot
.24273 .75683 Mdot
.5 Mabswid
.26528 .7648 m
.26747 .76557 L
s
1 Mabswid
.24273 .75683 Mdot
.24273 .75683 Mdot
.24273 .75683 Mdot
.24273 .75683 Mdot
.20818 .69352 m .26001 .75739 L .25718 .76715 L .004 .235 .744 r
F
0 g
.5 Mabswid
.25276 .76038 m
.25442 .76096 L
s
.21144 .68508 m .26001 .75739 L .20818 .69352 L .132 .285 .755 r
F
0 g
.24273 .75683 m
.25276 .76038 L
s
.34658 .8117 m
.34859 .81207 L
s
.34161 .8108 m
.34658 .8117 L
s
.33089 .80887 m
.34161 .8108 L
s
.33077 .80884 m
.33089 .80887 L
s
.32927 .80857 m
.33077 .80884 L
s
.32168 .8072 m
.32848 .80843 L
s
.31556 .80609 m
.32168 .8072 L
s
.26302 .53262 m .41002 .49095 L .26789 .53267 L .328 0 .03 r
F
0 g
.39114 .49649 m
.41553 .4989 L
s
.26302 .53262 m .39534 .48988 L .41002 .49095 L .328 0 .03 r
F
0 g
.30402 .51651 m
.35551 .49298 L
s
.2979 .51931 m
.30402 .51651 L
s
.36848 .49426 m
.37025 .49443 L
s
.37025 .49443 m
.37208 .49461 L
s
.35551 .49298 m
.36848 .49426 L
s
.35551 .49298 m
.3638 .49443 L
s
.3638 .49443 m
.36502 .49464 L
s
.33992 .4958 m
.35551 .49298 L
s
1 Mabswid
.35551 .49298 Mdot
.35551 .49298 Mdot
.35551 .49298 Mdot
.35551 .49298 Mdot
.5 Mabswid
.25844 .54255 m
.26648 .53845 L
s
.30102 .52081 m
.35551 .49298 L
s
1 Mabswid
.35551 .49298 Mdot
.35551 .49298 Mdot
.20832 .67591 Mdot
.5 Mabswid
.20832 .67591 m
.21079 .67876 L
s
.21079 .67876 m
.21122 .67926 L
s
1 Mabswid
.20832 .67591 Mdot
.20832 .67591 Mdot
.5 Mabswid
.20832 .67591 m
.21308 .66592 L
s
.21308 .66592 m
.21936 .65275 L
s
1 Mabswid
.20832 .67591 Mdot
.20832 .67591 Mdot
.5 Mabswid
.38223 .82486 m
.38484 .82651 L
s
.42836 .86993 m
.44012 .8853 L
s
.42605 .86691 m
.42836 .86993 L
s
.42383 .86402 m
.42605 .86691 L
s
.41878 .85741 m
.42383 .86402 L
s
.42373 .49337 m .56302 .53268 L .58591 .53848 L 0 .448 .735 r
F
.41002 .49095 m .56302 .53268 L .42373 .49337 L .028 .56 .855 r
F
0 g
.5386 .52422 m
.53919 .52471 L
s
.54141 .52657 m
.57501 .55475 L
s
.53919 .52471 m
.54057 .52587 L
s
.52692 .52323 m
.53655 .55463 L
s
.21144 .68508 m .26556 .74608 L .26001 .75739 L .132 .285 .755 r
F
0 g
.24605 .74833 m
.24662 .74685 L
s
.24273 .75683 m
.24605 .74833 L
s
.21547 .67604 m .26556 .74608 L .21144 .68508 L .233 .318 .746 r
F
0 g
.21149 .67657 m
.21236 .67675 L
s
.20832 .67591 m
.21149 .67657 L
s
.21122 .67926 m
.21166 .67976 L
s
1 Mabswid
.6805 .60466 Mdot
.5 Mabswid
.6805 .60466 m
.68093 .60497 L
s
1 Mabswid
.6805 .60466 Mdot
.6805 .60466 Mdot
.6805 .60466 Mdot
.5 Mabswid
.68047 .60465 m
.6805 .60466 L
s
1 Mabswid
.6805 .60466 Mdot
.5 Mabswid
.63979 .57642 m
.64177 .57779 L
s
.68046 .60463 m
.6805 .60466 L
s
1 Mabswid
.6805 .60466 Mdot
.78333 1.10948 m .68599 1.21767 L .76282 1.09862 L .58 .856 .522 r
F
0 g
.5 Mabswid
.73063 1.10179 m
.74753 1.12232 L
s
.57278 1.18497 m
.73566 1.1407 L
s
.81765 .95326 m .78333 1.10948 L .76282 1.09862 L .961 .944 .685 r
F
0 g
.81636 .95913 m
.81974 .96527 L
s
.83743 .942 m .78333 1.10948 L .81765 .95326 L 0 0 0 r
F
0 g
1 Mabswid
.67171 1.23993 Mdot
.5 Mabswid
.62377 1.27393 m
.67171 1.23993 L
s
.59776 1.29239 m
.62377 1.27393 L
s
.56292 1.3171 m
.59776 1.29239 L
s
.67002 1.23665 m
.67171 1.23993 L
s
.6687 1.2341 m
.67002 1.23665 L
s
1 Mabswid
.67171 1.23993 Mdot
.67171 1.23993 Mdot
.67171 1.23993 Mdot
.5 Mabswid
.67064 1.23595 m
.67171 1.23993 L
s
.6699 1.23315 m
.67064 1.23595 L
s
1 Mabswid
.67171 1.23993 Mdot
.5 Mabswid
.67171 1.23993 m
.69272 1.21422 L
s
.71695 1.18458 m
.73141 1.16689 L
s
.69272 1.21422 m
.71695 1.18458 L
s
1 Mabswid
.67171 1.23993 Mdot
.26789 .53267 m .42373 .49337 L .27215 .5337 L .375 0 .092 r
F
.26789 .53267 m .41002 .49095 L .42373 .49337 L F
0 g
.5 Mabswid
.29347 .52466 m
.30102 .52081 L
s
.27385 .53468 m
.2797 .53169 L
s
.64388 .56759 m .77033 .69564 L .65541 .58135 L 0 .24 .739 r
F
0 g
.66344 .59546 m
.66397 .59575 L
s
.68093 .60497 m
.68687 .60921 L
s
.68977 .61128 m
.69599 .61572 L
s
.68687 .60921 m
.68977 .61128 L
s
.75505 .68214 m
.77781 .73139 L
s
1 Mabswid
.56292 1.3171 Mdot
.5 Mabswid
.56292 1.3171 m
.56366 1.30973 L
s
.56285 1.31011 m
.56292 1.3171 L
s
1 Mabswid
.56292 1.3171 Mdot
.56292 1.3171 Mdot
.25844 .54255 Mdot
.5 Mabswid
.25844 .54255 m
.26753 .53925 L
s
.25844 .54255 m
.26441 .54938 L
s
1 Mabswid
.25844 .54255 Mdot
.25844 .54255 Mdot
.25844 .54255 Mdot
.25844 .54255 Mdot
.5 Mabswid
.42106 .9041 m
.42996 .91756 L
s
.4171 .8981 m
.42106 .9041 L
s
.43708 .91437 m
.43883 .91699 L
s
.44676 .93898 m
.45062 .94687 L
s
.27215 .5337 m .43605 .49723 L .27568 .53573 L .414 .004 .148 r
F
0 g
.27605 .53615 m
.28018 .53465 L
s
.42622 .49959 m
.4367 .50072 L
s
.27215 .5337 m .42373 .49337 L .43605 .49723 L .414 .004 .148 r
F
0 g
.31187 .52313 m
.31195 .5231 L
s
.40086 .49688 m
.40119 .49691 L
s
.38572 .49532 m
.38789 .49549 L
s
.35551 .49298 m
.38572 .49532 L
s
.39917 .49669 m
.40042 .49683 L
s
.40042 .49683 m
.40086 .49688 L
s
.38789 .49549 m
.39694 .49646 L
s
.39694 .49646 m
.39917 .49669 L
s
.21547 .67604 m .27409 .73327 L .26556 .74608 L .233 .318 .746 r
F
0 g
.24662 .74685 m
.24941 .7397 L
s
.24986 .73855 m
.25046 .737 L
s
.24941 .7397 m
.24986 .73855 L
s
.22437 .70996 m
.22968 .71327 L
s
.22022 .6665 m .27409 .73327 L .21547 .67604 L .312 .337 .726 r
F
0 g
.22968 .71327 m
.23396 .71594 L
s
.43605 .49723 m .58591 .53848 L .60778 .54611 L .324 0 0 r
F
0 g
.46827 .5041 m
.48182 .50589 L
s
.526 .5202 m
.52654 .52197 L
s
.53834 .524 m
.5386 .52422 L
s
.42373 .49337 m .58591 .53848 L .43605 .49723 L 0 .448 .735 r
F
0 g
.5233 .51138 m
.53834 .524 L
s
.5233 .51138 m
.526 .5202 L
s
.48182 .50589 m
.5233 .51138 L
s
.44817 .88845 m
.45542 .89648 L
s
.46547 .90761 m
.4661 .90831 L
s
.45542 .89648 m
.46192 .90368 L
s
.42226 .85973 m
.43127 .86972 L
s
.45832 .86874 m
.45883 .86895 L
s
.37004 .82566 m
.37895 .83065 L
s
.37895 .83065 m
.39178 .83784 L
s
1 Mabswid
.5233 .51138 Mdot
.5233 .51138 Mdot
.5233 .51138 Mdot
.5233 .51138 Mdot
.5 Mabswid
.49692 .51057 m
.5233 .51138 L
s
1 Mabswid
.5233 .51138 Mdot
.5 Mabswid
.46951 .50507 m
.47124 .50527 L
s
.46388 .50441 m
.46951 .50507 L
s
.46306 .50431 m
.46388 .50441 L
s
.47124 .50527 m
.5233 .51138 L
s
1 Mabswid
.5233 .51138 Mdot
.26556 .74608 m .32877 .80809 L .26001 .75739 L 0 .351 .825 r
F
.26556 .74608 m .33301 .80241 L .32877 .80809 L F
0 g
.5 Mabswid
.26747 .76557 m
.27283 .76747 L
s
.27283 .76747 m
.27475 .76815 L
s
.47608 .91749 m
.47864 .91975 L
s
.38223 .82486 m
.3846 .82735 L
s
.39933 .84282 m
.4001 .84362 L
s
.38472 .82747 m
.39933 .84282 L
s
.4001 .84362 m
.40024 .84377 L
s
.40024 .84377 m
.41507 .85934 L
s
.41507 .85934 m
.41942 .8639 L
s
.41942 .8639 m
.42447 .86921 L
s
.42447 .86921 m
.44026 .88579 L
s
.27568 .53573 m .44651 .50262 L .27835 .53875 L .445 .052 .198 r
F
0 g
.31195 .5231 m
.31233 .52296 L
s
.27568 .53573 m .43605 .49723 L .44651 .50262 L .445 .052 .198 r
F
0 g
.32415 .51866 m
.33233 .51569 L
s
.31233 .52296 m
.32415 .51866 L
s
.44587 .50229 m
.4594 .50388 L
s
.40733 .49777 m
.4074 .49778 L
s
.38789 .49549 m
.40548 .49755 L
s
.40548 .49755 m
.40733 .49777 L
s
1 Mabswid
.21936 .65275 Mdot
.5 Mabswid
.21936 .65275 m
.22232 .65458 L
s
.22232 .65458 m
.2237 .65543 L
s
.2237 .65543 m
.22373 .65545 L
s
1 Mabswid
.21936 .65275 Mdot
.5 Mabswid
.21936 .65275 m
.22239 .65262 L
s
.22239 .65262 m
.22414 .65254 L
s
.22414 .65254 m
.22448 .65253 L
s
1 Mabswid
.21936 .65275 Mdot
.5 Mabswid
.23012 .63328 m
.23313 .62782 L
s
.21936 .65275 m
.2245 .64344 L
s
.2245 .64344 m
.23012 .63328 L
s
1 Mabswid
.21936 .65275 Mdot
.21936 .65275 Mdot
.22022 .6665 m .28569 .71904 L .27409 .73327 L .312 .337 .726 r
F
0 g
.5 Mabswid
.25046 .737 m
.25268 .73131 L
s
.25291 .73073 m
.25384 .72834 L
s
.25268 .73131 m
.25291 .73073 L
s
.24733 .72429 m
.25384 .72834 L
s
.2457 .72327 m
.24733 .72429 L
s
.22561 .65653 m .28569 .71904 L .22022 .6665 L .372 .346 .7 r
F
0 g
.23396 .71594 m
.2457 .72327 L
s
.22549 .69569 m
.23504 .70669 L
s
.23688 .70881 m
.23989 .71228 L
s
.23504 .70669 m
.23688 .70881 L
s
1 Mabswid
.26441 .54938 Mdot
.5 Mabswid
.26441 .54938 m
.27446 .54653 L
s
.26441 .54938 m
.2645 .56234 L
s
1 Mabswid
.26441 .54938 Mdot
.5 Mabswid
.26441 .54938 m
.27392 .54523 L
s
.27999 .54258 m
.2989 .53433 L
s
1 Mabswid
.26441 .54938 Mdot
.26441 .54938 Mdot
.26441 .54938 Mdot
.66073 .5968 m .78999 .71749 L .80017 .73965 L .824 .35 0 r
F
0 g
.5 Mabswid
.70658 .6967 m
.72675 .66444 L
s
.65541 .58135 m .78999 .71749 L .66073 .5968 L .58 .075 0 r
F
0 g
.69599 .61572 m
.71084 .62632 L
s
.71084 .62632 m
.71137 .6267 L
s
.71497 .62927 m
.72176 .63412 L
s
.71137 .6267 m
.71497 .62927 L
s
.72176 .63412 m
.73832 .64594 L
s
.73816 .64618 m
.73832 .64594 L
s
.73206 .65594 m
.73254 .65517 L
s
.7315 .65685 m
.73206 .65594 L
s
.73254 .65517 m
.73312 .65425 L
s
.73355 .65356 m
.73816 .64618 L
s
.73312 .65425 m
.73355 .65356 L
s
.73832 .64594 m
.74961 .67038 L
s
.75141 .67427 m
.75421 .68034 L
s
.74961 .67038 m
.75063 .67257 L
s
.75063 .67257 m
.75141 .67427 L
s
.68599 1.21767 m .60578 1.23111 L .66734 1.16627 L .837 .928 .891 r
F
0 g
.66662 1.22091 m
.66938 1.23122 L
s
.66227 1.22164 m
.66786 1.23247 L
s
.68599 1.21767 m .58102 1.30335 L .60578 1.23111 L .837 .928 .891 r
F
0 g
.5174 1.32674 m
.58102 1.30335 L
s
.76282 1.09862 m .68599 1.21767 L .66734 1.16627 L .863 .887 .852 r
F
0 g
.73141 1.16689 m
.75772 1.1347 L
s
.75117 1.13648 m
.75772 1.1347 L
s
.75585 1.13243 m
.75772 1.1347 L
s
.78301 .77918 m .83743 .942 L .81765 .95326 L .997 .779 .484 r
F
0 g
.82964 .8681 m
.83029 .85497 L
s
.79844 .76062 m .83743 .942 L .78301 .77918 L .856 .6 .063 r
F
0 g
.8166 .80487 m
.82554 .82036 L
s
.8278 .82427 m
.83149 .83066 L
s
.82554 .82036 m
.8278 .82427 L
s
.83067 .84724 m
.83149 .83066 L
s
.83029 .85497 m
.83067 .84724 L
s
.82141 .83625 m
.82618 .8336 L
s
.82802 .83258 m
.83149 .83066 L
s
.82618 .8336 m
.82802 .83258 L
s
.27835 .53875 m .45463 .50959 L .28006 .54274 L .47 .093 .242 r
F
.27835 .53875 m .44651 .50262 L .45463 .50959 L F
0 g
.3366 .51414 m
.38789 .49549 L
s
.33233 .51569 m
.3366 .51414 L
s
.42781 .50845 m
.42789 .50845 L
s
.32975 .52086 m
.38789 .49549 L
s
.31771 .52612 m
.31914 .52549 L
s
.32527 .52282 m
.32975 .52086 L
s
.31914 .52549 m
.32527 .52282 L
s
.31498 .52731 m
.31771 .52612 L
s
.42646 .50841 m
.42688 .50842 L
s
.42688 .50842 m
.42781 .50845 L
s
.41988 .50821 m
.42646 .50841 L
s
.41059 .50792 m
.41988 .50821 L
s
1 Mabswid
.75772 1.1347 Mdot
.5 Mabswid
.75077 1.12969 m
.75772 1.1347 L
s
1 Mabswid
.75772 1.1347 Mdot
.75772 1.1347 Mdot
.75772 1.1347 Mdot
.5 Mabswid
.75243 1.12766 m
.75772 1.1347 L
s
1 Mabswid
.75772 1.1347 Mdot
.5 Mabswid
.75772 1.1347 m
.76611 1.10632 L
s
1 Mabswid
.75772 1.1347 Mdot
.44651 .50262 m .60778 .54611 L .62753 .5558 L .498 0 0 r
F
0 g
.5 Mabswid
.59721 .54689 m
.63979 .57642 L
s
.43605 .49723 m .60778 .54611 L .44651 .50262 L .324 0 0 r
F
0 g
.58011 .54187 m
.5987 .56935 L
s
.57769 .53828 m
.57813 .53894 L
s
.57813 .53894 m
.5783 .53919 L
s
.57662 .5367 m
.57769 .53828 L
s
.5233 .51138 m
.55203 .5219 L
s
.48373 .51017 m
.48525 .51022 L
s
.48321 .51015 m
.48373 .51017 L
s
.4868 .51026 m
.48796 .5103 L
s
.48525 .51022 m
.4868 .51026 L
s
.48796 .5103 m
.49308 .51046 L
s
.49308 .51046 m
.49692 .51057 L
s
.22561 .65653 m .30024 .70357 L .28569 .71904 L .372 .346 .7 r
F
0 g
.23989 .71228 m
.25384 .72834 L
s
.23152 .64626 m .30024 .70357 L .22561 .65653 L .418 .347 .67 r
F
0 g
1 Mabswid
.43883 .91699 Mdot
.43883 .91699 Mdot
.5 Mabswid
.43883 .91699 m
.44013 .91889 L
s
1 Mabswid
.43883 .91699 Mdot
.5 Mabswid
.43883 .91699 m
.43957 .91779 L
s
.43957 .91779 m
.44101 .91933 L
s
.44101 .91933 m
.44145 .9198 L
s
1 Mabswid
.43883 .91699 Mdot
.43883 .91699 Mdot
.5 Mabswid
.44356 .91883 m
.44391 .91896 L
s
.44587 .91973 m
.45454 .9231 L
s
.44016 .91751 m
.44356 .91883 L
s
.43968 .91732 m
.44016 .91751 L
s
.4394 .91721 m
.43968 .91732 L
s
.43883 .91699 m
.4394 .91721 L
s
1 Mabswid
.43883 .91699 Mdot
.38789 .49549 Mdot
.5 Mabswid
.38789 .49549 m
.41059 .50792 L
s
1 Mabswid
.38789 .49549 Mdot
.38789 .49549 Mdot
.38789 .49549 Mdot
.38789 .49549 Mdot
.38789 .49549 Mdot
.28006 .54274 m .45992 .51817 L .28074 .54769 L .488 .128 .281 r
F
.28006 .54274 m .45463 .50959 L .45992 .51817 L F
0 g
.23313 .62782 Mdot
.5 Mabswid
.23313 .62782 m
.23532 .62831 L
s
.23532 .62831 m
.23537 .62832 L
s
.23537 .62832 m
.23592 .62845 L
s
.23592 .62845 m
.23597 .62846 L
s
.23597 .62846 m
.23696 .62868 L
s
.23696 .62868 m
.23716 .62873 L
s
.23716 .62873 m
.23809 .62894 L
s
.23809 .62894 m
.23898 .62914 L
s
.23898 .62914 m
.23902 .62915 L
s
.23902 .62915 m
.23934 .62922 L
s
1 Mabswid
.23313 .62782 Mdot
.5 Mabswid
.23313 .62782 m
.23583 .62734 L
s
.23583 .62734 m
.23589 .62733 L
s
.23589 .62733 m
.23654 .62722 L
s
.23654 .62722 m
.2366 .62721 L
s
.2366 .62721 m
.23773 .62701 L
s
.23773 .62701 m
.23801 .62696 L
s
.23801 .62696 m
.23894 .62679 L
s
.23894 .62679 m
.2398 .62664 L
s
.2398 .62664 m
.23989 .62662 L
s
1 Mabswid
.23313 .62782 Mdot
.23313 .62782 Mdot
.23313 .62782 Mdot
.23152 .64626 m .31742 .68709 L .30024 .70357 L .418 .347 .67 r
F
0 g
.5 Mabswid
.2682 .68832 m
.2816 .6911 L
s
.26305 .68726 m
.2682 .68832 L
s
.23781 .63581 m .31742 .68709 L .23152 .64626 L .453 .342 .638 r
F
0 g
.26228 .6871 m
.26305 .68726 L
s
1 Mabswid
.2645 .56234 Mdot
.5 Mabswid
.2645 .56234 m
.27472 .56023 L
s
.25836 .58069 m
.2645 .56234 L
s
1 Mabswid
.2645 .56234 Mdot
.5 Mabswid
.2645 .56234 m
.27472 .55854 L
s
1 Mabswid
.2645 .56234 Mdot
.2645 .56234 Mdot
.2645 .56234 Mdot
.5 Mabswid
.42996 .91756 m
.43931 .92989 L
s
.43931 .92989 m
.44586 .93854 L
s
.27409 .73327 m .33301 .80241 L .26556 .74608 L .182 .423 .857 r
F
0 g
.27475 .76815 m
.29226 .77433 L
s
.30847 .79277 m
.31153 .78578 L
s
1 Mabswid
.25384 .72834 Mdot
.5 Mabswid
.25384 .72834 m
.25765 .73177 L
s
.25765 .73177 m
.25835 .7324 L
s
.25835 .7324 m
.26372 .73722 L
s
1 Mabswid
.25384 .72834 Mdot
.5 Mabswid
.25384 .72834 m
.26039 .7295 L
s
.26039 .7295 m
.2612 .72965 L
s
.2612 .72965 m
.26492 .73031 L
s
1 Mabswid
.25384 .72834 Mdot
.5 Mabswid
.25384 .72834 m
.26289 .7162 L
s
.26925 .70767 m
.27262 .70315 L
s
.26873 .70836 m
.26925 .70767 L
s
.26371 .71509 m
.26873 .70836 L
s
.26289 .7162 m
.26371 .71509 L
s
.27583 .69884 m
.27999 .69326 L
s
.27262 .70315 m
.27583 .69884 L
s
.27999 .69326 m
.2816 .6911 L
s
1 Mabswid
.25384 .72834 Mdot
.25384 .72834 Mdot
.25384 .72834 Mdot
.83149 .83066 Mdot
.83149 .83066 Mdot
.83149 .83066 Mdot
.5 Mabswid
.81484 .84058 m
.82582 .83403 L
s
.813 .84167 m
.81484 .84058 L
s
.82582 .83403 m
.83149 .83066 L
s
1 Mabswid
.83149 .83066 Mdot
.5 Mabswid
.81596 .80719 m
.82046 .81399 L
s
.80927 .79707 m
.81596 .80719 L
s
.80661 .79305 m
.80927 .79707 L
s
.82046 .81399 m
.83149 .83066 L
s
1 Mabswid
.83149 .83066 Mdot
.5 Mabswid
.818 .82338 m
.82338 .82629 L
s
.81331 .82085 m
.818 .82338 L
s
.8121 .8202 m
.81331 .82085 L
s
.82338 .82629 m
.83149 .83066 L
s
1 Mabswid
.83149 .83066 Mdot
.28074 .54769 m .46194 .52834 L .28033 .55356 L .502 .157 .315 r
F
0 g
.5 Mabswid
.27963 .55671 m
.29267 .55185 L
s
.28074 .54769 m .45992 .51817 L .46194 .52834 L .502 .157 .315 r
F
0 g
.3456 .52636 m
.35892 .52258 L
s
.32563 .53202 m
.32664 .53173 L
s
.32278 .53283 m
.32563 .53202 L
s
.32986 .53082 m
.33144 .53037 L
s
.32664 .53173 m
.32986 .53082 L
s
.37821 .51999 m
.41059 .50792 L
s
.35892 .52258 m
.41059 .50792 L
s
.23781 .63581 m .33666 .66987 L .31742 .68709 L .453 .342 .638 r
F
0 g
.24971 .67145 m
.25566 .67512 L
s
.25666 .67573 m
.2816 .6911 L
s
.25566 .67512 m
.25666 .67573 L
s
.25926 .68647 m
.25959 .68654 L
s
.25959 .68654 m
.26228 .6871 L
s
.24429 .62529 m .33666 .66987 L .23781 .63581 L .479 .333 .604 r
F
0 g
.24647 .66946 m
.24649 .66947 L
s
.23313 .62782 m
.24711 .60311 L
s
.19057 .63127 m
.24711 .60311 L
s
.19057 .63127 m
.25836 .58069 L
s
1 Mabswid
.37004 .82566 Mdot
.37004 .82566 Mdot
.5 Mabswid
.41251 .84637 m
.4185 .84929 L
s
.40442 .84242 m
.41105 .84565 L
s
.38546 .83317 m
.38972 .83525 L
s
.38972 .83525 m
.40442 .84242 L
s
.41105 .84565 m
.41251 .84637 L
s
.37004 .82566 m
.38546 .83317 L
s
.42474 .85233 m
.44029 .85991 L
s
.42401 .85197 m
.42432 .85212 L
s
.44029 .85991 m
.4412 .86035 L
s
.4412 .86035 m
.45288 .86605 L
s
.457 .86806 m
.45883 .86895 L
s
1 Mabswid
.37004 .82566 Mdot
.5 Mabswid
.37004 .82566 m
.37627 .82387 L
s
1 Mabswid
.37004 .82566 Mdot
.37004 .82566 Mdot
.5 Mabswid
.34212 .80406 m
.35636 .81507 L
s
.35724 .81575 m
.37004 .82566 L
s
1 Mabswid
.37004 .82566 Mdot
.27409 .73327 m .34311 .79417 L .33301 .80241 L .182 .423 .857 r
F
0 g
.5 Mabswid
.31329 .78177 m
.33041 .79501 L
s
.28045 .75226 m
.31329 .78177 L
s
.31153 .78578 m
.31319 .782 L
s
.31319 .782 m
.31329 .78177 L
s
.29226 .77433 m
.31301 .78167 L
s
.31301 .78167 m
.31329 .78177 L
s
1 Mabswid
.24711 .60311 Mdot
.5 Mabswid
.24711 .60311 m
.2546 .60317 L
s
.2546 .60317 m
.25463 .60317 L
s
.25463 .60317 m
.2549 .60317 L
s
.2549 .60317 m
.255 .60317 L
s
.255 .60317 m
.25512 .60317 L
s
1 Mabswid
.24711 .60311 Mdot
.5 Mabswid
.24711 .60311 m
.25529 .60103 L
s
.25529 .60103 m
.25532 .60102 L
s
.25532 .60102 m
.25556 .60096 L
s
.25556 .60096 m
.25569 .60093 L
s
.25569 .60093 m
.2557 .60093 L
s
1 Mabswid
.24711 .60311 Mdot
.5 Mabswid
.24711 .60311 m
.25836 .58069 L
s
1 Mabswid
.24711 .60311 Mdot
.24711 .60311 Mdot
.25836 .58069 Mdot
.5 Mabswid
.25836 .58069 m
.26821 .57759 L
s
.26821 .57759 m
.26821 .57759 L
s
.25836 .58069 m
.26785 .57957 L
s
.26785 .57957 m
.26785 .57957 L
s
1 Mabswid
.25836 .58069 Mdot
.25836 .58069 Mdot
.25836 .58069 Mdot
.25836 .58069 Mdot
.45463 .50959 m .62753 .5558 L .64388 .56759 L .618 .079 0 r
F
0 g
.5 Mabswid
.59412 .54475 m
.59531 .54557 L
s
.44651 .50262 m .62753 .5558 L .45463 .50959 L .498 0 0 r
F
0 g
.59114 .54268 m
.59375 .54449 L
s
.59375 .54449 m
.59412 .54475 L
s
.57501 .53433 m
.57662 .5367 L
s
.5714 .52899 m
.57501 .53433 L
s
.58145 .53596 m
.5869 .53974 L
s
.5869 .53974 m
.59114 .54268 L
s
.5714 .52899 m
.58145 .53596 L
s
.55203 .5219 m
.5714 .52899 L
s
.36601 .81949 m
.37752 .8244 L
s
.37752 .8244 m
.40006 .83402 L
s
.34859 .81207 m
.36601 .81949 L
s
.28033 .55356 m .46034 .54004 L .27882 .56031 L .512 .183 .346 r
F
.28033 .55356 m .46194 .52834 L .46034 .54004 L F
0 g
.33276 .53692 m
.33303 .53681 L
s
.33303 .53681 m
.33304 .53681 L
s
.33304 .53681 m
.33356 .53662 L
s
.33356 .53662 m
.33425 .53636 L
s
.33447 .53628 m
.33772 .53507 L
s
.33425 .53636 m
.33447 .53628 L
s
.33772 .53507 m
.33776 .53505 L
s
.34139 .5337 m
.35235 .52962 L
s
.33776 .53505 m
.34139 .5337 L
s
.35235 .52962 m
.37821 .51999 L
s
.38331 .53782 m
.41678 .53091 L
s
.33458 .52948 m
.3456 .52636 L
s
.33144 .53037 m
.33458 .52948 L
s
.24429 .62529 m .35716 .65222 L .33666 .66987 L .479 .333 .604 r
F
0 g
.24649 .66947 m
.24971 .67145 L
s
.25077 .61483 m .35716 .65222 L .24429 .62529 L .498 .32 .57 r
F
0 g
1 Mabswid
.73832 .64594 Mdot
.73832 .64594 Mdot
.73832 .64594 Mdot
.73832 .64594 Mdot
.73832 .64594 Mdot
.73832 .64594 Mdot
.27882 .56031 m .45492 .55317 L .27625 .56787 L .519 .205 .375 r
F
.27882 .56031 m .46034 .54004 L .45492 .55317 L F
0 g
.5 Mabswid
.3491 .55218 m
.35901 .54906 L
s
.35901 .54906 m
.3617 .54822 L
s
.3617 .54822 m
.3812 .54209 L
s
.3812 .54209 m
.41678 .53091 L
s
.32971 .54888 m
.33374 .54805 L
s
.32802 .54923 m
.32971 .54888 L
s
.33374 .54805 m
.33702 .54737 L
s
.33702 .54737 m
.33975 .54681 L
s
.33975 .54681 m
.36359 .54189 L
s
.36359 .54189 m
.38331 .53782 L
s
.66073 .5968 m .80017 .73965 L .65864 .61355 L .824 .35 0 r
F
.65864 .61355 m .80017 .73965 L .79844 .76062 L .9 .502 .249 r
F
0 g
.76207 .72236 m
.78563 .75388 L
s
.73911 .65467 m
.74046 .66951 L
s
.73832 .64594 m
.73911 .65467 L
s
.71264 .63863 m
.72461 .64204 L
s
.71108 .63819 m
.71264 .63863 L
s
.71037 .63798 m
.71108 .63819 L
s
.706 .63674 m
.71037 .63798 L
s
.72461 .64204 m
.72487 .64211 L
s
.72487 .64211 m
.73832 .64594 L
s
.70352 .62469 m
.71093 .62922 L
s
.69015 .61653 m
.70352 .62469 L
s
.68967 .61623 m
.69015 .61653 L
s
.71093 .62922 m
.72205 .63601 L
s
.72205 .63601 m
.73832 .64594 L
s
.25077 .61483 m .37799 .63443 L .35716 .65222 L .498 .32 .57 r
F
0 g
.27589 .63749 m
.28819 .64027 L
s
.29615 .64207 m
.32294 .64813 L
s
.28819 .64027 m
.29615 .64207 L
s
.29677 .6493 m
.30025 .64914 L
s
.3082 .64879 m
.32294 .64813 L
s
.30025 .64914 m
.3082 .64879 L
s
.25704 .60457 m .37799 .63443 L .25077 .61483 L .511 .304 .535 r
F
.27625 .56787 m .44566 .5676 L .27266 .57617 L .523 .227 .405 r
F
0 g
.27265 .5762 m
.27274 .57617 L
s
.27625 .56787 m .45492 .55317 L .44566 .5676 L .523 .227 .405 r
F
0 g
.34302 .55409 m
.34538 .55335 L
s
.34538 .55335 m
.3491 .55218 L
s
1 Mabswid
.31329 .78177 Mdot
.31329 .78177 Mdot
.31329 .78177 Mdot
.31329 .78177 Mdot
.31329 .78177 Mdot
.31329 .78177 Mdot
.25704 .60457 m .39817 .61681 L .37799 .63443 L .511 .304 .535 r
F
.2629 .59463 m .39817 .61681 L .25704 .60457 L .519 .286 .5 r
F
.27266 .57617 m .43278 .58315 L .26817 .58512 L .525 .247 .435 r
F
.27266 .57617 m .44566 .5676 L .43278 .58315 L F
0 g
.5 Mabswid
.34467 .5783 m
.34942 .57709 L
s
.34942 .57709 m
.35446 .57581 L
s
.35446 .57581 m
.40187 .56375 L
s
.31647 .57383 m
.33084 .57213 L
s
.33084 .57213 m
.40187 .56375 L
s
1 Mabswid
.5714 .52899 Mdot
.5714 .52899 Mdot
.5714 .52899 Mdot
.5714 .52899 Mdot
.5 Mabswid
.41678 .53091 m
.42919 .53076 L
s
.42919 .53076 m
.42985 .53075 L
s
.42985 .53075 m
.43375 .5307 L
s
.43375 .5307 m
.43709 .53066 L
s
.43709 .53066 m
.43784 .53065 L
s
.43784 .53065 m
.43791 .53065 L
s
1 Mabswid
.5714 .52899 Mdot
.5 Mabswid
.41059 .50792 m
.42999 .51047 L
s
.42999 .51047 m
.43279 .51083 L
s
.43279 .51083 m
.43305 .51086 L
s
.43305 .51086 m
.43363 .51094 L
s
.50499 .52029 m
.5714 .52899 L
s
.50095 .51976 m
.50499 .52029 L
s
.49942 .51956 m
.50095 .51976 L
s
.49782 .51935 m
.49942 .51956 L
s
1 Mabswid
.5714 .52899 Mdot
.45454 .9231 Mdot
.45454 .9231 Mdot
.5 Mabswid
.45454 .9231 m
.45857 .92775 L
s
.45857 .92775 m
.46218 .93192 L
s
1 Mabswid
.45454 .9231 Mdot
.5 Mabswid
.45454 .9231 m
.45814 .92554 L
s
.45814 .92554 m
.45839 .92571 L
s
1 Mabswid
.45454 .9231 Mdot
.45454 .9231 Mdot
.5 Mabswid
.45687 .92013 m
.45821 .91841 L
s
.45578 .92152 m
.4566 .92047 L
s
.4566 .92047 m
.45687 .92013 L
s
.45454 .9231 m
.45578 .92152 L
s
.46197 .9136 m
.4661 .90831 L
s
.45821 .91841 m
.45987 .91629 L
s
1 Mabswid
.45454 .9231 Mdot
.2629 .59463 m .41672 .59963 L .39817 .61681 L .519 .286 .5 r
F
0 g
.5 Mabswid
.30894 .60361 m
.36748 .60409 L
s
.3027 .60356 m
.30894 .60361 L
s
.33232 .6103 m
.36748 .60409 L
s
.32246 .61204 m
.33232 .6103 L
s
.26817 .58512 m .41672 .59963 L .2629 .59463 L .524 .267 .467 r
F
.26817 .58512 m .43278 .58315 L .41672 .59963 L F
.76282 1.09862 m .66734 1.16627 L .71578 1.07023 L .863 .887 .852 r
F
.77769 .95461 m .76282 1.09862 L .71578 1.07023 L .871 .813 .79 r
F
.81765 .95326 m .76282 1.09862 L .77769 .95461 L .961 .944 .685 r
F
0 g
.78208 1.05235 m
.79021 1.02488 L
s
.77583 1.07349 m
.78208 1.05235 L
s
.79021 1.02488 m
.79246 1.01727 L
s
.79267 1.01061 m
.79376 1.00913 L
s
.79246 1.01727 m
.7956 1.00662 L
s
.79619 1.00595 m
.79791 1.00399 L
s
.7956 1.00662 m
.79619 1.00595 L
s
.79791 1.00399 m
.79811 1.00377 L
s
.79376 1.00913 m
.79523 1.00713 L
s
.79523 1.00713 m
.7956 1.00662 L
s
.28569 .71904 m .34311 .79417 L .27409 .73327 L .334 .46 .839 r
F
0 g
.31329 .78177 m
.32067 .77588 L
s
.31329 .78177 m
.33313 .78706 L
s
1 Mabswid
.44586 .93854 Mdot
.44586 .93854 Mdot
.44586 .93854 Mdot
.5 Mabswid
.45176 .93516 m
.47261 .92321 L
s
.47261 .92321 m
.47611 .9212 L
s
.47645 .92101 m
.47864 .91975 L
s
.44586 .93854 m
.45176 .93516 L
s
.4609 .94594 m
.46455 .94773 L
s
.44586 .93854 m
.4609 .94594 L
s
.45992 .51817 m .64388 .56759 L .65541 .58135 L .686 .204 .102 r
F
.45463 .50959 m .64388 .56759 L .45992 .51817 L .618 .079 0 r
F
0 g
.53231 .52947 m
.5714 .52899 L
s
.52735 .52954 m
.53231 .52947 L
s
.52149 .52961 m
.52735 .52954 L
s
.52017 .52963 m
.52105 .52961 L
s
.52011 .52963 m
.52017 .52963 L
s
.52105 .52961 m
.52149 .52961 L
s
1 Mabswid
.41059 .50792 Mdot
.5 Mabswid
.41059 .50792 m
.41678 .53091 L
s
1 Mabswid
.41059 .50792 Mdot
.41059 .50792 Mdot
.41059 .50792 Mdot
.41059 .50792 Mdot
.41059 .50792 Mdot
.75326 .79467 m .81765 .95326 L .77769 .95461 L .928 .761 .655 r
F
.78301 .77918 m .81765 .95326 L .75326 .79467 L .997 .779 .484 r
F
0 g
.5 Mabswid
.80417 .84694 m
.813 .84167 L
s
1 Mabswid
.38223 .82486 Mdot
.5 Mabswid
.38223 .82486 m
.3852 .82778 L
s
.45266 .89417 m
.46587 .90718 L
s
.43445 .87625 m
.45266 .89417 L
s
.42201 .86401 m
.43445 .87625 L
s
.46587 .90718 m
.4759 .91706 L
s
.47604 .91719 m
.47864 .91975 L
s
.39737 .83976 m
.42201 .86401 L
s
.39413 .83657 m
.39737 .83976 L
s
.3852 .82778 m
.39413 .83657 L
s
1 Mabswid
.38223 .82486 Mdot
.38223 .82486 Mdot
.28569 .71904 m .36 .78342 L .34311 .79417 L .334 .46 .839 r
F
0 g
.5 Mabswid
.46455 .94773 m
.47819 .93742 L
s
.54183 1.02526 m .45315 .95204 L .47633 .96509 L .665 .421 .541 r
F
.54183 1.02526 m .51565 1.02944 L .45315 .95204 L F
0 g
.45062 .94687 m
.45315 .95204 L
s
.51565 1.02944 m
.54895 1.07817 L
s
.48155 .96283 m
.52725 1.01187 L
s
.45315 .95204 m
.47158 .97487 L
s
1 Mabswid
.7956 1.00662 Mdot
.5 Mabswid
.789 1.00491 m
.7956 1.00662 L
s
.78236 1.00318 m
.789 1.00491 L
s
1 Mabswid
.7956 1.00662 Mdot
.7956 1.00662 Mdot
.7956 1.00662 Mdot
.5 Mabswid
.79061 1.00314 m
.7956 1.00662 L
s
.78464 .99898 m
.79061 1.00314 L
s
1 Mabswid
.7956 1.00662 Mdot
.5 Mabswid
.79271 .99277 m
.7956 1.00662 L
s
.78877 .97395 m
.79271 .99277 L
s
1 Mabswid
.7956 1.00662 Mdot
.30024 .70357 m .36 .78342 L .28569 .71904 L .44 .479 .804 r
F
.65864 .61355 m .79844 .76062 L .64833 .63119 L .9 .502 .249 r
F
.64833 .63119 m .79844 .76062 L .78301 .77918 L .895 .57 .424 r
F
0 g
.5 Mabswid
.74995 .70614 m
.75074 .7072 L
s
.74617 .70109 m
.74995 .70614 L
s
.75005 .70751 m
.76433 .72911 L
s
.76433 .72911 m
.76812 .73484 L
s
.74046 .66951 m
.7406 .67108 L
s
.7406 .67108 m
.74061 .67116 L
s
.45992 .51817 m .65541 .58135 L .46194 .52834 L .686 .204 .102 r
F
0 g
.6185 .57124 m
.65954 .59336 L
s
.46194 .52834 m .65541 .58135 L .66073 .5968 L .719 .292 .232 r
F
0 g
.65413 .59453 m
.66053 .59844 L
s
.62399 .57613 m
.62726 .57812 L
s
.61205 .56776 m
.61221 .56785 L
s
.60744 .56527 m
.61164 .56754 L
s
.61164 .56754 m
.61205 .56776 L
s
.62284 .57543 m
.62399 .57613 L
s
.5714 .52899 m
.58864 .54961 L
s
.58864 .54961 m
.59477 .55694 L
s
.46166 .53036 m
.46759 .53028 L
s
.4166 .84636 m
.44777 .86963 L
s
.41165 .84267 m
.4166 .84636 L
s
.40006 .83402 m
.41165 .84267 L
s
1 Mabswid
.2816 .6911 Mdot
.5 Mabswid
.2816 .6911 m
.29241 .69903 L
s
.29241 .69903 m
.2932 .69961 L
s
.2932 .69961 m
.29321 .69962 L
s
1 Mabswid
.2816 .6911 Mdot
.5 Mabswid
.2816 .6911 m
.29113 .69168 L
s
.29113 .69168 m
.29123 .69168 L
s
.29123 .69168 m
.29316 .6918 L
s
1 Mabswid
.2816 .6911 Mdot
.5 Mabswid
.28357 .68905 m
.29194 .68035 L
s
.2816 .6911 m
.28357 .68905 L
s
.29194 .68035 m
.29227 .68001 L
s
.30405 .66776 m
.30457 .66722 L
s
.29227 .68001 m
.30405 .66776 L
s
.30457 .66722 m
.31151 .66002 L
s
.31421 .65721 m
.32294 .64813 L
s
.31151 .66002 m
.31421 .65721 L
s
1 Mabswid
.2816 .6911 Mdot
.2816 .6911 Mdot
.2816 .6911 Mdot
.4661 .90831 Mdot
.4661 .90831 Mdot
.5 Mabswid
.4661 .90831 m
.47303 .91405 L
s
.47597 .91649 m
.48024 .92002 L
s
1 Mabswid
.4661 .90831 Mdot
.5 Mabswid
.4661 .90831 m
.46925 .90938 L
s
.51023 .92323 m
.51701 .92552 L
s
1 Mabswid
.4661 .90831 Mdot
.4661 .90831 Mdot
.5 Mabswid
.46378 .89577 m
.46486 .9016 L
s
.46486 .9016 m
.4661 .90831 L
s
.46351 .89428 m
.46378 .89577 L
s
.46298 .89145 m
.46351 .89428 L
s
.46188 .88547 m
.46292 .89113 L
s
.45883 .86895 m
.46139 .88283 L
s
1 Mabswid
.4661 .90831 Mdot
.66734 1.16627 m .57908 1.13003 L .61418 1.09653 L .795 .716 .777 r
F
0 g
.5 Mabswid
.62463 1.14874 m
.64554 1.18923 L
s
.65013 1.1592 m
.65538 1.17887 L
s
.66734 1.16627 m .60578 1.23111 L .57908 1.13003 L .795 .716 .777 r
F
0 g
.56368 1.3096 m
.58101 1.13734 L
s
.58102 1.30335 m
.60578 1.23111 L
s
.71578 1.07023 m .66734 1.16627 L .61418 1.09653 L .769 .706 .793 r
F
0 g
.47718 .92787 m
.47819 .93742 L
s
.47511 .90842 m
.47718 .92787 L
s
.38405 .77041 m .41502 .84372 L .36 .78342 L .336 .476 .852 r
F
0 g
.36171 .79467 m
.36988 .79685 L
s
.38405 .77041 m .44435 .8415 L .41502 .84372 L .336 .476 .852 r
F
.57062 .99058 m .47633 .96509 L .50297 .95356 L .57 .446 .672 r
F
.57062 .99058 m .54183 1.02526 L .47633 .96509 L F
0 g
.54244 1.02454 m
.55903 1.04368 L
s
1 Mabswid
.47864 .91975 Mdot
.47864 .91975 Mdot
.47864 .91975 Mdot
.30024 .70357 m .38405 .77041 L .36 .78342 L .44 .479 .804 r
F
.31742 .68709 m .38405 .77041 L .30024 .70357 L .514 .488 .765 r
F
0 g
.5 Mabswid
.33035 .74189 m
.34396 .7443 L
s
.32621 .72384 m
.32735 .72468 L
s
.46145 .88904 m
.47191 .90388 L
s
.46023 .88731 m
.46145 .88904 L
s
.47191 .90388 m
.47511 .90842 L
s
.44777 .86963 m
.46023 .88731 L
s
1 Mabswid
.41678 .53091 Mdot
.5 Mabswid
.41678 .53091 m
.44091 .53477 L
s
.44091 .53477 m
.44169 .53489 L
s
.46063 .53791 m
.51487 .54656 L
s
.40187 .56375 m
.41678 .53091 L
s
1 Mabswid
.41678 .53091 Mdot
.41678 .53091 Mdot
.41678 .53091 Mdot
.41678 .53091 Mdot
.41678 .53091 Mdot
.46034 .54004 m .66073 .5968 L .65864 .61355 L .733 .352 .33 r
F
.46194 .52834 m .66073 .5968 L .46034 .54004 L .719 .292 .232 r
F
0 g
.5 Mabswid
.59706 .55968 m
.60744 .56527 L
s
.59706 .55968 m
.62191 .57486 L
s
.62191 .57486 m
.62284 .57543 L
s
.59477 .55694 m
.59706 .55968 L
s
.51828 .54711 m
.59706 .55968 L
s
.51724 .54694 m
.51828 .54711 L
s
1 Mabswid
.59706 .55968 Mdot
.59706 .55968 Mdot
.59706 .55968 Mdot
.59706 .55968 Mdot
.5 Mabswid
.40187 .56375 m
.42438 .56328 L
s
.53661 .56094 m
.59706 .55968 L
s
1 Mabswid
.59706 .55968 Mdot
.59706 .55968 Mdot
.71578 1.07023 m .61418 1.09653 L .64729 1.03145 L .769 .706 .793 r
F
.7196 .94786 m .71578 1.07023 L .64729 1.03145 L .763 .695 .788 r
F
.77769 .95461 m .71578 1.07023 L .7196 .94786 L .871 .813 .79 r
F
.57742 .92257 m .50297 .95356 L .51359 .90923 L .543 .499 .757 r
F
.57742 .92257 m .57062 .99058 L .50297 .95356 L F
.62953 .64933 m .78301 .77918 L .75326 .79467 L .863 .597 .535 r
F
0 g
.5 Mabswid
.74061 .67116 m
.74148 .68075 L
s
.64833 .63119 m .78301 .77918 L .62953 .64933 L .895 .57 .424 r
F
0 g
.74335 .69731 m
.74535 .69999 L
s
.74535 .69999 m
.74617 .70109 L
s
.74294 .69676 m
.74335 .69731 L
s
.74294 .69676 m
.74376 .69801 L
s
.74376 .69801 m
.75005 .70751 L
s
.7423 .68979 m
.74294 .69676 L
s
.74148 .68075 m
.7423 .68979 L
s
1 Mabswid
.45883 .86895 Mdot
.45883 .86895 Mdot
.5 Mabswid
.45883 .86895 m
.47648 .87874 L
s
.50888 .89673 m
.52376 .90499 L
s
.52376 .90499 m
.54217 .9152 L
s
1 Mabswid
.45883 .86895 Mdot
.5 Mabswid
.45883 .86895 m
.46406 .86915 L
s
1 Mabswid
.45883 .86895 Mdot
.45883 .86895 Mdot
.5 Mabswid
.44097 .84075 m
.44935 .85398 L
s
.44945 .85415 m
.45883 .86895 L
s
1 Mabswid
.45883 .86895 Mdot
.71019 .80706 m .77769 .95461 L .7196 .94786 L .838 .71 .722 r
F
.75326 .79467 m .77769 .95461 L .71019 .80706 L .928 .761 .655 r
F
0 g
.5 Mabswid
.77315 .86543 m
.77482 .86444 L
s
.77482 .86444 m
.78592 .85782 L
s
.76686 .86918 m
.77315 .86543 L
s
.76942 .87383 m
.76993 .87476 L
s
.76993 .87476 m
.77092 .87656 L
s
.76686 .86918 m
.76942 .87383 L
s
.77396 .90312 m
.77488 .90751 L
s
.77488 .90751 m
.77743 .9197 L
s
.76686 .86918 m
.77396 .90312 L
s
.31742 .68709 m .41483 .75554 L .38405 .77041 L .514 .488 .765 r
F
0 g
.32735 .72468 m
.3305 .72699 L
s
.34396 .7443 m
.34569 .74461 L
s
.33666 .66987 m .41483 .75554 L .31742 .68709 L .57 .491 .727 r
F
0 g
.35358 .74966 m
.35732 .74667 L
s
.35238 .75061 m
.35292 .75018 L
s
.35292 .75018 m
.35358 .74966 L
s
.348 .7541 m
.35238 .75061 L
s
.34569 .74461 m
.35732 .74667 L
s
.3305 .72699 m
.35732 .74667 L
s
.46034 .54004 m .65864 .61355 L .45492 .55317 L .733 .352 .33 r
F
0 g
.44876 .56277 m
.48478 .56202 L
s
1 Mabswid
.74294 .69676 Mdot
.74294 .69676 Mdot
.74294 .69676 Mdot
.5 Mabswid
.7284 .70587 m
.74294 .69676 L
s
.72223 .70974 m
.7284 .70587 L
s
.71213 .71606 m
.72223 .70974 L
s
1 Mabswid
.74294 .69676 Mdot
.5 Mabswid
.70713 .67551 m
.74294 .69676 L
s
.70529 .67442 m
.70713 .67551 L
s
.69898 .67068 m
.70529 .67442 L
s
.6848 .66226 m
.69898 .67068 L
s
1 Mabswid
.74294 .69676 Mdot
.5 Mabswid
.7209 .6921 m
.74294 .69676 L
s
.71469 .69078 m
.7209 .6921 L
s
.7144 .69072 m
.71469 .69078 L
s
.70557 .68885 m
.7144 .69072 L
s
1 Mabswid
.74294 .69676 Mdot
.32294 .64813 Mdot
.5 Mabswid
.32294 .64813 m
.32903 .65095 L
s
.32903 .65095 m
.33464 .65355 L
s
.33464 .65355 m
.33994 .656 L
s
1 Mabswid
.32294 .64813 Mdot
.5 Mabswid
.32294 .64813 m
.32725 .64817 L
s
.32725 .64817 m
.33237 .64822 L
s
.33237 .64822 m
.33633 .64826 L
s
.33633 .64826 m
.33846 .64829 L
s
1 Mabswid
.32294 .64813 Mdot
.5 Mabswid
.32294 .64813 m
.32712 .64399 L
s
.32712 .64399 m
.33541 .6358 L
s
.33541 .6358 m
.34088 .6304 L
s
.34124 .63003 m
.36266 .60886 L
s
.34088 .6304 m
.34124 .63003 L
s
.36266 .60886 m
.36306 .60846 L
s
.36306 .60846 m
.36748 .60409 L
s
1 Mabswid
.32294 .64813 Mdot
.32294 .64813 Mdot
.32294 .64813 Mdot
.35732 .74667 Mdot
.5 Mabswid
.35732 .74667 m
.37259 .7618 L
s
.37259 .7618 m
.37312 .76233 L
s
.37312 .76233 m
.37402 .76322 L
s
1 Mabswid
.35732 .74667 Mdot
.5 Mabswid
.35732 .74667 m
.36455 .74803 L
s
1 Mabswid
.35732 .74667 Mdot
.5 Mabswid
.35732 .74667 m
.36217 .74381 L
s
1 Mabswid
.35732 .74667 Mdot
.35732 .74667 Mdot
.35732 .74667 Mdot
.41483 .75554 m .44435 .8415 L .38405 .77041 L .496 .526 .818 r
F
.41483 .75554 m .48648 .83719 L .44435 .8415 L F
0 g
.5 Mabswid
.42006 .81129 m
.42197 .81074 L
s
.40445 .80607 m
.41589 .80912 L
s
.38576 .80108 m
.40445 .80607 L
s
.41589 .80912 m
.42002 .81022 L
s
.42002 .81022 m
.42197 .81074 L
s
.43418 .83002 m
.43792 .83593 L
s
.43792 .83593 m
.44097 .84075 L
s
.42831 .82075 m
.43418 .83002 L
s
.42197 .81074 m
.42831 .82075 L
s
.40219 .79113 m
.42197 .81074 L
s
1 Mabswid
.40187 .56375 Mdot
.5 Mabswid
.40187 .56375 m
.42552 .56871 L
s
.42552 .56871 m
.42632 .56887 L
s
1 Mabswid
.40187 .56375 Mdot
.40187 .56375 Mdot
.5 Mabswid
.37024 .60085 m
.37803 .59171 L
s
.37803 .59171 m
.39399 .573 L
s
.39399 .573 m
.40187 .56375 L
s
.36748 .60409 m
.37024 .60085 L
s
1 Mabswid
.40187 .56375 Mdot
.40187 .56375 Mdot
.40187 .56375 Mdot
.61418 1.09653 m .51565 1.02944 L .54183 1.02526 L .724 .573 .684 r
F
0 g
.5 Mabswid
.56063 1.11036 m
.56285 1.31011 L
s
.61418 1.09653 m .57908 1.13003 L .51565 1.02944 L .724 .573 .684 r
F
0 g
.56055 1.10324 m
.56063 1.11036 L
s
.47158 .97487 m
.51565 1.02944 L
s
.57908 1.13003 m
.60578 1.23111 L
s
.64729 1.03145 m .61418 1.09653 L .54183 1.02526 L .677 .58 .739 r
F
0 g
.57952 1.06733 m
.58716 1.07615 L
s
.58716 1.07615 m
.58988 1.08142 L
s
.58644 1.08335 m
.58716 1.07615 L
s
.58085 1.06938 m
.58716 1.07615 L
s
.55438 1.0861 m
.56046 1.09502 L
s
.55341 1.08469 m
.56046 1.09502 L
s
.56046 1.09502 m
.56055 1.10324 L
s
.6163 1.03271 m
.61773 1.03804 L
s
.6163 1.03271 m
.6202 1.03552 L
s
.45492 .55317 m .65864 .61355 L .64833 .63119 L .735 .395 .406 r
F
.64729 1.03145 m .54183 1.02526 L .57062 .99058 L .677 .58 .739 r
F
0 g
.51565 1.02944 m
.57908 1.13003 L
s
.60984 1.02833 m
.6163 1.03271 L
s
.60778 1.02565 m
.6163 1.03271 L
s
.33666 .66987 m .45107 .73927 L .41483 .75554 L .57 .491 .727 r
F
0 g
.37139 .74931 m
.37187 .7494 L
s
.36455 .74803 m
.37139 .74931 L
s
.35716 .65222 m .45107 .73927 L .33666 .66987 L .613 .491 .689 r
F
0 g
.36217 .74381 m
.37124 .73846 L
s
.37124 .73846 m
.37277 .73756 L
s
.45492 .55317 m .64833 .63119 L .44566 .5676 L .735 .395 .406 r
F
0 g
.59195 .57453 m
.59706 .55968 L
s
1 Mabswid
.58716 1.07615 Mdot
.5 Mabswid
.56046 1.09502 m
.58716 1.07615 L
s
1 Mabswid
.58716 1.07615 Mdot
.58716 1.07615 Mdot
.58716 1.07615 Mdot
.58716 1.07615 Mdot
.5 Mabswid
.58716 1.07615 m
.6163 1.03271 L
s
1 Mabswid
.58716 1.07615 Mdot
.42197 .81074 Mdot
.42197 .81074 Mdot
.5 Mabswid
.42197 .81074 m
.4383 .8164 L
s
1 Mabswid
.42197 .81074 Mdot
.5 Mabswid
.42197 .81074 m
.433 .80791 L
s
1 Mabswid
.42197 .81074 Mdot
.42197 .81074 Mdot
.42197 .81074 Mdot
.36748 .60409 Mdot
.5 Mabswid
.36748 .60409 m
.38048 .60795 L
s
.38048 .60795 m
.38337 .6088 L
s
.38337 .6088 m
.38783 .61013 L
s
.38783 .61013 m
.38858 .61035 L
s
1 Mabswid
.36748 .60409 Mdot
.5 Mabswid
.36748 .60409 m
.37911 .60395 L
s
.37911 .60395 m
.38789 .60385 L
s
1 Mabswid
.36748 .60409 Mdot
.36748 .60409 Mdot
.36748 .60409 Mdot
.36748 .60409 Mdot
.53911 .83151 m .51359 .90923 L .48648 .83719 L .567 .551 .796 r
F
0 g
.5 Mabswid
.48131 .8313 m
.4955 .83622 L
s
.53911 .83151 m .57742 .92257 L .51359 .90923 L .567 .551 .796 r
F
0 g
1 Mabswid
.56046 1.09502 Mdot
.56046 1.09502 Mdot
.56046 1.09502 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.64961 .93612 m .64729 1.03145 L .57062 .99058 L .664 .601 .775 r
F
0 g
.5 Mabswid
.64832 .98918 m
.66484 1.01116 L
s
.7196 .94786 m .64729 1.03145 L .64961 .93612 L .763 .695 .788 r
F
.64961 .93612 m .57062 .99058 L .57742 .92257 L .664 .601 .775 r
F
0 g
.62887 .96332 m
.63327 .96446 L
s
.62258 .96119 m
.62887 .96332 L
s
.6193 .95801 m
.62887 .96332 L
s
.62887 .96332 m
.63182 .96723 L
s
.6163 1.03271 m
.62887 .96332 L
s
1 Mabswid
.76686 .86918 Mdot
.5 Mabswid
.75612 .86954 m
.76686 .86918 L
s
.75421 .8696 m
.75612 .86954 L
s
.74433 .86993 m
.75421 .8696 L
s
.74361 .86995 m
.74433 .86993 L
s
1 Mabswid
.76686 .86918 Mdot
.76686 .86918 Mdot
.76686 .86918 Mdot
.5 Mabswid
.75651 .86517 m
.76686 .86918 L
s
.75483 .86451 m
.75651 .86517 L
s
.74877 .86216 m
.75483 .86451 L
s
.74725 .86158 m
.74877 .86216 L
s
1 Mabswid
.76686 .86918 Mdot
.5 Mabswid
.75381 .85235 m
.76686 .86918 L
s
.75194 .84993 m
.75381 .85235 L
s
.74264 .83794 m
.75194 .84993 L
s
.73978 .83424 m
.74264 .83794 L
s
1 Mabswid
.76686 .86918 Mdot
.44566 .5676 m .62953 .64933 L .43278 .58315 L .728 .426 .468 r
F
.44566 .5676 m .64833 .63119 L .62953 .64933 L F
0 g
.5 Mabswid
.58545 .59342 m
.59195 .57453 L
s
.59904 .6063 m
.60263 .60732 L
s
.60263 .60732 m
.60576 .60821 L
s
.60576 .60821 m
.60618 .60833 L
s
.49963 .58423 m
.52165 .58885 L
s
.52165 .58885 m
.52632 .58983 L
s
.41247 .60357 m
.49083 .60268 L
s
.35716 .65222 m .49067 .72204 L .45107 .73927 L .613 .491 .689 r
F
.37799 .63443 m .49067 .72204 L .35716 .65222 L .648 .486 .651 r
F
.60273 .66768 m .75326 .79467 L .71019 .80706 L .82 .604 .61 r
F
0 g
.73283 .77743 m
.74348 .78318 L
s
.62953 .64933 m .75326 .79467 L .60273 .66768 L .863 .597 .535 r
F
0 g
.68265 .75036 m
.68569 .752 L
s
.69967 .72387 m
.70569 .72009 L
s
.70569 .72009 m
.71213 .71606 L
s
.6827 .7345 m
.69967 .72387 L
s
.69241 .77315 m
.69684 .77886 L
s
.43278 .58315 m .60273 .66768 L .41672 .59963 L .716 .449 .521 r
F
.43278 .58315 m .62953 .64933 L .60273 .66768 L F
0 g
.59029 .60381 m
.59904 .6063 L
s
.609 .61728 m
.61337 .61987 L
s
.53061 .60222 m
.53953 .60212 L
s
.61337 .61987 m
.61599 .62142 L
s
.37799 .63443 m .53099 .70421 L .49067 .72204 L .648 .486 .651 r
F
0 g
.41833 .71069 m
.41926 .71014 L
s
.41639 .71184 m
.41833 .71069 L
s
.39817 .61681 m .53099 .70421 L .37799 .63443 L .676 .478 .611 r
F
0 g
.41926 .71014 m
.4227 .70812 L
s
.65678 .81684 m .7196 .94786 L .64961 .93612 L .755 .659 .755 r
F
.71019 .80706 m .7196 .94786 L .65678 .81684 L .838 .71 .722 r
F
.41672 .59963 m .5692 .68603 L .39817 .61681 L .699 .466 .568 r
F
.41672 .59963 m .60273 .66768 L .5692 .68603 L F
0 g
.52632 .58983 m
.58263 .60163 L
s
.54533 .60205 m
.58263 .60163 L
s
.53953 .60212 m
.54533 .60205 L
s
.58263 .60163 m
.59221 .60731 L
s
.59221 .60731 m
.59627 .60972 L
s
.59627 .60972 m
.609 .61728 L
s
.58263 .60163 m
.58849 .60329 L
s
.58849 .60329 m
.59029 .60381 L
s
.58263 .60163 m
.58511 .59442 L
s
.58511 .59442 m
.58545 .59342 L
s
.39817 .61681 m .5692 .68603 L .53099 .70421 L .676 .478 .611 r
F
0 g
.52265 .65014 m
.527 .65106 L
s
.527 .65106 m
.53543 .65284 L
s
.50028 .64991 m
.51308 .65004 L
s
.48811 .64979 m
.49329 .64984 L
s
.49329 .64984 m
.50028 .64991 L
s
.51308 .65004 m
.52265 .65014 L
s
.48085 .64972 m
.48811 .64979 L
s
.45855 .63111 m
.47002 .63452 L
s
.47463 .63588 m
.49856 .64298 L
s
.47002 .63452 m
.47095 .63479 L
s
.47095 .63479 m
.47463 .63588 L
s
.49856 .64298 m
.50573 .64511 L
s
.50573 .64511 m
.52265 .65014 L
s
.53543 .65284 m
.53635 .65303 L
s
.53635 .65303 m
.5426 .65436 L
s
.5426 .65436 m
.54723 .65534 L
s
.4006 .68412 m
.40486 .68609 L
s
.39196 .68011 m
.4006 .68412 L
s
.43211 .70257 m
.43576 .70041 L
s
.4227 .70812 m
.43211 .70257 L
s
.42513 .69548 m
.43576 .70041 L
s
.41468 .69064 m
.42513 .69548 L
s
.40486 .68609 m
.41468 .69064 L
s
.43038 .70009 m
.43576 .70041 L
s
.42426 .69972 m
.43038 .70009 L
s
.41305 .69904 m
.41804 .69934 L
s
.41804 .69934 m
.41826 .69936 L
s
.41826 .69936 m
.42426 .69972 L
s
1 Mabswid
.58263 .60163 Mdot
.58263 .60163 Mdot
.58263 .60163 Mdot
.5 Mabswid
.54015 .63598 m
.5531 .62551 L
s
.5531 .62551 m
.5616 .61864 L
s
.5616 .61864 m
.58263 .60163 L
s
.52265 .65014 m
.5271 .64654 L
s
.5271 .64654 m
.53662 .63884 L
s
.53662 .63884 m
.54015 .63598 L
s
1 Mabswid
.58263 .60163 Mdot
.58263 .60163 Mdot
.58263 .60163 Mdot
.45107 .73927 m .48648 .83719 L .41483 .75554 L .594 .554 .78 r
F
0 g
.62887 .96332 Mdot
.62887 .96332 Mdot
.62887 .96332 Mdot
.62887 .96332 Mdot
.62887 .96332 Mdot
.62887 .96332 Mdot
.45107 .73927 m .53911 .83151 L .48648 .83719 L .594 .554 .78 r
F
.5978 .82479 m .57742 .92257 L .53911 .83151 L .671 .608 .777 r
F
.5978 .82479 m .64961 .93612 L .57742 .92257 L F
0 g
.5 Mabswid
.59423 .87044 m
.59477 .87062 L
s
.65678 .81684 m .64961 .93612 L .5978 .82479 L .755 .659 .755 r
F
0 g
.60604 .87453 m
.61198 .87867 L
s
.60604 .87453 m
.61317 .87429 L
s
.60604 .87453 m
.62887 .96332 L
s
.59477 .87062 m
.60604 .87453 L
s
.59834 .87424 m
.60604 .87453 L
s
.5977 .87421 m
.59834 .87424 L
s
.5692 .68603 m .71019 .80706 L .65678 .81684 L .772 .599 .664 r
F
0 g
.68103 .74949 m
.68265 .75036 L
s
.60273 .66768 m .71019 .80706 L .5692 .68603 L .82 .604 .61 r
F
0 g
.66907 .74304 m
.67895 .74837 L
s
.67895 .74837 m
.68103 .74949 L
s
.66907 .74304 m
.68175 .73509 L
s
.68175 .73509 m
.6827 .7345 L
s
.66907 .74304 m
.69012 .77019 L
s
.69012 .77019 m
.69241 .77315 L
s
1 Mabswid
.43576 .70041 Mdot
.5 Mabswid
.43576 .70041 m
.44161 .70497 L
s
.44161 .70497 m
.44552 .70802 L
s
.44552 .70802 m
.44603 .70842 L
s
.44603 .70842 m
.46258 .72133 L
s
1 Mabswid
.43576 .70041 Mdot
.5 Mabswid
.43576 .70041 m
.4388 .70097 L
s
.4388 .70097 m
.44144 .70145 L
s
.44144 .70145 m
.4448 .70206 L
s
.4448 .70206 m
.45357 .70367 L
s
.64894 .73936 m
.66907 .74304 L
s
.64061 .73784 m
.64894 .73936 L
s
.63837 .73743 m
.64061 .73784 L
s
1 Mabswid
.43576 .70041 Mdot
.5 Mabswid
.43576 .70041 m
.43866 .69874 L
s
.43866 .69874 m
.44153 .69708 L
s
.44153 .69708 m
.45955 .68665 L
s
.45955 .68665 m
.46273 .68481 L
s
.51571 .65415 m
.52265 .65014 L
s
.47706 .67652 m
.49704 .66495 L
s
.46778 .68189 m
.47706 .67652 L
s
.49848 .66412 m
.51571 .65415 L
s
.49704 .66495 m
.49848 .66412 L
s
.46273 .68481 m
.46778 .68189 L
s
1 Mabswid
.43576 .70041 Mdot
.43576 .70041 Mdot
.43576 .70041 Mdot
.49067 .72204 m .53911 .83151 L .45107 .73927 L .664 .574 .744 r
F
0 g
.5 Mabswid
.50923 .71383 m
.59877 .7302 L
s
1 Mabswid
.60604 .87453 Mdot
.60604 .87453 Mdot
.60604 .87453 Mdot
.60604 .87453 Mdot
.60604 .87453 Mdot
.5 Mabswid
.57825 .83577 m
.60604 .87453 L
s
1 Mabswid
.60604 .87453 Mdot
.49067 .72204 m .5978 .82479 L .53911 .83151 L .664 .574 .744 r
F
0 g
.5 Mabswid
.57375 .8295 m
.57825 .83577 L
s
.52169 .77756 m
.5249 .77816 L
s
.52573 .78413 m
.52851 .78342 L
s
.5608 .7893 m
.63828 .81933 L
s
.50542 .75474 m
.50576 .755 L
s
1 Mabswid
.66907 .74304 Mdot
.5 Mabswid
.65055 .7484 m
.66907 .74304 L
s
.63183 .75383 m
.65055 .7484 L
s
1 Mabswid
.66907 .74304 Mdot
.66907 .74304 Mdot
.66907 .74304 Mdot
.66907 .74304 Mdot
.5 Mabswid
.63611 .72213 m
.66907 .74304 L
s
.52265 .65014 m
.52947 .65446 L
s
.52947 .65446 m
.54568 .66475 L
s
.54568 .66475 m
.55099 .66812 L
s
.55099 .66812 m
.55316 .66949 L
s
.6201 .71197 m
.63611 .72213 L
s
1 Mabswid
.66907 .74304 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.53099 .70421 m .65678 .81684 L .5978 .82479 L .721 .589 .707 r
F
.5692 .68603 m .65678 .81684 L .53099 .70421 L .772 .599 .664 r
F
.53099 .70421 m .5978 .82479 L .49067 .72204 L .721 .589 .707 r
F
0 g
.5 Mabswid
.55361 .77649 m
.5558 .77585 L
s
.54501 .77898 m
.55361 .77649 L
s
.53882 .78078 m
.54501 .77898 L
s
.51503 .76223 m
.53882 .78078 L
s
.50576 .755 m
.51503 .76223 L
s
.53882 .78078 m
.54453 .78299 L
s
.54453 .78299 m
.54981 .78504 L
s
.54981 .78504 m
.55113 .78555 L
s
.53073 .78285 m
.53882 .78078 L
s
.52851 .78342 m
.53073 .78285 L
s
.52785 .77871 m
.53882 .78078 L
s
.5249 .77816 m
.52785 .77871 L
s
.53882 .78078 m
.55348 .80122 L
s
.55348 .80122 m
.55955 .80969 L
s
.55955 .80969 m
.57168 .8266 L
s
1 Mabswid
.53882 .78078 Mdot
.53882 .78078 Mdot
.53882 .78078 Mdot
.53882 .78078 Mdot
.53882 .78078 Mdot
.53882 .78078 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{196.625, 286.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003400017PP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000<Ad0034M000a7@00<Ad0034M000a7@00<Ad
0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad
0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad
0034M000a7@00<Ad0034M000a7@006id0Q5DM000K7@24@04JeHA4E9d001[M0084EI[EV]FJa5AM000
JW@02Q5G4A5[EV]FJe5@M000JW@02a5GEeLAJeI[EV]=04md001YM0064FmGKeM_0Q401EI[EV]A04id
001YM0034EMG00EG00HAEV]FJeI=M000J7@02Q5GKeM_EfmGKeL24@04JeI[ETad001XM0034EMG00UG
00DAJeI[EP1;M000J7@03A5GG5M_EfmGKeM_Efl00Q400eI[EP1:M000J7@00a5GE`0;E`06EQ5FJeIA
B7@006Md014AG5MLEeaGG5M_EfmGKeM_E`024@03JeIA04Md001WM0034EMG00mG00E[4F]FJ`16M000
Ig@0515LEeaGG5MLEeaGKeM_EfmGKeM[0Q400eI[M014M000Ig@00a5GE`0BE`04EQ5FJdAd001WM00G
4EaGG5MLEeaGG5MLEeaGKeM_EfmGKeH00Q400f]dM011M000Ig@00a53E`0DE`04EQ4AJd9d001WM00L
4EaGG5MLEeaGG5MLEeaGG5M_EfmGKeLAEa5FJd5d001WM0064D=G@eM34UL34@03EVid03md001VM00L
4EMLEe`AG5MLEeaGG5MLEeaGG5MLEfmGKeM_E`9^@7@006Id0Q401d=G@eM3Ed<04UL0115JKVXoM000
IW@34@0GEeaGG5MLEeaGG5MLEeaGG5MLEeaGKeL00fl2KSmd001VM0034EM3008A00QG@eM3Ed=G@`aG
00I_FVmJKfXoM000IW@06Q53G5ML4EaGG5MLEeaGG5MLEeaGG5MLEeaK16l2KSid001VM0064DA3Ed=G
0Q401d=G@eM3Ed<02UL01fmGKeY_FQ40?W@006Id00PA@ea3G5MLE`8A015LEeaGG5MLEeaGG5MLEg1K
L004K`034Fid03ad001WM00B4D=4@dA3Ed=G4EM3Ed=G@eM315L02VmGKeM_FVmJ4FXmM000Ig@02Q5L
@ea3G4=LEe`24@0?EeaGG5MLEa5GG5]`Fg1K00A_00<AM7@0>g@006Md00`A@dA3A4=4@eM3Ed<24@06
Ed=G@eM30UL02fmGKeM_EfmJKa5^03ad001WM00>4Ea3G4=L@ea3G5MLEe`24@0=Ee`AG5M`Fg1KL5]`
4@03K`034GAd03Yd001WM00D4B]4@dA3A4=4@dA3Ed=G@a534D<2E`0<FeM_EfmGKeY_FQ5Z>g@006Md
010AA2mL@ea3G4=L@ea3G5ML0a402eaKL5]`Fg1KL5]`00=_00<AM7@0>G@006Md028A:c0[A4=4@dA3
A4=4@eM34D<A@e]GFeM_EfmGKeM_FVlA>g@006Md01lAA2m4;ea3G4=L@ea3G4=LEeaGL5]`Fg1KL5]`
Fg1K00=_00<AM7@0>7@006Md018A:c0[<2]4@dA3A4=4@dA3A4<2E`0?FeMKEe]GKeM_EfmJKeXA03Yd
001WM00P4D@_A2m4;ea3G4=L@ea3G4=LFg1KL5]`Fg1KL5]`Fg03K`034GAd03Md001WM00R4B/`:c0[
<2/`@dA3A4=4@dA3G5MK4E]GFeM_EfmGKeM_FP<A>7@006Md024A5bm4;d@_A2m4@ea3G4=L@eaGG5]`
4G1KL5]`Fg1KL5/00fl24CMd001WM08A028G:c0[<2/`:c13A4=4@ea3G4=KEe/AFeMKEfmGKeM_EfmJ
0Q4gM000Ig@24@0T4aL_A2m4;d@_A4=L@eaGG5MLEg1K4E]`Fg1KL5]`Fg1_4FlA=g@006Md0Q4091LC
5b/`:c0[<2/`@dA3G4=L@ea3FeLAEe]GFeM_EfmGKeY_4CMd001WM08A024C5a<G;d@_A2m4;dAGG5ML
EeaGG5]`Fa5KL5]`Fg1KL5/00flgM000Ig@24@0T4Q<G4aL[<2/`:c0[F4=L@ea3G4=LEe]G4EMKEfmG
KeM_EfmJ=g@006Md0Q408Q8G4aLC5bm4;d@_G4=LEeaGG5MLEeaKL5/AFg1KL5]`Fg02KcMd001WM08A
0Q808QLC5a<G:c0[<4=H@ea3G4=L@ea3FeMKEa5GFeM_EfmGKa4gM000Ig@24@8B028C5a<G4aL_A4=L
@ea3G5MLEeaGG5M`Fg0AL5/AFg1KL5/A=g@006Md0Q434P034aLC008A01<G:eQ3F4=H@ea3G4=L@eaG
FeMK00<A00IKEfmGKeXgM000Ig@24@<B00<A4aL00Q404Q=L@ea3G4=LEeaGG5MLEeaKL0<A00M`Fg1K
L7=b03Md001VM0@A0a8011LC4A42@`0AF4=H@eQ3F4=L@ea3G4=LEe/00Q400eMKE`02K`03LeYd03Id
001VM0<A021c4Q8B4ALCF4=H@ea3G4=L@eaGG5MLEeaGL15`4G1KL0=c>7@006Ed1A424P034A8C00I3
01MH@eQ3F4=L@ea3G4=L4E]G4EMKEg=_L`0hM000IG@24@05:a4A4Q400Q806eQ3F4=H@eQ3G4=L@ea3
G5MLEeaGG5M`Fg1KM003L`034GAd03Ed001TM0<A00P[4A4B4A93?`I301QH@eQ3F4=H@ea3G4=L@eaG
FeMdFg=_La4gM000I7@24@03:a4A008A01hBA4=4@eQ3F4=H@ea3G4=L@eaGG5MLEeaGG5]dKg@3L`03
4GAd03Ed001SM0LA00DB@cm3?`08@`0FF4=H@eQ3F4=L@ea3G4=dFgAKLfm^4CMd0014M0TA00@U>BDd
4G@84@0OA4=4@dA3F4=H@eQ3F4=L@ea3G4=LEeaGG5M`KgA_M002L`03FQ5d03Id000mM0PA0bD24@8U
11401RDi9CTU6`]d214024<o@cm3?d<o24<055Q3F4=H@ea3G4=LFgAKM5]cKg@A=g@003ad1Q439@<A
00Hi9CXi>ST24@09>STj>CXi>RDi00XA00<V4A400Q408D<o@d=4@dA3A4=H@eQ3F4=L@ea3G4=L@eaG
L5]`KgA_M002L`8A=g@003Ud1a439@<A00TU>BDi9CTU>RD01Q400cXU>P03>@8U00=d4A401Q402chA
?d<o@cm3?d<o00E301DA@d=H@eQ3F4=HFeaKG5]d4GAKLfl00Q4gM000=g@74@8U11401cXi>STj>CX0
114033XA>Shj?SXn>ShiD@@i00<U71401Q4044<o@cm4@dA3A4=H@eQ34D<24@0?G4=L@eaKG5]`Fg1_
4Fmd009c0Q4gM000=W@64@8U11401RDj9CXU>P<A01Hj9CXU?Q4n>Chi?STn>DdiCCU=>Ddi2A402Cm3
?d<o@cm3?`03@`<A0T<04EQ3F5MLEeaKG5]dFa5KLflA03Qd000dM0HA00<i9CX00a400cXi4@054@0K
?SXn>Shj?SXn4Chj?SXn>ShjDU5B>E4iDCUA00<i1a4074=4@dA3A4=H4EPAF4=L@eaKG5]LFg1KL6md
4G@2L`034GAd03Id000cM0<A0bD01cTU>RDA9CX00Q403RDA4A4i?STn>Chi?SXn1Q4013Xn>Sh24@09
>E4iDCU=>Ddi00/A00<o@cl00Q43@`0C4D=3F15LEeaGG5]LFgAK4E]c4@0iM000<G@39@05>STj>CX0
0Q401SXn>ShA?P8A00Tj?SXn>Shj?SX0114013hA?Sh34@<n1E80155BDE82D@06>E4iDCUA13T074<A
4A53F4=H@eQ3F5]LFeaKG5]`Fg1_M15dLa4iM000<7@54@0D4RDj9CXU?STn>Chi4CXn>Shj?SX54@0P
>ShA?SXn>Shj?SXnDE9ADU5BDE8iDCUA>E4iCCU=>Dd2>@<A00=3?d<00d<04E]GFeMLEeaGG5]LFgAK
4E/A03Yd000]M0HA00lB4A4n>Shj?SXn>Shj?SX02Q44?P034Chn00Ln00=FDUH01U824@9B00]ADU5B
>E4iDCUA>@034@0C>EQGG5MLEeaKG5]LFg1KL6mdK`024CYd000/M0@A00@B4A8A0Q802SXn4A4j?SXn
>Sh24@03>Shj00<A014j?SXn>Shj4CXn>Shj?SXn>P09DP03DE9A00@A00eB>E4iDCU=>Ddi4CU=008i
011GFeMKEeaGG5MLFeaKM15d0Q4jM000;7@34@034Q4B008A00<V4Sh033h24@Xn00<A?Sh01Sh03EIB
EU9FDUIBEU9FDUH015884@0EDE8i4CUA>E4iG5MLFeaKG5]`Fg1_00<A00=cM7@0>7@002]d1140118A
4A834@0V>Shj?SXn>Shj?SXn>Shj?SXn>Shj?SXn4Chj?SXn>Shj?U9FDUH34@UB3A404U4iCCU=>C1G
G5MLEeaKG5]dF`8A00=cM7@0>7@002Yd11401RHA4A8V4@8B33h01Cln?cho00dA01Lo?SlAEe9GDUMB
Ee9FDUIBEU9FDUIBEP09DP<A00iADU5A>C1KG5]LFg1KL0<A00=dLg@0>G@002Yd1A400a8A4P034@0:
4SXn>Shj?SXn>PPA00<n4A400Q401CXn4Chj00<A00hj?SYFDUIBEU9FDUIBEPiB00MADU4ADE9A008A
00eA>E4i<5MLEeaKG15d008A00=KM7@0>G@002Ud1A400bHA9P024@0:4Q4n?cho?Sln?`8A00Dn?cho
?P044@0/?cho?SlA?cho?Sln?ciGEUMFEe9GDUMBEe9GDUMBEU9FDUIBEU9FDUIBEQ45DP8A0U802e5B
FeaKL15`Ka5_03ad000YM0<A00HB4A4B4A834@hn00<A?Sh01Ch24@Pn01=GDUMBEe9GDUMBEU9FDUIB
EU9F00]B00<ADU800U80255B4E9ADU5B0Q401E]LFgAK03ed000XM0HA00<V4A800a40;Cln?cho?Sln
?cho?Sln?cho?Sln?chA?Sln?cho?SlnEeIGEUMFEeIGEUMFE`034@0EEe9GDUMBEe9FDUIBEU9F4EIB
EU9F00QB00MKL5]`KgA_03ad000XM0DA00<B4A400a40<A8n?cho?Sln?cho?Sln?cho?Sln?chA?Sln
?cho?SlnEe9GDUMBEe9GDUMBEe9GDUL01A401eIBEU9FDUH00U800a5BDP09DP09DE9A>E]LFa5K03ed
000XM0PA03TB4A8n?cho?Sln?cho?Sln?cho?Sln?cho4Cln?cho?SlnEeIGEUMFEeIGEUMFEeIGEUMF
EeIGEUL01Q405e9GDQ5BEU9FDUIBEU9FDUIBEQ5AFg0A03id000WM0PA02hB4A4A?cho?Sln?cho?Sln
?cho?Sln?cho4Cln?cho?SlnEe9GDUMBEe9GDUMB11401UMBEe9GDP/A00ABEU9F2e80115A>E/oM000
9g@74@0=4Q4A4Cln?cho?Sln?`0A4@04?cho?PEG01eFEeIGEUMFEeIGEUMFEeIGEUMFEeIGEUMFEe8A
DP054@0<DUMBEU9FDUIBEU5Y0U400a5dM00lM0009W@54@034Q4A00<A00hB?Sln?cho?Sln?cho?PDA
00Hn?a4A?Sl34@0W?ciG?ULnEciG?UMBEe9GDUMBEe9GDUMBEe9GDUMBEe9GDQ5BEU9F00<A00EFDUIB
EP05DP06IE5UDCTA?G@002Id11400a8A4@024P0N4A8n@ci3?T<n@ci3?T<n@ci3?T<n@a53?T<n@ci3
3UL06eIGEUMFEeIGEUMFEeIGEUMFEeHAEUMFEeIGDP024@0>Ee9GDUMBEe9YDFUAJE434C]d000VM0DA
04`B4A8A4Sho?Sln?cho?Sln?cho?Sln?cho4Cln?cho?Sm2Ed9G?ULnEciG?ULnEciG?UMBEe9GDUMB
Ee9GDUMBEe8ADUMBEe9GDUMB0Q403eIBEU9FDUIEJU5UDFEA>@034CUd000UM0XA01`o@cm3?d<o@cm3
?d<o@ci3?T<n@a53?T<n@ci355L085IGEUMFEeIGEUMFEeHAEUMFEeIGEUMFEeIGEUMBEe9G16X0155Y
DFT2D@034G@A03Qd000UM0@A11824@0k?cho?Sln?cho?Sln?cho?Sln?a4o?Sln?cho@UM2Ed9G@UM2
Ed9G?ULn4CiG?ULnEciGDUMBEe9GDUL00Q407U9GDUMBEe9GDUMBEe9GDUMBEeEZEFYEJU5UDFEA>@8A
>7@002Ed0Q454P094A93?d<o@cm3008A00To@cm3?d<o@cl00Q401d<o@cm3?d<04EL54@IG00=FEeH0
0Q405EMFEeIGEUMFEeIGEUMFEeIGEUMFK`06JP05DFUAJE40114fM0009G@44@8B00`A4Q8[?b/o?Sln
?ch54@0S?Sln4Cho?Sln?cho@eM3Ed9G@UM2Ed9G@UM2Ed9G?ULnEch00a40:SiG?ULnEa5GDUMBEe9G
DUMBEe9GDUMBEe9GDVYFJUIZEFYEJU5UDFEA>@@A=7@002Ed0Q40518C4A<A4cm3?d<o@cm3?d<o@cm3
214013m3?d<KE`8A0eL06Q5GEeMFEeIGEUMFEeIGEUMFEeIGEVmZKfY_1VX0155YDFT2D@9d0Q4cM000
9G@24@<B0a404cl[?b/o:cl[?b/o?SlA?cho4Cl00Q4073ho?UM3Ed=G@eM3Ed=G@UM2Ed9G@UM2Ed9G
@UL;4@0VEciG?UMBEe9GDUMBEe9GDUMBJUIZEVYFJUIZEFYEJUEUDFEA>G@24C=d000UM0<A01hC4Q4A
@cm3?d<o@cm3?d<o@cm3?d<A@cm3?a4oEd<LE`8A0eL00a5G4@024@EG019FEeIGEUMFEeI_EVmZKfY_
JVl7JP03JE5Y009A0a4bM0009G@34@104Q4B4R/o:cl[?b/o:cl[?b/o:clA?cho?SlnEd=G@eM3Ed=G
@eM3Ed=G@eM3Ed9G@UM2Ed9G@UM24D9G?ULnE`8A02HnEciG?ULnEciGDUMBKeI_EVmFKeIZEVYFJUHA
EFYEJUEUDFDA>@8A<W@002Ed0a408Q<A4b]4:d@[4Cm3?d<o@cm3?d<A@cm3?d<oEd=G@eM3Ed<FE`8A
25L34@QG015FKeI_EVmFKeI_JVmZKfY_JP024@AZ00MYDFUA4G@A035d000UM08A00@B4A4B0R/0<Cl[
?a4o:cl[?b/o:clA?b/o:cl[Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed=G@eM3Ed9G@UL00Q40:49G@UM2Ed9G
?ULnEciG?ULnEciGEU]FKeI_EVmFKeI_EVYFJUIZEVX24@09EFYEIE5U4CTA035d000VM00;4A8A4D@[
A2]4:d@00Q406cm3?d<o@clA?d<o@cmH@eQ3Ed=G@eM3Ed=G@`0>E`8A55L06FmGKeM_EfmFKeI_EVmF
KfY_JVmZKfY_JQ400fX01FUA4E4A035d000VM0<A00<B5b/00b/013l[?b/24@03?b/o008A00D[?b/o
:`06@`07Ed=G@eM3E`034@0;Ed=G@eM3Ed=G@eL00Q40;d=G@UM2Ed9G@UM2Ed9G@UM2EciG?U]FFeIK
EU]FKeI_EVmFKeI_EVYFJUIZEVYE008A00MZEFYA4E4A031d000VM08A00XC:c0[A2]4:d@[1Q406T<o
@cm3?eQ3F4=H@eQ3F4=G@eM3Ed=G4EM31eL00a5GE`0DE`0KKeM_EfmGKeM_EfmFKeI_EVmFKeI_JVmZ
KfXA009Z0Q42JP044FUADBmd000VM08A00DG:aL[5`04:`05?b/o:cl011400b/o:`0<@`07Ed=G@eM3
E`024@05@eM3Ed<00Q40<UM3Ed=G@eM3Ed=G@UM2Ed9G@UM2FeMKEe]FFeIKEU]FFeI_EVmFKeI_EVmF
JUIZEVYF1a40155UDCT^M0009W@24@0@61L/:a4[A2]4:d@[A154:`8A01I3?dA3A4=4@eQ3F4=H@eQ3
Ed=G@eM31a4CE`0SKeM_EfmGKeM_EfmGKeM_EfmGKeI_EVmFKeI_EVmZKfY_JVl00VX34@03JU5Y009A
;G@002Id0Q401a<G5b/A:aL01R/01A4[?b/o01=300IG@eM3Ed<64@0fEd=G@eM3Ed=G@eM3Ed=KEe]G
FeMKEe]GFeMKEU]FFeIKEU]FFeI_EVmFKeI_EVYFJUIZEVYF0a401UEZDFEA>Bad000VM0074A<H5aPA
;0024@0[:d@[A2/A:d@[A4=4@dA3A4=4@dA3F4=H@eQ3F4=H@eM3Ed<A@eM3Ea5G@`0<E`0WG5MLEfmG
KeM_EfmGKeM_EfmGKeM_EfmGKeI_EVmFKeI_EVmZKfY_008A0fX01A5ZJU5Y009A:g@002Id00/A4a<A
4aLA:a4[5`02:`0:4B/[:cl_A2m4;aA304TA@eM3Ed=G4EM3Ed=G@eM3Ed=KEe]GFeMKEe]GFeMKEe]G
FeMKEU]F4EIKEU]FFeI_EVmFKeI_EVmFJQ5ZEVYFJUDAEFYEIE4i02Yd000VM08A00DG4a4G;0034@0^
<2]44D@[A4=4@dA3A4=4@dA3A4=4@dA3F4=H@eQ3F4=H@eM3Ed=G@eLAEd=G@`AG01QLEeaGG5MLEeaG
KeM_EfmGKeM_EfmGKeL24@0=KeM_EfmFKeI_EVmFK`034@08KfY_JVmZKa44JP03JE5d02Ud000WM0@A
00@G4b/G0Q400b/A:`03:`08<2]4;d@_A2l24A93045G@eM3Ed=G4EM3Ed=KEe]GFeMKEe]GFeMKEe]G
FeMKEe]GFeMKEU]FFa5KEU]FFeI_EVmFKa5_EVmFJUIZEVYFJP024@05EFYEIE40:G@002Md00XADA4G
4APG;1L/0a40:4@[A2m4;dA3A4=4@a53A4=4@dA3A4=H@eQ3F4=H@eQ3F4=G@eM3Ed<2E`0OG5MLEeaG
G5MLEeaGG5MLEfmGKeM_EflAKeM_EfmGK`024@07EfmGKeM_EP024@0=KeI_EVmZKfY_JVmZK`024@=Z
00=Y5g@09g@002Qd00Ti4A4C4ALC:aL00Q403b/G<2/`:c0[A2m4;d@_4@0E@`0:Ed=G@eM3Ed=G@`9G
03UKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeIKEU]F4EIKEU]F4EI_EVmFKeI_EVYFJUIZEVXAJUEZEFD0
:7@002Ud00]=4A4A4aPG4AL/4@03<00;;d@_A2m4@dA3A4<00Q400dA3A0024@0c@dA3A4=H@eQ3F4=H
@eQ3G5MLEeaGG5MLEeaGG5MLEeaGG5MLEeaGKeM_EfmGKeM_EfmG00HA01E_4A5GKeI_EVmFKeI_EVmZ
KfY_JVl01FX00badM00UM000:W@05STA4a4C5a4[5c0G<1L`:c0[<2]4;d@54@03@a5300m300aH@eM3
Ed=G@eM3Ed<2E`0KFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]FFeIK00<A01YKEU]FKeI_EVmFKeI_EVYF
JUIZEVYFJUEZ4RMd000[M08A00PC4ALA5b`G70@`00/_A2m4;dA3A4=4@`054@0d@dA3A4=4@eQ3F4=L
@ea3G4=LEeaGG5MLEeaGG5MLEeaGG5MLEeaGG5M_EfmGKeM_EfmGK`@A00=GKa400Q404fmGKeI_EVmF
KeI_EVmZKfY_JVl00fX00a=dM00UM000;7@01A4C4ALA008G01DH5aPA<1L`:c0[<2/`;d@_A1544D@0
2D<055Q3F4=H@eQ3F4=G@eM3Ed=G4EM30UL055]GFeMKEe]GFeMKEe]GFeMKEe]G0Q4085]GFeIKEU/A
Fa5KEU]FKeI_EVmFKeIZEVYFJUIZEVXB9g@002ed00<A4a400Q401A`G71LL008A0S00HRm4;d@_A4=4
@dA3A154@dA3A4=4@dA3G4=L@ea3G4=L@eaGG5MLEe`AG5MLEeaGG5MLEeaGG5MLEfmGKeM_EfmGKeM_
EfmGKeM_4FmGKeM_EVmFKeI_EVmFKfY_JVmZKfXC9g@002ed0a400a<A5`024@0C61LH5a4G<2/`:c0[
<2m4;d@_A0024@=301Y4@dA3A4=H@eQ3F4=H@eQ3Ed=G@eM3Ea5G@`9G03EKEe]GFeMKEe]GFeMKEe]G
FeMKEe]GFeMKEU]FFa5KEU]FFeI_EVmFKeI_EVmFJUIZEVYE4P0VM000;W@24@055a<H5aP00Q4011LL
5a43<00WA2m4;dA3A4=4@dA3A4=4@dA3A4=4@ea3G4=L@ea3G4=LEeaGG5ML008A03MGG5MLEeaGG5ML
EeaGG5M_EfmGKeM_EfmGKeM_EfmGKa5_EfmGKeI_EVmFKeI_EVmZKfY_EFdB02Id000_M08A00@C9CTA
0QL64@0Z<14`:c0[<2m4;d@_A2l`@dA3A4=4@dA3F4=H@eQ3F4=H@eM3Ed=G@eM30Q42E`8A035KEe]G
FeMKEe]GFeMKEe]GFeMKEe]GFeIKEQ5FFeIKEU]FKeI_EVmFKeI_EVYEKEDB02Id000`M0<A0ST01Q4H
5a`G70@A02L`A2m4;dA3A4=4<4@`A4=4@dA3A4=4@ea3G4=L@ea3G4=LEeaGG5L01A40<eMLEeaGG5ML
EeaGG5MLEfmGKeM_EfmGKeM_EfmG4EM_EfmGKa5_EVmFKeI_EVmEKEE]4P0VM000<G@34@8i0Q401QLH
5aPA60@A02@[<2/`;c0_<2l`;c13A4=4@dA3A4=H@eQ3F4=H@eQ3Ed=G@eL24@0f@eLA4EMKEe]GFeMK
Ee]GFeMKEe]GFeMKEe]GFeMKEU]FFeIKEU]FFa5_EVmFKeI_KVmEKEE]9W@0039d1A402CTA5aPG4ALL
4@02<01MA2m45a``A314<4@`4D=4@dA3A4=4@ea3G4=L@ea3G4=LEeaGG5MLEa5GG5MLEeaGG5MLEeaG
G5MLEfmGKeM_EfmGKeM_EfmGKeM_EfmGKeM_EVm^LficKVeEKEDC02Ed000dM0039CTA00@A00/G4APG
614`5a4G70034@0T<2l`;c0_4D=4@dA3A4=4@eQ3F4=H@eQ3F4=G@eM3Ed=G@a530UL0;U]GFeMKEe]G
FeMKEe]GFeMKEe]GFeMKEe]FFeIKEU]FFeIKEVm^Kfi_KVmEKED24BEd000fM003>BDA00DA00dL5a`C
5a<L5a`G7314008A044`A30A@dA3A4=4@dA3G4=L@ea3G4=L@eaGG5MLEeaG4EMLEeaGG5MLEeaGG5ML
EeaGKeM_EfmGKeM_EfmGKeM_E`06K`0:LficKW=^LeE]E@8A97@003Yd1A403QPGDA4C4Q<G71LL;c0_
0a407blA@dA3A4=4@dA3F4=H@eQ3F4=H@eM3Ed=G@eLAEd<00UL065]GFeMKEe]GFeMKEe]GFeMKEe]G
FeMKE`9K01E_FfmKKe]_Ffm^Kfi_KVm^KEE]EA4097@003ad2A402a<L5a`G7314<4@`00DA03I3A4=4
@dA3G4=L@ea3G4=L@eaGG5MLEe`AG5MLEeaGG5MLEeaGG5MLEeaGKeM_EfmKL5]`Fg0:K`0:KW=^Lfic
EFeEK@8A8g@003md21403A`G71LL;c0_<2l`4D@00Q406d=4@dA3A4=H@eQ3F4=H@eQ3Ed=G@eM3Ea5G
@`02E`0<FeMKEe]GFeMKEe]G0U/086mKKe]_FfmKKe]_FfmKKe]_FfmKKfi_KVm^KeE]EA8A8g@004=d
1a40<A`G7314<4@`A154@dA3A4=4@dA3G4=L@ea3G4=L@eaGG5MLEa5GG5MLEeaGG5MLEe`00Q403e]L
FeaKL5]`Fg1KL5]`F`09K`09KW=^LficKVeE008A00=d4G@08G@004Ed1a409aLL;c0_<2lA@dA3A4=4
@dA3A4=H@eQ3F4=H@eQ3Ed=G@eM34D=G@`02E`0[FeMKEe]GFeMKEe]GKe]_FfmKKe]_FfmKKe]_FfmK
Ke]_KVm^Kfi_EFeEK@024B9d0018M0DA040GKc14<4@`4D=4@dA3A4=4@a53G4=L@ea3G4=LEeaGG5ML
Ea5GG5MLFeaKG5]LFeaKG5]LFg1KL5]`Fg1KL5]`2Fl02g=^LficKW=EKEEd008A8G@004]d114041`_
<2l`;a53A4=4@dA3A4<24@0PA4=4@dA3A4=4@ea3G4=L@a53G4=KEe]GFeMKEe]GFeL2F`0=Ke]_FfmK
Ke]_FfmKK`024@0>FfmKKe]_KVm^Kfi]EFd34B5d001<M0035a4A008A03d`A314<14_A2m44D@_A15L
@ea3G4=L@ea3G5MLEeaGG5LAEeaGG5]LFeaKG5]LFeaKG5]`Fg1KL5]`Fg1K00A_00<AKfl00Vl01fic
KW=^LeD00Q400a=d4@0QM000CW@0115A4A445`1=4D@[A2]4:d@[A4=4@dA3A4=4@dA3G4=L@ea3G15L
@eaGFeMKEe]GFeMKEe]GKe]_FfmKKe]_FfmKKe]_4FmKKe]_KVm^KfhAEFeEM1408G@004md00<ADA40
0Q40>aPG6154;d@_A2m4;dA3G4=L@ea3G4=LEeaGG5MLEe`AG5MLFeaKG5]LFeaKG5]LFg1KL5]`Fg1K
L5]`00A_00<AKfl00Vl02g=^LficKVeEKG@A025d001@M08A034m4A4A5a4[A2]4:d@[A2]4@dA3A4=4
@dA3G4=L@ea3G4<A@ea3FeMKEe]GFeMKEe]G009K01i_FfmKKe]_FfmKKe]_FflAKe]_KQ5^Kfi_EFeE
4Q4QM000DG@24@0m5a4A4ALA;d@_A2m4;dA3G4=L@ea3G4=L@eaGG5MLEeaG4EMLEeaKG5]LFeaKG5]L
FeaKL5]`Fg1KL5]`F`02K`034FlA00=_00/AKW=^Lfi]EFdB4@0QM000DW@24@8G1140>B]4:d@[A2/A
@dA3A4=4@dA3A4=L@ea3G4=L@a53G5MKEe]GFeMKEe]GFeM_FfmKKe]_FfmKKe]_F`034@0=Fa5KKfi_
KVm^KEE]4@0QM000Dg@24@045aPA608A01T_A2m4;d@_G4=L@ea3G4=L@eaGG5MLEeaG008A01]LEeaK
G5]LFeaKG5]LFeaKL5]`Fg1KL5]`Fg001Q42K`0:KW=^LficEFeE4B5d001DM0044ALG5`8A01X[4A4A
:d@[A4=4@dA3A4=4@dA3G4=L@ea3G0@A00e3FeMKEe]GFeMKEe]G009K01a_FfmKKe]_FfmKKe]_FflA
Ke]_KVm^Kfi]EFdA8G@005=d00HADQ4H5aP24@0g;d@_A2m4;dA3G4=L@ea3G4=LEeaGG5MLEeaG4EML
EeaKG5]LFeaKG5]LFg1KL5]`Fg1KL5]`F`04K`0=4Fm_Kg=^LficKVeE4@0QM000DG@24@03DCTA008A
0QL0BA54:d@[A2]4:dA3A4=4@dA3A4=4@ea3G4=L@ea34D=LEe]GFeMKEe]GFeMKEfmKKe]_FfmKKe]_
FfmKKa5_Ffm^Kfi_KVmEKED08G@004id11400e8i4@024@034Q4G008A03M4;d@_A2m4@ea3G4=L@ea3
G4=LEeaGG5MLEe`AG5MLFeaKG5]LFeaKG5]LFg1KL5]`Fg1KL5]`00A_00`AKfm_KW=^Lfi]EFdQM000
CG@00a5;4@024@03>E4A00<A02lB4A4A:d@[A2]4:a53A4=4@dA3A4=4@ea3G4=L@ea34D=L@e]GFeMK
Ee]GFeMKE`02F`0JKe]_FfmKKe]_FfmKKe/AFfmKKfi_KVm^KA4QM000C7@01A5<4DaP00<A041BC14A
4a8A:a4[A2]4;d@_G4=L@ea3G4=L@eaGG5MLEeaGG15LEeaGG5]LFeaKG5]LFeaKL5]`Fg1KL5]`Fg1K
0fl00a5_K`02K`08LficKW=E4A8PM000C7@01Q5P4GA;H08A00@iDQ4V0a824@L[0413A4=4@dA3A4=4
@ea3G4=L@ea3G15L@eaGFeMKEe]GFeMKEe]GKe]_FfmKKe]_FfmKKe/AFfmKKfi_KVm^KA4B87@004]d
00LAH15PC61<008A045B4A4U4A8A:a4[A2]4:d@[F4=H4Ea3G4=L@ea3G5MLEeaGG5LAEeaGG5]LFeaK
G5]LFeaKG5]`Fg1KL5]`Fg1KL002K`034Fm_009_00QcKW=^LfhAEB1d001:M0094F1;4D]PBf1;00LA
0R/24@H[1D<24@9301a4@dA3G4=L@ea3G15L@ea3FeMKEe]GFeMKEe]G0U/06FmKKe]_FfmKKe]_FflA
Ke]_Ffm^Kfi_EFd087@004Yd00hAG15LM5adG7AL4E4o?P8A03a44A4AA2]4:d@AF4=H@eQ3F4=H@eQ3
G5MLEeaGG5ML4EaGG5MLFeaKG5]LFeaKG5]`Fg1KL5]`Fg1KL5/7K`07KW=^Lfi]E@0PM000BG@0415K
4E]PFf1KH5]PFa4i?cT24@03:a8A00H[3D<0<ea3G4=L@ea34D=L@eaGFeMKEe]GFeMKEe]GKe]_FfmK
Ke]_FfmKKe]_FfmKKfi_KVm^K@0PM000BG@0315d4GALM5adG7ALM08A040n4ChA?Q<AA2]4:dA3F4=H
@eQ3F4=H@eQ3G5MLEeaGG5ML4EaGG5MLFeaKG5]LFeaKG5]LFg1KL5]`Fg1KL5]`1fl01W=^LficEB1d
0018M00>4F0AH5]PFf1KH5]PFf024@03>ClV008V00<A:b/00b/>@`0JG4=L@ea3G4=L4Ea3G4=KEe]G
FeMKEe]GFeL2F`0GKe]_FfmKKe]_FfmKKe]_Ffm^Kfi_KVd087@004Qd00hAG15LM5adG7ALM5adG0@A
03hW4A4nM2]4:dA3F4=H@eQ3F4=H@eQ3G5MLEeaGG5MLEa5GG5MLFeaKG5]LFeaKG5]LFg1KL5]`Fg1K
L5]`F`M_00A^Lfic8G@004Qd0Q403E]PFf1KH5]PFf1KH5/00Q40258A?bHo9SmK0R/>@`0`G4=L@ea3
G4=L4Ea3G4=LEeaGG5MLEeaGG5MLFfmKKe]_FfmKKe]_FfmKKe]_Ffm^0Q4QM000Ag@0DA5d4GALM5ad
G7ALM5adG7AL4E5B?Sln?cho?UQ3F4=H@eQ3F4=H@eQ3G5MLEeaGG5MLEa5GG5MLFeaKG5]LFeaKG5]L
FgAKM5]dFgAKM5]dF`07K`@A8G@004Md0Q406V1KH5]PFf1KH5]PFf1KH5/A?U8V?bIP?d<o3T<09ea3
G4=L@ea34D<A@ea3G5MLEeaGG5MLEeaGG5]`Fg1KL5]`Fg1KL007L`@A8G@004Id01<AG15LM5adG7AL
M5adG7ALM5ad008A0UL074=G@eM3Ed=G@eQ3F4=H@eQ3F4=LEeaGG5MLEe`34@0LG5MLFeaKG5]LFeaK
G5]LFgAKM5]dFgAKM5]dF`Mc0a4RM000AW@24@0BFf1KH5]PFf1KH5]PFf1KH5]P0Q402ciG?d<o@cm3
?d<o00Y302ML@ea3G4=L@ea34D=L@eaGG5MLEeaGG5MLEeaKL5]`Fg1KL5]`Fg001g<34B9d0016M00E
4E]`Fg1KL5]`Fg1KL5]`Fg1KL5]`008A0UL0>D=G@eM3Ed=G@eM3F4=H@eQ3G5MLEeaGG5MLEe`AG5ML
FeaKG5]LFeaKG5]LFgAKM5]dFgAKM5]dF`02L`034G=c009c0a4RM000AW@09A5LFeaKG5]LFeaKG5]L
FeaKG5]LFe`n4CiG?d<o@cm3?d<o@cl01T<09ea3G4=L@ea3G15L@ea3G5MLEeaGG5MLEeaGG5]`Fg1K
L5]`Fg1KL002L`034G=c009c0Q4SM000AG@05a5`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1K008A0eL0=d=G
@eM3Ed=G@eM3Ed=H@eaGG5MLEeaGG5LAEeaGG5]LFeaKG5]LFeaKG5]dFgAKM5]dFgAKM5/00W<0115c
Lg<34B=d0014M08A01MKG5]LFeaKG5]LFeaKG5]LFeaKG5]LF`024@0iEciG?d<o@cm3?d<o@cm3?ea3
G4=L@ea3G4=L4Ea3G15LEeaGG5MLEeaGG5MLFg1KL5]`Fg1KL5]`00=c00<ALg<00a4SM000AG@24@0G
Fg1KL5]`Fg1KL5]`Fg1KL5/AFg1KL5/00Q43E`0;@eM3Ed=G@eM3Ed<00UL0:5aGG5MLEeaGG5LAEeaG
G5]LFeaKG5]LFeaKG5]dFgAKM5]dFgAKM5/3L`034G=c008A97@004Ed02PAFa5KG5]LFeaKG5]LFeaK
G5]LFeaKG5]LFe`AEciG?d<o@cm3?d<o0T<0;EM3Ed=L@ea3G4=L4Ea3G4=LEeaGG5MLEeaGG5MLFg1K
L5]`Fg1KL5]`La5c4@02L`8A97@004Ed01`AL5/AFg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5/A15L01d=G
@eM3Ed<00UL0:EaGG5MLEeaGG5ML4EaGG5MLFeaKG5]LFeaKG5]LFgAKM5]dFgAKM5]d009c11400g<A
4@0TM000A7@24@0JFeaK4E]LFeaKG5]LFeaKG5]LFeaKG5]LFe`24@09?ULnEcm3?d<o009302YG@eM3
Ed=G@eM3G4<A@ea3G4=LEe`AG5MLEeaGG5MLFg1KL5]`Fg1KL5/4L`034G<A008A97@004Ad0Q407G1K
L5/AFg1KL5]`Fg1KL5]`Fg1KL5]`Fg1K4E/A00AG00=3Ed<00UL0:eaGG5MLEeaGG5MLEe`AG5MLEeaK
G5]LFeaKG5]LFeaKM5]dFgAKM5]dFg@017<0115c4A4UM000A7@24@0SFeaKG5/AFeaKG5]LFeaKG5]L
FeaKG5]LFeaK4E/A?ULnEcl00T<0;5M3Ed=G@eM3Ed=G@eM34D=L@ea3G5MLEeaGG5MLEeaGG5]`Fg1K
L5]`Fg1K17<0115c4A4UM000A7@0215K4E]`Fg1K0Q405W1KL5]`Fg1KL5]`Fg1KL5]`Fg0AL146E`0]
G5MLEeaGG5MLEeaG4ELAEeaGG5MLFeaKG5]LFeaKG5]LFgAKM5]dFgAKM5]d00=c00<ALg<00Q4UM000
A7@08A5L4EaKG5]LFe`AG5]LFeaKG5]LFeaKG5]LFeaKG15L4@07E`0;@eM3Ed=G@eM3Ed<00Q4015M3
Ed<2E`0HG5MLEeaGG5MLEeaGG5]`Fg1KL5]`Fg1K0g<0115cLa4VM000@g@0=A5`Fa5KL5]`Fg1KL15`
Fg1KL5]`Fg1KL5]`Fg1KL5/AFg0AFeMKEe]GG5MLEeaGG5MLEeaG008A01eLEeaGL5]LFeaKG5]LFeaK
G5]dFgAKM5]dFgAKM002L`034G=c008A9W@004=d02<AFe`AG5]LFeaKG5]L4EaKG5]LFeaKG5]LFeaK
G5]LFa5K4@08E`09@eM3Ed=G@eM3008A01iG@eM3Ee]LFeaGG5MLEeaGG5MLFg1KL5]`Fg1KL5/2L`03
4G=c008A9W@004=d05HAL5LAEg1GL5M`Eg1GL15`Eg1GL5M`Eg1GL5M`Eg1GL15`Ea5GFeMKEe]GG5ML
EeaGG5ML4EaGG5MLFg1KL5]`FeaKG5]LFeaKM5]dFgAKM5]dFgAc4@=c00<AM7@09G@004=d02DAEe/A
FeMKEe]GFeMKEe/AFeMKEe]GFeMKEe]GFeMKEa5GFd<A00QG02I3Ed=G@eLAEd=G@eM3G5]LFeaKG5]L
EeaGG5MLFg1KL5]`Fg1KL09c00DALg=c4@0WM000@g@0Da5`Ea5GL5M`Eg1GL5M`Eg0AL5M`Eg1GL5M`
Eg1GL5M`Ea5GL15KEe]GFeMKEeaGG5ML4EaGG5MLEg1KL5]`Fg1KL5]`FeaKG5]dFgAKM5]dFgAK009c
00DALg=c4@0WM000@g@08a5GFa5KEe]GFeMKEe]GFeMK4E]GFeMKEe]GFeMKEe]GFa5K009G00<AEeL0
1eL094=G4EM3Ed=G@eMKG5]LFeaKG5]LFeaKG5MLFg1KL5]`Fg1KL09c00<ALg<00Q4WM000@g@0EA5`
Ea5GL5M`Eg1GL5M`Eg1GL15`Eg1GL5M`Eg1GL5M`Eg0AL5ML4E]GFeMKEe/AG5LAEeaGG5MLFg1KL5]`
Fg1KL5]`Fg1KL5]dFgAKM5]dFgAKLa400g<00a5dM00VM000@g@09a5GFeLAEe]GFeMKEe]GFeMKEe/A
FeMKEe]GFeMKEe]GFeLAEe]34@07E`0W4ELA@eM3Ed=G@eaKG5]LFeaKG5]LFeaKG5]LFg1KL5]`Fg1K
L7<A00=c00<AM7@09W@004=d05DAL5M`4G1GL5M`Eg1GL5M`Eg1GL15`Eg1GL5M`Eg1GL5M`4G1GG5LA
Ee]GFeMKEa5GG5MLEeaGL5]`Fg1KL5]`Fg1KL5]`Fg1KM61dFgAKM5]dFg<A00=c00<AM7@09W@004=d
02DAEe]G4EMKEe]GFeMKEe]GFeMKEe/AFeMKEe]GFeMKEe]GFa5K009G00<AEeL015L34@9G0213Ed=G
FeaKG5]LFeaKG5]LFeaKG5]dFgAKM5]`Fg1KL0Ec:G@004=d01HAL5M`4G1GL5M`Eg1GL5M`Eg1GL5M`
0Q4045M`Eg1GL5M`Eg1G4EM`Ee`24@0YEe/A4EMKEe]GG5MLFg1KL5]`Fg1KL5]`Fg1KL5]`H7APM61d
H7AKM5/017<00a5dM00WM000@g@0;15GFeLAEe]GFeMKEe]GFeMKEe]GFeMKEa5GFeMKEe]GFeMKEa5G
Fd=G4ELA2EL07T=LFeaKG5]LFeaKG5]LFeaKG5]dFgAKM5]dFgAKL0Ac00<AM7@09g@004=d02TAL5M`
4G1GL5M`Eg1GL5M`Eg1GL5M`Eg1G4EM`Eg1GL5M`Eg0AL5MLE`024@0WFeMKEe]GFeMKEg1KL5]`Fg1K
L5]`Fg1KL5]`FgAPM61dH7APM61d00Ec:W@004=d02LAEe]G4EMKEe]GFeMKEe]GFeMKEe]GFeMKEa5G
FeMKEe]GFeMK4E/00UL00d<AE`08E`0PG5]LFeaKG5]LFeaKG5]LFeaKM5]dFgAKM5]dFgAKBdH3LbYd
0013M00Z4G1GL15`Eg1GL5M`Eg1GL5M`Eg1GL5M`Eg1G4EM`Eg1GL5M`Ea5GL5ML0Q40:EMKEe]GFeM`
Fg1KL5]`Fg1KL5]`Fg1KL5]`H7APM61dH7APM61O4Em6009c:W@004=d02LAEe]G4EMKEe]GFeMKEe]G
FeMKEe]GFeMKEe]G4EMKEe]GFeMK4E/00UL00clA4@06E`0TG5]LFeaKG5]LFeaKG5]LFeaKG5]dFgAK
M5]dFgAKM4HAAT]6:g@004=d02PAL5M`Ea5GL5M`Eg1GL5M`Eg1GL5M`Eg1GL5M`Ea5GL5MKEe]GFa5K
0UL0;15G4E]GFeM`Fg1KL5]`Fg1KL5]`Fg1KL5]`FgAPM61dH7APM61dAUlAGdIO:g@004=d01LAEe]G
Fa5KEe]GFeMKEe]GFeMKEe]GF`07E`034EMG00EG00PAEeMG4CmG4@9G02ELFeaKG5]LFeaKG5]LFeaK
G5]LFgAKM5]dFgAKM5]d4D/ABdI;02ad0013M01@4G1GL5LAEg1GL5M`Eg1GL5MKEe]GFeMKEe]GFeMK
Ea5GFeMKEe]G4EMK4EM34EM`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1PM61dH7APM61dH5l24@03AUmd02ad
0013M0074EMKEe/AF`0IE`034EMG00AG02PAEeLA?eLo4E]LFeaKG5]LFeaKG5]LFeaKG5]LFgAKM5]d
FgAKM5];0a400d]dM00/M000@g@0Ca5KEe]G4EMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEa5GFeMK
Ea5GFa5K@eLAL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]dH7APM61dH7APGdH00Q400emdM00]M000@g@00a5G
E`02E`034EMG01YG00<AEeL00eL00a5G4@02E`0T?a4AG5]LFeaKG5]LFeaKG5]LFeaKM5]dFgAKM5]d
FgA6BdHA<7@004Ad028AEe]G4EMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]G0Q401e]GFa5K4E/0
0UL24@0PFg1KL5]`Fa5KL5]`Fg1KL5]`H7APM61dH7APM4IOAQ4aM000A7@01A5GEeLA01mG00@AEeMG
0Q42E`0R?a4AG5]LFeaKG5]LFeaKG5]LFeaKM5]dFgAKM5]dFd]64C9d0015M00W4E]G4EMKEe]GFeMK
Ee]GFeMKEe]GFeMKEe]GFeMKEe]GFeMK4E]G008A00=KEe/00Q407e]`Fg1KL5]`Fg1KL15`Fg1KM61d
H7APM61dH5m64DH0<W@004Ed00DAEeMG4@0PE`044EMG4@=G020A?a5KG5]LFeaKG5]LFeaKG5]dFgAK
M5]dFgAKBdI;4C=d0015M00/4E]GFa5KEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GFeMKEe/AFa5K
Ea42E`0M4G1KL5]`Fg1KL5]`Fg1KM61dH7APM61dH7A6Ga40=7@004Id00@AEeLA8UL24@9G01lAEa4A
FeaKG5]LFeaKG5]LFgAKM5]dFgAKM5]dAT/A03Ed0016M00Z4EMK4E]GFeMKEe]GFeMKEe]GFeMKEe]G
FeMKEe]GFeMKEe]GFeMK4E]G11406W1KL5]`Fg1KL5]`Fa5PM61dH7APM61dAUlA=W@004Id00@AEeLA
8eL24@0NEa4A?ULAG5]LFeaKG5]LFgAKM5]dFgAKM5]dFd/A=g@004Md02@AFa5KEe]GFeMKEe]GFeMK
Ee]GFeMKEe]GFeMKEe]GFeMKEe/2E`044ELA4@=G01PAFg1KL5]`Fg1K4F1dH7APM61dH7APGa4hM000
Ag@00a5G4@0NE`08?ULnEchA?UL24@0I?ULAG5]LFeaKG5]dFgAKM5]dFgAKM5]d4@0iM000B7@24@0I
FeMKEe]GFeMKEe]GFeMKEe]GFeMKEe]GF`0:E`054EMG4EL00a405U]`Fg1KL5]dH7APM61dH7APM61d
AQ4iM000B7@24AIG01@nEciG?ULnEciG?ULn4CiG4ELnE`8A01AKG5]LFgAKM5]dFgAKM5]dFgA64CYd
0018M00C4ELAEe]GFeMKEe]GFeMKEe]GF`0BE`044EMG4@AG01@AL5]`FgAPM61dH7APM61dH7AP4C]d
0019M08A3EL0<3iG?ULnEciG?ULnEciG?ULnEciG?ULAEa5G?ULn4E]LFgAKM5]dFgAKM5]dFgAK4Cad
0019M08A00QGFeMKEe]GFa]G00<AEa4015L0315`FgAPM61dH7APM08A00APM60A?G@004Yd00<AEeL0
0eL0=SiG?ULnEciG?ULnEciG?ULnEciG?ULnEciG?ULnEa5G4ELnEciG4GAKM5]dFgAKM5]dFgAK4Cid
001:M0hA5UL24@IG00hAH7APM61dH7APM61dH08A?W@004]d0a402SiG?ULnEciG?ULK4@0@EciG4GAK
M5]dFgAKM5]dF`8A?g@004ad00@AEa4A7UL24@=G0a402gAPM61dH7APM61d00<A@7@004ed00<A?UL0
0Q4073iG?ULnEciG?ULnEciG?ULnEciG?ULnEciG?UL24@0@?ULj?SXAFgAKM5]dFgAKM0<A@G@004id
00@AEeMG0Q4JE`8A00mB?U8nDQ5dH7APM61dH7@00a52M000Cg@01A4nEciG008A01PnEciG?ULnEciG
?ULnEciG?ULnEciG>Sh24@0=>Shj?Q5dFgAKM5]dF`034DAd001@M0034EMG00=G0Q4AE`05?U8nDSh0
0Q403e8nDShAH7APM61dH15d4@15M000D7@0215G?ULnEciG0Q4033iG?ULnEciG?ULnE`8n00Hj?SXn
>Sh24@0;>Shj?Q5dFgAKM5/00a56M000DG@00a5GE`06E`<A1eL02U8nDSiB?U8nDSh24@0<DSiB4GAP
M61d4G@AB7@0059d00/AEciG?ULnEciG?P024@0?Echn>Shj?SXn>Shj?SXn008A00Pj?SXAFgAKM0<A
BG@005=d00<AEeL02EL24@0=?U8nDSiB?U8nDSiB?P024@07DShAH7APM0024D]d001DM00=4ELnEciG
?ULj?SXn>P024@0B?SXn>Shj?SXn>ShA?SXn4GAK0Q5=M000EG@03Q5GEeLnDSiB?U8nDSiB0Q4043iB
?U8nDSiB?Q4nDShAH15?M000EW@24@0=>Shj?SXn>Shj?SXn>P024@09?SXn>Shj?Q4n008A00=K4G@0
Cg@005Qd0Q403E8nDSiB?U8nDSiB?U800Q401CiB?U8n00DADG@005Yd0a4033hj?SXn>Shj?SXn>P8A
00<n>Q400a5CM000GG@24@0<?U8nDSiB?U8nDSiB1A5DM000Gg@34@07>Shj?SXn>P024@9d0Q5EM000
HW@24@03DSiB008AFg@006Ad0a5MM000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000
a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000a7@00<Ad0034M000
a7@00001\
\>"],
  ImageRangeCache->{{{0, 195.625}, {285.75, 0}} -> {0.147757, -0.00268051, \
0.00347888, 0.00347888}}],

Cell[BoxData[
    \({16.6899999999999977`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["\<\
In the parametric center of the surface, the triangle net shows \
that the parametric aperture is circular: all triangles in the center share \
the center point.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[seashellmirror, 
\tPlotPoints -> 40, SurfacePoints -> Mesh, GraphicDesign -> Off, PlotType -> \
SideView,
\tPlotRange -> {{-2.5,0}, {-2.5,0}, {4,7}}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
1 0.4 -1.6 0.4 [
[ 0 0 0 0 ]
[ 1 1.2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.2 L
0 1.2 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
[ ] 0 setdash
.78535 .97611 m
.74374 1.02148 L
.42837 .85044 L
.78535 .97611 L
s
.78535 .97611 Mdot
.74374 1.02148 Mdot
.42837 .85044 Mdot
.74374 1.02148 m
.68168 1.05394 L
.42837 .85044 L
.74374 1.02148 L
s
.74374 1.02148 Mdot
.68168 1.05394 Mdot
.42837 .85044 Mdot
.68168 1.05394 m
.60744 1.07061 L
.42837 .85044 L
.68168 1.05394 L
s
.68168 1.05394 Mdot
.60744 1.07061 Mdot
.42837 .85044 Mdot
.60744 1.07061 m
.52997 1.07062 L
.42837 .85044 L
.60744 1.07061 L
s
.60744 1.07061 Mdot
.52997 1.07062 Mdot
.42837 .85044 Mdot
.52997 1.07062 m
.45678 1.05488 L
.42837 .85044 L
.52997 1.07062 L
s
.52997 1.07062 Mdot
.45678 1.05488 Mdot
.42837 .85044 Mdot
.45678 1.05488 m
.39277 1.02555 L
.42837 .85044 L
.45678 1.05488 L
s
.45678 1.05488 Mdot
.39277 1.02555 Mdot
.42837 .85044 Mdot
.39277 1.02555 m
.34008 .98533 L
.42837 .85044 L
.39277 1.02555 L
s
.39277 1.02555 Mdot
.34008 .98533 Mdot
.42837 .85044 Mdot
.34008 .98533 m
.29895 .93709 L
.42837 .85044 L
.34008 .98533 L
s
.34008 .98533 Mdot
.29895 .93709 Mdot
.42837 .85044 Mdot
.29895 .93709 m
.26867 .88371 L
.42837 .85044 L
.29895 .93709 L
s
.29895 .93709 Mdot
.26867 .88371 Mdot
.42837 .85044 Mdot
.26867 .88371 m
.24851 .82823 L
.42837 .85044 L
.26867 .88371 L
s
.26867 .88371 Mdot
.24851 .82823 Mdot
.42837 .85044 Mdot
.24851 .82823 m
.23841 .77403 L
.42837 .85044 L
.24851 .82823 L
s
.24851 .82823 Mdot
.23841 .77403 Mdot
.42837 .85044 Mdot
.23841 .77403 m
.23937 .72478 L
.42837 .85044 L
.23841 .77403 L
s
.23841 .77403 Mdot
.23937 .72478 Mdot
.42837 .85044 Mdot
.23937 .72478 m
.25331 .68409 L
.42837 .85044 L
.23937 .72478 L
s
.23937 .72478 Mdot
.25331 .68409 Mdot
.42837 .85044 Mdot
.25331 .68409 m
.28238 .655 L
.42837 .85044 L
.25331 .68409 L
s
.25331 .68409 Mdot
.28238 .655 Mdot
.42837 .85044 Mdot
.28238 .655 m
.32777 .63946 L
.42837 .85044 L
.28238 .655 L
s
.28238 .655 Mdot
.32777 .63946 Mdot
.42837 .85044 Mdot
.32777 .63946 m
.38864 .63813 L
.42837 .85044 L
.32777 .63946 L
s
.32777 .63946 Mdot
.38864 .63813 Mdot
.42837 .85044 Mdot
.38864 .63813 m
.46164 .65051 L
.42837 .85044 L
.38864 .63813 L
s
.38864 .63813 Mdot
.46164 .65051 Mdot
.42837 .85044 Mdot
.46164 .65051 m
.54135 .67534 L
.42837 .85044 L
.46164 .65051 L
s
.46164 .65051 Mdot
.54135 .67534 Mdot
.42837 .85044 Mdot
.54135 .67534 m
.62103 .71105 L
.42837 .85044 L
.54135 .67534 L
s
.54135 .67534 Mdot
.62103 .71105 Mdot
.42837 .85044 Mdot
.62103 .71105 m
.69349 .75593 L
.42837 .85044 L
.62103 .71105 L
s
.62103 .71105 Mdot
.69349 .75593 Mdot
.42837 .85044 Mdot
.69349 .75593 m
.75163 .80799 L
.42837 .85044 L
.69349 .75593 L
s
.69349 .75593 Mdot
.75163 .80799 Mdot
.42837 .85044 Mdot
.75163 .80799 m
.78908 .8646 L
.42837 .85044 L
.75163 .80799 L
s
.75163 .80799 Mdot
.78908 .8646 Mdot
.42837 .85044 Mdot
.78908 .8646 m
.80101 .92217 L
.42837 .85044 L
.78908 .8646 L
s
.78908 .8646 Mdot
.80101 .92217 Mdot
.42837 .85044 Mdot
.80101 .92217 m
.78535 .97611 L
.42837 .85044 L
.80101 .92217 L
s
.80101 .92217 Mdot
.78535 .97611 Mdot
.42837 .85044 Mdot
.78535 .97611 m
.74374 1.02148 L
s
.74374 1.02148 m
1 1.06468 L
s
1 1.03815 m
.78535 .97611 L
s
.78535 .97611 Mdot
.74374 1.02148 Mdot
1 1.13853 m
.74374 1.02148 L
s
.74374 1.02148 m
1 1.06468 L
s
.74374 1.02148 Mdot
.74374 1.02148 m
.68168 1.05394 L
s
.68168 1.05394 m
1 1.15581 L
s
1 1.13853 m
.74374 1.02148 L
s
.74374 1.02148 Mdot
.68168 1.05394 Mdot
.89557 1.2 m
.68168 1.05394 L
s
.68168 1.05394 m
1 1.15581 L
s
.68168 1.05394 Mdot
.68168 1.05394 m
.60744 1.07061 L
s
.60744 1.07061 m
.86476 1.2 L
s
.89557 1.2 m
.68168 1.05394 L
s
.68168 1.05394 Mdot
.60744 1.07061 Mdot
.73514 1.2 m
.60744 1.07061 L
s
.60744 1.07061 m
.86476 1.2 L
s
.60744 1.07061 Mdot
.60744 1.07061 m
.52997 1.07062 L
s
.52997 1.07062 m
.70518 1.2 L
s
.73514 1.2 m
.60744 1.07061 L
s
.60744 1.07061 Mdot
.52997 1.07062 Mdot
.61601 1.2 m
.52997 1.07062 L
s
.52997 1.07062 m
.70518 1.2 L
s
.52997 1.07062 Mdot
.52997 1.07062 m
.45678 1.05488 L
s
.45678 1.05488 m
.59639 1.2 L
s
.61601 1.2 m
.52997 1.07062 L
s
.52997 1.07062 Mdot
.45678 1.05488 Mdot
.52508 1.2 m
.45678 1.05488 L
s
.45678 1.05488 m
.59639 1.2 L
s
.45678 1.05488 Mdot
.45678 1.05488 m
.39277 1.02555 L
s
.39277 1.02555 m
.51986 1.2 L
s
.52508 1.2 m
.45678 1.05488 L
s
.45678 1.05488 Mdot
.39277 1.02555 Mdot
.50707 1.2 m
.44409 1.15373 L
.39277 1.02555 L
s
.39277 1.02555 m
.51986 1.2 L
s
.44409 1.15373 Mdot
.39277 1.02555 Mdot
.39277 1.02555 m
.34008 .98533 L
.44409 1.15373 L
.39277 1.02555 L
s
.39277 1.02555 Mdot
.34008 .98533 Mdot
.44409 1.15373 Mdot
.44409 1.15373 m
.38281 1.07436 L
.34008 .98533 L
.44409 1.15373 L
s
.44409 1.15373 Mdot
.38281 1.07436 Mdot
.34008 .98533 Mdot
.34008 .98533 m
.29895 .93709 L
.38281 1.07436 L
.34008 .98533 L
s
.34008 .98533 Mdot
.29895 .93709 Mdot
.38281 1.07436 Mdot
.38281 1.07436 m
.34238 .98646 L
.29895 .93709 L
.38281 1.07436 L
s
.38281 1.07436 Mdot
.34238 .98646 Mdot
.29895 .93709 Mdot
.29895 .93709 m
.26867 .88371 L
.34238 .98646 L
.29895 .93709 L
s
.29895 .93709 Mdot
.26867 .88371 Mdot
.34238 .98646 Mdot
.34238 .98646 m
.31518 .89186 L
.26867 .88371 L
.34238 .98646 L
s
.34238 .98646 Mdot
.31518 .89186 Mdot
.26867 .88371 Mdot
.26867 .88371 m
.24851 .82823 L
.31518 .89186 L
.26867 .88371 L
s
.26867 .88371 Mdot
.24851 .82823 Mdot
.31518 .89186 Mdot
.31518 .89186 m
.29465 .79234 L
.24851 .82823 L
.31518 .89186 L
s
.31518 .89186 Mdot
.29465 .79234 Mdot
.24851 .82823 Mdot
.24851 .82823 m
.23841 .77403 L
.29465 .79234 L
.24851 .82823 L
s
.24851 .82823 Mdot
.23841 .77403 Mdot
.29465 .79234 Mdot
.29465 .79234 m
.27606 .69215 L
.23841 .77403 L
.29465 .79234 L
s
.29465 .79234 Mdot
.27606 .69215 Mdot
.23841 .77403 Mdot
.23841 .77403 m
.23937 .72478 L
.27606 .69215 L
.23841 .77403 L
s
.23841 .77403 Mdot
.23937 .72478 Mdot
.27606 .69215 Mdot
.27606 .69215 m
.2596 .59911 L
.23937 .72478 L
.27606 .69215 L
s
.27606 .69215 Mdot
.2596 .59911 Mdot
.23937 .72478 Mdot
.23937 .72478 m
.25331 .68409 L
.2596 .59911 L
.23937 .72478 L
s
.23937 .72478 Mdot
.25331 .68409 Mdot
.2596 .59911 Mdot
.2596 .59911 m
.25333 .52321 L
.25331 .68409 L
.2596 .59911 L
s
.2596 .59911 Mdot
.25333 .52321 Mdot
.25331 .68409 Mdot
.25331 .68409 m
.28238 .655 L
.25333 .52321 L
.25331 .68409 L
s
.25331 .68409 Mdot
.28238 .655 Mdot
.25333 .52321 Mdot
.25333 .52321 m
.27145 .47324 L
.28238 .655 L
.25333 .52321 L
s
.25333 .52321 Mdot
.27145 .47324 Mdot
.28238 .655 Mdot
.28238 .655 m
.32777 .63946 L
.27145 .47324 L
.28238 .655 L
s
.28238 .655 Mdot
.32777 .63946 Mdot
.27145 .47324 Mdot
.27145 .47324 m
.32699 .4536 L
.32777 .63946 L
.27145 .47324 L
s
.27145 .47324 Mdot
.32699 .4536 Mdot
.32777 .63946 Mdot
.32777 .63946 m
.38864 .63813 L
.32699 .4536 L
.32777 .63946 L
s
.32777 .63946 Mdot
.38864 .63813 Mdot
.32699 .4536 Mdot
.32699 .4536 m
.42365 .4631 L
.38864 .63813 L
.32699 .4536 L
s
.32699 .4536 Mdot
.42365 .4631 Mdot
.38864 .63813 Mdot
.38864 .63813 m
.46164 .65051 L
.42365 .4631 L
.38864 .63813 L
s
.38864 .63813 Mdot
.46164 .65051 Mdot
.42365 .4631 Mdot
.42365 .4631 m
.55341 .49643 L
.46164 .65051 L
.42365 .4631 L
s
.42365 .4631 Mdot
.55341 .49643 Mdot
.46164 .65051 Mdot
.46164 .65051 m
.54135 .67534 L
.55341 .49643 L
.46164 .65051 L
s
.46164 .65051 Mdot
.54135 .67534 Mdot
.55341 .49643 Mdot
.55341 .49643 m
.70144 .54715 L
.54135 .67534 L
.55341 .49643 L
s
.55341 .49643 Mdot
.70144 .54715 Mdot
.54135 .67534 Mdot
.54135 .67534 m
.62103 .71105 L
.70144 .54715 L
.54135 .67534 L
s
.54135 .67534 Mdot
.62103 .71105 Mdot
.70144 .54715 Mdot
.70144 .54715 m
.85295 .61076 L
.62103 .71105 L
.70144 .54715 L
s
.70144 .54715 Mdot
.85295 .61076 Mdot
.62103 .71105 Mdot
.62103 .71105 m
.69349 .75593 L
.85295 .61076 L
.62103 .71105 L
s
.62103 .71105 Mdot
.69349 .75593 Mdot
.85295 .61076 Mdot
.85295 .61076 m
.99605 .68614 L
.69349 .75593 L
.85295 .61076 L
s
.85295 .61076 Mdot
.99605 .68614 Mdot
.69349 .75593 Mdot
.69349 .75593 m
.75163 .80799 L
.99605 .68614 L
.69349 .75593 L
s
.69349 .75593 Mdot
.75163 .80799 Mdot
.99605 .68614 Mdot
.99605 .68614 m
0 0 rlineto s
.99605 .68614 m
1 .68898 L
s
1 .78555 m
.75163 .80799 L
.99605 .68614 L
s
.99605 .68614 Mdot
.75163 .80799 Mdot
.75163 .80799 m
.78908 .8646 L
s
.78908 .8646 m
1 .80724 L
s
1 .78555 m
.75163 .80799 L
s
.75163 .80799 Mdot
.78908 .8646 Mdot
1 .87106 m
.78908 .8646 L
s
.78908 .8646 m
1 .80724 L
s
.78908 .8646 Mdot
.78908 .8646 m
.80101 .92217 L
s
.80101 .92217 m
1 .90034 L
s
1 .87106 m
.78908 .8646 L
s
.78908 .8646 Mdot
.80101 .92217 Mdot
1 .95251 m
.80101 .92217 L
s
.80101 .92217 m
1 .90034 L
s
.80101 .92217 Mdot
.80101 .92217 m
.78535 .97611 L
s
.78535 .97611 m
1 .98264 L
s
1 .95251 m
.80101 .92217 L
s
.80101 .92217 Mdot
.78535 .97611 Mdot
1 1.03815 m
.78535 .97611 L
s
.78535 .97611 m
1 .98264 L
s
.78535 .97611 Mdot
.50707 1.2 m
.44409 1.15373 L
s
.44409 1.15373 m
.50177 1.2 L
s
.44409 1.15373 Mdot
.56686 1.2 m
.44409 1.15373 L
s
.44409 1.15373 m
.50177 1.2 L
s
.44409 1.15373 Mdot
.44409 1.15373 m
.38281 1.07436 L
s
.38281 1.07436 m
.56762 1.2 L
s
.56686 1.2 m
.44409 1.15373 L
s
.44409 1.15373 Mdot
.38281 1.07436 Mdot
.56838 1.2 m
.53436 1.08865 L
.38281 1.07436 L
s
.38281 1.07436 m
.56762 1.2 L
s
.53436 1.08865 Mdot
.38281 1.07436 Mdot
.38281 1.07436 m
.34238 .98646 L
.53436 1.08865 L
.38281 1.07436 L
s
.38281 1.07436 Mdot
.34238 .98646 Mdot
.53436 1.08865 Mdot
.53436 1.08865 m
.52125 .97808 L
.34238 .98646 L
.53436 1.08865 L
s
.53436 1.08865 Mdot
.52125 .97808 Mdot
.34238 .98646 Mdot
.34238 .98646 m
.31518 .89186 L
.52125 .97808 L
.34238 .98646 L
s
.34238 .98646 Mdot
.31518 .89186 Mdot
.52125 .97808 Mdot
.52125 .97808 m
.52147 .86352 L
.31518 .89186 L
.52125 .97808 L
s
.52125 .97808 Mdot
.52147 .86352 Mdot
.31518 .89186 Mdot
.31518 .89186 m
.29465 .79234 L
.52147 .86352 L
.31518 .89186 L
s
.31518 .89186 Mdot
.29465 .79234 Mdot
.52147 .86352 Mdot
.52147 .86352 m
.52428 .7386 L
.29465 .79234 L
.52147 .86352 L
s
.52147 .86352 Mdot
.52428 .7386 Mdot
.29465 .79234 Mdot
.29465 .79234 m
.27606 .69215 L
.52428 .7386 L
.29465 .79234 L
s
.29465 .79234 Mdot
.27606 .69215 Mdot
.52428 .7386 Mdot
.52428 .7386 m
.51212 .6042 L
.27606 .69215 L
.52428 .7386 L
s
.52428 .7386 Mdot
.51212 .6042 Mdot
.27606 .69215 Mdot
.27606 .69215 m
.2596 .59911 L
.51212 .6042 L
.27606 .69215 L
s
.27606 .69215 Mdot
.2596 .59911 Mdot
.51212 .6042 Mdot
.51212 .6042 m
.4728 .47345 L
.2596 .59911 L
.51212 .6042 L
s
.51212 .6042 Mdot
.4728 .47345 Mdot
.2596 .59911 Mdot
.2596 .59911 m
.25333 .52321 L
.4728 .47345 L
.2596 .59911 L
s
.2596 .59911 Mdot
.25333 .52321 Mdot
.4728 .47345 Mdot
.4728 .47345 m
.41757 .36839 L
.25333 .52321 L
.4728 .47345 L
s
.4728 .47345 Mdot
.41757 .36839 Mdot
.25333 .52321 Mdot
.25333 .52321 m
.27145 .47324 L
.41757 .36839 L
.25333 .52321 L
s
.25333 .52321 Mdot
.27145 .47324 Mdot
.41757 .36839 Mdot
.41757 .36839 m
.38421 .30932 L
.27145 .47324 L
.41757 .36839 L
s
.41757 .36839 Mdot
.38421 .30932 Mdot
.27145 .47324 Mdot
.27145 .47324 m
.32699 .4536 L
.38421 .30932 L
.27145 .47324 L
s
.27145 .47324 Mdot
.32699 .4536 Mdot
.38421 .30932 Mdot
.38421 .30932 m
.41422 .30421 L
.32699 .4536 L
.38421 .30932 L
s
.38421 .30932 Mdot
.41422 .30421 Mdot
.32699 .4536 Mdot
.32699 .4536 m
.42365 .4631 L
.41422 .30421 L
.32699 .4536 L
s
.32699 .4536 Mdot
.42365 .4631 Mdot
.41422 .30421 Mdot
.41422 .30421 m
.52125 .34581 L
.42365 .4631 L
.41422 .30421 L
s
.41422 .30421 Mdot
.52125 .34581 Mdot
.42365 .4631 Mdot
.42365 .4631 m
.55341 .49643 L
.52125 .34581 L
.42365 .4631 L
s
.42365 .4631 Mdot
.55341 .49643 Mdot
.52125 .34581 Mdot
.52125 .34581 m
.68338 .41709 L
.55341 .49643 L
.52125 .34581 L
s
.52125 .34581 Mdot
.68338 .41709 Mdot
.55341 .49643 Mdot
.55341 .49643 m
.70144 .54715 L
.68338 .41709 L
.55341 .49643 L
s
.55341 .49643 Mdot
.70144 .54715 Mdot
.68338 .41709 Mdot
.68338 .41709 m
.86574 .50024 L
.70144 .54715 L
.68338 .41709 L
s
.68338 .41709 Mdot
.86574 .50024 Mdot
.70144 .54715 Mdot
.70144 .54715 m
.85295 .61076 L
.86574 .50024 L
.70144 .54715 L
s
.70144 .54715 Mdot
.85295 .61076 Mdot
.86574 .50024 Mdot
.86574 .50024 m
0 0 rlineto s
.86574 .50024 m
1 .56279 L
s
1 .59071 m
.85295 .61076 L
.86574 .50024 L
s
.86574 .50024 Mdot
.85295 .61076 Mdot
.85295 .61076 m
.99605 .68614 L
s
.99605 .68614 m
1 .67815 L
s
1 .59071 m
.85295 .61076 L
s
.85295 .61076 Mdot
.99605 .68614 Mdot
1 .68586 m
.99605 .68614 L
s
.99605 .68614 m
1 .67815 L
s
.99605 .68614 Mdot
.99605 .68614 m
0 0 rlineto s
.99605 .68614 m
1 .68898 L
s
1 .68586 m
.99605 .68614 L
s
.99605 .68614 Mdot
.73955 1.2 m
.73288 1.15373 L
s
.73288 1.15373 m
.57085 1.2 L
s
.73288 1.15373 Mdot
.56838 1.2 m
.53436 1.08865 L
.73288 1.15373 L
s
.73288 1.15373 m
.57085 1.2 L
s
.53436 1.08865 Mdot
.73288 1.15373 Mdot
.73288 1.15373 m
.73268 1.01862 L
.53436 1.08865 L
.73288 1.15373 L
s
.73288 1.15373 Mdot
.73268 1.01862 Mdot
.53436 1.08865 Mdot
.53436 1.08865 m
.52125 .97808 L
.73268 1.01862 L
.53436 1.08865 L
s
.53436 1.08865 Mdot
.52125 .97808 Mdot
.73268 1.01862 Mdot
.73268 1.01862 m
.74619 .90417 L
.52125 .97808 L
.73268 1.01862 L
s
.73268 1.01862 Mdot
.74619 .90417 Mdot
.52125 .97808 Mdot
.52125 .97808 m
.52147 .86352 L
.74619 .90417 L
.52125 .97808 L
s
.52125 .97808 Mdot
.52147 .86352 Mdot
.74619 .90417 Mdot
.74619 .90417 m
.78353 .79321 L
.52147 .86352 L
.74619 .90417 L
s
.74619 .90417 Mdot
.78353 .79321 Mdot
.52147 .86352 Mdot
.52147 .86352 m
.52428 .7386 L
.78353 .79321 L
.52147 .86352 L
s
.52147 .86352 Mdot
.52428 .7386 Mdot
.78353 .79321 Mdot
.78353 .79321 m
.83501 .66454 L
.52428 .7386 L
.78353 .79321 L
s
.78353 .79321 Mdot
.83501 .66454 Mdot
.52428 .7386 Mdot
.52428 .7386 m
.51212 .6042 L
.83501 .66454 L
.52428 .7386 L
s
.52428 .7386 Mdot
.51212 .6042 Mdot
.83501 .66454 Mdot
.83501 .66454 m
.85959 .50979 L
.51212 .6042 L
.83501 .66454 L
s
.83501 .66454 Mdot
.85959 .50979 Mdot
.51212 .6042 Mdot
.51212 .6042 m
.4728 .47345 L
.85959 .50979 L
.51212 .6042 L
s
.51212 .6042 Mdot
.4728 .47345 Mdot
.85959 .50979 Mdot
.85959 .50979 m
.81245 .34779 L
.4728 .47345 L
.85959 .50979 L
s
.85959 .50979 Mdot
.81245 .34779 Mdot
.4728 .47345 Mdot
.4728 .47345 m
.41757 .36839 L
.81245 .34779 L
.4728 .47345 L
s
.4728 .47345 Mdot
.41757 .36839 Mdot
.81245 .34779 Mdot
.81245 .34779 m
.69529 .22004 L
.41757 .36839 L
.81245 .34779 L
s
.81245 .34779 Mdot
.69529 .22004 Mdot
.41757 .36839 Mdot
.41757 .36839 m
.38421 .30932 L
.69529 .22004 L
.41757 .36839 L
s
.41757 .36839 Mdot
.38421 .30932 Mdot
.69529 .22004 Mdot
.69529 .22004 m
.57867 .16572 L
.38421 .30932 L
.69529 .22004 L
s
.69529 .22004 Mdot
.57867 .16572 Mdot
.38421 .30932 Mdot
.38421 .30932 m
.41422 .30421 L
.57867 .16572 L
.38421 .30932 L
s
.38421 .30932 Mdot
.41422 .30421 Mdot
.57867 .16572 Mdot
.57867 .16572 m
.55422 .19681 L
.41422 .30421 L
.57867 .16572 L
s
.57867 .16572 Mdot
.55422 .19681 Mdot
.41422 .30421 Mdot
.41422 .30421 m
.52125 .34581 L
.55422 .19681 L
.41422 .30421 L
s
.41422 .30421 Mdot
.52125 .34581 Mdot
.55422 .19681 Mdot
.55422 .19681 m
.65144 .29406 L
.52125 .34581 L
.55422 .19681 L
s
.55422 .19681 Mdot
.65144 .29406 Mdot
.52125 .34581 Mdot
.52125 .34581 m
.68338 .41709 L
.65144 .29406 L
.52125 .34581 L
s
.52125 .34581 Mdot
.68338 .41709 Mdot
.65144 .29406 Mdot
.65144 .29406 m
.81891 .42207 L
.68338 .41709 L
.65144 .29406 L
s
.65144 .29406 Mdot
.81891 .42207 Mdot
.68338 .41709 Mdot
.68338 .41709 m
.86574 .50024 L
.81891 .42207 L
.68338 .41709 L
s
.68338 .41709 Mdot
.86574 .50024 Mdot
.81891 .42207 Mdot
.81891 .42207 m
.99022 .54715 L
.86574 .50024 L
.81891 .42207 L
s
.81891 .42207 Mdot
.99022 .54715 Mdot
.86574 .50024 Mdot
.86574 .50024 m
0 0 rlineto s
.86574 .50024 m
1 .56279 L
s
1 .55364 m
.99022 .54715 L
.86574 .50024 L
s
.86574 .50024 Mdot
.99022 .54715 Mdot
.99022 .54715 m
0 0 rlineto s
.99022 .54715 m
1 .5537 L
s
1 .55364 m
.99022 .54715 L
s
.99022 .54715 Mdot
.73955 1.2 m
.73288 1.15373 L
s
.73288 1.15373 m
.8167 1.2 L
s
.73288 1.15373 Mdot
.87072 1.2 m
.89296 1.02555 L
.73288 1.15373 L
s
.73288 1.15373 m
.8167 1.2 L
s
.89296 1.02555 Mdot
.73288 1.15373 Mdot
.73288 1.15373 m
.73268 1.01862 L
.89296 1.02555 L
.73288 1.15373 L
s
.73288 1.15373 Mdot
.73268 1.01862 Mdot
.89296 1.02555 Mdot
.89296 1.02555 m
.90029 .87588 L
.73268 1.01862 L
.89296 1.02555 L
s
.89296 1.02555 Mdot
.90029 .87588 Mdot
.73268 1.01862 Mdot
.73268 1.01862 m
.74619 .90417 L
.90029 .87588 L
.73268 1.01862 L
s
.73268 1.01862 Mdot
.74619 .90417 Mdot
.90029 .87588 Mdot
.90029 .87588 m
.92166 .77049 L
.74619 .90417 L
.90029 .87588 L
s
.90029 .87588 Mdot
.92166 .77049 Mdot
.74619 .90417 Mdot
.74619 .90417 m
.78353 .79321 L
.92166 .77049 L
.74619 .90417 L
s
.74619 .90417 Mdot
.78353 .79321 Mdot
.92166 .77049 Mdot
.92166 .77049 m
.99592 .68167 L
.78353 .79321 L
.92166 .77049 L
s
.92166 .77049 Mdot
.99592 .68167 Mdot
.78353 .79321 Mdot
.78353 .79321 m
.83501 .66454 L
.99592 .68167 L
.78353 .79321 L
s
.78353 .79321 Mdot
.83501 .66454 Mdot
.99592 .68167 Mdot
.99592 .68167 m
0 0 rlineto s
.99592 .68167 m
1 .6778 L
s
1 .6084 m
.83501 .66454 L
.99592 .68167 L
s
.99592 .68167 Mdot
.83501 .66454 Mdot
.83501 .66454 m
.85959 .50979 L
s
.85959 .50979 m
1 .54267 L
s
1 .6084 m
.83501 .66454 L
s
.83501 .66454 Mdot
.85959 .50979 Mdot
1 .46899 m
.85959 .50979 L
s
.85959 .50979 m
1 .54267 L
s
.85959 .50979 Mdot
.85959 .50979 m
.81245 .34779 L
s
.81245 .34779 m
1 .37671 L
s
1 .46899 m
.85959 .50979 L
s
.85959 .50979 Mdot
.81245 .34779 Mdot
1 .28403 m
.81245 .34779 L
s
.81245 .34779 m
1 .37671 L
s
.81245 .34779 Mdot
.81245 .34779 m
.69529 .22004 L
s
.69529 .22004 m
1 .22134 L
s
1 .28403 m
.81245 .34779 L
s
.81245 .34779 Mdot
.69529 .22004 Mdot
1 .0838 m
.69529 .22004 L
s
.69529 .22004 m
1 .22134 L
s
.69529 .22004 Mdot
.69529 .22004 m
.57867 .16572 L
s
.57867 .16572 m
1 .08081 L
s
1 .0838 m
.69529 .22004 L
s
.69529 .22004 Mdot
.57867 .16572 Mdot
1 .07634 m
.79989 .04315 L
.57867 .16572 L
s
.57867 .16572 m
1 .08081 L
s
.79989 .04315 Mdot
.57867 .16572 Mdot
.57867 .16572 m
.55422 .19681 L
.79989 .04315 L
.57867 .16572 L
s
.57867 .16572 Mdot
.55422 .19681 Mdot
.79989 .04315 Mdot
.79989 .04315 m
.70657 .13064 L
.55422 .19681 L
.79989 .04315 L
s
.79989 .04315 Mdot
.70657 .13064 Mdot
.55422 .19681 Mdot
.55422 .19681 m
.65144 .29406 L
.70657 .13064 L
.55422 .19681 L
s
.55422 .19681 Mdot
.65144 .29406 Mdot
.70657 .13064 Mdot
.70657 .13064 m
.78113 .30207 L
.65144 .29406 L
.70657 .13064 L
s
.70657 .13064 Mdot
.78113 .30207 Mdot
.65144 .29406 Mdot
.65144 .29406 m
.81891 .42207 L
.78113 .30207 L
.65144 .29406 L
s
.65144 .29406 Mdot
.81891 .42207 Mdot
.78113 .30207 Mdot
.78113 .30207 m
.92457 .49976 L
.81891 .42207 L
.78113 .30207 L
s
.78113 .30207 Mdot
.92457 .49976 Mdot
.81891 .42207 Mdot
.81891 .42207 m
.99022 .54715 L
.92457 .49976 L
.81891 .42207 L
s
.81891 .42207 Mdot
.99022 .54715 Mdot
.92457 .49976 Mdot
.92457 .49976 m
0 0 rlineto s
.92457 .49976 m
1 .61298 L
s
1 .57157 m
.99022 .54715 L
.92457 .49976 L
s
.92457 .49976 Mdot
.99022 .54715 Mdot
.99022 .54715 m
0 0 rlineto s
.99022 .54715 m
1 .5537 L
s
1 .57157 m
.99022 .54715 L
s
.99022 .54715 Mdot
.95014 1.2 m
.97471 1.08598 L
s
.97471 1.08598 m
.88828 1.2 L
s
.97471 1.08598 Mdot
.87072 1.2 m
.89296 1.02555 L
.97471 1.08598 L
s
.97471 1.08598 m
.88828 1.2 L
s
.89296 1.02555 Mdot
.97471 1.08598 Mdot
.97471 1.08598 m
0 0 rlineto s
.97471 1.08598 m
1 .89527 L
s
1 .85966 m
.89296 1.02555 L
.97471 1.08598 L
s
.97471 1.08598 Mdot
.89296 1.02555 Mdot
.89296 1.02555 m
.90029 .87588 L
s
.90029 .87588 m
1 .85187 L
s
1 .85966 m
.89296 1.02555 L
s
.89296 1.02555 Mdot
.90029 .87588 Mdot
1 .82024 m
.97431 .68973 L
.90029 .87588 L
s
.90029 .87588 m
1 .85187 L
s
.97431 .68973 Mdot
.90029 .87588 Mdot
.90029 .87588 m
.92166 .77049 L
.97431 .68973 L
.90029 .87588 L
s
.90029 .87588 Mdot
.92166 .77049 Mdot
.97431 .68973 Mdot
.97431 .68973 m
.99156 .59452 L
.92166 .77049 L
.97431 .68973 L
s
.97431 .68973 Mdot
.99156 .59452 Mdot
.92166 .77049 Mdot
.92166 .77049 m
.99592 .68167 L
.99156 .59452 L
.92166 .77049 L
s
.92166 .77049 Mdot
.99592 .68167 Mdot
.99156 .59452 Mdot
.99156 .59452 m
0 0 rlineto s
.99156 .59452 m
1 .58999 L
s
1 .67603 m
.99592 .68167 L
.99156 .59452 L
s
.99156 .59452 Mdot
.99592 .68167 Mdot
.99592 .68167 m
0 0 rlineto s
.99592 .68167 m
1 .6778 L
s
1 .67603 m
.99592 .68167 L
s
.99592 .68167 Mdot
1 .07634 m
.79989 .04315 L
s
.79989 .04315 m
1 .00251 L
s
.79989 .04315 Mdot
.88348 0 m
.79989 .04315 L
s
.79989 .04315 m
1 .00251 L
s
.79989 .04315 Mdot
.79989 .04315 m
.70657 .13064 L
s
.70657 .13064 m
.9073 0 L
s
.88348 0 m
.79989 .04315 L
s
.79989 .04315 Mdot
.70657 .13064 Mdot
.9402 0 m
.84263 .09927 L
.70657 .13064 L
s
.70657 .13064 m
.9073 0 L
s
.84263 .09927 Mdot
.70657 .13064 Mdot
.70657 .13064 m
.78113 .30207 L
.84263 .09927 L
.70657 .13064 L
s
.70657 .13064 Mdot
.78113 .30207 Mdot
.84263 .09927 Mdot
.84263 .09927 m
.88882 .35238 L
.78113 .30207 L
.84263 .09927 L
s
.84263 .09927 Mdot
.88882 .35238 Mdot
.78113 .30207 Mdot
.78113 .30207 m
.92457 .49976 L
.88882 .35238 L
.78113 .30207 L
s
.78113 .30207 Mdot
.92457 .49976 Mdot
.88882 .35238 Mdot
.88882 .35238 m
.97317 .62086 L
.92457 .49976 L
.88882 .35238 L
s
.88882 .35238 Mdot
.97317 .62086 Mdot
.92457 .49976 Mdot
.92457 .49976 m
0 0 rlineto s
.92457 .49976 m
1 .61298 L
s
1 .64224 m
.97317 .62086 L
.92457 .49976 L
s
.92457 .49976 Mdot
.97317 .62086 Mdot
.97317 .62086 m
0 0 rlineto s
.97317 .62086 m
1 .8088 L
s
1 .64224 m
.97317 .62086 L
s
.97317 .62086 Mdot
.95014 1.2 m
.97471 1.08598 L
s
.97471 1.08598 m
.95008 1.2 L
s
.97471 1.08598 Mdot
.96725 1.2 m
1 1.12549 L
s
1 1.05047 m
.97471 1.08598 L
s
.97471 1.08598 m
.95008 1.2 L
s
.97471 1.08598 Mdot
.97471 1.08598 m
0 0 rlineto s
.97471 1.08598 m
1 .89527 L
s
1 1.05047 m
.97471 1.08598 L
s
.97471 1.08598 Mdot
1 .82024 m
.97431 .68973 L
s
.97431 .68973 m
1 .68423 L
s
.97431 .68973 Mdot
1 .60973 m
.93016 .49944 L
.97431 .68973 L
s
.97431 .68973 m
1 .68423 L
s
.93016 .49944 Mdot
.97431 .68973 Mdot
.97431 .68973 m
.99156 .59452 L
.93016 .49944 L
.97431 .68973 L
s
.97431 .68973 Mdot
.99156 .59452 Mdot
.93016 .49944 Mdot
.93016 .49944 m
.9626 .40127 L
.99156 .59452 L
.93016 .49944 L
s
.93016 .49944 Mdot
.9626 .40127 Mdot
.99156 .59452 Mdot
.99156 .59452 m
0 0 rlineto s
.99156 .59452 m
1 .58999 L
s
1 .43726 m
.9626 .40127 L
.99156 .59452 L
s
.99156 .59452 Mdot
.9626 .40127 Mdot
.9626 .40127 m
0 0 rlineto s
.9626 .40127 m
1 .39221 L
s
1 .43726 m
.9626 .40127 L
s
.9626 .40127 Mdot
.9402 0 m
.84263 .09927 L
s
.84263 .09927 m
.96501 0 L
s
.84263 .09927 Mdot
1 .03348 m
.95303 .09187 L
.84263 .09927 L
s
.84263 .09927 m
.96501 0 L
s
.95303 .09187 Mdot
.84263 .09927 Mdot
.84263 .09927 m
.88882 .35238 L
.95303 .09187 L
.84263 .09927 L
s
.84263 .09927 Mdot
.88882 .35238 Mdot
.95303 .09187 Mdot
.95303 .09187 m
.97232 .41997 L
.88882 .35238 L
.95303 .09187 L
s
.95303 .09187 Mdot
.97232 .41997 Mdot
.88882 .35238 Mdot
.88882 .35238 m
.97317 .62086 L
.97232 .41997 L
.88882 .35238 L
s
.88882 .35238 Mdot
.97317 .62086 Mdot
.97232 .41997 Mdot
.97232 .41997 m
.95421 .7461 L
.97317 .62086 L
.97232 .41997 L
s
.97232 .41997 Mdot
.95421 .7461 Mdot
.97317 .62086 Mdot
.97317 .62086 m
0 0 rlineto s
.97317 .62086 m
1 .8088 L
s
1 .83845 m
.95421 .7461 L
.97317 .62086 L
s
.97317 .62086 Mdot
.95421 .7461 Mdot
.95421 .7461 m
.89296 1.02555 L
s
.89296 1.02555 m
1 .85966 L
s
1 .83845 m
.95421 .7461 L
s
.95421 .7461 Mdot
.89296 1.02555 Mdot
1 1.00881 m
.89296 1.02555 L
s
.89296 1.02555 m
1 .85966 L
s
.89296 1.02555 Mdot
.89296 1.02555 m
0 0 rlineto s
.89296 1.02555 m
.9079 1.2 L
s
.92381 1.2 m
1 1.05061 L
s
1 1.00881 m
.89296 1.02555 L
s
.89296 1.02555 Mdot
1 1.12017 m
.9327 1.2 L
s
.92381 1.2 m
1 1.05061 L
s
.97841 1.2 m
1 1.15775 L
s
1 1.12017 m
.9327 1.2 L
s
.97841 1.2 m
1 1.15775 L
s
.97404 1.2 m
1 1.17327 L
s
.97404 1.2 m
1 1.17327 L
s
.9626 1.2 m
.98459 1.1688 L
s
.98459 1.1688 m
1 1.1631 L
s
.98459 1.1688 Mdot
1 1.17134 m
.98459 1.1688 L
s
.98459 1.1688 m
1 1.1631 L
s
.98459 1.1688 Mdot
.98459 1.1688 m
0 0 rlineto s
.98459 1.1688 m
1 1.19956 L
s
1 1.17134 m
.98459 1.1688 L
s
.98459 1.1688 Mdot
.99061 1.2 m
.99662 1.15596 L
s
.99662 1.15596 m
.97362 1.2 L
s
.99662 1.15596 Mdot
.96725 1.2 m
1 1.12549 L
s
1 1.14741 m
.99662 1.15596 L
s
.99662 1.15596 m
.97362 1.2 L
s
.99662 1.15596 Mdot
.99662 1.15596 m
0 0 rlineto s
.99662 1.15596 m
1 1.15043 L
s
1 1.14741 m
.99662 1.15596 L
s
.99662 1.15596 Mdot
1 .55866 m
.99022 .54715 L
s
.99022 .54715 m
1 .57157 L
s
.99022 .54715 Mdot
1 .60973 m
.93016 .49944 L
.99022 .54715 L
s
.99022 .54715 m
1 .57157 L
s
.93016 .49944 Mdot
.99022 .54715 Mdot
.99022 .54715 m
.7899 .34418 L
.93016 .49944 L
.99022 .54715 L
s
.99022 .54715 Mdot
.7899 .34418 Mdot
.93016 .49944 Mdot
.93016 .49944 m
.9626 .40127 L
.7899 .34418 L
.93016 .49944 L
s
.93016 .49944 Mdot
.9626 .40127 Mdot
.7899 .34418 Mdot
.7899 .34418 m
.89541 .21776 L
.9626 .40127 L
.7899 .34418 L
s
.7899 .34418 Mdot
.89541 .21776 Mdot
.9626 .40127 Mdot
.9626 .40127 m
0 0 rlineto s
.9626 .40127 m
1 .39221 L
s
1 .28874 m
.89541 .21776 L
.9626 .40127 L
s
.9626 .40127 Mdot
.89541 .21776 Mdot
.89541 .21776 m
0 0 rlineto s
.89541 .21776 m
1 .19936 L
s
1 .28874 m
.89541 .21776 L
s
.89541 .21776 Mdot
1 .03348 m
.95303 .09187 L
s
.95303 .09187 m
1 .03812 L
s
.95303 .09187 Mdot
1 .09358 m
.95303 .09187 L
s
.95303 .09187 m
1 .03812 L
s
.95303 .09187 Mdot
.95303 .09187 m
.97232 .41997 L
s
.97232 .41997 m
1 .29351 L
s
1 .09358 m
.95303 .09187 L
s
.95303 .09187 Mdot
.97232 .41997 Mdot
1 .44166 m
.97232 .41997 L
s
.97232 .41997 m
1 .29351 L
s
.97232 .41997 Mdot
.97232 .41997 m
.95421 .7461 L
s
.95421 .7461 m
1 .61244 L
s
1 .44166 m
.97232 .41997 L
s
.97232 .41997 Mdot
.95421 .7461 Mdot
1 .57547 m
.87681 .83631 L
.95421 .7461 L
s
.95421 .7461 m
1 .61244 L
s
.87681 .83631 Mdot
.95421 .7461 Mdot
.95421 .7461 m
.89296 1.02555 L
.87681 .83631 L
.95421 .7461 L
s
.95421 .7461 Mdot
.89296 1.02555 Mdot
.87681 .83631 Mdot
.87681 .83631 m
.73288 1.15373 L
.89296 1.02555 L
.87681 .83631 L
s
.87681 .83631 Mdot
.73288 1.15373 Mdot
.89296 1.02555 Mdot
.89296 1.02555 m
0 0 rlineto s
.89296 1.02555 m
.9079 1.2 L
s
.8453 1.2 m
.73288 1.15373 L
.89296 1.02555 L
s
.89296 1.02555 Mdot
.73288 1.15373 Mdot
.73288 1.15373 m
0 0 rlineto s
.73288 1.15373 m
.75554 1.2 L
s
.8453 1.2 m
.73288 1.15373 L
s
.73288 1.15373 Mdot
.9626 1.2 m
.98459 1.1688 L
s
.98459 1.1688 m
.97363 1.2 L
s
.98459 1.1688 Mdot
.94396 1.2 m
.98459 1.1688 L
s
.98459 1.1688 m
.97363 1.2 L
s
.98459 1.1688 Mdot
.98459 1.1688 m
0 0 rlineto s
.98459 1.1688 m
1 1.19956 L
s
.94396 1.2 m
.98459 1.1688 L
s
.98459 1.1688 Mdot
.99061 1.2 m
.99662 1.15596 L
s
.99662 1.15596 m
.98424 1.2 L
s
.99662 1.15596 Mdot
1 1.15318 m
.99662 1.15596 L
s
.99662 1.15596 m
.98424 1.2 L
s
.99662 1.15596 Mdot
.99662 1.15596 m
0 0 rlineto s
.99662 1.15596 m
1 1.15043 L
s
1 1.15318 m
.99662 1.15596 L
s
.99662 1.15596 Mdot
1 .55866 m
.99022 .54715 L
s
.99022 .54715 m
1 .55286 L
s
.99022 .54715 Mdot
1 .57146 m
.86574 .50024 L
.99022 .54715 L
s
.99022 .54715 m
1 .55286 L
s
.86574 .50024 Mdot
.99022 .54715 Mdot
.99022 .54715 m
.7899 .34418 L
.86574 .50024 L
.99022 .54715 L
s
.99022 .54715 Mdot
.7899 .34418 Mdot
.86574 .50024 Mdot
.86574 .50024 m
.61244 .25332 L
.7899 .34418 L
.86574 .50024 L
s
.86574 .50024 Mdot
.61244 .25332 Mdot
.7899 .34418 Mdot
.7899 .34418 m
.89541 .21776 L
.61244 .25332 L
.7899 .34418 L
s
.7899 .34418 Mdot
.89541 .21776 Mdot
.61244 .25332 Mdot
.61244 .25332 m
.86952 .06749 L
.89541 .21776 L
.61244 .25332 L
s
.61244 .25332 Mdot
.86952 .06749 Mdot
.89541 .21776 Mdot
.89541 .21776 m
0 0 rlineto s
.89541 .21776 m
1 .19936 L
s
1 .13732 m
.86952 .06749 L
.89541 .21776 L
s
.89541 .21776 Mdot
.86952 .06749 Mdot
.86952 .06749 m
0 0 rlineto s
.86952 .06749 m
1 .03154 L
s
1 .13732 m
.86952 .06749 L
s
.86952 .06749 Mdot
1 .57547 m
.87681 .83631 L
s
.87681 .83631 m
1 .67416 L
s
.87681 .83631 Mdot
1 .63123 m
.76613 .86213 L
.87681 .83631 L
s
.87681 .83631 m
1 .67416 L
s
.76613 .86213 Mdot
.87681 .83631 Mdot
.87681 .83631 m
.73288 1.15373 L
.76613 .86213 L
.87681 .83631 L
s
.87681 .83631 Mdot
.73288 1.15373 Mdot
.76613 .86213 Mdot
.76613 .86213 m
0 0 rlineto s
.76613 .86213 m
.56896 1.2 L
s
.57085 1.2 m
.73288 1.15373 L
.76613 .86213 L
s
.76613 .86213 Mdot
.73288 1.15373 Mdot
.73288 1.15373 m
0 0 rlineto s
.73288 1.15373 m
.75554 1.2 L
s
.57085 1.2 m
.73288 1.15373 L
s
.73288 1.15373 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{240, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003`000180P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?1d003BM08A17@00a5dM005M0034GAd00=d
00<AM7@017@34@00d7@34@=d0Q47M0034GAd009d0Q42M0DA0g@00<id0a43M08A27@00a5dM002M0DA
27@00<ad0a44M08A27@00a5d4@044@ad003:M0<A17@24@Md1A42M0034GAd00ad0038M0<A1G@24@=d
1A400g@AM002M08A3g@00<Id0a45M0LA1G@0115dM7@24A1d0034M0<A17@54@Ud00DAM7Ad4@0@M08A
0032M0<A0W@64@]d00DAM7Ad4@0=M0@A0G@14@00`7@74@=d00<AM7@02W@00a5dM0024@]d0a44M08A
002nM0DA1G@24@ad00<AM7@00Q48M0@A1W@24@5d002mM08A0g@74@ad00@AM7@A1W@44@Ud0Q42M000
^g@34@Md0Q400g@A4@054@Ed00@AM7@A17@44@]d0Q43M000^G@44@Id0Q49M0TA00=d4A400Q4?M003
4GAd009d002gM0DA1W@24@id00<AM1401Q4?M08A17@00;Ed0a400g@A4@05M08A3g@44@Ed1a48M08A
1G@00;=d11400g@A4@05M08A3W@24@03M15d00ad1a400g@A4@06M000/W@34@9d0Q44M08A3W@64A=d
1a43M000/7@44@9d00<AM7@00g@24@id1A4017@A4A4AM08A17@44@00[W@44@=d00<AM7@00W@24@id
0Q401G@A4G@A00=d0a4>M08A1W@34@00[7@24@03M15d00=d00<AM7@00W@00a5dM00=M08A00=d4A40
0W@00a5dM003M0<A37@00a5dM0054@5d0A414@00ZW@24@03M14A00Ad00@AM7Ad0Q4?M0034GAd008A
0g@00a5dM005M0<A27@54@Ad0Q42M000ZG@44@Ed00DAM7Ad4@0?M08A0W@24@Ad00<AM7@00g@J4@00
Yg@24@03M14A00Ed00<AM7@00Q4?M18A0W@64@Ad00@AM7Ad0a46M000YG@24@03M14A00Ed0Q400g@A
4@0?M0@A0W@00a5dM005M0034GAd00DA1G@34@9d00<AM1400Q48M000Xg@24@9d0Q45M08A00=d4A40
37@54@Ad0Q45M0DA37@54@]d002QM08A0W@24@Id114:M0@A0W@00a5dM004M0034G@A00@A0W@00a5d
M00=M0@A2g@009md0Q42M08A1g@44@Md1144M08A17@64@Id00<AM7@02W@34@03M14A00<A2G@009id
0Q42M08A1g@34@Ed1147M0LA0W@0115dM146M0034GAd00Qd0Q44M08A0W@34@Md002LM08A0W@24@Qd
0a42M0@A1g@64@Md00@AM7@A1g@00a5dM005M08A1G@00a5d4@04M0<A1G@009Yd0Q43M08A27@64@Id
214:M0044GAd4@Md00<AM7@00W@34@Md00@AM7@A1G@34@=d002HM08A0g@24@Qd1145M0DA1G@24@]d
00@AM7@A1g@00a5dM0034@Ud00@AM7@A1g@34@5d002FM08A0g@24@Qd0Q4017@AM7@54@Qd0Q4<M003
4GAd009d00<AM7@017@34@ad00@AM7@A2G@24@00U7@34@=d0Q47M08A00=d4A400a4<M08A3G@00a5d
M002M0034GAd00=d0Q4=M0054GAdM1402g@009=d0Q43M08A1g@54@04M15d4@ad00<AM7@03G@00a5d
M002M0034GAd00<A00=d4A4037@01A5dM7@A00]d002AM08A17@24@=d1A46M0044GAd4@Ud0Q4?M003
4GAd00=d1144M0034GAd00Yd00DAM7Ad4@0;M000Sg@24@Ad2A48M0054GAdM14027@24A1d00<AM7@0
0W@24@Md00<AM7@02W@01A5dM7@A00]d002=M08A0g@54@=d0Q4:M0034GAd009d00<AM7@017@00a5d
M00@M0034G@A008A0W@00a5dM004M0034GAd00Ud00<AM7@00W@00a5dM009M000Rg@94@Ad0Q4<M003
4GAd009d00<AM7@00W@24A9d1144M0034GAd00Ad00<AM7@02G@00a5dM002M0034GAd00Ud002:M0<A
0g@24@=d0a4=M0034GAd00=d0Q42M0034GAd015d0Q47M0034GAd00Ad00<AM7@02G@00a5dM002M003
4GAd00Ud0028M08A00Ed4A4AM0024@9d0Q4@M0034GAd00Ad0a4BM08A00=d4G@01W@00a5dM005M003
4GAd00Qd00<AM7@00W@00a5dM009M000Qg@34@=d0a400g@A4@0BM0034GAd00Ad0Q4@M0<A0W@24@Md
00<AM7@01G@00a5dM007M0034GAd00=d00<AM7@02G@008Id0a43M0034GAd00<A4W@00a5dM004M003
4G@A00id0a44M0034GAd00Id00<AM7@01G@00a5dM007M0034GAd00=d00<AM7@02G@008Ad1142M0DA
0g@24A1d00<AM7@00W@24@9d00<AM7@02W@24@Md00<AM7@01g@00a5dM004M0034GAd00Md00<AM7@0
0g@00a5dM009M000Pg@24@03M15d00@A27@24@id00@AM7Ad0Q44M0034GAd00Md0Q49M0034GAd00Md
00<AM7@017@00a5dM007M0034GAd00=d00<AM7@02G@0089d0Q400g@A4@034@ad0a4:M0034GAd008A
1W@00a5dM004M0<A2W@00a5dM008M0034GAd00Ed00<AM7@01G@00a5dM004M0034GAd00Ud0020M0<A
0W@34A1d0a48M0044G@A4@Qd00@AM7Ad0Q4=M0034GAd00Qd00<AM7@01G@00a5dM005M0034GAd00Ed
00<AM7@027@007md0a42M08A5G@24@Id0Q4:M0044G@A4@md00<AM7@027@00a5dM005M0034GAd00Ed
00<AM7@01G@00a5dM005M0<A001nM0<A00=d4A400Q4GM08A0g@24@Yd0a4@M0034GAd00Yd00<AM7@0
17@00a5dM005M0034GAd00Ed00<AM7@01A43M000O7@34@9d0Q4017@AM14HM0@A2G@34@03M15d00md
00<AM7@02W@00a5dM004M0034GAd00Ad00<AM7@017@54@Qd001kM0<A0W@0115dM143M0034GAd01Id
0a47M08A17@00a5dM00>M0034GAd00Yd00<AM7@01G@00a5dM003M0034G@A00@A0W@00a5dM008M000
NW@0115d4G@24@=d00<AM7@00W@00a5dM00CM08A00=d4G@00a42M08A1g@00a5dM00<M0034GAd00]d
00<AM7@01G@00a5dM0054@Md00<AM7@027@007Qd11400g@A4@04M0034GAd00=d00<AM7@04G@01A5d
M7@A00=dBa4007Md11400g@AM005M0034GAd00Ad00<AM7@03W@24@Ad1A400g@AM009M0034GAd00]d
00<AM7@01g@84@=d1142M08A27@00a5dM008M000MW@00a5d4@034@Id00<AM7@01W@00a5dM00<M08A
0W@34@03M14A00Ad00<AM7@01g@00a5dM00:M0/A1G@00a5dM002M0084GAd4G@AM149M0034GAd00Qd
001dM08A00=d4G@00Q47M0034GAd00Md00<AM7@02W@54@9d0Q47M0034GAd00Id0Q45M0PA3W@0115d
M7@24@9d00<AM7@00Q49M0034GAd00Qd001cM08A00Ad4G@A2G@00a5dM008M0034GAd00Md1143M0<A
27@24@Ed2A46M0034GAd00ed00<AM7@00Q43M0044GAdM08A27@00a5dM008M000LG@24@03M14A008A
2W@00a5dM009M0034GAd00=d1144M08A00=d4G@01g@84@=d00<AM7@02G@00a5dM00=M0044GAd4@Ed
00DAM7@AM0024@Id00<AM7@027@0071d0Q400g@A4@024@Yd00<AM7@02g@74@Ad0Q43M0TA0g@24@Md
00<AM7@01g@00a5dM00>M0034G@A00Id00<AM1400g@24@Ed00<AM7@027@006md00<AM7@00a4<M003
4GAd00Ud1142M08A0W@94@ad00<AM7@01G@00a5dM007M0034GAd00id0Q48M08A1G@24@=d00<AM7@0
27@006ed0Q42M0034G@A00ed00<AM7@01G@44@Ad2145M0034GAd00ad00<AM7@01G@00a5dM006M003
4GAd00id0Q48M08A1W@24@9d00<AM7@027@006ad0Q42M0<A3W@00a5dM002M0@A27@54@Md00<AM7@0
3G@00a5dM004M0034GAd00Ed00<AM7@03W@00a5d4@08M08A27@44@Ud001[M0044GAdM0<A3g@00a5d
4@024@ed1147M0034GAd00id00<AM7@017@00a5dM004M0034GAd00ed00@AM7@A27@24@Ud0a49M000
JG@24@9d0a4?M0@A3W@24@04M14AM08A17@00a5dM00@M0034GAd00=d00<AM7@017@00a5dM00<M08A
0W@00a5dM006M08A2g@24@Qd001XM08A0W@34@ed0a400g@AM00=M08A17@24@9d0Q42M0034GAd015d
00<AM7@00W@24@Ad00<AM7@037@24@=d00<AM7@01W@24@]d0a47M000Ig@0115dM7@34@Yd1144M003
4GAd00Yd0Q47M08A0g@34AAd00<AM7@00W@00a5dM002M0034GAd00ad00<AM7@00g@00a5dM005M003
4G@A00Yd00<AM7@00Q45M000IG@24@=d0Q49M0@A1g@00a5dM008M0<A2G@24@=d0a4CM08A0g@00a5d
M002M0034GAd00]d00<AM7@017@00a5dM004M0044GAd4@Yd00@AM7Ad0Q44M000I7@24@=d0Q47M0<A
2W@00a5dM008M08A37@24@9d00<AM7@00Q4BM08A0g@01A5dM7@A00ad00<AM7@01G@00a5dM004M004
4GAd4@Yd00<AM7@00g@00a5d4@014@00Hg@0115dM7@34@Ad114=M0034GAd00Id0Q4?M08A00=d4G@0
0g@24A5d0Q42M0044GAd4@ad00<AM7@01W@00a5dM004M0054GAdM1402G@00a5dM002M0@A0G@0065d
0Q43M08A0g@34A5d00<AM7@017@24A9d0Q47M08A47@24@9d00<AM1402g@00a5dM007M0034GAd00Ad
00DAM7Ad4@09M0034G@A008A17@14@00H7@24@=d1Q4DM0034GAd009d0Q4DM0TA0W@24@md00HAM7@A
M14:M08A2G@00a5dM003M0034GAd00=d00<AM7@01W@34@Id0A4005md00<AM7@00W@44AMd00<AM7@0
0Q4DM08A00Ad4A4A1G@@4@Ad00@AM7@A2W@24@]d00<AM7@00W@00a5dM003M0034GAd00=d1148M04A
001MM08A0W@44AUd00@AM14A4g@34@Ad0a49M08A2G@94@Ud00<AM7@02W@00a5dM002M0034GAd00=d
00<AM7@00a43M0034GAd00Id0A4005ad21400g@A4@0GM08A4W@34@Md00@AM7@A2W@24@ed1A46M003
4GAd00]d00<AM7@00W@00a5dM003M0<A1W@00a5dM005M04A0G@005]d0a44M08A0g@34A9d0a4AM0<A
2G@0115dM7@24@Yd0Q4<M0<A00=d4A400g@00a5dM00<M0054GAdM1400g@34@03M15d00Id00<AM7@0
1G@14@5d001JM0<A17@00a5d4@06M08A3g@24@03M15d00ed0a4<M0034GAd009d0Q4;M08A2g@24@=d
0a4?M0064GAdM15d0Q44M0034GAd00Ed00<AM7@01G@14@5d001JM0034G@A00Ad00<AM14027@34@Yd
0Q42M0034GAd00]d0Q4@M0034GAd009d0Q4<M08A2G@34@=d0a4?M0034G@A008A1g@00a5dM004M003
4GAd00Ed0A41M000FG@24@9d00@AM7@A0W@00a5dM009M08A1W@24@Ad00<AM7@027@34A9d00<AM7@0
0g@34@ad0Q48M0<A00=d4G@00W@34@]d0a400g@AM007M0034GAd00Ed00<AM7@00g@14@5d0G@005Qd
0a42M0044G@A4@9d00<AM7@02g@34@03M14A00Id00<AM7@01G@34AEd00<AM7@017@34@ed0Q46M0DA
1G@34@Id0a4017@AM149M0034GAd00Ed00<AM7@00g@14@5d0G@005Md0a44M08A0g@00a5dM00=M0<A
1g@00a5dM003M0<A5g@24@Id0a4>M08A17@0115d4A48M0<A00Ad4A4A17@00a5d4@0:M0034GAd00Ad
00<AM7@00g@14@5d0G@005Md00<AM14017@24@=d00<AM7@02g@24@=d0a43M0044GAdM0<A6g@00a5d
M005M0@A3W@24@=d1148M0@A1W@00a5d4@0:M0034GAd00Ad00<AM7@00g@14@5d0G@005Id00<AM140
1G@24@=d00<AM7@02G@34@Md0Q400g@AM0024Aid00<AM7@01W@44@md0Q4017@AM7@24@Ed0a43M08A
17@00a5d4@0;M0034GAd00=d00<AM7@00W@00a5dM001M000EG@24@03M15d00=d00@AM14A0g@00a5d
M007M08A2g@34B1d00<AM7@01g@24@03M15d00id0a43M0034GAd00<A27@24@=d00<AM7@02W@00a5d
M003M0034GAd009d00<AM7@00G@005Ed00@AM7@A17@0115dM143M0034GAd00Ed0Q4=M08A00=d4A40
7g@00a5dM007M08A00=d4A402g@=4@]d114<M0034GAd00=d00<AM7@00W@00a5dM001M000E7@0115d
M144M0034GAd009d00@AM7@A1G@24@id0a43M08A7G@00a5dM004M1<A17@74@9d1Q47M08A3G@00a5d
M002M0034GAd009d00<AM7@00G@005=d00DAM7Ad4@03M0034GAd00=d00@AM7@A0g@24@md0Q42M003
4GAd009d0a4>M1<A1G@24@9d00<AM7@02W@44@=d1145M0LA00Ad4A4A2g@00a5dM002M0044GAdM08A
0g@005=d00@AM7@A17@00a5dM004M0044G@AM08A4G@01A5dM7@A009d4a4<M0034GAd00Yd0Q42M08A
1g@34@9d0a42M08A0W@34@Ud1Q49M0034GAd009d00DAM7Ad4@04M000DW@01A5dM7@A00=d00<AM7@0
1G@44@Md4a47M08A5g@00a5dM00:M08A0W@24@=d0a45M0@A00Ad4G@A17@34@Qd00<AM1401a44M005
4GAdM1400g@00a5dM002M000DG@00a5dM002M0054GAdM14027@:4@Yd00<AM7@00g@00a5dM009M0<A
57@00a5dM00;M08A0g@34@Ud00<AM1400Q400g@A4@06M0<A1G@01A5dM7@A00Ed1a400g@AM002M003
4GAd009d001AM0054GAdM1400g@00a5dM005M0@A4G@00a5dM005M0034GAd00Yd0a4BM0034GAd00ad
1a49M0034GAd00<A00=d4G@027@34@9d0Q43M08A1g@00a5dM0064@Ad001@M0034GAd009d00<AM7@0
0Q46M08A0W@00a5dM00>M08A1g@00a5dM00=M08A47@24@ad1143M08A2G@00a5dM0024@9d00<AM7@0
2G@44@Ad0Q47M0044GAd4@9d00<AM1400a4004md00<AM7@00W@24@9d00<AM7@00g@34@=d0Q4>M08A
27@00a5dM00?M08A3g@00a5dM007M0<A0g@24@Ad00<AM7@01W@0115dM7@24@9d00<AM7@02g@34@=d
0Q46M0044GAd4@9d00<AM7@00g@004id0Q44M0044GAd4@Ed0a44M08A3W@00a5dM007M0034GAd015d
0a4<M0034GAd00Ed0a46M08A17@24@Id0Q43M08A00=d4A4037@24@04M14A4@9d00<AM7@017@00a5d
4@02M0034GAd00=d001>M0034GAd00=d00@AM7@A17@00a5d4@05M0034G@A00ad00<AM7@027@00a5d
M00CM0<A2W@00a5dM002M0<A2W@24@Ad0Q46M0044GAdM0<A00=d4G@02g@24@Ad1A44M0064GAd4G@A
0g@24@00CG@00a5dM003M0044GAd4@=d1146M0034G@A00]d00<AM7@02W@00a5dM00EM08A2G@44@id
0Q45M0034GAd00=d0Q42M0064G@A4G@A2g@24@Md0a43M0034GAd008A00Ad4A4A0W@004ad0Q45M004
4GAd4@9d1147M0044GAd4@Ud00<AM7@02g@00a5dM00GM0<A1G@34A5d0Q45M08A0g@24@9d00<AM7@0
0Q400g@AM00:M0034GAd00Md11400g@AM0034@Ed001<M0034GAd00Ad00@AM15d0Q400g@A4@08M003
4GAd008A1g@24@ed00<AM7@06G@64@03M15d019d0Q45M08A0g@24@9d00<AM7@00a4;M08A2W@00a5d
4@044@Id001;M0034GAd00Ad00@AM15d0Q400g@A4@09M0054GAdM1401g@00a5dM00<M0034GAd01Ud
1A42M0034GAd019d0Q46M0034GAd008A0W@0115dM7@34@Yd0Q4;M0HA1W@004Yd00<AM7@01G@0115d
4A42M08A2W@00a5dM002M0034GAd00=d00<AM7@03W@00a5dM00FM08A1G@24@03M15d01=d0Q46M0<A
00Ad4G@A17@34@Ud0Q4<M08A00=d4A401W@004Yd00<AM7@017@0115d4A42M08A2g@00a5dM002M003
4GAd009d00<AM7@03g@00a5dM00CM0<A2G@B4@Ed0Q46M0@A0W@0115dM7@44@Qd00<AM1402g@64@Ed
0019M0034GAd00Ed0a42M08A37@00a5dM003M0044GAd4A9d00<AM7@047@34@]d1Q4<M14A00Ad4G@A
17@34@Ud0Q4;M0054G@A4G@00Q44M000B7@00a5dM005M0<A0W@24@id00<AM7@00W@0115d4A4BM003
4GAd00ed0a4<M08A0W@0115dM7@24A9d0Q47M08A00=d4G@017@34@Qd0Q4:M0034GAd00HA0g@004Qd
00<AM7@017@44@03M15d00md00<AM7@00g@24A=d00<AM7@02g@34@ed0Q43M0034GAd00=d0Q4AM08A
1W@54@Ed0a47M0034G@A00Ud00<AM7@00Q400g@A4@024@9d0017M0034GAd00Ad00HAM14AM14AM003
4GAd00=d00<AM7@04g@00a5dM007M0<A3W@24@Id00<AM7@017@24A5d00<AM7@017@44@Id0a46M003
4G@A00Ud00<AM7@00Q43M0<A0G@004Id00<AM7@00g@24@05M14AM1404W@00a5dM002M0034G@A01Ad
00<AM7@017@34@md0Q48M0034GAd00Id0Q4@M0034GAd00=d00<AM1400Q46M0<A1W@24@Qd00@AM7Ad
0Q44M0<A0015M08A17@24@9d0a4CM0054GAdM1400W@24A=d00<AM7@00W@34A1d0Q49M0034GAd00Qd
0a4>M0034GAd00=d1A46M0<A1G@00a5d4@07M0044GAdM08A1W@14@00AG@0115dM7@24@Ad0Q4DM004
4GAd4@Ad00<AM7@04G@00a5d4@024A5d0Q4;M0034GAd00Yd0a4=M0034GAd009d11400g@A4@05M0<A
17@00a5d4@06M08A0g@24@Md0014M0044GAdM08A17@24AEd00@AM14A1G@00a5dM00?M0<A4W@24@ed
00<AM7@03G@24@ad00<AM7@00W@34@9d0Q45M0034G@A00=d00<AM1401W@00a5dM002M08A1g@004=d
0Q42M0034GAd00=d1a4AM0<A1W@00a5dM00=M08A0W@00a5dM00?M08A3W@00a5dM00?M08A2g@00a5d
M002M08A0g@24@Ed00<AM1400W@0115d4A45M0034GAd00=d00<AM7@01G@004=d00@AM14A0g@54@Ed
3145M08A27@00a5dM009M0<A17@00a5dM00=M08A47@00a5dM00AM08A2W@0115dM7@34@Ad0Q44M003
4G@A009d00<AM14017@24@Ed00<AM7@01G@0049d00DAM14AM0034@9d00@AM14A47@84@Md00<AM7@0
1W@34@Md00<AM7@037@24A5d00<AM7@04g@24@Ud00@AM7Ad0Q45M08A0g@24@06M15d4G@A17@00a5d
M003M08A1g@0045d0a4017@A4A43M0034GAd008A5G@00a5d4@034@Ed00<AM7@00W@34@Yd00<AM7@0
2W@24AAd00<AM7@057@24@Qd00<AM7@00Q46M08A0g@24@05M14AM14017@00a5dM003M08A1g@0045d
1144M08A0g@24AEd00<AM7@00g@44@04M14AM0<A3G@00a5dM007M08A5W@00a5dM00FM0<A1W@00a5d
M0024@Id0a42M08A00Ed4GAd4@02M0034GAd00Ad0Q45M08A0010M08A1W@24@Ad00<AM1404g@00a5d
4@08M0PA37@00a5dM006M08A5g@00a5dM00HM0<A1G@0115d4A48M08A0W@24@04M15d4@9d00<AM7@0
17@24@03M14A008A0W@0041d00<AM7@017@24@Ed00<AM1404g@00a5d4@04M0LA00=d4A403a46M08A
6G@00a5dM00KM08A17@0115d4A48M08A00=d4A401142M0034GAd00=d1146M000?g@34@Ad0Q46M003
4G@A01=d00<AM1401142M08A0g@00a5dM002M0@A27@;4AMd00<AM7@07G@24@=d0a49M0HA00Ad4A4A
0W@44@03M14A00Md000oM0<A0g@24@Md00@AM7@A47@54@Ad0Q45M0034GAd00Id1145M0034GAd008A
1G@<4@]d00<AM7@07g@24@9d0a4:M0@A0W@44@Ed0a46M000?g@34@9d0Q48M0044GAd4@ad11401G@A
4G@A00=d0Q46M0034GAd00Yd114017@A4A4CM0`A8g@24@03M14A00]d1a47M0<A1W@003id00@AM15d
0a49M0044GAd4@Md1A45M0044GAdM0<A27@00a5dM00=M0@A7g@<4AYd1148M0XA1W@34@Id000nM004
4G@AM08A2W@00a5dM0024@9d114:M0034GAd008A2g@00a5dM00=M08A00Ad4A4A7G@00a5dM008M0/A
47@44@=d1145M0@A00=d4G@017@34@Id000nM0034G@A00<A2W@00a5d4@044@id00<AM1400Q4;M003
4GAd00ed0Q44M0<A6W@00a5dM00CM0`A00=d4A402149M0DA00=d4G@00g@34@Id000mM0034GAd008A
00=d4G@01g@44@9d00<AM7@03W@24@9d00<AM7@02G@00a5dM00<M0034G@A00Md0a4GM0034GAd01ed
2Q400g@A4@024@Qd1A400g@AM002M0<A1W@003ed00LAM15d4G@A00=d1A42M0054GAdM1403W@24@Ad
00<AM7@02W@00a5dM00;M0034G@A00Yd0a4DM0034GAd01Ud1142M0@A00Ad4A5d2145M0HA00Ad4GAd
0a46M000?G@24@9d00<AM1401146M0034GAd009d00<AM7@02W@00a5d4@05M0034GAd00Ud00<AM7@0
2W@0115dM14=M0<A4G@00a5dM00EM0@A0W@44@Ed0Q45M0LA0g@64@03M15d008A00=d4G@017@003ad
0Q400g@A4@024@03M15d00Qd00<AM7@00W@00a5dM008M08A0W@00a5dM003M0034GAd00Ud00<AM7@0
2G@24@9d00<AM7@03G@44@id00<AM7@04W@44@9d1148M0034GAd00Md2a400g@A4@044@03M15d00Ad
000lM0<A0W@0115dM149M0034GAd009d00<AM7@01W@24@Ad00<AM7@00g@00a5dM009M08A2W@01A5d
M7@A019d0a4<M0034GAd00id1142M0@A2g@24@]d2Q400g@A4@034@03M15d00Ad000lM0034GAd009d
00DAM7Ad4@08M0034GAd00=d00<AM7@00g@24@Id00<AM7@00g@00a5dM00:M0034GAd00Md00DAM7Ad
4@0FM0<A2G@00a5dM00;M0@A0W@34@md0Q4=M0XA00Id4A4AM145M000?7@00a5dM002M0054GAdM140
27@00a5dM003M0034GAd009d0Q46M0034GAd00Ad00<AM7@02W@00a5dM007M0054GAdM1406G@34@Md
00<AM7@01W@44@9d114BM08A3g@>4@Ed000lM08A0g@01A5dM7@A00Qd00<AM7@00g@00a5dM0024@Qd
00<AM7@01G@00a5dM009M0034GAd00Id00<AM7@00W@00a5dM00JM0<A17@00a5dM003M0<A0W@44AId
0Q4AM0HA00=d4A401A43M000?7@24@=d00<AM7@00W@00a5dM005M0034GAd00Ad0Q4:M0034GAd00Ed
00<AM7@02W@00a5dM004M08A17@00a5dM00MM0<A00=d4G@01142M0@A6G@24A9d1Q400g@A4@034@03
M14A004A000lM08A0g@00a5dM002M0034GAd00Ed00<AM7@00g@24@]d00<AM7@01G@00a5dM00:M003
4GAd00Ad00<AM7@00g@00a5dM00PM0<A0W@44Aed0Q4BM0TA00Ad4A4A0g@003ad0Q43M0034GAd009d
00<AM7@01G@0115dM7@24@03M15d00Ud0Q47M0034GAd00Yd00<AM7@00g@00a5dM004M0034GAd01md
1Q4PM0034G@A01=d00<AM1400a4017@A4G@44@5d000lM0<A0W@00a5dM003M0034GAd00Ad00@AM14A
17@00a5dM007M0034GAd00Id00<AM7@02W@24@Ad00<AM7@017@00a5dM00NM0@A0g@24Aid00<AM140
4g@0115d4G@44@04M14AM0<A000lM0<A0W@00a5dM003M0034GAd00Ad0Q46M0034GAd00Md00<AM7@0
1g@00a5dM00:M0054GAdM1401g@00a5dM00JM0DA00=d4G@01G@24Aad0Q4DM0<A0W@:4@00?7@34@9d
00<AM7@017@00a5dM002M08A1g@00a5dM007M0034GAd00Md00<AM7@02W@00a5dM0024@Md00<AM7@0
5g@34@9d00@AM7@A2G@34AUd0Q4DM08A00=d4G@00a42M08A0G@14@4A000lM0<A0g@00a5dM003M003
4GAd008A00=d4G@01g@00a5dM006M0034GAd00Md00<AM7@02W@0115dM148M0034GAd01=d1144M005
4GAdM14037@24AMd0Q4EM0<A00=d4A400Q400g@A4@034@00?7@34@=d00<AM7@00g@34@=d00<AM7@0
1W@00a5dM005M0034GAd00Qd00<AM7@02g@24@Ud00<AM7@03g@44@Id0Q43M0034GAd00ed0Q4EM08A
5G@34@03M15d008A00Ad4GAd0Q4003ad0Q401G@AM7@A00Ed0Q44M0034GAd00Id00<AM7@01G@00a5d
M008M0034GAd00]d0Q49M0034GAd00ad1148M08A17@00a5dM00?M08A4W@00a5d4@0EM08A00Ad4A5d
1143M04A000lM08A00Ed4GAd4@03M08A00=d4G@00g@00a5dM007M0034GAd00Ad00<AM7@02G@00a5d
M00:M0034GAd00Qd00<AM7@027@44@]d00<AM7@00g@00a5dM00BM0<A3g@00a5d4@0EM0034G@A008A
00=d4A400Q42M08A000lM0044G@A4@9d00@AM14A0g@00a5dM002M0034GAd00Md00<AM7@017@00a5d
M009M0034GAd00Ud0a49M0034GAd00Ed0a4>M0034GAd00Ad00<AM7@05G@24@ed00<AM1405G@00a5d
4@024@03M15d00<A0G@14@5d000lM0044G@A4@9d0a45M0054GAdM1402G@00a5dM004M0034GAd00Ud
00<AM7@02G@00a5d4@08M0034GAd009d114?M08A1W@00a5dM00HM08A2g@00a5d4@0FM0064G@A4G@A
0W@44@5d000lM0044G@AM0<A1g@01A5dM7@A00Ud0Q44M0034GAd00Yd00<AM7@027@0115dM148M0DA
4W@24@Md00<AM7@06W@24@Ud00<AM1405W@01Q5d4A5d4@9d1A4003ad00<AM1400Q400g@AM006M005
4GAdM1402W@00a5dM002M0034GAd00Yd00<AM7@027@0115dM146M0@A57@24@Md00<AM7@07G@34@Id
0Q4GM0034G@A00PA0W@003ad00<AM1407Q400g@AM00<M0034GAd00Id00<AM7@00W@00a5d4@034@9d
00<AM7@04W@00a5dM007M0034GAd021d0Q43M0034G@A015d214017@AM143M0<A0G@003ad00LAM15d
4G@A00Qd00@AM7@A2W@00a5dM00Q4@Ed00<AM7@04G@00a5dM007M0034GAd02=d0Q4017@AM14:M0PA
1W@00a5d4@024@9d1141M000?7@00a5d4@02M08A27@24@03M15d00Yd00<AM7@00Q4=M0034GAd00Ed
00<AM1400Q4017@AM7@64A5d0Q4:M0034GAd02Ed0Q400g@AM002M0LA3W@00a5d4@024@9d0Q41M04A
0A4003ad0a42M08A2G@00a5d4@0;M0044GAd4@id00<AM7@017@44@=d00<AM7@01G@64@]d0Q4:M003
4GAd02Md1Q4EM0034G@A008A00=d4A400Q41M04A000lM0@A00=d4A402G@00a5d4@0;M0044GAd4@id
00<AM7@00W@34@Id00<AM7@01G@00a5dM003M0HA17@00a5dM00:M0034GAd02Id0a4017@A4A4EM004
4G@AM0DA0W@14@00?7@44@03M14A00Yd0Q4<M0034G@A00md11400g@AM006M0034GAd00Ed00<AM7@0
2G@54@]d0Q4VM08A00=d4G@00g@24AAd1A4017@A4G@24@5d000lM08A00Id4G@AM149M08A37@00a5d
4@0=M0<A0g@24@Md00<AM7@01G@00a5dM00:M08A0W@64@Ed00<AM7@08W@34@03M14A00Md0Q4@M0@A
0W@44@03M14A005d000lM08A00Ad4GAd0Q49M08A37@24@ad0a400g@AM002M0034GAd00Md00<AM7@0
17@00a5dM009M08A2G@64B9d0a42M0<A2G@24@Yd1143M0034GAd00@A00=d4A400A4003ad0Q4017@A
M7@24@Yd00<AM7@02g@00a5dM007M0<A17@0115dM14:M0034GAd00Ad00<AM7@027@24@id1a4KM08A
17@24@03M15d00Yd0Q45M0@A1W@00a5dM0034@04M14A4@5d000lM08A00Ad4GAd0Q49M1<A0g@34@Md
00@AM7@A2W@00a5dM004M0034GAd00Md00<AM7@03G@24@Id1A4CM0<A1G@24@9d00<AM7@02g@64@Ud
00<AM1400a42M08A0G@003ad0Q4017@AM7@24@Id0a400g@A4@0<M0034GAd00LA27@24@]d00<AM7@0
17@00a5dM006M0034GAd00id00<AM7@02W@64@]d0a46M0034GAd009d00<AM7@02W@54@]d1Q4017@A
4G@14@00?7@24@03M14A009d00<AM7@00W@24@Ed00<AM7@02W@00a5d4@024@Ad1a42M08A2g@00a5d
M003M0034GAd00Ed0Q4AM0034GAd011d1A44M08A27@00a5dM003M0034GAd00Md0a45M08A2G@34@03
M14A00<A0W@003ad0Q42M0054GAd4G@00a47M0034GAd00Ud0a4=M0DA2g@00a5dM003M0034GAd00Ad
0Q4AM0034GAd01Id1Q47M0034GAd00=d00<AM7@01G@34@Yd0Q47M0<A00Ad4A5d0Q42M000?7@24@9d
00<AM7@00Q4;M0034GAd00Ed0a42M0034GAd00id00<AM1400Q48M0034GAd00=d00<AM7@00g@00a5d
M00AM0034GAd01Ed0a44M0DA00=d4G@01G@00a5dM002M0<A3g@24@Ed0a4017@AM7@24@9d000lM08A
0W@01A5d4G@A00]d00<AM7@00g@34@Ad00<AM7@03W@00a5dM002M0<A1G@00a5dM003M0034GAd009d
00<AM7@04G@00a5dM00DM0<A2W@74@9d00<AM1400Q4DM08A0g@54@04M15d4@9d000kM0<A0W@24@9d
0Q4;M0034G@A008A1g@00a5dM00=M08A1g@44@03M15d00Ad00<AM7@00Q4DM0034GAd019d0Q4<M08A
1W@64AMd0Q401G@A4A5d00<A0W@14@5d000kM08A0g@00a5dM002M0034GAd00Qd0a4:M0034GAd00ed
00<AM7@02W@34@Ad00@AM14A57@00a5dM00@M0<A3G@24@=d1A400g@AM002M0PA4G@44@04M14A4@9d
0A41M000>g@24@9d0Q45M0034GAd00Ed0a400g@AM00:M0034GAd00ad00<AM7@02g@54@04M14A4AEd
00<AM7@03W@34@id1Q45M0034GAd00Yd2149M0@A00=d4A400g@14@5d000kM08A00Ad4G@A1W@0115d
M7@34@Ad00<AM7@02G@00a5dM00<M0034GAd00ad00@AM7Ad0a4EM0034GAd00ed0Q4?M0@A2G@00a5d
M00BM10A0g@24@00>g@34@=d00<AM7@00g@44@Qd00<AM7@027@00a5dM00<M0034GAd00ad00HAM7Ad
4G@34A=d00<AM7@02g@24@ed1A4;M0034GAd01]d2A42M08A000kM08A17@0115dM7@44@Yd00<AM7@0
27@00a5dM00<M0034GAd00ad00DAM7Ad4@04M08A47@00a5dM009M0<A2g@44@=d00<AM7@02W@00a5d
M00JM0034G@A008A00=d4A401Q4003Yd1143M0034G@A008A0g@00a5dM008M0034GAd00Md00<AM7@0
2g@24@id00@AM7@A1g@24@id00<AM7@01g@34@Ud1146M0034GAd00]d00<AM7@06G@24@05M14A4G@0
214003Yd0Q42M0034GAd00<A1W@00a5dM007M0034GAd00Qd00<AM7@02W@00a5dM00=M0044G@A4@Ud
0Q4;M0034GAd00Id0Q48M0@A2G@00a5dM00;M0034GAd01Ud11400g@A4@074@9d000jM08A0g@34@9d
2149M0034GAd00Md00<AM7@02W@00a5dM00=M0034G@A00ad0Q49M0034GAd00=d0a45M0DA2g@24@id
00<AM7@067@0115d4G@:4@=d000jM08A0g@34@Qd1A46M0034GAd00Md00<AM7@02W@00a5dM00=M08A
3g@24@Id00<AM7@00W@34@=d1A4>M08A3W@24AUd1Q400g@A4@054@Ad000jM08A0W@00a5d4@024@Ud
00<AM7@02148M0034GAd00Yd00<AM7@03G@24A5d0Q44M0034GAd008A0W@54A5d0Q4?M0034GAd01Ad
1A401G@AM15d00@A00Ad4A4A17@003Yd00HAM7@AM142M08A2G@00a5dM005M0DA1G@00a5dM00:M003
4GAd00ed00<AM7@04W@;4AEd0Q4@M0034GAd00md1A42M0034GAd008A00=d4A40114017@AM144M000
>G@24@05M15dM1400W@34@Qd0Q47M08A0W@74@Yd0Q4>M08A5W@54AQd00<AM7@03g@00a5dM00<M0@A
1W@0115dM7@44@03M14A00@A00=d4G@00g@003Ud0a42M0064GAdM15d0Q48M0034GAd00Id00<AM7@0
1G@64@Id00<AM7@037@24@03M15d015d11400g@A4@0HM0034GAd011d00<AM7@01g@54@Ud00@AM7Ad
1142M0@A0W@00a5d4@03M000>G@24@=d00DAM7Ad4@02M08A27@00a5dM005M0034GAd00Id00<AM7@0
0W@54@03M15d00ed00@AM7@A3W@44@03M14A00Ad0Q4EM0034GAd015d00<AM7@00g@44@ed00<AM7@0
0a42M0034G@A00<A0g@00a5d4@03M000>G@01A5dM7@A00Ed00<AM7@00Q48M0034GAd00Ed00<AM7@0
1G@00a5dM007M0HA2G@01A5dM7@A00Yd1143M08A27@24A9d00<AM7@04G@00a5d4@044A1d00<AM140
0Q4017@AM142M0@A0g@00a5d4@03M000>G@34@03M15d00Ad00@AM7Ad0Q47M08A1W@00a5dM005M003
4GAd00Qd00<AM7@00W@54@Ad00DAM7Ad4@06M0@A1W@24@Yd0Q4?M08A4W@44AAd1142M0074GAd4G@A
M0024@Ad00<AM1400g@003Ud00<AM7@00Q45M0034GAd009d0Q47M0034GAd00Ed00<AM7@01G@00a5d
M007M0034GAd00Md1Q42M0034G@A00@A2G@00a5dM00<M08A37@24@id1A400g@AM00DM0<A17@01A5d
4G@A009d0Q44M0034G@A00=d000iM0034GAd00<A17@00a5dM003M08A1g@00a5dM004M0034GAd00Ed
00<AM7@01W@24@]d00@AM7Ad1A4;M08A4G@24@Ud0Q4:M0DA1W@00a5dM00AM0<A1G@01a5dM15d4G@0
0a45M08A0g@003Ud00@AM7@A0W@0115dM7@24@Ed0Q47M0034GAd00Ad00<AM7@017@00a5dM006M003
4GAd00Yd1142M0034GAd00DA1G@24A=d0Q47M08A1g@54@Yd00<AM7@03g@34@Md00<AM7@00Q4017@A
4A46M0034G@A009d000iM0034G@A00Ad0Q42M0034GAd00Ed00<AM7@017@24@Ed00<AM7@017@00a5d
M006M0034GAd00Id1146M0034GAd00Ed1A4GM08A17@00a5dM002M0DA3W@00a5dM00>M0@A1g@01A5d
M15d00DA1W@00a5d4@02M000>7@24@03M15d00Ed00<AM14027@00a5dM004M0034GAd00Ad00<AM7@0
0g@00a5dM006M0034GAd009d1142M08A1W@00a5dM007M0LA5G@24@03M15d00@A4g@00a5dM00<M0<A
00=d4G@01g@00a5dM0084@Ed00<AM1400W@003Qd00<AM14027@24@Ud00<AM7@017@00a5dM003M003
4GAd00=d00<AM7@01W@54@Id00<AM7@01G@00a5dM006M0034GAd00Ed1A4AM0@A5W@24@ad0a42M003
4GAd00Id00<AM7@011400g@AM0024@Ed0a42M000>7@00a5d4@09M08A2G@00a5dM003M08A1G@00a5d
M003M0044GAdM0DA2G@00a5dM006M0034GAd00Ad0Q4=M0DA2G@34@9d00<AM7@05G@00a5dM009M0<A
0g@00a5dM007M0034GAd00<A00Ed4A4AM0024@Ed0Q42M000>7@24@]d0a48M0034GAd00=d00<AM7@0
0g@00a5dM003M0@A0g@24@Qd0Q48M0034GAd00=d0Q4CM0DA0W@24@Id00<AM7@057@00a5dM007M0<A
17@00a5dM007M0044GAdM0DA00Ed4GAd4@05M08A0W@003Qd0Q4;M0044GAd4@Qd00<AM7@00g@00a5d
M003M0HA1W@00a5dM007M0034GAd00Md00<AM7@00W@00a5dM00GM0DA1g@00a5dM00BM0034GAd00Id
0a45M0034GAd00Qd00<AM7@01Q4017@AM7@24@Ad0Q42M000>7@00a5dM00:M0044GAdM08A1g@00a5d
M003M0HA17@00a5dM004M0034GAd00Id00<AM7@027@00a5dM0024AMd0a45M0DA0g@24A9d00<AM7@0
17@34@Id00<AM7@027@94@9d00DAM7Ad4@04M0034G@A005d000hM08A2g@00a5dM003M0034GAd00Ed
00<AM1401143M08A0g@00a5dM004M0034GAd00Ed0Q4:M0034G@A01Id0a4=M0HA4G@00a5dM002M0<A
1g@00a5dM004M0HA00=d4A400a4017@AM144M08A17@24@5d000hM0034G@A00<A1g@00a5dM004M08A
0g@44@Ad00<AM7@00W@00a5dM002M0034GAd00=d00<AM7@01G@00a5dM009M08A5G@34AAd1A4<M004
4GAdM0<A27@84@Ad00<AM1401142M0034G@A00Ed00<AM7@00W@24@5d000hM0044GAdM0DA1G@00a5d
M004M0@A17@00a5dM002M0044GAdM08A0g@00a5dM003M0034GAd00Ad00<AM7@02G@24A=d0a4HM08A
0W@44@Qd00<AM1400Q44M0LA2g@24@04M14A4@9d00@AM7@A1G@84@00>G@00a5dM003M0HA00Ad4GAd
1142M08A1G@00a5dM002M0054GAdM1400g@00a5dM002M08A1W@00a5dM008M0034G@A011d0a4LM08A
1G@54@9d2Q44M0034GAd00Yd0Q42M08A0g@<4@9d0Q41M000>G@00a5dM005M0<A00=d4A400Q48M003
4GAd00=d0Q42M08A0W@01A5dM7@A00Ad00<AM7@017@00a5dM007M08A0W@00a5dM00;M0<A87@24@Ud
1Q49M0034GAd00Yd31400g@AM005M08A0W@24@5d000iM0034GAd00Qd0a4017@A4A47M08A17@24@9d
00DAM7Ad4@02M0034GAd009d00<AM7@00g@00a5dM007M0034GAd009d00<AM7@02G@34BAd00<AM7@0
0g@64@]d00<AM7@00W@;4@05M14AM1400W@0115dM148M0044GAdM08A000iM0034GAd00Md0Q4017@A
4A42M0@A1G@00a5dM002M08A0W@0115dM143M0054GAdM1401G@00a5dM005M08A17@24@Qd0a4XM0PA
00=d4G@01W@;4@Ed0Q400g@AM0024@9d00@AM7@A0W@00a5dM006M08A0W@24@00>W@00a5dM005M08A
0g@00a5d4@024@9d1143M08A0g@24@9d00@AM7@A0W@01A5dM7@A00Ad00<AM7@01G@24@Ed00<AM7@0
17@34BQd1A401G@A4A5d00/A0W@00a5dM009M08A00=d4G@00a401G@AM7@A00=d00<AM7@01g@00a5d
M0024@00>W@00a5dM004M0034GAd00=d00<AM7@00W@24@Ad0a42M0044GAdM08A00Ed4A5d4@02M005
4GAdM1400g@24@Id00<AM7@01G@0115dM7@34BQd11400g@A4@074@03M15d00Qd00<AM7@02G@24@9d
00@AM14A0W@0115dM143M0034GAd00Md1A4003Yd00<AM7@00g@00a5dM004M0034GAd00Ad0a44M0DA
0W@24@07M15dM15d4@02M08A0g@00a5dM003M08A27@00a5d4@024BId2A44M0034GAd009d00<AM7@0
1g@00a5dM009M0064GAdM15d0Q43M0044GAd4@9d00<AM7@01g@44@5d0A4003Yd00@AM7Ad0Q47M003
4GAd00Md0Q45M0<A0W@24@06M15d4G@A0W@01A5dM7@A00Ed0Q48M0<A8W@84@ad00<AM7@00W@00a5d
M006M0034GAd00Qd0Q44M0<A17@00a5d4@03M0034GAd00=d1142M08A0G@14@00>g@0115d4A48M003
4GAd00Ud0a45M0DA00Qd4G@AM15d4@9d0Q43M08A1g@34@03M15d01]d2Q4BM0054GAdM1401g@00a5d
M008M08A17@34@Ed00<AM1400g@00a5d4@034@Md0A41M04A000kM0<A2W@00a5dM00;M0<A17@74@04
M15d4@9d00@AM7Ad0Q45M0<A17@00a5dM00BM0PA0g@44AId00<AM1401g@00a5dM008M0034GAd00Ad
0Q45M0054G@A4G@0114;M08A0G@003]d1A48M0034GAd00ed0a43M08A00=d4A400a4017@AM143M003
4GAd00=d0a46M0034GAd00Yd2147M0@A6W@34@Id00<AM7@01g@24@Id0Q46M0DA0W@00a5dM00;M04A
0G@003]d0Q43M0TA4W@34@9d00<AM1401a400g@A4@03M0<A2G@00a5dM002M0PA37@34Amd0Q45M003
4GAd00Md0Q46M08A17@44@03M15d009d00<AM7@037@24@00?7@24@Yd2A4<M0<A00=d4A402A4017@A
4A4:M0LA47@44B9d0Q44M0034GAd00Md00<AM7@00W@44@03M14A00<A0g@24@Ad00<AM7@03G@14@00
?7@00a5d4@09M08A1g@94@Id2Q4017@A4A44M0PA0W@00a5dM00>M0@A9W@34@9d00<AM7@01W@24@03
M14A008A0W@44@Md0Q44M0034GAd00id000mM0034G@A00Ud00<AM7@03W@84@03M14A00dA2W@00a5d
M00:M0@A:W@01A5d4G@A00Qd1142M0@A0W@24@Id00<AM14017@00a5dM00>M000?G@00a5dM0024@Md
00<AM7@05W@C4@Md00<AM7@01g@44Bad00DAM7Ad4@06M0@A00=d4A400Q45M0034G@A00Id0Q44M003
4GAd00ad0a4003ed00@AM7Ad0Q46M0034GAd01=d3a46M1hA97@01a5dM15d4G@02A49M0034G@A00Id
0Q44M0034GAd00Qd1A42M000?W@0115dM7@24@Ed00<AM7@03g@44@Ad00<AM1403Q44M0<A00=d4G@0
114?M1dA27@00a5d4@044@03M14A008A37@01A5dM7@A00Ed0Q44M0034GAd00Ad1A45M04A000nM003
4GAd009d0Q45M0034GAd00Ud1A46M08A00=d4A402a43M0/A;g@K4@Ed00DAM7Ad4@05M0034GAd00=d
00<AM7@01A48M04A0G@003id00<AM7@00g@24@Ad00<AM7@017@54@Yd00LAM7@AM15d00<A00=d4G@0
0Q400g@A4@0<4@03M14A00@A<7@34@Ad0a4:M1XA2g@14@5d000oM0034GAd00=d0Q43M0034G@A00@A
3G@24@=d00@AM15d0Q400g@A4@064@04M14A4@Id00<AM1401142M0DA:g@34@Ad0Q4?M0034GAd009d
00<AM7@00W@00a5d4@044@Ed3A4003md00<AM7@01G@54A5d0Q43M0034G@A00LA00Ad4A5d0a43M0<A
0g@00a5dM004M0HA00=d4A400a4UM08A00=d4G@00W@34@id0Q44M0034GAd00DA0g@00a5dM00<M003
4GAd005d0010M0034GAd00HA00=d4G@03g@;4@04M15d4@9d00@AM14A0W@24@Ed114;M0HA00=d4A40
114OM08A00Ed4GAd4@02M0034GAd00ad00@AM7Ad1A400g@A4@05M0034GAd00ad00<AM7@00G@0041d
0a46M0034G@A00Yd1a44M0044GAd4@9d00DAM7@AM0024@9d00@AM7Ad0Q46M0<A3g@54@9d1A4JM004
4G@AM08A0g@00a5dM00:M0HA0W@01Q5d4A5d4@Ed00<AM7@02g@00a5dM002M000@7@24@03M14A00@A
00=d4A400g@74@9d0Q46M0054GAdM1400W@0115dM142M08A0W@24@=d0Q44M0034G@A00<A4G@54@9d
1Q4CM0034GAd00<A17@00a5dM005M0DA00=d4G@01G@34@9d00<AM7@00W@00a5dM00;M08A17@0045d
0Q46M0HA27@24@Id0Q43M0044GAd4@=d00@AM7@A0g@24@Ad0Q42M0034GAd009d0a4DM0HA0W@54@id
00@AM7@A1W@24@03M14A00<A1W@00a5dM004M08A0g@00a5dM002M0034GAd00]d00<AM7@00g@0049d
00<AM7@01W@0115d4A46M08A27@00a5dM002M0054GAdM1400W@01A5dM7@A00=d0Q45M0<A1g@34AId
1Q42M0DA27@54@=d1Q4:M0034GAd00Ad0Q44M0034GAd009d00<AM7@02W@00a5dM003M04A0012M08A
27@00a5dM0034@9d0Q48M0034GAd009d00<AM7@00W@00a5dM0024@=d00<AM7@00W@00a5dM003M08A
2W@34AUd1A42M0HA0W@84@Ad00<AM7@02G@00a5dM003M0034G@A00Ad00<AM7@00W@00a5dM009M08A
00=d4A400a4004=d0Q47M0034GAd00=d0Q49M08A17@00a5dM002M0054GAdM14017@00a5dM002M08A
17@34@]d0a4KM0DA0g@54@03M15d00Id00<AM7@027@00a5dM002M08A0W@00a5dM002M0044GAdM08A
17@:4@Ad0A4004=d0Q47M0034GAd009d0Q4017@A4A46M0034GAd00=d00<AM7@00W@0115dM7@24@=d
0Q44M08A0g@00a5dM0024@ad0a4MM0HA0g@00a5dM005M0034GAd00Qd00@AM7Ad0Q44M0044GAdM0XA
1W@00a5dM005M04A0014M08A1W@00a5dM0024@Ed0a43M0034GAd00Ad00<AM7@00W@00a5dM002M003
4GAd009d0Q44M08A0W@00a5dM002M08A37@44AMd1142M0034G@A00DA1g@00a5dM006M08A0W@<4@=d
00<AM7@027@24@Id0A41M000A7@00a5d4@06M0<A2G@44@Id00<AM7@00W@00a5dM002M0034GAd00=d
00<AM7@017@00a5d4@06M08A3G@34A9d1144M0044GAd4@9d00<AM7@01A42M0034GAd009d2Q45M004
4GAd4@Ad00<AM7@027@00a5dM005M04A0G@004Ed0Q46M0034GAd00]d0a44M0034GAd00=d00<AM7@0
0g@00a5dM003M0034GAd00Ad0Q48M08A3W@34@ad0a48M0044GAd4@9d00<AM7@01G@74@Ad00<AM140
27@0115dM144M0034GAd00Md00<AM7@01W@14@5d0015M0034G@A00=d0a4<M0044GAdM08A0W@00a5d
M004M0034GAd009d00<AM7@017@00a5dM004M08A27@24A1d0a46M0<A2W@0115dM143M0034GAd00Md
00@AM7Ad1a49M0044GAd4@=d00<AM7@027@00a5dM006M04A0G@004Id00DAM15d4@02M0034GAd00Ud
0Q45M0<A1W@00a5dM003M0034GAd00Ad00<AM7@00g@34@Ud0Q4AM0HA37@01A5dM7@A00=d00<AM7@0
1W@00a5dM006M08A00=d4A401A42M0044GAd4@=d00<AM7@01g@00a5dM007M04A0G@004Id1144M003
4GAd00Qd00<AM7@01W@34@Ad00<AM7@00g@00a5dM004M08A17@0115dM14:M08A3g@64@ad00DAM7Ad
4@03M0034GAd00Id00<AM7@01G@24@Ud1a42M0034GAd00Id00<AM7@027@14@5d0017M0034G@A00Ad
00<AM7@01g@00a5dM006M08A0W@34@03M15d00Ed00<AM7@017@24@=d00@AM7Ad0Q4:M08A2G@44@Ed
1148M0034GAd009d00DAM7Ad4@08M0034GAd00Ad0Q4<M0034GAd00PA1G@00a5dM007M04A0G@1M000
B7@00a5d4@03M0034GAd00Id0Q48M0034GAd00Ad0Q46M0034GAd00Ed00DAM7Ad4@04M08A2g@24@Ad
114;M0<A1W@00a5dM002M0054GAdM1401g@00a5dM004M08A3G@0115dM142M0034GAd009d1a48M04A
0G@1M000B7@24@03M15d009d00<AM7@01G@00a5dM007M0034GAd00Ed1144M0034GAd00Ed00@AM7@A
1G@24@ad114BM0<A0W@00a5dM003M0054GAdM1401g@00a5dM003M0034G@A00ed00@AM7@A0W@00a5d
M005M0044GAdM0LA00=d4G@00G@004Ud0a43M0034GAd00Ad00<AM7@027@00a5dM005M0034GAd00<A
0W@00a5dM006M0034G@A00Md00<AM7@01g@54AId0a45M0054GAdM1401g@00a5dM002M0044G@A4@ed
00@AM7@A0W@00a5dM005M0034GAd00Qd114004Ud1142M0034GAd00=d0Q4:M0034GAd00Id00<AM7@0
0W@44@Qd0Q48M08A17@34@Ed0Q4EM0034G@A008A0W@0115dM148M0034GAd008A0W@00a5dM00=M003
4G@A009d00<AM7@017@00a5dM00:M04A0G@1M000BW@44@03M15d00Ad00<AM7@027@00a5dM007M003
4GAd00Ad0a47M08A2G@54@Yd0Q4BM0034GAd00=d0a42M0034GAd00Ed00<AM7@00Q43M0034GAd00ed
00<AM1400W@00a5dM003M0034GAd00]d0A41M05d001;M0@A00=d4G@00W@00a5dM009M0034GAd00Md
00<AM7@01G@44@Id00<AM7@01G@54@id0Q4@M0034GAd00Ad1A47M0044G@A4@=d00<AM7@03W@01A5d
4G@A00Id00<AM7@02g@14@5d0G@004]d00HAM14AM143M0034GAd00Ud00<AM7@01g@00a5dM006M003
4GAd00<A0g@24@=d1144M0034GAd00ed0Q4=M0034GAd00Ed00@AM7Ad0a45M08A1G@00a5dM00>M005
4G@AM1401G@00a5dM00;M0034GAd005d001<M0034G@A008A0W@00a5dM00:M0034GAd00Md00<AM7@0
1W@00a5dM003M08A00=d4G@00a49M08A3g@24@Yd00<AM7@01W@01A5dM7@A009d0a400g@A4@05M003
4GAd00md00DAM15d4@04M08A3G@00a5dM001M000CG@01Q5d4A5d4@ed00<AM7@01g@00a5dM005M0hA
2g@24@md0Q49M0034GAd00Id00DAM7Ad4@05M1dA00=d4G@00g@00a5dM00<M0034GAd005d001=M003
4GAd00<A2G@F4@9d00<AM7@01G@00a5dM0054@Qd0Q4@M08A1W@00a5dM007M0054GAdM14017@24@9d
1A4BM1`A001>M0034GAd00/A0g@00a5dM009M0034GAd00Md00<AM7@017@0115dM7@24@9d1A45M003
4GAd00md0Q44M0034GAd00Md00DAM7Ad4@03M08A1g@34A1d00@AM14A0g@24@md00<AM7@00G@004id
0Q4017@A4A4;M0034GAd00Ud00<AM7@01g@00a5dM004M0034GAd009d00<AM7@01G@54@03M14A015d
0Q400g@AM009M0054GAdM1400W@24@Md00@AM7Ad114<M0@A0g@00a5dM00>M0034GAd005d001?M003
4GAd00@A2G@00a5dM009M0034GAd00Qd00<AM7@00g@00a5dM003M0034GAd00Ud1A4AM08A2W@0115d
M142M0<A1g@00a5dM005M0<A2G@24@05M15dM14047@00a5dM002M000D7@00a5d4@054@Id0Q4;M003
4GAd00Qd00<AM7@017@00a5dM003M0034GAd00]d214;M0@A27@01A5dM15d00<A27@00a5dM008M0@A
1G@24@03M15d008A47@00a5dM002M000D7@00a5dM0024@03M15d008A17@00a5dM00:M0034GAd00Ud
00<AM7@00g@00a5dM004M0034GAd00ad00<AM7@00g@54@Ed00@AM7Ad0Q46M0044GAdM0@A27@00a5d
M00<M0@A0W@34@9d00<AM7@03g@00a5dM002M000DG@0115d4A42M0034GAd008A0W@00a5dM00:M003
4GAd00Ud00<AM7@00g@00a5dM004M08A3W@24@Qd1Q45M08A17@00a5dM0044@Ud00<AM7@047@54@03
M15d015d00<AM7@00W@0059d00@AM14A0W@00a5dM0044@ad00<AM7@02G@24@Ad00<AM7@01G@24@id
0Q4;M0HA0g@24@9d00<AM1400a49M0034GAd01Ad114BM0DA001BM0044G@A4@=d0Q42M08A3G@00a5d
M009M0034GAd009d00<AM7@01W@00a5dM00=M08A2G@00a5dM004M0TA0W@00a5dM008M0034GAd01Ad
0a400g@A4@024@Ud1Q44M000Dg@0115d4A43M08A00=d4G@00Q4;M0034GAd00Ud0Q43M0034GAd00Md
00<AM7@03W@00a5dM006M0034GAd00Ud3144M0034GAd01Ed0Q45M0XA17@00a5dM003M000Dg@34@03
M15d00=d0Q43M08A2G@00a5dM00:M0054GAdM1402W@00a5dM00>M08A1G@00a5dM008M0<A00=d4A40
1144M1<A2G@24@9d1Q4017@A4A47M0034GAd00=d001DM0044G@A4@Ed0Q44M08A1g@00a5dM00:M005
4GAdM1402g@00a5dM00>M08A17@00a5dM005M0<A0g@34@03M14A00LA00=d4G@03W@=4@Yd1143M003
4GAd00=d001EM08A00=d4G@00g@44@Ad0Q45M0034GAd00]d00@AM7@A2g@24A1d0Q42M0034GAd00Ad
0a43M08A00Ed4GAd4@02M08A17@64A9d1A4?M0@A1G@005Ed00<AM1400Q44M08A00=d4A4017@24@=d
00<AM7@02g@01A5dM7@A00]d0Q4AM08A17@34@Ad0Q43M0044GAd4@Ad0Q42M08A17@64@]d0Q400g@A
M0024A5d1142M000EW@24@03M15d00=d0Q43M0<A0W@24@9d00<AM7@037@0115dM14<M0034GAd011d
1A45M08A1G@0115dM146M0<A2g@64@Ad0Q42M0054GAdM14047@0115dM7@24@00Eg@24@03M15d00=d
0Q44M0<A0W@24@03M15d00ad00@AM7@A3G@00a5dM00>M0@A1G@24@Md00@AM7@A27@34@md1a400g@A
M003M08A3W@00a5dM003M000Eg@24@03M15d00=d00<AM1401W@24@9d0Q4>M0034G@A00id00<AM7@0
2W@44@9d0Q4017@A4A49M0044GAd4@Md00@AM7Ad0Q4>M08A17@64@03M14A00ad00<AM7@017@005Qd
0Q400g@AM003M0<A1g@24@04M14A4@ad00<AM1403g@00a5dM006M0<A0W@0115dM7@44@]d00@AM7@A
1g@00a5dM003M08A2g@24@Ed0Q44M0HA2G@00a5dM003M04A001HM08A0W@01a5dM7@AM1402G@64@]d
0Q4?M08A1G@34@=d1A43M0@A27@0115dM146M0034GAd00Id0Q48M0034GAd00Ed00<AM1401g@84@=d
00<AM7@00W@24@00FG@24@03M15d009d0Q400g@AM008M08A00=d4A401147M08A47@00a5dM0034@=d
1149M0034G@A008A1G@0115dM146M0034GAd00Qd0a44M0034GAd00Id00<AM1402G@00a5dM003M0HA
00=d4A400G@005Yd00@AM7@A0g@0115dM149M08A0g@94@03M14A011d0a42M0@A0W@00a5dM009M08A
0W@34@9d00<AM1401W@00a5dM00;M0DA2G@00a5d4@0:M08A1W@00a5dM0044@00FW@24@03M14A009d
00<AM7@00Q48M0034G@A00Ad0Q45M1PA1W@00a5dM00;M0034GAd009d0a400g@AM005M0034GAd00ed
0a49M0034G@A00]d0Q45M0034G@A008A0W@005]d1A42M0044GAd4@Ud00<AM1401G@24@Id0Q48M0<A
1W@34@Ad00<AM7@03G@24@Ad1A43M08A3W@0115dM7@24@Md00<AM1403G@01Q5dM7@AM0<A0g@005ad
0Q400g@A4@084@Id00@AM7@A1W@24@Ad0a44M0<A2W@44@03M15d015d00PAM7Ad4G@AM0DA3G@24@Id
0a44M0034G@A00id0Q401W@AM15d4@=d001LM0@A0g@01Q5dM7@AM0TA00=d4G@01W@24@9d0Q400g@A
M0034@ed00<AM1400Q4CM08A00Ad4G@A17@44@Yd0Q49M0<A00Ed4GAd4@0?M0@A00=d4G@00g@005ed
1142M0044GAdM08A1g@00a5d4@084@9d0a400g@A4@024A1d00<AM1400Q4CM0<A00=d4G@00g@0115d
M7@34@Id0Q4<M0<A0W@00a5dM00?M0044GAd4@Ad001NM0054G@A4G@00Q43M0034GAd00Id00DAM7Ad
4@05M0LA0W@24A1d0Q42M08A4g@34@Ad00<AM7@017@34@9d00<AM7@03W@44A1d0Q400g@AM004M000
Gg@00a5d4@034@Ad00<AM7@01G@00a5dM002M0034GAd00Id00<AM1400Q42M0034GAd00ed0Q44M08A
4G@34@=d00<AM7@027@34A1d00<AM7@00Q4>M0<A00=d4G@017@0061d00<AM1400Q45M0034GAd00Ed
00<AM7@00W@00a5dM006M0034GAd00HA37@0115dM145M08A3g@00a5d4@024@03M15d00Qd0Q42M0<A
3G@01A5dM15d00<A2g@24@03M15d00Ed001PM0@A00=d4A400g@24@Id00<AM7@00W@24@Md00<AM7@0
0Q42M0@A2W@01A5dM7@A00Id0Q4=M08A0W@24@Ud0Q46M0<A2W@0115dM143M0<A27@00a5d4@024@Id
001QM0044G@AM0<A0g@00a5dM005M0034GAd009d0Q46M0054GAdM1401G@44@Id00<AM7@00g@00a5d
M005M08A2g@24@=d0a46M0034GAd00Ud0a47M0044GAd4@Id0Q45M0034GAd008A1g@0069d00HAM15d
4G@24@9d00<AM7@017@00a5dM003M08A1W@01A5dM7@A00Ed0Q4017@A4A43M0034GAd00=d0Q48M08A
2G@24@9d0Q400g@A4@03M08A3g@34@Ad00@AM7@A27@24@9d0Q42M0034GAd00Id001SM08A00Ad4GAd
0Q42M0034GAd00Ad00<AM7@00g@24@Ed00@AM7Ad0Q46M0044GAdM0<A1g@24@Ud0Q47M08A0W@00a5d
M002M0@A4g@44@Ad00<AM7@01g@34@=d00<AM7@01W@006Ad1143M08A00=d4G@017@00a5dM004M08A
17@00a5dM002M0034GAd00Ed0Q42M0034G@A00<A17@24@Yd0Q45M08A0W@00a5dM003M08A5g@34@9d
00<AM7@027@64@Md0A4006Ad1144M0@A17@24@Id0Q43M0034GAd00=d00<AM7@01G@24@03M15d00=d
1142M08A2g@24@=d0Q400g@AM004M0034GAd008A5G@00a5dM0034@Ud00@AM7Ad0a46M04A0G@006Ed
0a46M08A1G@00a5dM005M08A0g@00a5dM002M08A27@00a5dM007M0DA37@24@05M14AM1400g@24@Ad
0Q4DM0034GAd009d1A44M08A0g@24@03M14A00=d0A41M04A001VM0<A1W@24@Ad0Q47M08A0W@00a5d
M003M0034GAd00Id0a4:M0<A3G@44@=d0Q47M08A4W@00a5dM002M0044GAdM0@A00=d4G@00g@24@=d
0a41M04A0A4006Md0Q48M0034GAd009d00<AM7@01W@24@03M15d00Ed00<AM7@017@00a5dM0024@]d
114;M0<A0W@00a5dM008M08A4G@00a5dM002M0034GAd00Ad1142M0034G@A00Ad1141M000Ig@34@Md
0a42M0034GAd00Md0Q400g@AM004M08A17@00a5dM003M0034GAd00Ud0Q400g@A4@024@Md0Q400g@A
4@0=M08A3g@00a5dM002M0034GAd00Ad00@AM7Ad0a400g@AM002M08A0W@24@00J7@24@Qd00<AM140
0W@00a5dM007M0<A1W@00a5dM002M0034GAd00Ad0Q4:M08A0g@44@Ad11400g@A4@0<M08A3W@00a5d
M002M0034GAd00Ad00<AM7@00W@00a5d4@024@03M14A009d0A41M05d001YM08A27@00a5d4@024@Yd
0Q47M0044GAd4@Qd0Q4:M08A1W@34@04M14A4@Ad0Q4<M08A2g@00a5dM003M0034GAd00=d00<AM7@0
0W@24@04M15dM0<A0W@14@5d0A4006Yd0Q48M0034G@A008A2W@24@Id0Q400g@AM009M0034GAd00Qd
0Q48M0<A1g@24@]d0Q4:M0034GAd00=d00<AM7@00W@00a5dM003M0044GAd4@9d00<AM7@01A4006]d
1145M08A0W@24@Yd00<AM7@01G@24@ad0Q49M08A0g@44@03M14A008A1g@24@]d0Q48M0034GAd00=d
00@AM7Ad0Q44M0074GAdM15d4@04M0034G@A004A001/M0DA17@0115dM7@24@Ud0Q46M08A3G@24@Ud
1145M08A00=d4A400Q46M08A2W@24@Md00<AM7@00g@01A5dM7@A00Ed00@AM7Ad0Q44M0044G@A4@5d
001]M08A0W@34@9d00DAM7@AM0024@Qd0Q45M0<A3W@24@Ad1A47M08A0g@44@Id0Q4:M08A1G@00a5d
M003M0044GAd4@Ed00@AM7Ad0Q45M0034G@A008A001^M0<A0g@24@06M15dM15d0Q47M0034G@A00=d
00@AM7@A3g@54@Ed00<AM7@017@00a5d4@04M0DA1G@24@Ud0Q44M0034GAd00=d00<AM1401W@01A5d
M7@A00Ed1142M000L7@24@Ad0a400g@AM002M08A1G@0115dM142M0054GAdM14037@54@Qd00<AM7@0
0g@00a5d4@06M0DA1G@24@Ud00DAM7Ad4@06M08A1G@0115dM7@24@Ad1a40075d0a44M0@A0g@24@Ad
00@AM7Ad0Q45M0034GAd00Ed1145M08A1g@00a5dM003M0034G@A00Id0Q42M0<A17@24@Qd0Q400g@A
M005M0034GAd00Ad00<AM7@00a43M0LA0G@0079d0a44M0034G@A008A0g@24@=d00<AM7@00Q45M003
4GAd009d1149M08A1g@00a5dM002M0034G@A00Qd0Q42M0<A17@24@Qd00<AM7@017@24@Ed00<AM7@0
0Q400g@AM0024@03M14A00<A0W@007=d0a44M0044G@AM0<A00=d4A400W@01Q5dM15d4@Ed114?M003
4GAd00Ed00DAM7Ad4@02M0034GAd00Md0Q43M08A0g@34@Id0a43M0034G@A00Ed00@AM7@A0W@34@03
M14A00@A0W@007Ad1142M0<A17@44@04M15d4@=d00<AM1400Q400g@AM00AM08A1W@0115dM142M003
4GAd00Ud0Q43M0<A0W@34@Ad00DAM7@AM0024@03M15d00=d00@AM7@A0W@24@9d1Q41M04A0G@007Id
0a42M0<A1G@64@03M14A008A17@00a5dM00AM08A1W@00a5d4@02M08A37@24@Ad0Q42M0<A0W@0115d
M7@24@9d00@AM7Ad0Q4017@AM7@24@=d1Q41M04A0A4007Md00<AM1400W@24@Qd1144M0034GAd009d
00<AM7@04W@00a5dM004M08A0g@00a5dM00;M08A1G@24@9d0Q400g@AM002M0054G@AM1400g@00a5d
4@02M0034G@A009d11400g@A4@02M04A0000\
\>"],
  ImageRangeCache->{{{0, 239}, {287, 0}} -> {-2.50001, 3.99894, 0.0104604, \
0.0104604}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trace", "Subsection"],

Cell["The mirror is ready to be traced.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Timing[propagatedseashellmirror = PropagateSystem[{
\tMove[LineOfRays[1], {-2, 1, 9}, {1, 0, 0}],
\tResonate[seashellmirror],
\tBoundary[{-2.5, -2.5, 0}, {2.5, 2.5, 12}]
}, MaxIterations->40];]\
\>", "Input"],

Cell[BoxData[
    \({10.9000000000000053`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["Two rays are emerging at the top opening, one at the bottom.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[propagatedseashellmirror, PlotPoints -> 30, RayPointSize \
-> 5];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.84267 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.428812 1.87955 -0.0368803 1.87955 [
[ 0 0 0 0 ]
[ 1 1.84267 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.84267 L
0 1.84267 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.3984 .58597 m
.10275 .24818 L
s
.90507 .40933 m
.3984 .58597 L
s
.63769 .04219 m
.90507 .40933 L
s
.90507 .40933 m
.97512 1.64732 L
s
.10275 .24818 m
.63769 .04219 L
s
.0271 1.50888 m
.10275 .24818 L
s
.56615 .85834 m .62278 .75381 L .53034 .84366 L .634 .524 .712 r
F
.56615 .85834 m .66721 .75074 L .62278 .75381 L F
.59555 .8735 m .66721 .75074 L .56615 .85834 L .513 .376 .631 r
F
.41653 .91463 m .56615 .85834 L .53034 .84366 L .733 .555 .651 r
F
.43296 .93382 m .56615 .85834 L .41653 .91463 L .688 .473 .589 r
F
.43296 .93382 m .59555 .8735 L .56615 .85834 L F
.53034 .84366 m .57303 .75912 L .49314 .82923 L .724 .65 .775 r
F
.53034 .84366 m .62278 .75381 L .57303 .75912 L F
.39826 .89444 m .53034 .84366 L .49314 .82923 L .775 .642 .716 r
F
.41653 .91463 m .53034 .84366 L .39826 .89444 L .733 .555 .651 r
F
0 g
.38772 1.26388 m
.38799 1.2464 L
s
.38799 1.2464 m
.3984 .58597 L
s
.59555 .8735 m .69881 .75293 L .66721 .75074 L .513 .376 .631 r
F
.61502 .88935 m .69881 .75293 L .59555 .8735 L .321 .152 .49 r
F
.44582 .95165 m .59555 .8735 L .43296 .93382 L .641 .389 .523 r
F
.44582 .95165 m .61502 .88935 L .59555 .8735 L F
.49314 .82923 m .52775 .76486 L .46011 .81529 L .797 .79 .846 r
F
.49314 .82923 m .57303 .75912 L .52775 .76486 L F
.3803 .87371 m .49314 .82923 L .46011 .81529 L .809 .74 .788 r
F
.39826 .89444 m .49314 .82923 L .3803 .87371 L .775 .642 .716 r
F
.62278 .75381 m .60083 .68422 L .57303 .75912 L .729 .681 .804 r
F
.62278 .75381 m .64557 .65191 L .60083 .68422 L F
.66721 .75074 m .64557 .65191 L .62278 .75381 L .568 .542 .786 r
F
.57303 .75912 m .55799 .71594 L .52775 .76486 L .857 .836 .824 r
F
.57303 .75912 m .60083 .68422 L .55799 .71594 L F
.61502 .88935 m .71386 .7626 L .69881 .75293 L .321 .152 .49 r
F
.62296 .90563 m .71386 .7626 L .61502 .88935 L 0 0 .167 r
F
.45399 .96779 m .61502 .88935 L .44582 .95165 L .586 .296 .444 r
F
.45399 .96779 m .62296 .90563 L .61502 .88935 L F
.29358 .92434 m .43296 .93382 L .41653 .91463 L .851 .578 .526 r
F
.29681 .93655 m .43296 .93382 L .29358 .92434 L .833 .533 .482 r
F
.29681 .93655 m .44582 .95165 L .43296 .93382 L F
.28995 .91117 m .41653 .91463 L .39826 .89444 L .869 .632 .577 r
F
.29358 .92434 m .41653 .91463 L .28995 .91117 L .851 .578 .526 r
F
.66721 .75074 m .67865 .62514 L .64557 .65191 L .568 .542 .786 r
F
.69881 .75293 m .67865 .62514 L .66721 .75074 L .181 .24 .689 r
F
.2993 .94761 m .44582 .95165 L .29681 .93655 L .819 .496 .443 r
F
.2993 .94761 m .45399 .96779 L .44582 .95165 L F
.46011 .81529 m .49481 .77288 L .43608 .80286 L .797 .966 .914 r
F
.49481 .77288 m .48831 .77563 L .43608 .80286 L F
.53611 .73963 m .50709 .76615 L .53814 .73657 L 0 0 0 r
F
.46011 .81529 m .52775 .76486 L .50322 .77016 L .797 .966 .914 r
F
.532 .7458 m .50696 .76668 L .53611 .73963 L 0 0 0 r
F
.52961 .74939 m .52743 .75105 L .532 .7458 L F
.52743 .75105 m .50696 .76668 L .532 .7458 L F
.54319 .73287 m .53814 .73657 L .55038 .71078 L F
.54319 .73287 m .55038 .71078 L .55069 .72424 L F
.55799 .71594 m .55899 .67345 L .55224 .72242 L .857 .745 .23 r
F
.55228 .72236 m .55038 .71078 L .55252 .68936 L 0 0 .118 r
F
.5517 .72305 m .55224 .72242 L .55171 .72303 L .857 .745 .23 r
F
.55799 .71594 m .55657 .71754 L .54144 .73493 L F
.55069 .72424 m .55038 .71078 L .55177 .71926 L 0 0 .118 r
F
.55171 .72303 m .55177 .71926 L .55228 .72236 L F
.55069 .72424 m .55177 .71926 L .55171 .72303 L F
.55657 .71754 m .55224 .72242 L .55226 .7225 L .857 .745 .23 r
F
.55224 .72252 m .55224 .72242 L .54144 .73493 L F
.54144 .73493 m .5481 .72722 L .5436 .7324 L F
.52775 .76486 m .52845 .76084 L .50322 .77016 L .796 .96 .637 r
F
.52845 .76084 m .52915 .7568 L .51132 .76598 L F
.52845 .76084 m .51132 .76598 L .50322 .77016 L F
.52915 .7568 m .5075 .76683 L .50322 .77016 L F
.5305 .74899 m .52961 .74939 L .50322 .77016 L F
.50567 .76768 m .50709 .76615 L .50679 .76734 L .142 0 0 r
F
.50679 .76734 m .50696 .76668 L .52961 .74939 L 0 0 0 r
F
.50696 .76668 m .50709 .76615 L .53611 .73963 L F
.50567 .76768 m .49041 .7744 L .50709 .76615 L .142 0 0 r
F
.49041 .7744 m .46922 .78373 L .49451 .77199 L F
.49041 .7744 m .49451 .77199 L .50709 .76615 L F
.50322 .77016 m .50683 .76714 L .49781 .77132 L .796 .96 .637 r
F
.48161 .79021 m .50322 .77016 L .49781 .77132 L .797 .966 .914 r
F
.46011 .81529 m .49781 .77132 L .49481 .77288 L F
.50476 .76866 m .49062 .77466 L .50567 .76768 L .142 0 0 r
F
.49062 .77466 m .46922 .78373 L .50567 .76768 L F
.46051 .79191 m .48831 .77563 L .46079 .79178 L 0 0 0 r
F
.43608 .80286 m .46204 .78932 L .46051 .79191 L F
.46204 .78932 m .48831 .77563 L .46051 .79191 L F
.46011 .81529 m .50322 .77016 L .48161 .79021 L .797 .966 .914 r
F
.4714 .78865 m .45914 .79135 L .47008 .78568 L .142 0 0 r
F
.43608 .80286 m .46051 .79191 L .46034 .79192 L 0 0 0 r
F
.46035 .79191 m .45914 .79135 L .4714 .78865 L .142 0 0 r
F
.45693 .79198 m .45599 .78987 L .46035 .79191 L .217 0 0 r
F
.53056 .74864 m .53082 .74713 L .50322 .77016 L .796 .96 .637 r
F
.49168 .78267 m .46952 .78443 L .49452 .77324 L .142 0 0 r
F
.49767 .77302 m .49452 .77324 L .49869 .77137 L F
.49168 .78267 m .49452 .77324 L .49767 .77302 L F
.50089 .7728 m .50567 .76768 L .50433 .77388 L F
.50221 .77442 m .50433 .77388 L .5038 .77634 L F
.50089 .7728 m .50433 .77388 L .50221 .77442 L F
.49862 .77296 m .50221 .77442 L .49851 .77535 L .255 0 .315 r
F
.49862 .77296 m .50089 .7728 L .50221 .77442 L F
.52547 .85649 m .5162 .83366 L .52569 .8251 L .667 .445 .573 r
F
.5162 .83366 m .50745 .81213 L .51917 .82046 L F
.5162 .83366 m .51917 .82046 L .52569 .8251 L F
.48804 .78656 m .48784 .78664 L .49168 .78267 L .142 0 0 r
F
.50592 .77764 m .52261 .78279 L .50691 .78297 L .255 0 .315 r
F
.50115 .78939 m .50433 .77698 L .50691 .78297 L 0 0 0 r
F
.50433 .77698 m .50517 .77367 L .50557 .77578 L F
.50433 .77698 m .50557 .77578 L .50691 .78297 L F
.50158 .78892 m .51798 .78356 L .5247 .79589 L .568 .349 .543 r
F
.51798 .78356 m .52382 .78479 L .5247 .79589 L F
.51019 .81158 m .5247 .79589 L .51917 .82046 L F
.49486 .79641 m .50742 .79619 L .51019 .81158 L F
.50742 .79619 m .5247 .79589 L .51019 .81158 L F
.50013 .79053 m .5247 .79589 L .49486 .79641 L F
.4711 .79925 m .47333 .798 L .4813 .80015 L .445 .029 .155 r
F
.4588 .79621 m .45844 .79539 L .46629 .79713 L .217 0 0 r
F
.5026 .81045 m .50575 .81092 L .51507 .8387 L .764 .478 .501 r
F
.48575 .78739 m .51917 .82046 L .48129 .7935 L .568 .349 .543 r
F
.52177 .85869 m .50575 .81092 L .52547 .85649 L .667 .445 .573 r
F
.50575 .81092 m .50745 .81213 L .52547 .85649 L F
.53028 .83865 m .52569 .8251 L .53083 .83578 L F
.5276 .85281 m .52642 .83566 L .53028 .83865 L F
.52642 .83566 m .52569 .8251 L .53028 .83865 L F
.53478 .85381 m .57098 .87061 L .54854 .90025 L .711 .597 .727 r
F
.57098 .87061 m .56858 .87614 L .54854 .90025 L F
.54089 .84685 m .57257 .87134 L .53478 .85381 L F
.54089 .84685 m .5287 .79695 L .54764 .83915 L .599 .432 .627 r
F
.52569 .8251 m .53649 .82885 L .54089 .84685 L .667 .445 .573 r
F
.53028 .83865 m .54089 .84685 L .53478 .85381 L .711 .597 .727 r
F
.53334 .84101 m .54089 .84685 L .54579 .8669 L .667 .445 .573 r
F
.52569 .8251 m .54089 .84685 L .53334 .84101 L F
.52727 .82848 m .57387 .86978 L .57257 .87134 L .711 .597 .727 r
F
.53028 .83865 m .54691 .89476 L .52641 .8591 L F
.54691 .89476 m .54854 .90025 L .54531 .89424 L F
.54691 .89476 m .54531 .89424 L .52641 .8591 L F
.45705 .98196 m .62296 .90563 L .45399 .96779 L .51 .171 .329 r
F
.45705 .98196 m .6197 .92152 L .62296 .90563 L F
.45526 .99394 m .6197 .92152 L .45705 .98196 L .37 0 .124 r
F
.45526 .99394 m .60707 .93584 L .6197 .92152 L F
.44936 1.00361 m .60707 .93584 L .45526 .99394 L .061 0 0 r
F
.44936 1.00361 m .58792 .9475 L .60707 .93584 L F
.44044 1.01098 m .58792 .9475 L .44936 1.00361 L .4 .848 .762 r
F
.44044 1.01098 m .56546 .95595 L .58792 .9475 L F
.42964 1.01629 m .56546 .95595 L .44044 1.01098 L .646 .959 .929 r
F
.42964 1.01629 m .54269 .96146 L .56546 .95595 L F
.29925 .9776 m .44044 1.01098 L .44936 1.00361 L .762 .337 .241 r
F
.29698 .98123 m .44044 1.01098 L .29925 .9776 L .737 .276 .154 r
F
.29698 .98123 m .42964 1.01629 L .44044 1.01098 L F
.29419 .98329 m .40237 1.00964 L .29698 .98123 L .708 .211 .058 r
F
.40237 1.00964 m .42964 1.01629 L .40279 1.00919 L F
.40237 1.00964 m .40279 1.00919 L .29698 .98123 L F
.30133 .96563 m .45526 .99394 L .45705 .98196 L .794 .428 .364 r
F
.30076 .9724 m .45526 .99394 L .30133 .96563 L .78 .388 .311 r
F
.30076 .9724 m .44936 1.00361 L .45526 .99394 L F
.29925 .9776 m .44936 1.00361 L .30076 .9724 L .762 .337 .241 r
F
.29419 .98329 m .418 1.01989 L .42964 1.01629 L .708 .211 .058 r
F
.29117 .98379 m .40633 1.02221 L .418 1.01989 L .68 .155 0 r
F
.29117 .98379 m .38247 1.00978 L .29419 .98329 L F
.38247 1.00978 m .3899 1.01189 L .38389 1.01009 L F
.38247 1.00978 m .38389 1.01009 L .29419 .98329 L F
.39677 1.01385 m .418 1.01989 L .3968 1.01362 L F
.418 1.01989 m .54269 .96146 L .42964 1.01629 L .717 .961 .944 r
F
.418 1.01989 m .51338 .96951 L .54269 .96146 L F
.56974 .86867 m .57257 .87134 L .56957 .86902 L .711 .597 .727 r
F
.5276 .85281 m .53028 .83865 L .54579 .8669 L .667 .445 .573 r
F
.53028 .83865 m .53083 .83578 L .53334 .84101 L F
.53028 .83865 m .53334 .84101 L .54579 .8669 L F
.56974 .86867 m .56957 .86902 L .53028 .83865 L .711 .597 .727 r
F
.52727 .82848 m .56974 .86867 L .53028 .83865 L F
.54764 .83915 m .54787 .83569 L .55803 .84689 L .599 .432 .627 r
F
.52727 .82848 m .5415 .83457 L .57387 .86978 L .711 .597 .727 r
F
.54787 .83569 m .56693 .83905 L .57109 .85662 L .599 .432 .627 r
F
.54787 .83569 m .57109 .85662 L .55803 .84689 L F
.5287 .79695 m .53876 .81728 L .54764 .83915 L F
.52931 .79639 m .56187 .83178 L .54792 .8357 L .592 .48 .695 r
F
.56187 .83178 m .56888 .83939 L .56693 .83905 L F
.56187 .83178 m .56693 .83905 L .54792 .8357 L F
.58135 .86078 m .57839 .76132 L .6042 .85516 L .569 .453 .682 r
F
.57109 .85662 m .57659 .85275 L .57651 .86065 L .711 .597 .727 r
F
.57659 .85275 m .57807 .85525 L .57651 .86065 L F
.57831 .85565 m .58104 .85013 L .58135 .86078 L .569 .453 .682 r
F
.57409 .84853 m .5783 .8495 L .57831 .85565 L F
.5783 .8495 m .58104 .85013 L .57831 .85565 L F
.55108 .76494 m .55147 .75063 L .56673 .77837 L .322 .245 .612 r
F
.55108 .76494 m .56673 .77837 L .56672 .77868 L F
.53757 .7408 m .55799 .71594 L .53866 .73813 L .796 .96 .637 r
F
.52775 .76486 m .55538 .72016 L .53757 .7408 L F
.55538 .72016 m .55799 .71594 L .53757 .7408 L F
.55147 .75063 m .55224 .72242 L .56539 .77254 L .322 .245 .612 r
F
.55147 .75063 m .56539 .77254 L .56676 .77778 L F
.55147 .75063 m .56676 .77778 L .56673 .77837 L F
.5597 .80161 m .55291 .77896 L .56504 .77872 L .569 .453 .682 r
F
.56622 .78882 m .56716 .76966 L .57816 .76541 L F
.50557 .77578 m .5233 .77172 L .52284 .78278 L .255 0 .315 r
F
.52915 .7568 m .5305 .74899 L .5075 .76683 L .796 .96 .637 r
F
.52284 .78278 m .52774 .75219 L .52614 .78266 L 0 0 0 r
F
.50777 .77364 m .52331 .77147 L .50557 .77578 L .255 0 .315 r
F
.52331 .77147 m .5233 .77172 L .50557 .77578 L F
.51556 .78305 m .52284 .78278 L .52277 .78457 L 0 0 0 r
F
.52284 .78278 m .52614 .78266 L .52376 .78401 L F
.5228 .78393 m .52376 .78401 L .52277 .78457 L F
.52284 .78278 m .52376 .78401 L .5228 .78393 L F
.55147 .78184 m .55159 .78001 L .5545 .79121 L .599 .432 .627 r
F
.52775 .76486 m .53866 .73813 L .52916 .75676 L .796 .96 .637 r
F
.53551 .75125 m .53691 .74157 L .53888 .73883 L 0 0 0 r
F
.5274 .78103 m .53344 .75598 L .53551 .75125 L F
.53344 .75598 m .53691 .74157 L .53551 .75125 L F
.54319 .73287 m .55069 .72424 L .5513 .75037 L F
.54319 .73287 m .5513 .75037 L .54461 .73984 L F
.53551 .75125 m .55958 .77241 L .52801 .77879 L .322 .245 .612 r
F
.55958 .77241 m .55353 .77817 L .52786 .77936 L F
.52637 .78421 m .53691 .74157 L .5274 .78103 L 0 0 0 r
F
.52584 .78554 m .55289 .78623 L .55257 .81561 L .592 .48 .695 r
F
.52452 .78407 m .52637 .78421 L .52584 .78554 L F
.52637 .78421 m .55289 .78623 L .52584 .78554 L F
.5305 .74899 m .53814 .73657 L .53691 .74157 L 0 0 0 r
F
.52961 .74939 m .53814 .73657 L .5305 .74899 L F
.53691 .74157 m .53739 .7396 L .53866 .73813 L F
.52916 .75676 m .53866 .73813 L .53082 .74713 L .796 .96 .637 r
F
.52774 .75219 m .53691 .74157 L .52637 .78421 L 0 0 0 r
F
.55174 .81722 m .57829 .84454 L .5783 .8495 L .592 .48 .695 r
F
.52446 .78406 m .55256 .81563 L .55174 .81722 L F
.55256 .81563 m .57829 .84454 L .55174 .81722 L F
.52452 .78407 m .55257 .81561 L .52446 .78406 L F
.55257 .81561 m .57829 .84454 L .55256 .81563 L F
.55257 .81561 m .55256 .81563 L .52446 .78406 L F
.55257 .81561 m .56812 .78509 L .57829 .84454 L F
.57329 .84819 m .57409 .84853 L .57109 .85662 L .711 .597 .727 r
F
.57409 .84853 m .57936 .85079 L .57659 .85275 L F
.57409 .84853 m .57659 .85275 L .57109 .85662 L F
.56904 .86452 m .57651 .86065 L .57387 .86978 L F
.5415 .83457 m .57109 .85662 L .56904 .86452 L F
.57109 .85662 m .57651 .86065 L .56904 .86452 L F
.57259 .86293 m .57109 .85662 L .57342 .84838 L .569 .453 .682 r
F
.57109 .85662 m .56693 .83905 L .57329 .84819 L F
.57109 .85662 m .57329 .84819 L .57342 .84838 L F
.57259 .86293 m .57342 .84838 L .58135 .86078 L F
.54792 .8357 m .57518 .84878 L .54888 .83773 L .592 .48 .695 r
F
.57518 .84878 m .57409 .84853 L .54888 .83773 L F
.57342 .84838 m .57347 .84749 L .57409 .84853 L .569 .453 .682 r
F
.57342 .84838 m .57409 .84853 L .58135 .86078 L F
.56888 .83939 m .57814 .84947 L .57296 .84772 L .592 .48 .695 r
F
.57814 .84947 m .57936 .85079 L .57518 .84878 L F
.57814 .84947 m .57518 .84878 L .57296 .84772 L F
.56693 .83905 m .57296 .84772 L .54792 .8357 L F
.56888 .83939 m .57296 .84772 L .56693 .83905 L F
.53174 .7942 m .57936 .85079 L .52931 .79639 L F
.52446 .78406 m .57936 .85079 L .52382 .78479 L F
.56693 .83905 m .55858 .80381 L .57342 .84838 L .569 .453 .682 r
F
.52774 .75219 m .52637 .78421 L .52606 .78418 L 0 0 0 r
F
.5655 .77761 m .55831 .77885 L .52441 .77952 L .322 .245 .612 r
F
.55858 .80381 m .55189 .77556 L .55963 .80175 L .569 .453 .682 r
F
.55858 .80381 m .55963 .80175 L .57342 .84838 L F
.57332 .84805 m .55963 .80175 L .57347 .84749 L F
.55963 .80175 m .55189 .77556 L .5597 .80161 L F
.55963 .80175 m .5597 .80161 L .57347 .84749 L F
.52606 .78418 m .52637 .78421 L .52597 .7858 L 0 0 0 r
F
.52277 .78457 m .52523 .78318 L .52382 .78479 L F
.52369 .78313 m .52452 .78407 L .52446 .78406 L .592 .48 .695 r
F
.52801 .77879 m .52786 .77936 L .52441 .77952 L .322 .245 .612 r
F
.55958 .77241 m .52786 .77936 L .52801 .77879 L F
.52637 .78421 m .5274 .78103 L .52692 .78282 L 0 0 0 r
F
.52441 .77952 m .52783 .77948 L .52369 .78313 L .322 .245 .612 r
F
.55159 .78001 m .55269 .77896 L .55858 .80381 L .599 .432 .627 r
F
.55159 .78001 m .55858 .80381 L .5545 .79121 L F
.55958 .77241 m .5655 .77761 L .55353 .77817 L .322 .245 .612 r
F
.5655 .77761 m .56672 .77868 L .55831 .77885 L F
.56374 .78431 m .56716 .76966 L .56642 .78479 L .569 .453 .682 r
F
.52382 .78479 m .5246 .78407 L .526 .78525 L 0 0 0 r
F
.5246 .78407 m .52614 .78266 L .52606 .78418 L F
.5246 .78407 m .52606 .78418 L .526 .78525 L F
.52523 .78318 m .52614 .78266 L .52382 .78479 L F
.52369 .78313 m .5523 .78439 L .55279 .78594 L .592 .48 .695 r
F
.56374 .78431 m .56642 .78479 L .56622 .78882 L .569 .453 .682 r
F
.5597 .80161 m .56374 .78431 L .56622 .78882 L F
.52369 .78313 m .56699 .78731 L .52452 .78407 L .592 .48 .695 r
F
.52369 .78313 m .54554 .78105 L .56812 .78509 L F
.52382 .78479 m .54888 .83773 L .52518 .78986 L F
.54764 .83915 m .53215 .78336 L .54554 .78105 L .599 .432 .627 r
F
.55147 .78184 m .54554 .78105 L .55159 .78001 L F
.54554 .78105 m .56794 .78404 L .56812 .78509 L .592 .48 .695 r
F
.54764 .83915 m .54554 .78105 L .55147 .78184 L .599 .432 .627 r
F
.52783 .77948 m .56708 .779 L .52692 .78282 L .322 .245 .612 r
F
.52783 .77948 m .52692 .78282 L .52369 .78313 L F
.52597 .7858 m .52637 .78421 L .52692 .78282 L 0 0 0 r
F
.52678 .7833 m .52692 .78282 L .52706 .78246 L F
.52597 .7858 m .52692 .78282 L .52678 .7833 L F
.52692 .78282 m .5274 .78103 L .52706 .78246 L F
.55171 .72303 m .55224 .72242 L .55108 .76494 L .322 .245 .612 r
F
.55189 .77556 m .55069 .72424 L .55228 .72236 L 0 0 .118 r
F
.53551 .75125 m .54327 .73773 L .55108 .76494 L .322 .245 .612 r
F
.54217 .736 m .54319 .73287 L .54461 .73984 L 0 0 0 r
F
.5436 .7324 m .5517 .72305 L .5439 .73204 L .857 .745 .23 r
F
.5517 .72305 m .55171 .72303 L .5439 .73204 L F
.5481 .72722 m .55224 .72242 L .5436 .7324 L F
.5439 .73204 m .55171 .72303 L .53551 .75125 L .322 .245 .612 r
F
.56672 .77868 m .56708 .779 L .52441 .77952 L F
.52597 .7858 m .54217 .736 L .55189 .77556 L 0 0 0 r
F
.54327 .73773 m .5513 .75037 L .55108 .76494 L .322 .245 .612 r
F
.54217 .736 m .54461 .73984 L .55189 .77556 L 0 0 0 r
F
.54327 .73773 m .55171 .72303 L .5513 .75037 L .322 .245 .612 r
F
.52706 .78246 m .5274 .78103 L .54319 .73287 L 0 0 0 r
F
.5274 .78103 m .53888 .73883 L .54319 .73287 L F
.54144 .73493 m .5439 .73204 L .53866 .73813 L .857 .745 .23 r
F
.53691 .74157 m .53866 .73813 L .54319 .73287 L 0 0 0 r
F
.53739 .7396 m .53814 .73657 L .54319 .73287 L F
.53866 .73813 m .5439 .73204 L .53082 .74713 L .857 .745 .23 r
F
.53082 .74713 m .5439 .73204 L .53551 .75125 L .322 .245 .612 r
F
.5305 .74899 m .53056 .74864 L .52961 .74939 L .796 .96 .637 r
F
.52774 .75219 m .52961 .74939 L .5305 .74899 L 0 0 0 r
F
.53082 .74713 m .53551 .75125 L .52441 .77952 L .322 .245 .612 r
F
.53551 .75125 m .52801 .77879 L .52441 .77952 L F
.55289 .78623 m .56699 .78731 L .55858 .80381 L .592 .48 .695 r
F
.55289 .78623 m .55858 .80381 L .55257 .81561 L F
.5545 .79121 m .55858 .80381 L .56693 .83905 L .599 .432 .627 r
F
.54787 .83569 m .55147 .78184 L .56693 .83905 L F
.55147 .78184 m .5545 .79121 L .56693 .83905 L F
.55279 .78594 m .56812 .78509 L .56699 .78731 L .592 .48 .695 r
F
.5523 .78439 m .56812 .78509 L .55279 .78594 L F
.50557 .77578 m .52369 .78313 L .50592 .77764 L .255 0 .315 r
F
.52261 .78279 m .51556 .78305 L .50691 .78297 L F
.52641 .8591 m .54973 .91216 L .5263 .85968 L .711 .597 .727 r
F
.51916 .94884 m .52597 .95819 L .51502 .96873 L .797 .714 .772 r
F
.52714 .94354 m .52597 .95819 L .51916 .94884 L F
.53394 .94211 m .54845 .91156 L .54968 .91214 L .78 .671 .743 r
F
.54973 .91216 m .54962 .91211 L .5263 .85968 L .711 .597 .727 r
F
.53075 .96349 m .55244 .91342 L .54269 .96146 L .78 .671 .743 r
F
.55244 .91342 m .56858 .87614 L .55667 .91538 L F
.55244 .91342 m .55667 .91538 L .54269 .96146 L F
.54854 .90025 m .55244 .91342 L .52641 .8591 L .711 .597 .727 r
F
.55244 .91342 m .54973 .91216 L .52641 .8591 L F
.56278 .92674 m .57101 .87322 L .6042 .85516 L .765 .681 .77 r
F
.57101 .87322 m .58135 .86078 L .6042 .85516 L F
.54269 .96146 m .55667 .91538 L .56278 .92674 L F
.57098 .87061 m .57257 .87134 L .56858 .87614 L .711 .597 .727 r
F
.55667 .91538 m .57259 .86293 L .56278 .92674 L .765 .681 .77 r
F
.55244 .91342 m .57387 .86978 L .55689 .92845 L .711 .597 .727 r
F
.54854 .90025 m .56858 .87614 L .55244 .91342 L F
.56858 .87614 m .57387 .86978 L .55244 .91342 L F
.52665 .96419 m .55112 .9128 L .53075 .96349 L .78 .671 .743 r
F
.55112 .9128 m .56858 .87614 L .55244 .91342 L F
.55112 .9128 m .55244 .91342 L .53075 .96349 L F
.53394 .94211 m .54968 .91214 L .52665 .96419 L F
.54968 .91214 m .56858 .87614 L .55112 .9128 L F
.54968 .91214 m .55112 .9128 L .52665 .96419 L F
.53524 .93817 m .54143 .89638 L .54845 .91156 L F
.5263 .85968 m .54962 .91211 L .54893 .91179 L .711 .597 .727 r
F
.5263 .85968 m .55476 .92521 L .52618 .86342 L F
.52714 .94354 m .54579 .8669 L .53524 .93817 L .78 .671 .743 r
F
.53023 .90504 m .53588 .89121 L .528 .93285 L .827 .699 .724 r
F
.52852 .9039 m .52714 .94354 L .51916 .94884 L .797 .714 .772 r
F
.53023 .90504 m .52714 .94354 L .52852 .9039 L F
.53588 .89121 m .53959 .8924 L .52192 .96499 L .827 .699 .724 r
F
.53762 .89177 m .54845 .91156 L .54223 .90322 L .711 .597 .727 r
F
.52618 .86342 m .53959 .8924 L .53762 .89177 L F
.53959 .8924 m .54845 .91156 L .53762 .89177 L F
.52618 .86342 m .54223 .90322 L .5259 .87238 L F
.52454 .87383 m .5259 .87238 L .52456 .87396 L .692 .491 .611 r
F
.51655 .82193 m .5257 .87126 L .52454 .87383 L F
.5257 .87126 m .5259 .87238 L .52454 .87383 L F
.53023 .90504 m .52574 .87206 L .53588 .89121 L .827 .699 .724 r
F
.52425 .86346 m .52607 .86696 L .5259 .87238 L .692 .491 .611 r
F
.51547 .86243 m .52177 .85869 L .52456 .87396 L F
.51547 .86243 m .52456 .87396 L .52289 .87594 L F
.51458 .84486 m .51507 .8387 L .51702 .84956 L .764 .478 .501 r
F
.51702 .84956 m .51507 .8387 L .52177 .85869 L F
.47333 .798 m .48072 .79891 L .4813 .80015 L .445 .029 .155 r
F
.4711 .79925 m .4813 .80015 L .4809 .80044 L F
.483 .8032 m .4806 .80066 L .48203 .80129 L .764 .478 .501 r
F
.4806 .80066 m .4809 .80044 L .5026 .81045 L F
.4809 .80044 m .48146 .80003 L .48375 .80116 L F
.4809 .80044 m .48375 .80116 L .5026 .81045 L F
.4751 .79699 m .4714 .78865 L .47885 .79488 L .142 0 0 r
F
.47885 .79488 m .4714 .78865 L .48185 .79319 L F
.47333 .798 m .47885 .79488 L .48072 .79891 L .445 .029 .155 r
F
.46051 .79191 m .46079 .79178 L .46035 .79191 L 0 0 0 r
F
.35394 .83318 m .43608 .80286 L .42413 .7937 L .746 .948 .945 r
F
.42413 .7937 m .42256 .79378 L .43147 .79274 L .217 0 0 r
F
.42344 .79379 m .42413 .7937 L .42391 .79353 L .746 .948 .945 r
F
.35394 .83318 m .42413 .7937 L .42344 .79379 L F
.45693 .79198 m .42413 .7937 L .45599 .78987 L .217 0 0 r
F
.42413 .7937 m .43147 .79274 L .45599 .78987 L F
.42256 .79378 m .41783 .79403 L .42103 .79368 L F
.42256 .79378 m .42103 .79368 L .45599 .78987 L F
.4751 .79699 m .46035 .79191 L .4714 .78865 L .142 0 0 r
F
.47613 .79931 m .47333 .798 L .4751 .79699 L F
.47333 .798 m .46035 .79191 L .4751 .79699 L F
.43252 .80013 m .46034 .79192 L .42391 .79353 L 0 0 0 r
F
.43608 .80286 m .46034 .79192 L .43252 .80013 L F
.45844 .79539 m .46047 .79197 L .47333 .798 L .217 0 0 r
F
.4588 .79621 m .47333 .798 L .47192 .79879 L .445 .029 .155 r
F
.46629 .79713 m .47333 .798 L .47613 .79931 L .217 0 0 r
F
.45844 .79539 m .47333 .798 L .46629 .79713 L F
.43204 .79442 m .4588 .79621 L .47192 .79879 L .445 .029 .155 r
F
.4588 .79621 m .47462 .79727 L .47333 .798 L F
.46051 .79191 m .45693 .79198 L .44651 .79253 L 0 0 0 r
F
.35394 .83318 m .42344 .79379 L .34883 .81493 L .746 .948 .945 r
F
.42344 .79379 m .42391 .79353 L .42278 .79385 L F
.42344 .79379 m .42278 .79385 L .34883 .81493 L F
.42329 .79376 m .41783 .79403 L .42345 .79374 L .217 0 0 r
F
.40634 .79658 m .4014 .79582 L .40732 .79644 L 0 .521 .831 r
F
.40729 .79827 m .42103 .79435 L .40639 .79667 L .438 .876 .871 r
F
.42103 .79435 m .42278 .79385 L .40732 .79644 L F
.42103 .79435 m .40732 .79644 L .39721 .79813 L F
.42936 .79615 m .4014 .79582 L .41783 .79403 L .217 0 0 r
F
.44285 .79938 m .47736 .80039 L .46757 .80855 L .653 .302 .365 r
F
.47736 .80039 m .47736 .80045 L .46757 .80855 L F
.47743 .80039 m .47742 .80194 L .46757 .80855 L F
.49499 .85504 m .47808 .83071 L .4778 .8188 L .884 .508 .322 r
F
.48557 .84357 m .47808 .83071 L .49499 .85504 L F
.49362 .84523 m .4778 .8188 L .48588 .82489 L F
.47743 .80039 m .47963 .80046 L .47742 .80194 L .653 .302 .365 r
F
.44465 .79935 m .47964 .80045 L .44285 .79938 L F
.47935 .80001 m .47877 .79871 L .48011 .80014 L .764 .478 .501 r
F
.43863 .79514 m .4809 .80044 L .47411 .79902 L .445 .029 .155 r
F
.43027 .7943 m .4809 .80044 L .43863 .79514 L F
.4809 .80044 m .48 .80021 L .47411 .79902 L F
.47973 .8004 m .48011 .80014 L .50511 .82666 L .764 .478 .501 r
F
.45992 .79874 m .48 .80021 L .4426 .79928 L .653 .302 .365 r
F
.45925 .79721 m .4588 .79621 L .47468 .79904 L .217 0 0 r
F
.45925 .79721 m .47468 .79904 L .47411 .79902 L F
.45925 .79721 m .42425 .79369 L .45693 .79198 L F
.45844 .79539 m .45693 .79198 L .46047 .79197 L F
.42391 .79353 m .47885 .79488 L .47462 .79727 L .445 .029 .155 r
F
.42391 .79353 m .47462 .79727 L .43204 .79442 L F
.44651 .79253 m .42907 .79255 L .42391 .79353 L 0 0 0 r
F
.45693 .79198 m .42907 .79255 L .44651 .79253 L F
.4588 .79621 m .46629 .79713 L .47491 .79904 L .217 0 0 r
F
.47468 .79904 m .47491 .79904 L .47573 .79922 L F
.4588 .79621 m .47491 .79904 L .47468 .79904 L F
.48575 .78739 m .4714 .78865 L .48852 .7836 L .142 0 0 r
F
.4816 .79308 m .47637 .79081 L .48575 .78739 L F
.47637 .79081 m .4714 .78865 L .48575 .78739 L F
.4714 .78865 m .46952 .78443 L .49168 .78267 L F
.46952 .78443 m .49062 .77466 L .50476 .76866 L F
.49481 .77288 m .49571 .77178 L .48831 .77563 L .797 .966 .914 r
F
.46079 .79178 m .49571 .77178 L .48102 .78272 L 0 0 0 r
F
.46952 .78443 m .46922 .78373 L .49062 .77466 L .142 0 0 r
F
.48831 .77563 m .49571 .77178 L .46079 .79178 L 0 0 0 r
F
.47008 .78568 m .45599 .78987 L .46922 .78373 L .142 0 0 r
F
.45914 .79135 m .45599 .78987 L .47008 .78568 L F
.46035 .79191 m .48102 .78272 L .42907 .79255 L 0 0 0 r
F
.46079 .79178 m .48102 .78272 L .46035 .79191 L F
.45693 .79198 m .46035 .79191 L .46047 .79197 L .217 0 0 r
F
.42391 .79353 m .47383 .78408 L .47885 .79488 L .445 .029 .155 r
F
.4239 .7929 m .45038 .79613 L .42384 .78888 L F
.46932 .79844 m .47411 .79902 L .47096 .79839 L F
.48 .80021 m .47964 .80045 L .4426 .79928 L .653 .302 .365 r
F
.47964 .80045 m .47963 .80046 L .44285 .79938 L F
.42391 .79353 m .47411 .79902 L .4239 .7929 L .445 .029 .155 r
F
.4611 .80138 m .42425 .79369 L .45925 .79721 L .217 0 0 r
F
.46139 .80205 m .45915 .80154 L .4611 .80138 L F
.45915 .80154 m .42425 .79369 L .4611 .80138 L F
.49414 .84677 m .50345 .85687 L .50015 .85689 L .787 .597 .643 r
F
.49412 .84675 m .49421 .84684 L .49414 .84677 L F
.51938 .89783 m .52377 .87709 L .52512 .88292 L .827 .699 .724 r
F
.51938 .89783 m .52512 .88292 L .52035 .89847 L F
.52377 .87709 m .52532 .87911 L .53023 .90504 L F
.50691 .93498 m .52208 .87928 L .51459 .91716 L .915 .784 .702 r
F
.50646 .92578 m .52208 .87928 L .50691 .93498 L F
.40633 1.02221 m .49647 .97759 L .418 1.01989 L .715 .971 .931 r
F
.49647 .97759 m .49849 .97659 L .49645 .97769 L F
.49647 .97759 m .49645 .97769 L .418 1.01989 L F
.52035 .89847 m .52512 .88292 L .53023 .90504 L .827 .699 .724 r
F
.52439 .87418 m .52541 .87296 L .53023 .90504 L F
.52509 .87084 m .52574 .87206 L .53023 .90504 L F
.53146 .88979 m .5148 .96894 L .49833 .97554 L .797 .714 .772 r
F
.53146 .88979 m .51502 .96873 L .51482 .96882 L F
.49647 .97759 m .49658 .97746 L .49849 .97659 L .715 .971 .931 r
F
.49849 .97659 m .51338 .96951 L .4963 .97853 L F
.49645 .97769 m .4963 .97853 L .418 1.01989 L F
.49849 .97659 m .4963 .97853 L .49645 .97769 L F
.39233 1.01754 m .4057 1.02201 L .39212 1.01748 L .662 .119 0 r
F
.4057 1.02201 m .40633 1.02221 L .40572 1.02201 L F
.4057 1.02201 m .40572 1.02201 L .39212 1.01748 L F
.41942 1.01133 m .44377 .9976 L .47144 .98487 L .591 .948 .851 r
F
.40137 1.02052 m .42721 1.00655 L .41942 1.01133 L F
.42721 1.00655 m .44377 .9976 L .41942 1.01133 L F
.40116 1.02045 m .44253 .99817 L .40137 1.02052 L F
.48362 .80442 m .52289 .87594 L .51055 .85735 L .692 .491 .611 r
F
.48362 .80442 m .51055 .85735 L .50961 .85566 L F
.52289 .87594 m .52015 .87237 L .51063 .85751 L F
.52289 .87594 m .51063 .85751 L .51055 .85735 L F
.50646 .92578 m .50709 .90211 L .5221 .87542 L .915 .784 .702 r
F
.52289 .87594 m .52327 .87664 L .52015 .87237 L .692 .491 .611 r
F
.51935 .90177 m .49743 .97438 L .51682 .90997 L .797 .714 .772 r
F
.49743 .97438 m .4973 .97484 L .49743 .97438 L F
.49743 .97438 m .49743 .97438 L .51682 .90997 L F
.49447 .94772 m .49511 .97397 L .48432 .97889 L .849 .862 .852 r
F
.49519 .94793 m .49511 .97397 L .49447 .94772 L F
.44516 .9925 m .48432 .97889 L .43643 1.00071 L F
.30085 .95734 m .45705 .98196 L .45399 .96779 L .806 .462 .406 r
F
.30133 .96563 m .45705 .98196 L .30085 .95734 L .794 .428 .364 r
F
.49669 .86078 m .51365 .88276 L .50817 .89734 L .787 .597 .643 r
F
.49669 .86078 m .50817 .89734 L .50045 .88141 L F
.50045 .88141 m .50817 .89734 L .50494 .90595 L F
.51365 .88276 m .50537 .90518 L .50494 .90595 L F
.50229 .87135 m .50229 .87144 L .50231 .87142 L F
.50229 .87144 m .50469 .89871 L .50232 .8715 L F
.50229 .87144 m .50232 .8715 L .50231 .87142 L F
.4973 .97484 m .4973 .97481 L .51682 .90997 L .797 .714 .772 r
F
.49648 .97755 m .49649 .97747 L .51682 .90997 L F
.51682 .90997 m .49654 .97731 L .50161 .95952 L F
.52208 .87928 m .52327 .87664 L .5157 .91357 L .915 .784 .702 r
F
.51682 .90997 m .50161 .95952 L .50333 .95363 L .797 .714 .772 r
F
.52564 .88094 m .53146 .88979 L .51918 .92157 L F
.40633 1.02221 m .4456 1.00054 L .49647 .97759 L .715 .971 .931 r
F
.4456 1.00054 m .48577 .97838 L .49624 .97761 L F
.4456 1.00054 m .49624 .97761 L .49647 .97759 L F
.51935 .90177 m .51918 .92157 L .4978 .97691 L .797 .714 .772 r
F
.49649 .9775 m .4978 .97691 L .49264 .99025 L F
.51935 .90177 m .4978 .97691 L .49649 .9775 L F
.52564 .88094 m .51918 .92157 L .51935 .90177 L F
.52327 .87664 m .52377 .87709 L .51938 .89783 L .915 .784 .702 r
F
.5194 .89552 m .51938 .89783 L .50454 .96803 L F
.52327 .87664 m .51938 .89783 L .5194 .89552 L F
.51459 .91716 m .5157 .91357 L .50454 .96803 L F
.52208 .87928 m .5157 .91357 L .51459 .91716 L F
.50021 .95051 m .51459 .91716 L .50333 .95363 L F
.52035 .89847 m .51935 .90177 L .51682 .90997 L .797 .714 .772 r
F
.50454 .96803 m .51938 .89783 L .53023 .90504 L .827 .699 .724 r
F
.52035 .89847 m .51682 .90997 L .50967 .93188 L .797 .714 .772 r
F
.51682 .90997 m .50333 .95363 L .50967 .93188 L F
.52208 .87928 m .52304 .87643 L .52327 .87664 L .915 .784 .702 r
F
.50646 .92578 m .5221 .87542 L .52304 .87643 L F
.50015 .85689 m .52564 .88094 L .52177 .89328 L .787 .597 .643 r
F
.49412 .84675 m .52177 .89328 L .49669 .86078 L F
.50634 .89282 m .51176 .87494 L .50745 .89555 L .949 .898 .509 r
F
.51176 .87494 m .51231 .8731 L .51192 .8749 L F
.51176 .87494 m .51192 .8749 L .50745 .89555 L F
.50469 .89871 m .50469 .89868 L .50231 .87142 L .787 .597 .643 r
F
.49412 .84675 m .50494 .90595 L .50229 .87135 L F
.49497 .9457 m .49766 .94066 L .49606 .94819 L .949 .898 .509 r
F
.50499 .90622 m .50501 .90686 L .49606 .94819 L F
.49151 .94895 m .48432 .97889 L .44516 .9925 L .849 .862 .852 r
F
.49497 .9457 m .49078 .95875 L .49151 .94895 L F
.49078 .95875 m .48432 .97889 L .49151 .94895 L F
.4952 .94548 m .49506 .94591 L .49497 .9457 L F
.49506 .94591 m .48432 .97889 L .49497 .9457 L F
.49511 .97397 m .47144 .98487 L .43643 1.00071 L F
.32218 .99412 m .36554 1.00859 L .32252 .99425 L .662 .119 0 r
F
.36554 1.00859 m .39233 1.01754 L .36341 1.00789 L F
.36554 1.00859 m .36341 1.00789 L .32252 .99425 L F
.40631 1.02221 m .39516 1.02368 L .40633 1.02221 L F
.39233 1.01754 m .39212 1.01748 L .32252 .99425 L F
.32218 .99412 m .39516 1.02368 L .40631 1.02221 L F
.39439 1.0198 m .43601 1.0011 L .39516 1.02368 L 0 0 0 r
F
.43601 1.0011 m .44253 .99817 L .42895 1.00549 L F
.43601 1.0011 m .42895 1.00549 L .39516 1.02368 L F
.47989 .97387 m .46624 .98236 L .47961 .9744 L .849 .862 .852 r
F
.48577 .97838 m .49727 .97438 L .49647 .97759 L .715 .971 .931 r
F
.44253 .99817 m .44377 .9976 L .40137 1.02052 L .591 .948 .851 r
F
.39516 1.02368 m .47144 .98487 L .40633 1.02221 L F
.47144 .98487 m .4834 .97946 L .40633 1.02221 L F
.49511 .97397 m .49511 .97416 L .47144 .98487 L .849 .862 .852 r
F
.51365 .88276 m .51615 .886 L .50537 .90518 L .787 .597 .643 r
F
.49606 .94819 m .50745 .89555 L .49867 .94896 L .915 .784 .702 r
F
.50745 .89555 m .51231 .8731 L .50804 .89688 L F
.50745 .89555 m .50804 .89688 L .49867 .94896 L F
.50499 .90622 m .50537 .90518 L .50501 .90686 L .949 .898 .509 r
F
.50537 .91167 m .50709 .90211 L .50646 .92578 L .915 .784 .702 r
F
.50494 .90595 m .52177 .89328 L .50967 .93188 L .787 .597 .643 r
F
.51615 .886 m .52177 .89328 L .50494 .90595 L F
.50494 .90595 m .50499 .90622 L .50229 .87135 L F
.50499 .90622 m .50478 .89971 L .50229 .87135 L F
.50498 .90618 m .50634 .89282 L .50537 .90518 L .949 .898 .509 r
F
.50473 .89815 m .50634 .89282 L .50498 .90618 L F
.50634 .89282 m .50745 .89555 L .50537 .90518 L F
.51176 .87494 m .50701 .88039 L .51231 .8731 L F
.49891 .9492 m .49596 .95394 L .4952 .94548 L .849 .862 .852 r
F
.50333 .95363 m .49596 .95394 L .49891 .9492 L F
.50333 .95363 m .49768 .97299 L .49596 .95394 L F
.49768 .97299 m .49511 .97416 L .4952 .94548 L F
.49497 .9457 m .49151 .94895 L .48428 .96567 L F
.4834 .97946 m .48577 .97838 L .40633 1.02221 L .591 .948 .851 r
F
.49511 .97416 m .49508 .9819 L .43643 1.00071 L .849 .862 .852 r
F
.43601 1.0011 m .49088 .97215 L .44253 .99817 L 0 0 0 r
F
.43643 1.00071 m .43803 1.0002 L .43601 1.0011 L .849 .862 .852 r
F
.49151 .94895 m .44173 .99573 L .48428 .96567 L F
.44173 .99573 m .43601 1.0011 L .44544 .99418 L F
.44173 .99573 m .44544 .99418 L .48428 .96567 L F
.45067 .992 m .49088 .97215 L .43601 1.0011 L 0 0 0 r
F
.44253 .99817 m .49088 .97215 L .44377 .9976 L .591 .948 .851 r
F
.44377 .9976 m .49088 .97215 L .47144 .98487 L F
.45821 .98836 m .4748 .98119 L .48556 .97514 L 0 0 0 r
F
.46025 .98771 m .4748 .98119 L .45821 .98836 L F
.45067 .992 m .48556 .97514 L .48748 .97383 L F
.46502 .98603 m .48033 .97872 L .45067 .992 L F
.44976 .9967 m .49508 .9819 L .43129 1.00952 L .849 .862 .852 r
F
.44976 .9967 m .43129 1.00952 L .42344 1.01292 L F
.43586 1.00125 m .44976 .9967 L .42344 1.01292 L F
.43839 1.00008 m .49508 .9819 L .43586 1.00125 L F
.42344 1.01292 m .49264 .99025 L .41513 1.02073 L F
.49508 .9819 m .49264 .99025 L .42344 1.01292 L F
.4626 .98704 m .45933 .98936 L .46535 .98589 L F
.45933 .98936 m .41513 1.02073 L .46517 .98602 L F
.45933 .98936 m .46517 .98602 L .46535 .98589 L F
.43601 1.0011 m .43628 1.00093 L .48428 .96567 L F
.44552 .99415 m .43628 1.00093 L .45067 .992 L F
.39439 1.0198 m .45067 .992 L .43601 1.0011 L 0 0 0 r
F
.45067 .992 m .46025 .98771 L .45821 .98836 L F
.46624 .98236 m .43586 1.00125 L .46653 .98243 L .849 .862 .852 r
F
.43628 1.00093 m .43586 1.00125 L .45083 .99194 L F
.45067 .992 m .45083 .99194 L .47989 .97387 L F
.43628 1.00093 m .45083 .99194 L .45067 .992 L F
.43601 1.0011 m .43839 1.00008 L .43586 1.00125 L F
.43601 1.0011 m .43586 1.00125 L .43628 1.00093 L F
.43803 1.0002 m .43839 1.00008 L .43601 1.0011 L F
.32218 .99412 m .32252 .99425 L .29117 .98379 L .662 .119 0 r
F
.30843 .99051 m .39516 1.02368 L .32218 .99412 L F
.36903 1.01332 m .39501 1.02362 L .36672 1.0128 L .655 .102 0 r
F
.38382 1.01934 m .38387 1.01936 L .30138 .98781 L F
.39501 1.02362 m .30138 .98781 L .30139 .98781 L F
.25947 .87191 m .29117 .98379 L .29419 .98329 L .947 .693 .23 r
F
.25947 .87191 m .28822 .98277 L .29117 .98379 L .921 .659 .169 r
F
.28822 .98277 m .32218 .99412 L .29117 .98379 L .662 .119 0 r
F
.28822 .98277 m .30843 .99051 L .32218 .99412 L F
.25947 .87191 m .28564 .98024 L .28822 .98277 L .87 .601 .073 r
F
.28564 .98024 m .36482 1.01164 L .28822 .98277 L .655 .102 0 r
F
.36482 1.01164 m .36903 1.01332 L .36579 1.01209 L F
.36482 1.01164 m .36579 1.01209 L .28822 .98277 L F
.36903 1.01332 m .36672 1.0128 L .28822 .98277 L F
.28564 .98024 m .32088 .99598 L .3311 .99827 L F
.32088 .99598 m .38479 1.02454 L .3311 .99827 L F
.3899 1.01189 m .39249 1.01257 L .29419 .98329 L .68 .155 0 r
F
.39677 1.01385 m .3968 1.01362 L .29419 .98329 L F
.25947 .87191 m .29419 .98329 L .29698 .98123 L .958 .71 .26 r
F
.25947 .87191 m .28375 .97619 L .28564 .98024 L .78 .512 0 r
F
.28375 .97619 m .33556 1.00098 L .28564 .98024 L .649 .091 0 r
F
.39501 1.02362 m .39501 1.02362 L .38387 1.01936 L .655 .102 0 r
F
.39501 1.02362 m .38387 1.01936 L .38382 1.01934 L F
.37243 1.01862 m .38479 1.02454 L .37102 1.01838 L .649 .091 0 r
F
.33556 1.00098 m .37243 1.01862 L .32297 .99692 L F
.37243 1.01862 m .37102 1.01838 L .32297 .99692 L F
.33556 1.00098 m .32297 .99692 L .28564 .98024 L F
.30422 .98598 m .37547 1.0248 L .38062 1.02254 L F
.39501 1.02362 m .39516 1.02368 L .39501 1.02362 L .655 .102 0 r
F
.39501 1.02362 m .38479 1.02454 L .39516 1.02368 L F
.3311 .99827 m .38479 1.02454 L .39501 1.02362 L F
.38479 1.02454 m .39439 1.0198 L .39498 1.0228 L 0 0 0 r
F
.38479 1.02454 m .39498 1.0228 L .39516 1.02368 L F
.48428 .96567 m .44552 .99415 L .47989 .97387 L .849 .862 .852 r
F
.50473 .89815 m .50548 .89229 L .51176 .87494 L .949 .898 .509 r
F
.50551 .88638 m .50701 .88039 L .50473 .89815 L F
.50568 .91004 m .50479 .89176 L .50443 .8888 L .787 .597 .643 r
F
.50477 .89963 m .50443 .8888 L .50231 .87142 L F
.50568 .91004 m .50443 .8888 L .50477 .89963 L F
.50568 .91004 m .50967 .93188 L .50479 .89176 L F
.50232 .87152 m .50502 .89371 L .4994 .87018 L .891 .724 .667 r
F
.50162 .87113 m .4994 .87018 L .49932 .86986 L F
.50232 .87152 m .4994 .87018 L .50162 .87113 L F
.50287 .87166 m .48557 .84357 L .49499 .85504 L .884 .508 .322 r
F
.50701 .88039 m .50162 .87113 L .50287 .87166 L F
.50162 .87113 m .48557 .84357 L .50287 .87166 L F
.50383 .87657 m .50033 .87042 L .503 .87349 L 0 0 .408 r
F
.50033 .87042 m .49617 .86312 L .50162 .87113 L F
.49617 .86312 m .49507 .86019 L .50162 .87113 L F
.48377 .84134 m .4851 .84298 L .50162 .87113 L F
.472 .82067 m .4716 .81958 L .48557 .84357 L F
.4851 .84298 m .48557 .84357 L .50162 .87113 L F
.472 .82067 m .48557 .84357 L .4851 .84298 L F
.47411 .79902 m .48 .80021 L .45992 .79874 L .653 .302 .365 r
F
.46139 .80205 m .45925 .79721 L .47613 .79931 L .217 0 0 r
F
.45925 .79721 m .47573 .79922 L .47613 .79931 L F
.42384 .78888 m .47096 .79839 L .45992 .79874 L .653 .302 .365 r
F
.44583 .79918 m .4426 .79928 L .43406 .79702 L .217 0 0 r
F
.44831 .7991 m .41876 .7942 L .42433 .79371 L F
.46139 .80205 m .44583 .79918 L .44831 .7991 L F
.44583 .79918 m .41876 .7942 L .44831 .7991 L F
.44092 .79835 m .45992 .79874 L .4426 .79928 L .653 .302 .365 r
F
.42391 .79353 m .43027 .7943 L .43863 .79514 L .445 .029 .155 r
F
.42384 .78888 m .45992 .79874 L .44092 .79835 L .653 .302 .365 r
F
.50499 .85686 m .47957 .8005 L .50979 .85682 L .764 .478 .501 r
F
.47957 .8005 m .47935 .80001 L .4796 .80048 L F
.47957 .8005 m .4796 .80048 L .50979 .85682 L F
.4138 .79711 m .4014 .79582 L .42936 .79615 L .217 0 0 r
F
.42384 .78888 m .4426 .79928 L .43376 .78981 L .653 .302 .365 r
F
.40634 .79658 m .39727 .79233 L .4014 .79582 L 0 .521 .831 r
F
.39727 .79233 m .39574 .79225 L .4014 .79582 L F
.3917 .78971 m .38436 .78679 L .4014 .79582 L F
.40557 .79522 m .42384 .78888 L .39963 .79286 L .438 .876 .871 r
F
.39963 .79286 m .42384 .78888 L .39842 .79238 L F
.39842 .79238 m .42384 .78888 L .4068 .79278 L .041 0 0 r
F
.40351 .79158 m .39084 .78729 L .40634 .79658 L 0 .521 .831 r
F
.39084 .78729 m .3829 .78557 L .40634 .79658 L F
.41876 .7942 m .41783 .79403 L .42433 .79371 L .217 0 0 r
F
.39721 .79813 m .42391 .79353 L .42384 .78888 L .438 .876 .871 r
F
.4068 .79278 m .42384 .78888 L .43376 .78981 L .041 0 0 r
F
.4068 .79278 m .43376 .78981 L .39317 .7878 L F
.44277 .79938 m .46757 .80855 L .45888 .80831 L .653 .302 .365 r
F
.44285 .79938 m .46757 .80855 L .44277 .79938 L F
.46757 .80855 m .46537 .81003 L .45888 .80831 L F
.49425 .84688 m .49415 .84661 L .50418 .8567 L .884 .508 .322 r
F
.49415 .84661 m .47742 .80268 L .50221 .85272 L F
.49415 .84661 m .50221 .85272 L .50418 .8567 L F
.50499 .85686 m .47779 .80269 L .47988 .80118 L .764 .478 .501 r
F
.50435 .85686 m .52381 .87809 L .50371 .85687 L .787 .597 .643 r
F
.5051 .85686 m .51024 .86268 L .50435 .85686 L F
.51024 .86268 m .52381 .87809 L .50435 .85686 L F
.47742 .80268 m .47742 .80194 L .50435 .85686 L .884 .508 .322 r
F
.50537 .85895 m .52564 .88094 L .50538 .85896 L .787 .597 .643 r
F
.50537 .85895 m .50538 .85896 L .49414 .84677 L F
.49421 .84684 m .50537 .85895 L .49414 .84677 L F
.50345 .85687 m .52564 .88094 L .50015 .85689 L F
.52381 .87809 m .52564 .88094 L .49412 .84675 L F
.50418 .8567 m .50435 .85686 L .51231 .8731 L .884 .508 .322 r
F
.47742 .80268 m .50435 .85686 L .50418 .8567 L F
.51231 .8731 m .50435 .85686 L .50499 .85686 L .764 .478 .501 r
F
.50435 .85686 m .47779 .80269 L .50499 .85686 L F
.49358 .84379 m .5051 .85686 L .49412 .84675 L .787 .597 .643 r
F
.5051 .85686 m .50371 .85687 L .49412 .84675 L F
.48584 .81593 m .48678 .81569 L .48716 .81678 L .653 .302 .365 r
F
.48584 .81593 m .48716 .81678 L .49028 .82572 L F
.48588 .82489 m .4778 .8188 L .47742 .80268 L .884 .508 .322 r
F
.47683 .81826 m .48584 .81593 L .49028 .82572 L .653 .302 .365 r
F
.45888 .80831 m .47629 .81291 L .47683 .81826 L F
.47629 .81291 m .48678 .81569 L .47683 .81826 L F
.44763 .80062 m .4778 .8188 L .45303 .80205 L F
.44277 .79938 m .4778 .8188 L .44763 .80062 L F
.43562 .79949 m .4366 .79947 L .44763 .80062 L 0 .521 .831 r
F
.44797 .8007 m .44763 .80062 L .4577 .80166 L F
.43562 .79949 m .44763 .80062 L .44797 .8007 L F
.4576 .80167 m .4577 .80166 L .46139 .80205 L F
.44803 .80072 m .4577 .80166 L .4576 .80167 L F
.43562 .79949 m .44797 .8007 L .44803 .80072 L F
.44797 .8007 m .4577 .80166 L .44803 .80072 L F
.4426 .79928 m .44465 .79935 L .44285 .79938 L .653 .302 .365 r
F
.46139 .80205 m .44763 .80062 L .4426 .79928 L .217 0 0 r
F
.46139 .80205 m .4426 .79928 L .44583 .79918 L F
.4426 .79928 m .44763 .80062 L .43376 .78981 L .653 .302 .365 r
F
.44763 .80062 m .45303 .80205 L .45289 .80196 L F
.46757 .80855 m .48678 .81569 L .46537 .81003 L F
.42278 .79385 m .42391 .79353 L .40632 .79656 L .438 .876 .871 r
F
.40635 .7966 m .40632 .79656 L .39721 .79813 L F
.42278 .79385 m .40632 .79656 L .40635 .7966 L F
.40634 .79658 m .40732 .79644 L .4366 .79947 L 0 .521 .831 r
F
.40634 .79658 m .4366 .79947 L .43562 .79949 L F
.44663 .80258 m .44905 .80386 L .44743 .80337 L .759 .44 .445 r
F
.46706 .81341 m .46991 .81492 L .4716 .81958 L F
.47359 .82586 m .4716 .81958 L .47456 .82772 L F
.46706 .81341 m .4716 .81958 L .47359 .82586 L F
.4756 .81731 m .46889 .81213 L .46514 .80975 L .653 .302 .365 r
F
.46524 .81031 m .46514 .80975 L .45303 .80205 L F
.4756 .81731 m .46514 .80975 L .46524 .81031 L F
.46504 .80915 m .46458 .80826 L .46575 .8097 L 0 0 .408 r
F
.46458 .80826 m .46139 .80205 L .46503 .80844 L F
.46458 .80826 m .46503 .80844 L .46575 .8097 L F
.44449 .80248 m .42608 .79964 L .43774 .80043 L 0 .521 .831 r
F
.44575 .80222 m .43774 .80043 L .45024 .80128 L F
.44641 .80236 m .45303 .80205 L .44663 .80258 L .759 .44 .445 r
F
.45303 .80205 m .46214 .80784 L .44663 .80258 L F
.46214 .80784 m .451 .80446 L .44663 .80258 L F
.46889 .81213 m .46991 .81492 L .44663 .80258 L F
.44641 .80236 m .44743 .80337 L .45288 .80376 L F
.52013 .85554 m .51959 .84164 L .52217 .85845 L .692 .491 .611 r
F
.48582 .8067 m .50511 .82666 L .52013 .85554 L F
.51458 .84486 m .5026 .81045 L .51507 .8387 L .764 .478 .501 r
F
.5069 .8301 m .5026 .81045 L .51458 .84486 L F
.50511 .82666 m .483 .8032 L .5026 .81045 L F
.483 .8032 m .48203 .80129 L .5026 .81045 L F
.48147 .80051 m .52013 .85554 L .51547 .86243 L .692 .491 .611 r
F
.52013 .85554 m .52217 .85845 L .52177 .85869 L F
.52013 .85554 m .52177 .85869 L .51547 .86243 L F
.51063 .85751 m .52381 .87809 L .49358 .84379 L .787 .597 .643 r
F
.50961 .85566 m .50511 .82666 L .51319 .8621 L .764 .478 .501 r
F
.50511 .82666 m .5026 .81045 L .50645 .82924 L F
.50511 .82666 m .50645 .82924 L .51319 .8621 L F
.51257 .85906 m .50645 .82924 L .51338 .85972 L F
.50645 .82924 m .5026 .81045 L .5069 .8301 L F
.50645 .82924 m .5069 .8301 L .51338 .85972 L F
.50435 .8252 m .51655 .82193 L .51959 .84164 L .692 .491 .611 r
F
.48147 .80051 m .49618 .80949 L .50435 .8252 L F
.49618 .80949 m .51655 .82193 L .50435 .8252 L F
.50511 .82666 m .51959 .84164 L .52013 .85554 L F
.51338 .85972 m .5069 .8301 L .51458 .84486 L .764 .478 .501 r
F
.50979 .85682 m .4796 .80048 L .50511 .82666 L F
.4796 .80048 m .47973 .8004 L .50511 .82666 L F
.47988 .80118 m .47613 .79931 L .47877 .79871 L F
.47736 .80039 m .47743 .80039 L .47736 .80045 L .653 .302 .365 r
F
.47779 .80269 m .47613 .79931 L .47988 .80118 L .764 .478 .501 r
F
.47963 .80046 m .48147 .80051 L .47742 .80285 L .653 .302 .365 r
F
.4774 .80196 m .47742 .80285 L .46757 .80855 L F
.47963 .80046 m .47742 .80285 L .4774 .80196 L F
.46757 .80855 m .48147 .80051 L .48678 .81569 L F
.4685 .80977 m .46139 .80205 L .46612 .80223 L .884 .508 .322 r
F
.46214 .80784 m .46889 .81213 L .451 .80446 L .759 .44 .445 r
F
.4778 .8188 m .46934 .81241 L .46889 .81213 L .653 .302 .365 r
F
.4778 .8188 m .46889 .81213 L .4756 .81731 L F
.47808 .83071 m .4716 .81958 L .47742 .80268 L .884 .508 .322 r
F
.4716 .81958 m .46612 .80223 L .47742 .80268 L F
.50126 .86827 m .4778 .8188 L .49362 .84523 L F
.4778 .8188 m .49028 .82572 L .46934 .81241 L .653 .302 .365 r
F
.46889 .81213 m .49028 .82572 L .46991 .81492 L .759 .44 .445 r
F
.4785 .83481 m .47456 .82772 L .47816 .83149 L 0 0 .408 r
F
.47857 .83553 m .47769 .83381 L .4785 .83481 L F
.47769 .83381 m .47456 .82772 L .4785 .83481 L F
.46514 .80848 m .46139 .80205 L .4685 .80977 L .884 .508 .322 r
F
.472 .82067 m .46503 .80844 L .4716 .81958 L 0 0 .408 r
F
.46503 .80844 m .46139 .80205 L .46514 .80848 L F
.46503 .80844 m .46514 .80848 L .4716 .81958 L F
.45289 .80196 m .45303 .80205 L .44641 .80236 L .759 .44 .445 r
F
.45324 .80383 m .44575 .80222 L .44894 .80155 L 0 .521 .831 r
F
.45289 .80196 m .45024 .80128 L .46139 .80205 L F
.46348 .80542 m .46256 .80319 L .46309 .80535 L 0 0 .408 r
F
.46309 .80535 m .46256 .80319 L .46139 .80205 L F
.46479 .80781 m .46256 .80319 L .46504 .80915 L F
.47456 .82772 m .46504 .80915 L .47231 .82154 L F
.46504 .80915 m .46575 .8097 L .47816 .83149 L F
.47456 .82772 m .46256 .80319 L .47238 .82346 L F
.47456 .82772 m .47231 .82154 L .47816 .83149 L F
.48377 .84134 m .472 .82067 L .4851 .84298 L F
.46991 .81492 m .49028 .82572 L .47656 .83154 L .759 .44 .445 r
F
.49932 .86986 m .5029 .88485 L .49883 .87595 L .891 .724 .667 r
F
.5029 .88485 m .50502 .89371 L .49883 .87595 L F
.49883 .87595 m .50502 .89371 L .49498 .92474 L F
.49883 .87595 m .49498 .92474 L .49496 .92458 L F
.49793 .87398 m .49494 .92489 L .48839 .94295 L F
.49856 .86944 m .49822 .87462 L .49793 .87398 L F
.49822 .87462 m .49494 .92489 L .49793 .87398 L F
.49932 .86986 m .49787 .88804 L .49856 .86944 L F
.49787 .88804 m .49494 .92489 L .49744 .88654 L F
.49787 .88804 m .49744 .88654 L .49856 .86944 L F
.49494 .86743 m .47857 .83553 L .4999 .87018 L 0 0 .408 r
F
.46991 .81492 m .47656 .83154 L .47456 .82772 L .759 .44 .445 r
F
.47857 .83553 m .47816 .83149 L .50383 .87657 L 0 0 .408 r
F
.51231 .8731 m .50961 .85566 L .51319 .8621 L .764 .478 .501 r
F
.49028 .82572 m .51063 .85751 L .49358 .84379 L .787 .597 .643 r
F
.50701 .88039 m .49425 .84688 L .51231 .8731 L .884 .508 .322 r
F
.49425 .84688 m .50418 .8567 L .51231 .8731 L F
.50382 .87207 m .50126 .86827 L .49412 .84675 L F
.50701 .88039 m .50287 .87166 L .50382 .87207 L F
.50287 .87166 m .50126 .86827 L .50382 .87207 L F
.50701 .88039 m .49412 .84675 L .49425 .84688 L F
.49412 .84675 m .50231 .87142 L .50043 .85597 L .787 .597 .643 r
F
.50043 .85597 m .50231 .87142 L .49932 .86986 L .891 .724 .667 r
F
.50231 .87142 m .50232 .87152 L .50162 .87113 L F
.50231 .87142 m .50162 .87113 L .49932 .86986 L F
.49425 .84688 m .49412 .84675 L .49362 .84523 L .884 .508 .322 r
F
.49028 .82572 m .49412 .84675 L .50043 .85597 L .787 .597 .643 r
F
.47738 .83311 m .49028 .82572 L .50043 .85597 L .759 .44 .445 r
F
.47653 .83155 m .47656 .83154 L .47456 .82772 L 0 0 .408 r
F
.49579 .86909 m .47656 .83154 L .47653 .83155 L F
.49579 .86909 m .49494 .86743 L .49494 .86744 L F
.49856 .86944 m .49793 .87398 L .49853 .8751 L .891 .724 .667 r
F
.49496 .92458 m .49498 .92474 L .49494 .92489 L F
.48895 .94072 m .50475 .88794 L .49494 .92489 L .127 0 .358 r
F
.50475 .88794 m .50701 .88039 L .50487 .88828 L F
.50475 .88794 m .50487 .88828 L .49494 .92489 L F
.49856 .86944 m .49853 .8751 L .50354 .8826 L .891 .724 .667 r
F
.49853 .8751 m .49839 .90311 L .50323 .88384 L F
.49853 .8751 m .50323 .88384 L .50354 .8826 L F
.49455 .91841 m .50464 .88764 L .48895 .94072 L .127 0 .358 r
F
.50464 .88764 m .50701 .88039 L .50475 .88794 L F
.50464 .88764 m .50475 .88794 L .48895 .94072 L F
.50002 .87735 m .49579 .86909 L .50383 .87657 L 0 0 .408 r
F
.50538 .88227 m .50002 .87735 L .50383 .87657 L F
.4792 .97628 m .48318 .96822 L .48075 .97715 L .127 0 .358 r
F
.4748 .98119 m .48033 .97872 L .48249 .97737 L 0 0 0 r
F
.4748 .98119 m .48249 .97737 L .49088 .97215 L F
.48033 .97872 m .48318 .96822 L .48428 .96567 L .949 .898 .509 r
F
.48748 .97383 m .48556 .97514 L .49088 .97215 L 0 0 0 r
F
.48033 .97872 m .48428 .96567 L .49088 .97215 L .949 .898 .509 r
F
.48428 .96567 m .49222 .93946 L .49171 .95178 L F
.48428 .96567 m .49171 .95178 L .49088 .97215 L F
.4952 .94548 m .49519 .94793 L .49447 .94772 L .849 .862 .852 r
F
.49222 .93946 m .49606 .94819 L .49088 .97215 L .949 .898 .509 r
F
.49497 .9457 m .47961 .9744 L .48549 .97079 L .849 .862 .852 r
F
.48171 .96954 m .49494 .92489 L .48318 .96822 L .127 0 .358 r
F
.47729 .97353 m .48839 .94295 L .48171 .96954 L F
.48839 .94295 m .49494 .92489 L .48171 .96954 L F
.48318 .96822 m .49268 .9332 L .48428 .96567 L .949 .898 .509 r
F
.49104 .93693 m .48937 .94574 L .48786 .94678 L .891 .724 .667 r
F
.48428 .96567 m .49268 .9332 L .49222 .93946 L .949 .898 .509 r
F
.49222 .93946 m .50551 .88638 L .50473 .89815 L F
.49268 .9332 m .50701 .88039 L .49222 .93946 L F
.50502 .89371 m .48937 .94574 L .49104 .93693 L .891 .724 .667 r
F
.49222 .93946 m .50498 .90618 L .49248 .94006 L .949 .898 .509 r
F
.50498 .90618 m .50537 .90518 L .50499 .90622 L F
.50498 .90618 m .50499 .90622 L .49248 .94006 L F
.49248 .94006 m .50499 .90622 L .49766 .94066 L F
.49248 .94006 m .49766 .94066 L .49497 .9457 L F
.50469 .89871 m .50478 .89971 L .50469 .89868 L .787 .597 .643 r
F
.50478 .89971 m .50568 .91004 L .50477 .89963 L F
.50478 .89971 m .50477 .89963 L .50469 .89868 L F
.50499 .90622 m .50568 .91004 L .50478 .89971 L F
.49222 .93946 m .50473 .89815 L .50498 .90618 L .949 .898 .509 r
F
.49867 .94896 m .50537 .91167 L .50646 .92578 L .915 .784 .702 r
F
.49088 .97215 m .50646 .92578 L .50691 .93498 L F
.50502 .89371 m .50967 .93188 L .48937 .94574 L .891 .724 .667 r
F
.48839 .94295 m .49494 .92489 L .48786 .94678 L F
.49106 .92367 m .48839 .94295 L .49455 .91841 L F
.47614 .97458 m .49494 .92489 L .47729 .97353 L .127 0 .358 r
F
.48036 .97394 m .47998 .9747 L .48549 .97079 L .849 .862 .852 r
F
.48549 .97079 m .47998 .9747 L .48426 .97278 L F
.49088 .97215 m .49606 .94819 L .49867 .94896 L .915 .784 .702 r
F
.50967 .93188 m .50333 .95363 L .4952 .94548 L .849 .862 .852 r
F
.50967 .93188 m .49497 .9457 L .48549 .97079 L F
.48786 .94678 m .50967 .93188 L .48426 .97278 L .891 .724 .667 r
F
.49455 .91841 m .48426 .97278 L .49872 .91213 L F
.48839 .94295 m .48426 .97278 L .49455 .91841 L F
.50548 .89229 m .50701 .88039 L .5107 .87615 L .949 .898 .509 r
F
.50548 .89229 m .5107 .87615 L .51176 .87494 L F
.52327 .87664 m .52322 .87659 L .52015 .87237 L .692 .491 .611 r
F
.52333 .87673 m .5221 .87542 L .52015 .87237 L F
.52177 .85869 m .5224 .85989 L .52456 .87396 L F
.50709 .90211 m .51231 .8731 L .52528 .86976 L .915 .784 .702 r
F
.49607 .91377 m .50541 .89906 L .50701 .88039 L .127 0 .358 r
F
.50541 .89906 m .50859 .89405 L .50825 .89114 L F
.50541 .89906 m .50825 .89114 L .50701 .88039 L F
.50101 .87927 m .50002 .87735 L .50051 .8778 L 0 0 .408 r
F
.50101 .87927 m .50051 .8778 L .50538 .88227 L F
.50354 .8826 m .50323 .88384 L .50585 .88872 L .891 .724 .667 r
F
.5036 .88432 m .50101 .87927 L .50273 .88045 L 0 0 .408 r
F
.50401 .88384 m .50273 .88045 L .50538 .88227 L F
.5036 .88432 m .50273 .88045 L .50401 .88384 L F
.50273 .88248 m .49835 .87325 L .49958 .87627 L F
.50784 .89131 m .5036 .88432 L .50538 .88227 L F
.50859 .89405 m .5073 .89153 L .50784 .89131 L F
.5073 .89153 m .5036 .88432 L .50784 .89131 L F
.49786 .91266 m .50859 .89405 L .49607 .91377 L .127 0 .358 r
F
.49872 .91213 m .48426 .97278 L .50105 .9128 L .891 .724 .667 r
F
.5053 .90223 m .50859 .89405 L .49786 .91266 L .127 0 .358 r
F
.49872 .91213 m .49786 .91266 L .49455 .91841 L F
.5053 .90223 m .49786 .91266 L .49872 .91213 L F
.5051 .89415 m .50573 .89607 L .50697 .89166 L .891 .724 .667 r
F
.49288 .91046 m .50573 .89607 L .5051 .89415 L F
.49288 .91046 m .50105 .9128 L .50573 .89607 L F
.47614 .97458 m .49455 .91841 L .48895 .94072 L .127 0 .358 r
F
.47614 .97458 m .49595 .92542 L .49455 .91841 L F
.43586 1.00125 m .41513 1.02073 L .47998 .9747 L .849 .862 .852 r
F
.43586 1.00125 m .47998 .9747 L .48036 .97394 L F
.44552 .99415 m .45067 .992 L .47989 .97387 L F
.47998 .9747 m .4626 .98704 L .4792 .97628 L F
.46624 .98236 m .46653 .98243 L .47961 .9744 L F
.47792 .97557 m .48318 .96822 L .4792 .97628 L .127 0 .358 r
F
.47614 .97458 m .4817 .96955 L .47792 .97557 L F
.4817 .96955 m .48318 .96822 L .47792 .97557 L F
.4655 .98583 m .48033 .97872 L .46524 .98594 L 0 0 0 r
F
.46524 .98594 m .48033 .97872 L .46503 .98603 L F
.46503 .98603 m .48033 .97872 L .46502 .98603 L F
.46999 .98326 m .48033 .97872 L .4655 .98583 L .335 0 .007 r
F
.4626 .98704 m .46535 .98589 L .4792 .97628 L .849 .862 .852 r
F
.47998 .9747 m .4792 .97628 L .48426 .97278 L F
.39128 1.02143 m .4655 .98583 L .39144 1.02126 L 0 0 0 r
F
.4655 .98583 m .46524 .98594 L .39144 1.02126 L F
.39622 1.01897 m .46524 .98594 L .39622 1.01889 L F
.46524 .98594 m .46503 .98603 L .39622 1.01889 L F
.41193 1.01139 m .46503 .98603 L .41222 1.01125 L F
.41193 1.01139 m .41222 1.01125 L .39639 1.01881 L F
.39639 1.01881 m .41193 1.01139 L .39639 1.01881 L F
.46503 .98603 m .46502 .98603 L .39639 1.01881 L F
.46703 .9842 m .46535 .98589 L .46443 .98625 L .726 .979 .917 r
F
.37547 1.0248 m .45245 .99097 L .38479 1.02454 L .335 0 .007 r
F
.46793 .98378 m .46535 .98589 L .46703 .9842 L .726 .979 .917 r
F
.29471 .98199 m .37547 1.0248 L .30422 .98598 L .649 .091 0 r
F
.28375 .97619 m .29471 .98199 L .30422 .98598 L F
.25947 .87191 m .29698 .98123 L .29925 .9776 L .959 .711 .263 r
F
.28289 .97061 m .35203 1.01108 L .28375 .97619 L .626 .065 0 r
F
.39639 1.01881 m .46502 .98603 L .45067 .992 L 0 0 0 r
F
.39622 1.01889 m .39639 1.01881 L .39639 1.01881 L F
.39144 1.02126 m .39622 1.01897 L .39622 1.01889 L F
.38479 1.02454 m .39128 1.02143 L .39144 1.02126 L F
.45245 .99097 m .46075 .98774 L .38479 1.02454 L .335 0 .007 r
F
.46075 .98774 m .46484 .98614 L .39271 1.02074 L F
.46075 .98774 m .39271 1.02074 L .39269 1.02071 L F
.39516 1.02368 m .40116 1.02045 L .40137 1.02052 L .591 .948 .851 r
F
.41082 1.013 m .41513 1.02073 L .39187 1.02242 L .726 .979 .917 r
F
.46484 .98614 m .43535 1.00666 L .41082 1.013 L F
.43535 1.00666 m .41513 1.02073 L .41082 1.013 L F
.35725 1.01414 m .3724 1.02301 L .35301 1.0129 L .626 .065 0 r
F
.3724 1.02301 m .37547 1.0248 L .37218 1.02306 L F
.3724 1.02301 m .37218 1.02306 L .35301 1.0129 L F
.35203 1.01108 m .35725 1.01414 L .34501 1.00866 L F
.35725 1.01414 m .35301 1.0129 L .34501 1.00866 L F
.35203 1.01108 m .34501 1.00866 L .28375 .97619 L F
.31019 .98659 m .36751 1.0242 L .37232 1.02296 L F
.38481 1.0207 m .39219 1.01849 L .39063 1.01814 L .335 0 .007 r
F
.37547 1.0248 m .38587 1.02087 L .38481 1.0207 L F
.38587 1.02087 m .39219 1.01849 L .38481 1.0207 L F
.39063 1.01814 m .39377 1.01789 L .3923 1.0174 L F
.39219 1.01849 m .39377 1.01789 L .39063 1.01814 L F
.46517 .98602 m .41513 1.02073 L .46484 .98614 L .726 .979 .917 r
F
.39377 1.01789 m .39779 1.01637 L .3923 1.0174 L .335 0 .007 r
F
.39269 1.02071 m .39271 1.02074 L .38479 1.02454 L F
.46535 .98589 m .39187 1.02242 L .38344 1.02304 L .726 .979 .917 r
F
.46535 .98589 m .38344 1.02304 L .45281 .9908 L F
.42834 1.00483 m .43716 1.0015 L .42501 1.00548 L .335 0 .007 r
F
.46333 1.00645 m .4632 1.0045 L .45864 1.01485 L 0 0 0 r
F
.4632 1.0045 m .46299 1.00142 L .46188 1.00485 L F
.4632 1.0045 m .46188 1.00485 L .45864 1.01485 L F
.46349 1.00887 m .46333 1.00645 L .45625 1.02223 L F
.46333 1.00645 m .45864 1.01485 L .45625 1.02223 L F
.49802 .97134 m .49795 .97166 L .48577 .97838 L .591 .948 .851 r
F
.49802 .97134 m .48577 .97838 L .4834 .97946 L F
.47144 .98487 m .49088 .97215 L .4983 .96991 L F
.47144 .98487 m .4983 .96991 L .49802 .97134 L F
.49768 .97299 m .49508 .9819 L .49511 .97416 L .849 .862 .852 r
F
.48577 .97838 m .49795 .97166 L .49727 .97438 L .715 .971 .931 r
F
.47144 .98487 m .49802 .97134 L .4834 .97946 L .591 .948 .851 r
F
.49654 .97731 m .49656 .97724 L .50161 .95952 L .797 .714 .772 r
F
.49649 .97747 m .4967 .97635 L .50161 .95952 L F
.49088 .97215 m .50021 .95051 L .4983 .96991 L .915 .784 .702 r
F
.50021 .95051 m .50333 .95363 L .4983 .96991 L F
.4983 .96991 m .51459 .91716 L .50454 .96803 L F
.50454 .96803 m .53023 .90504 L .52192 .96499 L .827 .699 .724 r
F
.49802 .97134 m .4983 .96991 L .50454 .96803 L .591 .948 .851 r
F
.49802 .97134 m .50454 .96803 L .49795 .97166 L F
.4973 .97484 m .49648 .97755 L .4973 .97481 L .797 .714 .772 r
F
.49648 .97755 m .49264 .99025 L .49649 .97747 L F
.49833 .97554 m .49955 .97505 L .4961 .98131 L F
.51338 .96951 m .52665 .96419 L .54269 .96146 L .717 .961 .944 r
F
.49955 .97505 m .5148 .96894 L .4961 .98131 L .797 .714 .772 r
F
.4961 .98131 m .5148 .96894 L .49264 .99025 L F
.49849 .97659 m .50454 .96803 L .52192 .96499 L .715 .971 .931 r
F
.49658 .97746 m .50454 .96803 L .49849 .97659 L F
.49795 .97166 m .50454 .96803 L .49647 .97759 L F
.49654 .97731 m .49649 .97747 L .49656 .97724 L .797 .714 .772 r
F
.49649 .97747 m .49264 .99025 L .4967 .97635 L F
.49849 .97659 m .52192 .96499 L .51338 .96951 L .715 .971 .931 r
F
.5003 .96583 m .50958 .98603 L .51582 .94797 L .785 .573 .614 r
F
.46821 1.01429 m .45625 1.02223 L .45864 1.02875 L .439 .15 .376 r
F
.49413 .97515 m .45931 1.01843 L .46821 1.01429 L F
.45931 1.01843 m .45625 1.02223 L .46821 1.01429 L F
.47815 1.00967 m .50958 .98603 L .46821 1.01429 L .864 .65 .611 r
F
.48085 1.00842 m .48514 1.00508 L .47815 1.00967 L F
.48514 1.00508 m .50958 .98603 L .47815 1.00967 L F
.52714 .94354 m .53314 .93956 L .52597 .95819 L .797 .714 .772 r
F
.54461 .90978 m .52987 .95444 L .52597 .95819 L F
.52192 .96499 m .53394 .94211 L .52665 .96419 L .78 .671 .743 r
F
.52192 .96499 m .53524 .93817 L .53394 .94211 L F
.52192 .96499 m .52714 .94354 L .53524 .93817 L F
.51482 .96882 m .51502 .96873 L .5148 .96894 L .797 .714 .772 r
F
.51338 .96951 m .52192 .96499 L .52665 .96419 L .717 .961 .944 r
F
.53023 .90504 m .528 .93285 L .52192 .96499 L .827 .699 .724 r
F
.52353 .9607 m .51482 .97797 L .52997 .97441 L .685 .415 .508 r
F
.49409 1.02509 m .50905 .99316 L .50958 .98603 L .851 .705 .7 r
F
.50905 .99316 m .50999 .99068 L .50958 .98603 L F
.51482 .97797 m .50905 .99316 L .52997 .97441 L .685 .415 .508 r
F
.53363 .97928 m .52781 .98746 L .53654 .98315 L .862 .644 .606 r
F
.52997 .97441 m .53654 .98315 L .53703 .98049 L F
.47815 1.05726 m .51156 1.0103 L .49409 1.02509 L .963 .919 .714 r
F
.51156 1.0103 m .52676 .98893 L .52468 .99123 L F
.51156 1.0103 m .52468 .99123 L .49409 1.02509 L F
.52612 1.00017 m .5127 1.02938 L .5324 .99258 L F
.48972 1.04414 m .49924 1.03802 L .52612 1.00017 L F
.49924 1.03802 m .5127 1.02938 L .52612 1.00017 L F
.47867 1.05806 m .5127 1.02938 L .48972 1.04414 L F
.53898 .98206 m .53479 .98881 L .55282 .98478 L .923 .957 .632 r
F
.53479 .98881 m .52911 1.01017 L .55282 .98478 L F
.55952 1.00457 m .57212 .99789 L .57611 .9895 L .865 .833 .813 r
F
.56689 1.00244 m .49848 1.06465 L .60316 .99195 L .827 .998 .78 r
F
.56689 1.00244 m .55113 1.01552 L .57212 .99789 L 0 0 0 r
F
.56116 1.00409 m .53837 1.02611 L .56689 1.00244 L .827 .998 .78 r
F
.53837 1.02611 m .49848 1.06465 L .56689 1.00244 L F
.56689 1.00244 m .57212 .99789 L .55952 1.00457 L 0 0 0 r
F
.54032 1.02201 m .49848 1.06465 L .57874 .98711 L .827 .998 .78 r
F
.49848 1.06465 m .48361 1.07359 L .52015 1.07616 L .383 0 0 r
F
.48361 1.07359 m .44641 1.09596 L .49034 1.08416 L F
.48361 1.07359 m .49034 1.08416 L .52015 1.07616 L F
.50657 1.05641 m .49006 1.06735 L .49848 1.06465 L .827 .998 .78 r
F
.4991 1.06039 m .49734 1.06161 L .49961 1.05879 L .553 .121 .174 r
F
.49657 1.06174 m .49006 1.06735 L .50657 1.05641 L .827 .998 .78 r
F
.54706 1.11325 m .423 1.11606 L .39595 1.18084 L .792 .842 .889 r
F
.52015 1.07616 m .423 1.11606 L .54706 1.11325 L .534 .924 .853 r
F
.44678 1.10629 m .44641 1.09596 L .423 1.11606 L F
.49027 1.08843 m .46355 1.09301 L .44678 1.10629 L F
.46355 1.09301 m .44641 1.09596 L .44678 1.10629 L F
.48789 1.08539 m .44641 1.09596 L .49027 1.08843 L F
.5099 1.07891 m .44641 1.09596 L .51371 1.07881 L F
.48438 1.08043 m .47753 1.09002 L .4829 1.07402 L .383 0 0 r
F
.47753 1.09002 m .47699 1.08942 L .4829 1.07402 L F
.47586 1.09235 m .47496 1.09037 L .4829 1.07402 L F
.4829 1.07402 m .47044 1.09967 L .44641 1.09596 L F
.47044 1.09967 m .47003 1.10052 L .46752 1.10003 L F
.47044 1.09967 m .46752 1.10003 L .44641 1.09596 L F
.47414 1.10113 m .46926 1.1019 L .47196 1.09948 L .553 .121 .174 r
F
.46926 1.1019 m .46671 1.1023 L .47003 1.10052 L F
.46926 1.1019 m .47003 1.10052 L .47196 1.09948 L F
.47586 1.09235 m .47003 1.10052 L .47496 1.09037 L .383 0 0 r
F
.49353 1.06763 m .48438 1.08043 L .4829 1.07402 L F
.47753 1.09002 m .47586 1.09235 L .47699 1.08942 L F
.49848 1.06465 m .49079 1.07435 L .49353 1.06763 L F
.49079 1.07435 m .48474 1.08197 L .49353 1.06763 L F
.48474 1.08197 m .47003 1.10052 L .48438 1.08043 L F
.48474 1.08197 m .48438 1.08043 L .49353 1.06763 L F
.48414 1.08658 m .48179 1.11403 L .47522 1.10304 L .695 .275 .246 r
F
.48816 1.06796 m .47003 1.10052 L .49848 1.06465 L F
.48306 1.08409 m .47048 1.0997 L .48345 1.07892 L .553 .121 .174 r
F
.48232 1.09393 m .47048 1.0997 L .48306 1.08409 L F
.47003 1.10052 m .46593 1.10272 L .44641 1.09596 L .383 0 0 r
F
.46789 1.10613 m .46749 1.10766 L .46467 1.10309 L .605 .249 .339 r
F
.46789 1.10613 m .46467 1.10309 L .4648 1.10305 L F
.46789 1.10613 m .4648 1.10305 L .46721 1.1057 L F
.48208 1.12024 m .46749 1.10766 L .46789 1.10613 L F
.49053 1.12864 m .48211 1.12098 L .48208 1.12024 L F
.48211 1.12098 m .46749 1.10766 L .48208 1.12024 L F
.48129 1.10326 m .48179 1.11403 L .48414 1.08658 L .516 .147 .278 r
F
.4808 1.10614 m .48179 1.11403 L .48129 1.10326 L F
.54706 1.11325 m .39595 1.18084 L .57781 1.17549 L .792 .842 .889 r
F
.53067 1.16857 m .51246 1.1653 L .49053 1.12864 L .605 .249 .339 r
F
.49053 1.12864 m .50193 1.16342 L .46749 1.10766 L F
.4813 1.11978 m .48011 1.13368 L .47134 1.1102 L .695 .275 .246 r
F
.48047 1.11928 m .48011 1.13368 L .4813 1.11978 L .516 .147 .278 r
F
.51246 1.1653 m .50193 1.16342 L .49053 1.12864 L .605 .249 .339 r
F
.48047 1.11928 m .48572 1.12489 L .48485 1.12625 L .516 .147 .278 r
F
.48047 1.11928 m .48485 1.12625 L .48035 1.12415 L F
.48572 1.12489 m .49972 1.13983 L .4869 1.13581 L F
.48572 1.12489 m .4869 1.13581 L .48011 1.13368 L F
.53067 1.16857 m .49053 1.12864 L .48034 1.11999 L .605 .249 .339 r
F
.54054 1.15216 m .53067 1.16857 L .50127 1.1402 L .395 .305 .635 r
F
.5003 1.1374 m .50127 1.1402 L .49721 1.13627 L F
.54054 1.15216 m .50127 1.1402 L .5003 1.1374 L F
.49782 1.13228 m .49721 1.13627 L .48865 1.12801 L F
.54054 1.15216 m .49721 1.13627 L .49782 1.13228 L F
.4648 1.10305 m .46494 1.10325 L .47134 1.1102 L .605 .249 .339 r
F
.46593 1.10272 m .45706 1.10536 L .44641 1.09596 L .383 0 0 r
F
.47048 1.0997 m .4644 1.10266 L .47888 1.08462 L .553 .121 .174 r
F
.46671 1.1023 m .4644 1.10266 L .48232 1.09393 L F
.47763 1.11625 m .46789 1.10613 L .47134 1.1102 L .605 .249 .339 r
F
.4813 1.11978 m .47346 1.1118 L .47763 1.11625 L F
.47346 1.1118 m .46789 1.10613 L .47763 1.11625 L F
.48208 1.12024 m .46789 1.10613 L .4813 1.11978 L F
.46789 1.10613 m .46721 1.1057 L .47134 1.1102 L F
.4648 1.10305 m .46467 1.10309 L .4644 1.10266 L F
.4648 1.10305 m .4644 1.10266 L .46494 1.10325 L F
.4648 1.10305 m .45855 1.10668 L .45706 1.10536 L .383 0 0 r
F
.46593 1.10272 m .46494 1.10325 L .4648 1.10305 L F
.46494 1.10325 m .45855 1.10668 L .4648 1.10305 L F
.47522 1.10304 m .4813 1.11978 L .47134 1.1102 L .695 .275 .246 r
F
.49053 1.12864 m .47134 1.1102 L .48034 1.11999 L .605 .249 .339 r
F
.47874 1.11825 m .4644 1.10266 L .47414 1.10113 L .553 .121 .174 r
F
.4808 1.10614 m .47414 1.10113 L .48186 1.09991 L F
.48179 1.11403 m .4813 1.11978 L .47522 1.10304 L .695 .275 .246 r
F
.47874 1.11825 m .47414 1.10113 L .4808 1.10614 L .553 .121 .174 r
F
.47003 1.10052 m .46766 1.1035 L .46889 1.10113 L .383 0 0 r
F
.46766 1.1035 m .46242 1.1101 L .46889 1.10113 L F
.46889 1.10113 m .46242 1.1101 L .45855 1.10668 L F
.46949 1.09998 m .46821 1.10244 L .46901 1.1018 L .695 .275 .246 r
F
.47067 1.09544 m .46821 1.10244 L .46949 1.09998 L F
.47067 1.09544 m .46551 1.10461 L .46821 1.10244 L F
.46551 1.10461 m .46636 1.10515 L .46901 1.1018 L F
.47048 1.0997 m .47888 1.08462 L .48345 1.07892 L .553 .121 .174 r
F
.48566 1.06876 m .47067 1.09544 L .47003 1.10052 L .695 .275 .246 r
F
.47067 1.09544 m .46901 1.1018 L .47003 1.10052 L F
.48566 1.06876 m .47003 1.10052 L .48816 1.06796 L F
.47414 1.10113 m .47196 1.09948 L .48232 1.09393 L .553 .121 .174 r
F
.51371 1.07881 m .48789 1.08539 L .49027 1.08843 L .534 .924 .853 r
F
.48778 1.09446 m .48345 1.07892 L .49734 1.06161 L .553 .121 .174 r
F
.4808 1.10614 m .48435 1.11216 L .48438 1.11253 L .516 .147 .278 r
F
.48373 1.10835 m .48345 1.07892 L .48778 1.09446 L .553 .121 .174 r
F
.48136 1.10656 m .48345 1.07892 L .48373 1.10835 L F
.48566 1.06876 m .48414 1.08658 L .46656 1.10562 L .695 .275 .246 r
F
.48186 1.09991 m .47645 1.10077 L .48232 1.09393 L .553 .121 .174 r
F
.48099 1.09836 m .4808 1.10614 L .48179 1.09946 L .516 .147 .278 r
F
.48099 1.09836 m .48197 1.09824 L .4825 1.09467 L F
.47645 1.10077 m .47414 1.10113 L .47818 1.09757 L .553 .121 .174 r
F
.48414 1.08658 m .46763 1.11705 L .46242 1.1101 L .695 .275 .246 r
F
.4808 1.10614 m .48414 1.08658 L .48473 1.07961 L .516 .147 .278 r
F
.48283 1.09814 m .48318 1.10137 L .48099 1.09836 L F
.47645 1.10077 m .47818 1.09757 L .48232 1.09393 L .553 .121 .174 r
F
.48566 1.06876 m .46656 1.10562 L .46551 1.10461 L .695 .275 .246 r
F
.47993 1.09776 m .48134 1.0844 L .47961 1.08031 L .553 .121 .174 r
F
.48134 1.0844 m .48224 1.07586 L .4807 1.07847 L F
.48134 1.0844 m .4807 1.07847 L .47961 1.08031 L F
.48311 1.07966 m .48407 1.08292 L .48473 1.07961 L .516 .147 .278 r
F
.48146 1.07971 m .48407 1.08292 L .48311 1.07966 L F
.48146 1.07971 m .48099 1.09836 L .48407 1.08292 L F
.49053 1.12864 m .48208 1.12024 L .4813 1.11978 L .605 .249 .339 r
F
.4808 1.10614 m .48047 1.11928 L .48179 1.11403 L .516 .147 .278 r
F
.48047 1.11928 m .4813 1.11978 L .48179 1.11403 L F
.4808 1.10614 m .49972 1.13983 L .48047 1.11928 L F
.48685 1.1107 m .50086 1.14019 L .4808 1.10614 L F
.48034 1.11999 m .49734 1.06161 L .4991 1.06039 L .553 .121 .174 r
F
.48395 1.10852 m .4874 1.09757 L .48283 1.09814 L F
.4879 1.09598 m .4991 1.06039 L .48433 1.0838 L F
.48099 1.09836 m .4825 1.09467 L .48473 1.07961 L .516 .147 .278 r
F
.48283 1.09814 m .48225 1.08709 L .48172 1.08792 L .553 .121 .174 r
F
.48253 1.07314 m .48241 1.07425 L .48566 1.06876 L .516 .147 .278 r
F
.48241 1.07425 m .48414 1.07185 L .48566 1.06876 L F
.48226 1.07569 m .48355 1.07426 L .48566 1.06876 L F
.48226 1.07569 m .48198 1.07834 L .48355 1.07426 L F
.48216 1.07785 m .48224 1.07586 L .48206 1.07755 L .553 .121 .174 r
F
.48198 1.07834 m .48473 1.07961 L .48536 1.07224 L .516 .147 .278 r
F
.48198 1.07834 m .48536 1.07224 L .48355 1.07426 L F
.48146 1.07971 m .48184 1.0797 L .48198 1.07834 L F
.48184 1.0797 m .48473 1.07961 L .48198 1.07834 L F
.48216 1.07785 m .48206 1.07755 L .48134 1.0844 L .553 .121 .174 r
F
.48172 1.08792 m .48216 1.07785 L .48134 1.0844 L F
.48172 1.08792 m .4991 1.06039 L .48224 1.07586 L F
.47961 1.08031 m .48224 1.07586 L .47957 1.07831 L F
.48224 1.07586 m .48226 1.07569 L .47957 1.07831 L F
.47957 1.07831 m .48058 1.07733 L .48115 1.07692 L 0 0 0 r
F
.48058 1.07733 m .48209 1.07585 L .48154 1.07649 L F
.48159 1.07446 m .48147 1.07913 L .48198 1.07834 L .516 .147 .278 r
F
.48159 1.07446 m .48169 1.07636 L .48154 1.07649 L F
.48097 1.07625 m .48181 1.07552 L .4817 1.07517 L 0 0 0 r
F
.48058 1.07733 m .48154 1.07649 L .48115 1.07692 L F
.48147 1.07913 m .48146 1.07971 L .48154 1.0795 L .516 .147 .278 r
F
.48147 1.07913 m .48154 1.0795 L .48198 1.07834 L F
.48154 1.07649 m .48283 1.09814 L .48134 1.0844 L F
.48169 1.07636 m .48283 1.09814 L .48154 1.07649 L F
.48209 1.07585 m .48226 1.07569 L .48208 1.07588 L 0 0 0 r
F
.48209 1.07585 m .48208 1.07588 L .48154 1.07649 L F
.48159 1.07446 m .48198 1.07834 L .48253 1.07314 L .516 .147 .278 r
F
.48169 1.07636 m .48833 1.09745 L .48283 1.09814 L F
.48205 1.07604 m .48833 1.09745 L .48169 1.07636 L F
.48189 1.07772 m .48294 1.07907 L .48205 1.07604 L 0 0 .384 r
F
.48189 1.07772 m .48205 1.07604 L .48183 1.07714 L F
.51016 1.05275 m .4991 1.06039 L .50657 1.05641 L .827 .998 .78 r
F
.52719 1.0354 m .4991 1.06039 L .51016 1.05275 L F
.48115 1.07692 m .55113 1.01552 L .48109 1.07698 L 0 0 0 r
F
.48159 1.07446 m .48205 1.07604 L .48169 1.07636 L .516 .147 .278 r
F
.48203 1.07617 m .48181 1.07552 L .48097 1.07625 L 0 0 0 r
F
.48115 1.07692 m .48197 1.07611 L .49575 1.06412 L F
.47336 1.08631 m .48138 1.07541 L .48034 1.0762 L .619 .823 .419 r
F
.4991 1.06039 m .49657 1.06174 L .48226 1.07569 L .553 .121 .174 r
F
.4991 1.06039 m .48226 1.07569 L .48224 1.07586 L F
.48226 1.07569 m .49657 1.06174 L .48115 1.07692 L 0 0 0 r
F
.48183 1.07714 m .48205 1.07604 L .48178 1.07511 L 0 0 .384 r
F
.48166 1.0752 m .48178 1.07511 L .48159 1.07446 L F
.47825 1.08001 m .48097 1.07625 L .4817 1.07517 L .619 .823 .419 r
F
.48165 1.07521 m .48166 1.0752 L .48164 1.07498 L 0 0 .384 r
F
.48178 1.07738 m .48164 1.07498 L .48162 1.07493 L F
.47825 1.08001 m .4817 1.07517 L .48138 1.07541 L .619 .823 .419 r
F
.48109 1.07698 m .48203 1.07617 L .48203 1.07617 L 0 0 0 r
F
.48006 1.07171 m .48178 1.07738 L .48162 1.07493 L 0 0 .384 r
F
.48355 1.07426 m .48536 1.07224 L .48566 1.06876 L .516 .147 .278 r
F
.54579 1.0144 m .48743 1.06714 L .49006 1.06735 L .827 .998 .78 r
F
.48743 1.06714 m .48657 1.06847 L .49006 1.06735 L F
.49731 1.06276 m .55113 1.01552 L .55978 1.00834 L 0 0 0 r
F
.49731 1.06276 m .55978 1.00834 L .56689 1.00244 L F
.49946 1.05926 m .49961 1.05879 L .49657 1.06174 L .553 .121 .174 r
F
.52719 1.0354 m .49657 1.06174 L .4991 1.06039 L .827 .998 .78 r
F
.49575 1.06412 m .49657 1.06174 L .55113 1.01552 L 0 0 0 r
F
.48197 1.07611 m .49657 1.06174 L .49575 1.06412 L F
.48241 1.07425 m .48226 1.07569 L .48414 1.07185 L .516 .147 .278 r
F
.49657 1.06174 m .49961 1.05879 L .51611 1.04493 L 0 0 0 r
F
.49657 1.06174 m .51611 1.04493 L .55113 1.01552 L F
.51423 1.03302 m .4898 1.06358 L .53545 1.023 L F
.4898 1.06358 m .48566 1.06876 L .48743 1.06714 L F
.4898 1.06358 m .48743 1.06714 L .53545 1.023 L F
.48743 1.06714 m .48566 1.06876 L .48657 1.06847 L .827 .998 .78 r
F
.4898 1.06358 m .48159 1.07446 L .48566 1.06876 L 0 0 0 r
F
.51423 1.03302 m .48607 1.06878 L .4898 1.06358 L F
.48607 1.06878 m .48159 1.07446 L .4898 1.06358 L F
.48897 1.06517 m .48572 1.06925 L .51423 1.03302 L F
.48572 1.06925 m .48159 1.07446 L .48607 1.06878 L F
.48572 1.06925 m .48607 1.06878 L .51423 1.03302 L F
.5127 1.02938 m .5132 1.02878 L .53515 .98746 L .865 .833 .813 r
F
.5132 1.02878 m .52911 1.01017 L .53491 .98834 L F
.5132 1.02878 m .53491 .98834 L .53515 .98746 L F
.46314 1.04102 m .4649 1.0442 L .46766 1.04852 L .613 .046 0 r
F
.47467 1.05755 m .47395 1.05897 L .47463 1.05794 L .685 .415 .508 r
F
.48118 1.03088 m .47709 1.05939 L .49409 1.02509 L .938 .694 .543 r
F
.47701 1.04797 m .47709 1.05939 L .48118 1.03088 L F
.46892 1.03304 m .49409 1.02509 L .48514 1.00508 L .864 .65 .611 r
F
.48118 1.03088 m .46645 1.0373 L .47467 1.05755 L .685 .415 .508 r
F
.47048 1.03277 m .46645 1.0373 L .48118 1.03088 L F
.46645 1.0373 m .46314 1.04102 L .46377 1.04192 L F
.46645 1.0373 m .46377 1.04192 L .47467 1.05755 L F
.46918 1.033 m .49409 1.02509 L .46892 1.03304 L .938 .694 .543 r
F
.48118 1.03088 m .48441 1.02943 L .46918 1.033 L F
.48441 1.02943 m .49409 1.02509 L .46918 1.033 L F
.48514 1.00508 m .49409 1.02509 L .50958 .98603 L .864 .65 .611 r
F
.46733 1.03343 m .46672 1.03342 L .46314 1.04102 L .439 .15 .376 r
F
.46733 1.03343 m .46314 1.04102 L .46918 1.033 L F
.49508 .99854 m .46918 1.033 L .50909 .98932 L .685 .415 .508 r
F
.46918 1.033 m .46314 1.04102 L .47048 1.03277 L F
.46918 1.033 m .47048 1.03277 L .50909 .98932 L F
.46821 1.01429 m .50958 .98603 L .5003 .96583 L .785 .573 .614 r
F
.49413 .97515 m .45864 1.02875 L .46031 1.03332 L .439 .15 .376 r
F
.46672 1.03342 m .46031 1.03332 L .46314 1.04102 L F
.49413 .97515 m .46031 1.03332 L .46672 1.03342 L F
.48118 1.03088 m .46892 1.03304 L .46768 1.03343 L .938 .694 .543 r
F
.45749 1.03747 m .4582 1.03643 L .45524 1.03737 L F
.45531 1.03808 m .45524 1.03737 L .43583 1.0435 L F
.45749 1.03747 m .45524 1.03737 L .45531 1.03808 L F
.47463 1.05794 m .47395 1.05897 L .47514 1.06145 L .862 .644 .606 r
F
.47467 1.05755 m .46314 1.04102 L .47382 1.05875 L .685 .415 .508 r
F
.47467 1.05755 m .47382 1.05875 L .47404 1.05879 L F
.4738 1.05875 m .47709 1.05939 L .4674 1.04673 L .938 .694 .543 r
F
.46314 1.04102 m .45551 1.04038 L .45751 1.043 L .613 .046 0 r
F
.46314 1.04102 m .45751 1.043 L .46602 1.04621 L F
.46031 1.03332 m .4582 1.03643 L .46314 1.04102 L .352 0 0 r
F
.4582 1.03643 m .45551 1.04038 L .46273 1.04099 L F
.4582 1.03643 m .46273 1.04099 L .46314 1.04102 L F
.43583 1.0435 m .4582 1.03643 L .4524 1.03059 L .864 .65 .611 r
F
.47485 1.05895 m .47514 1.06145 L .47564 1.06249 L .862 .644 .606 r
F
.47463 1.05794 m .47477 1.05894 L .47485 1.05895 L F
.47477 1.05894 m .47514 1.06145 L .47485 1.05895 L F
.47103 1.05412 m .47156 1.05514 L .47381 1.05875 L .613 .046 0 r
F
.47382 1.05875 m .47381 1.05875 L .47395 1.05897 L F
.47103 1.05412 m .47381 1.05875 L .47382 1.05875 L F
.44868 1.05393 m .47367 1.05873 L .43553 1.05135 L .951 .614 .21 r
F
.47367 1.05873 m .476 1.05918 L .47376 1.05874 L F
.47367 1.05873 m .47376 1.05874 L .43553 1.05135 L F
.48164 1.07506 m .4817 1.07517 L .48293 1.07335 L .619 .823 .419 r
F
.48138 1.07541 m .48157 1.07527 L .48164 1.07506 L F
.48157 1.07527 m .4817 1.07517 L .48164 1.07506 L F
.47686 1.06001 m .47485 1.05895 L .47537 1.06128 L .862 .644 .606 r
F
.47698 1.06031 m .47537 1.06128 L .47564 1.06249 L F
.4775 1.05947 m .47537 1.06128 L .47698 1.06031 L F
.50191 1.04164 m .48095 1.07035 L .48262 1.07279 L .923 .957 .632 r
F
.49379 1.0506 m .48095 1.07034 L .49393 1.05054 L .862 .644 .606 r
F
.49393 1.05053 m .4948 1.04957 L .4899 1.05252 L .619 .823 .419 r
F
.48095 1.07034 m .48095 1.07035 L .49393 1.05053 L .862 .644 .606 r
F
.4954 1.04435 m .5127 1.02938 L .49446 1.04474 L .619 .823 .419 r
F
.50191 1.04164 m .48159 1.07446 L .502 1.0416 L .923 .957 .632 r
F
.49415 1.05029 m .48095 1.07035 L .50191 1.04164 L F
.50178 1.04169 m .5127 1.02938 L .4954 1.04435 L .619 .823 .419 r
F
.5215 1.02383 m .55428 1.00734 L .56416 .99696 L .865 .833 .813 r
F
.5127 1.02938 m .52024 1.02538 L .5215 1.02383 L F
.52024 1.02538 m .55428 1.00734 L .5215 1.02383 L F
.54579 1.0144 m .49006 1.06735 L .55661 1.00541 L .827 .998 .78 r
F
.53545 1.023 m .48743 1.06714 L .54579 1.0144 L F
.48805 1.06579 m .55021 1.01073 L .49331 1.05802 L 0 0 0 r
F
.50093 1.05708 m .55021 1.01073 L .48805 1.06579 L F
.51534 1.03162 m .55021 1.01073 L .51993 1.02578 L F
.49331 1.05802 m .53545 1.023 L .50834 1.03581 L F
.53545 1.023 m .55021 1.01073 L .50834 1.03581 L F
.55661 1.00541 m .55235 1.00938 L .54032 1.02201 L .827 .998 .78 r
F
.55235 1.00938 m .49006 1.06735 L .54032 1.02201 L F
.57524 .98642 m .54032 1.02201 L .57874 .98711 L F
.56689 1.00244 m .55952 1.00457 L .5127 1.02938 L 0 0 0 r
F
.57524 .98642 m .56434 .99678 L .55661 1.00541 L .827 .998 .78 r
F
.5127 1.02938 m .56416 .99696 L .56622 .9948 L .865 .833 .813 r
F
.56434 .99678 m .54579 1.0144 L .55428 1.00734 L .827 .998 .78 r
F
.56434 .99678 m .55428 1.00734 L .55661 1.00541 L F
.56434 .99678 m .53545 1.023 L .54579 1.0144 L F
.57524 .98642 m .56691 .99408 L .56434 .99678 L F
.5127 1.02938 m .57115 .99162 L .51922 1.02175 L .865 .833 .813 r
F
.56691 .99408 m .53545 1.023 L .56434 .99678 L .827 .998 .78 r
F
.55282 .98478 m .52675 1.01738 L .57524 .98642 L 0 0 0 r
F
.52675 1.01738 m .55987 .99816 L .57524 .98642 L F
.55282 .98478 m .53456 1.00776 L .52675 1.01738 L F
.51423 1.03302 m .53545 1.023 L .56691 .99408 L F
.55987 .99816 m .56691 .99408 L .57524 .98642 L F
.51423 1.03302 m .56691 .99408 L .55987 .99816 L F
.52911 1.01017 m .53456 1.00776 L .55282 .98478 L .923 .957 .632 r
F
.62296 .90563 m .71227 .77959 L .71386 .7626 L 0 0 .167 r
F
.6197 .92152 m .71227 .77959 L .62296 .90563 L .69 .882 .501 r
F
.58792 .9475 m .6702 .82323 L .60707 .93584 L .827 .822 .844 r
F
.58792 .9475 m .63799 .84193 L .6702 .82323 L F
.56546 .95595 m .63799 .84193 L .58792 .9475 L .779 .728 .806 r
F
.59759 .93001 m .58527 .96473 L .61297 .912 L .865 .833 .813 r
F
.59202 .93209 m .61297 .912 L .5863 .93423 L F
.56546 .95595 m .6042 .85516 L .63799 .84193 L .779 .728 .806 r
F
.54269 .96146 m .6042 .85516 L .56546 .95595 L .765 .681 .77 r
F
.5863 .93423 m .61297 .912 L .59807 .87343 L .743 .672 .782 r
F
.58934 .93309 m .57524 .98642 L .58605 .96208 L .782 .709 .783 r
F
.59727 .86316 m .58445 .93492 L .58934 .93309 L F
.58445 .93492 m .57524 .98642 L .58934 .93309 L F
.58934 .93309 m .58605 .96208 L .59759 .93001 L F
.512 1.03039 m .5127 1.02938 L .4948 1.04957 L .619 .823 .419 r
F
.49409 1.02509 m .52468 .99123 L .50841 .99452 L .851 .705 .7 r
F
.52468 .99123 m .52676 .98893 L .52174 .99046 L F
.52468 .99123 m .52174 .99046 L .50841 .99452 L F
.47642 1.05655 m .47709 1.05939 L .47706 1.05556 L .938 .694 .543 r
F
.47642 1.05655 m .47706 1.05556 L .47689 1.0328 L F
.47521 1.05149 m .47642 1.05655 L .47689 1.0328 L F
.47431 1.05576 m .47709 1.05939 L .47135 1.03529 L F
.52997 .97441 m .51969 .98992 L .51983 .98996 L .862 .644 .606 r
F
.50841 .99452 m .52049 .99013 L .50905 .99316 L .851 .705 .7 r
F
.52997 .97441 m .51983 .98996 L .5203 .99008 L .862 .644 .606 r
F
.52049 .99013 m .51969 .98992 L .50905 .99316 L .851 .705 .7 r
F
.4948 1.04957 m .50178 1.04169 L .48247 1.05618 L .619 .823 .419 r
F
.4899 1.05252 m .48247 1.05618 L .47696 1.06032 L F
.4948 1.04957 m .48247 1.05618 L .4899 1.05252 L F
.52174 .99046 m .50648 1.02021 L .53087 .98768 L .862 .644 .606 r
F
.53165 .98744 m .5024 1.02816 L .53569 .98621 L F
.51156 1.0103 m .48535 1.04838 L .5024 1.02816 L F
.5024 1.02816 m .5324 .99258 L .53607 .98574 L .963 .919 .714 r
F
.53757 .98405 m .53491 .98834 L .53898 .98206 L .923 .957 .632 r
F
.47709 1.05939 m .5324 .99258 L .48535 1.04838 L .963 .919 .714 r
F
.53491 .98834 m .50191 1.04164 L .53479 .98879 L .923 .957 .632 r
F
.53491 .98834 m .53479 .98879 L .53898 .98206 L F
.502 1.0416 m .4862 1.06704 L .48757 1.06611 L F
.502 1.0416 m .48572 1.06925 L .50516 1.04028 L F
.50156 1.0455 m .50516 1.04028 L .4948 1.04957 L .619 .823 .419 r
F
.50516 1.04028 m .512 1.03039 L .50191 1.04164 L F
.50516 1.04028 m .50191 1.04164 L .4948 1.04957 L F
.50191 1.04164 m .502 1.0416 L .53898 .98206 L .923 .957 .632 r
F
.53882 .98203 m .53594 .98642 L .53491 .98834 L F
.53515 .98746 m .53226 1.00648 L .53607 .98574 L .865 .833 .813 r
F
.53654 .98315 m .53617 .98606 L .53882 .98203 L .862 .644 .606 r
F
.52174 .99046 m .536 .98612 L .53654 .98315 L F
.536 .98612 m .53617 .98606 L .53654 .98315 L F
.54013 .9777 m .53882 .98203 L .53898 .98206 L .783 .681 .752 r
F
.54075 .97699 m .55474 .96105 L .54541 .9683 L .865 .833 .813 r
F
.54238 .97234 m .54226 .97268 L .54541 .9683 L .963 .919 .714 r
F
.54131 .97323 m .5399 .97797 L .54013 .9777 L .783 .681 .752 r
F
.54111 .9734 m .5399 .97797 L .54131 .97323 L F
.54238 .97234 m .54541 .9683 L .54049 .97374 L .963 .919 .714 r
F
.53947 .9743 m .53913 .97832 L .54047 .97498 L .731 .611 .724 r
F
.53947 .9743 m .54047 .97498 L .54049 .97374 L F
.54049 .97374 m .54047 .97498 L .54111 .9734 L F
.53913 .97832 m .5399 .97797 L .54111 .9734 L F
.54049 .97374 m .54541 .9683 L .54052 .97164 L .851 .705 .7 r
F
.54238 .97234 m .54049 .97374 L .54111 .9734 L .963 .919 .714 r
F
.53524 .93817 m .54845 .91156 L .53394 .94211 L .78 .671 .743 r
F
.54845 .91156 m .55476 .92521 L .54461 .90978 L .711 .597 .727 r
F
.54893 .91179 m .55689 .92845 L .55476 .92521 L F
.54962 .91211 m .55689 .92845 L .54893 .91179 L F
.54845 .91156 m .54579 .8669 L .57259 .86293 L .78 .671 .743 r
F
.55244 .91342 m .55689 .92845 L .54973 .91216 L .711 .597 .727 r
F
.54461 .90978 m .55689 .92845 L .52987 .95444 L .797 .714 .772 r
F
.54973 .91216 m .55689 .92845 L .54962 .91211 L .711 .597 .727 r
F
.54968 .91214 m .57259 .86293 L .56858 .87614 L .78 .671 .743 r
F
.54845 .91156 m .57259 .86293 L .54968 .91214 L F
.55803 .84689 m .57109 .85662 L .57259 .86293 L .599 .432 .627 r
F
.54579 .8669 m .54764 .83915 L .57259 .86293 L F
.54764 .83915 m .55803 .84689 L .57259 .86293 L F
.57173 .85795 m .5542 .92436 L .56383 .91094 L .783 .681 .752 r
F
.54541 .9683 m .54986 .94982 L .55091 .90382 L .743 .672 .782 r
F
.54986 .94982 m .55437 .9234 L .55091 .90382 L F
.56325 .85544 m .56022 .87867 L .57173 .85795 L .731 .611 .724 r
F
.56022 .87867 m .55507 .91802 L .56629 .87755 L F
.56022 .87867 m .56629 .87755 L .57173 .85795 L F
.54143 .89638 m .54579 .8669 L .54845 .91156 L .78 .671 .743 r
F
.53588 .89121 m .54579 .8669 L .53959 .8924 L .827 .699 .724 r
F
.55091 .90382 m .55619 .88956 L .54099 .88222 L .635 .606 .803 r
F
.55619 .88956 m .56022 .87867 L .54727 .88106 L F
.55619 .88956 m .54727 .88106 L .54099 .88222 L F
.54845 .91156 m .54606 .91046 L .54223 .90322 L .711 .597 .727 r
F
.5412 .92454 m .54541 .9683 L .55091 .90382 L .851 .705 .7 r
F
.54101 .93808 m .54541 .9683 L .5412 .92454 L F
.54112 .97123 m .54541 .9683 L .54101 .93808 L F
.5407 .95963 m .54101 .93808 L .53955 .92807 L F
.54112 .97123 m .54101 .93808 L .5407 .95963 L F
.53947 .9743 m .54049 .97374 L .54054 .97043 L .731 .611 .724 r
F
.5407 .95963 m .53947 .9743 L .54054 .97043 L F
.5407 .95963 m .52997 .97441 L .53882 .98203 L F
.53955 .92807 m .52997 .97441 L .5407 .95963 L F
.52993 .94524 m .52353 .9607 L .52997 .97441 L .58 .472 .695 r
F
.54223 .90322 m .54461 .90978 L .52564 .88094 L .711 .597 .727 r
F
.53588 .89121 m .52647 .87171 L .54579 .8669 L .827 .699 .724 r
F
.52647 .87171 m .52538 .86946 L .52872 .86904 L F
.52647 .87171 m .52872 .86904 L .54579 .8669 L F
.52574 .87206 m .52538 .86946 L .53588 .89121 L F
.5259 .87238 m .54223 .90322 L .52564 .88094 L .711 .597 .727 r
F
.53146 .88979 m .53023 .90504 L .52852 .9039 L .797 .714 .772 r
F
.53146 .88979 m .53314 .93956 L .52714 .94354 L F
.52843 .86795 m .52852 .86625 L .52872 .86904 L .667 .445 .573 r
F
.52547 .85649 m .52852 .86625 L .52843 .86795 L F
.52547 .85649 m .52569 .8251 L .52852 .86625 L F
.52872 .86904 m .5276 .85281 L .54579 .8669 L F
.51655 .82193 m .5263 .85968 L .52607 .86696 L .692 .491 .611 r
F
.51655 .82193 m .52607 .86696 L .52425 .86346 L F
.52538 .86946 m .52547 .85649 L .52872 .86904 L .667 .445 .573 r
F
.55437 .9234 m .56022 .87867 L .55091 .90382 L .743 .672 .782 r
F
.54975 .85145 m .54623 .89354 L .55384 .90262 L .731 .611 .724 r
F
.52727 .82848 m .53028 .83865 L .5263 .85968 L .711 .597 .727 r
F
.51655 .82193 m .52727 .82848 L .5263 .85968 L .692 .491 .611 r
F
.55091 .90382 m .54099 .88222 L .52642 .85088 L .635 .606 .803 r
F
.5412 .92454 m .55091 .90382 L .53567 .93414 L .851 .705 .7 r
F
.54606 .91046 m .54461 .90978 L .54223 .90322 L .711 .597 .727 r
F
.52327 .87664 m .52439 .87418 L .52377 .87709 L .915 .784 .702 r
F
.52333 .87673 m .52564 .88094 L .52234 .8758 L .692 .491 .611 r
F
.52333 .87673 m .52234 .8758 L .52304 .87643 L F
.52327 .87664 m .52333 .87673 L .52322 .87659 L F
.52327 .87664 m .52538 .86946 L .52439 .87418 L .915 .784 .702 r
F
.52377 .87709 m .52439 .87418 L .52532 .87911 L .827 .699 .724 r
F
.52289 .87594 m .52456 .87396 L .52564 .88094 L .692 .491 .611 r
F
.52304 .87643 m .52538 .86946 L .52327 .87664 L .915 .784 .702 r
F
.52304 .87643 m .5221 .87542 L .52528 .86976 L F
.52528 .86976 m .51231 .8731 L .52538 .86946 L F
.52564 .88094 m .52035 .89847 L .50967 .93188 L .797 .714 .772 r
F
.52439 .87418 m .52509 .87084 L .52541 .87296 L .827 .699 .724 r
F
.52509 .87084 m .52538 .86946 L .52574 .87206 L F
.52083 .87073 m .51702 .84956 L .52538 .86946 L .764 .478 .501 r
F
.51702 .84956 m .52177 .85869 L .52538 .86946 L F
.52456 .87396 m .5259 .87238 L .52564 .88094 L .692 .491 .611 r
F
.52177 .85869 m .52217 .85845 L .5224 .85989 L F
.52538 .86946 m .52177 .85869 L .52547 .85649 L .667 .445 .573 r
F
.46633 .99048 m .47157 .9885 L .46634 .99041 L .335 0 .007 r
F
.47437 .98481 m .47157 .9885 L .47515 .9845 L F
.3923 1.0174 m .47114 .98866 L .47342 .98519 L F
.43716 1.0015 m .46633 .99048 L .43519 1.00177 L F
.46633 .99048 m .46634 .99041 L .43519 1.00177 L F
.43716 1.0015 m .43519 1.00177 L .42501 1.00548 L F
.39779 1.01637 m .42834 1.00483 L .40745 1.01188 L F
.42834 1.00483 m .42501 1.00548 L .40745 1.01188 L F
.39779 1.01637 m .40745 1.01188 L .3923 1.0174 L F
.36751 1.0242 m .39779 1.01637 L .37547 1.0248 L .565 .163 .238 r
F
.3923 1.0174 m .41476 1.00848 L .45245 .99097 L .335 0 .007 r
F
.3899 1.01189 m .39677 1.01385 L .39249 1.01257 L .68 .155 0 r
F
.45281 .9908 m .38344 1.02304 L .36751 1.0242 L .726 .979 .917 r
F
.41476 1.00848 m .47515 .9845 L .45245 .99097 L .335 0 .007 r
F
.36751 1.0242 m .46674 .99016 L .39779 1.01637 L .565 .163 .238 r
F
.46674 .99016 m .46633 .99048 L .39779 1.01637 L F
.38123 1.02095 m .4535 1.01632 L .46299 1.00142 L .677 .294 .313 r
F
.46299 1.00142 m .3808 1.02103 L .38197 1.02075 L 0 0 0 r
F
.40182 1.01605 m .38197 1.02075 L .39537 1.01759 L F
.44784 1.00505 m .43853 1.00727 L .40182 1.01605 L F
.39599 1.01745 m .4535 1.01632 L .38123 1.02095 L .746 .346 .294 r
F
.37959 1.02137 m .44352 1.03116 L .39599 1.01745 L F
.39599 1.01745 m .44352 1.03116 L .4535 1.01632 L F
.45589 1.01235 m .40445 1.01877 L .44945 1.02225 L 0 0 0 r
F
.42681 1.01007 m .38197 1.02075 L .40182 1.01605 L F
.43306 1.00857 m .38197 1.02075 L .42681 1.01007 L F
.44784 1.00505 m .39537 1.01759 L .40596 1.01508 L F
.46299 1.00142 m .38197 1.02075 L .44784 1.00505 L F
.3808 1.02103 m .36751 1.0242 L .40117 1.01623 L F
.47114 .98866 m .47157 .9885 L .47342 .98519 L .335 0 .007 r
F
.46674 .99016 m .47157 .9885 L .46633 .99048 L .565 .163 .238 r
F
.37861 1.02039 m .46299 1.00142 L .47157 .9885 L F
.36751 1.0242 m .3808 1.02103 L .37861 1.02039 L F
.3808 1.02103 m .46299 1.00142 L .37861 1.02039 L F
.37738 1.01985 m .37897 1.01971 L .36751 1.0242 L .726 .979 .917 r
F
.46999 .98326 m .47515 .9845 L .48033 .97872 L .335 0 .007 r
F
.47317 .98361 m .47351 .9826 L .47877 .97717 L .127 0 .358 r
F
.44274 .99106 m .37897 1.01971 L .37738 1.01985 L .726 .979 .917 r
F
.47294 .97776 m .44185 .99164 L .44274 .99106 L F
.44185 .99164 m .37897 1.01971 L .44274 .99106 L F
.47294 .97776 m .46443 .98625 L .37897 1.01971 L F
.47792 .97557 m .46443 .98625 L .47294 .97776 L F
.47833 .9758 m .46535 .98589 L .47792 .97557 L F
.4792 .97628 m .47858 .97672 L .47833 .9758 L F
.47858 .97672 m .46535 .98589 L .47833 .9758 L F
.47792 .97557 m .47499 .97686 L .47485 .9775 L F
.47499 .97686 m .38793 1.01521 L .47485 .9775 L F
.45245 .99097 m .46999 .98326 L .46075 .98774 L .335 0 .007 r
F
.47485 .9775 m .38793 1.01521 L .38945 1.01493 L .726 .979 .917 r
F
.46535 .98589 m .46517 .98602 L .46484 .98614 L F
.46999 .98326 m .4655 .98583 L .46484 .98614 L .335 0 .007 r
F
.46999 .98326 m .46484 .98614 L .46075 .98774 L F
.45245 .99097 m .47515 .9845 L .46999 .98326 L F
.46718 .98232 m .38945 1.01493 L .42594 1.00823 L .726 .979 .917 r
F
.47485 .9775 m .38945 1.01493 L .46718 .98232 L F
.47792 .97557 m .46793 .98378 L .46703 .9842 L F
.47351 .9826 m .42594 1.00823 L .47264 .98397 L F
.47792 .97557 m .47304 .97863 L .47351 .9826 L F
.47304 .97863 m .42594 1.00823 L .47351 .9826 L F
.47351 .9826 m .47657 .975 L .47762 .97604 L .127 0 .358 r
F
.47614 .97458 m .48075 .97715 L .48033 .97872 L F
.47351 .9826 m .47714 .97357 L .47614 .97458 L F
.47317 .98361 m .47352 .98273 L .47351 .9826 L F
.47351 .9826 m .47762 .97604 L .47877 .97717 L F
.47317 .98361 m .47877 .97717 L .47682 .98111 L F
.47342 .98519 m .47157 .9885 L .47437 .98481 L .335 0 .007 r
F
.47157 .9885 m .47317 .98361 L .48033 .97872 L .127 0 .358 r
F
.47157 .9885 m .47353 .9835 L .47317 .98361 L F
.47356 .98311 m .46152 1.00169 L .46299 1.00142 L .726 .979 .917 r
F
.47792 .97557 m .47351 .9826 L .47356 .98311 L F
.47359 .98334 m .47352 .98273 L .47317 .98361 L .127 0 .358 r
F
.47351 .9826 m .46152 1.00169 L .47356 .98311 L .726 .979 .917 r
F
.47353 .9835 m .47359 .98334 L .47317 .98361 L .127 0 .358 r
F
.48426 .97278 m .4792 .97628 L .47792 .97557 L .726 .979 .917 r
F
.47823 .97543 m .47792 .97557 L .46299 1.00142 L F
.46714 .99434 m .47359 .98334 L .47157 .9885 L .538 .333 .551 r
F
.50307 .90558 m .49862 .92148 L .49216 .93597 L .981 .91 .65 r
F
.47359 .98334 m .50047 .91476 L .47352 .98273 L .127 0 .358 r
F
.50047 .91476 m .50859 .89405 L .50035 .91488 L F
.50047 .91476 m .50035 .91488 L .47352 .98273 L F
.47264 .98397 m .42594 1.00823 L .46152 1.00169 L .726 .979 .917 r
F
.49595 .92542 m .50307 .90558 L .49455 .91841 L .127 0 .358 r
F
.47714 .97357 m .50859 .89405 L .47614 .97458 L F
.50307 .90558 m .49216 .93597 L .46299 1.00142 L .981 .91 .65 r
F
.47659 .96939 m .49966 .91509 L .49216 .93597 L .538 .333 .551 r
F
.49595 .92542 m .5053 .90223 L .50307 .90558 L .127 0 .358 r
F
.49966 .91509 m .50177 .91012 L .49216 .93597 L .538 .333 .551 r
F
.50177 .91012 m .50314 .90688 L .50047 .91476 L F
.50314 .90688 m .50859 .89405 L .5024 .90985 L F
.50314 .90688 m .5024 .90985 L .50047 .91476 L F
.50177 .91012 m .50047 .91476 L .49216 .93597 L F
.46299 1.00142 m .46473 .99753 L .47157 .9885 L F
.47682 .98111 m .47877 .97717 L .48033 .97872 L .127 0 .358 r
F
.48426 .97278 m .47823 .97543 L .46299 1.00142 L .726 .979 .917 r
F
.47685 .97033 m .49216 .93597 L .4776 .97311 L .538 .333 .551 r
F
.47352 .98273 m .47714 .97357 L .47351 .9826 L .127 0 .358 r
F
.46454 .99777 m .47659 .96939 L .47359 .98334 L .538 .333 .551 r
F
.47659 .96939 m .4776 .97311 L .47359 .98334 L F
.46454 .99777 m .47359 .98334 L .46714 .99434 L F
.49216 .93597 m .47398 .98663 L .46299 1.00142 L .981 .91 .65 r
F
.49216 .93597 m .48426 .97278 L .47398 .98663 L F
.49862 .92148 m .48426 .97278 L .49216 .93597 L F
.47659 .96939 m .49216 .93597 L .47685 .97033 L .538 .333 .551 r
F
.4933 .93006 m .51355 .91641 L .50859 .89405 L F
.49984 .9312 m .51355 .91641 L .4933 .93006 L F
.49779 .94257 m .51355 .91641 L .48688 .94517 L F
.50585 .88872 m .49839 .90311 L .50697 .89166 L .891 .724 .667 r
F
.50684 .89171 m .50307 .90558 L .50139 .9096 L .981 .91 .65 r
F
.50725 .8914 m .50713 .89109 L .50644 .88981 L 0 0 .408 r
F
.5073 .89153 m .50644 .88981 L .50585 .88872 L F
.50859 .89405 m .50725 .8914 L .5073 .89153 L F
.50725 .8914 m .50644 .88981 L .5073 .89153 L F
.49579 .86909 m .49494 .86744 L .50383 .87657 L F
.49494 .86743 m .4999 .87018 L .50383 .87657 L F
.50786 .88774 m .503 .87349 L .50701 .88039 L F
.50859 .89405 m .503 .87349 L .50786 .88774 L F
.49856 .86944 m .50697 .89166 L .50714 .89105 L .891 .724 .667 r
F
.50445 .88042 m .50714 .89105 L .50817 .88736 L F
.49856 .86944 m .50714 .89105 L .50445 .88042 L F
.51355 .91641 m .51352 .91631 L .50859 .89405 L .325 .323 .703 r
F
.50662 .89127 m .50139 .9096 L .50214 .9026 L .981 .91 .65 r
F
.50671 .89123 m .50139 .9096 L .50662 .89127 L F
.50644 .88981 m .50232 .88137 L .50273 .88248 L 0 0 .408 r
F
.50232 .88137 m .49835 .87325 L .50273 .88248 L F
.50323 .88384 m .49839 .90311 L .50585 .88872 L .891 .724 .667 r
F
.50716 .89115 m .49835 .87325 L .50644 .88981 L 0 0 .408 r
F
.50292 .883 m .49472 .86668 L .49579 .86909 L F
.50585 .88872 m .50279 .88266 L .50292 .883 L F
.50279 .88266 m .49472 .86668 L .50292 .883 L F
.50644 .88981 m .49472 .86668 L .50585 .88872 L F
.49853 .8751 m .49288 .91046 L .49839 .90311 L .891 .724 .667 r
F
.49793 .87398 m .49288 .91046 L .49853 .8751 L F
.49579 .86909 m .48415 .84601 L .47656 .83154 L 0 0 .408 r
F
.47603 .83176 m .47656 .83154 L .47738 .83311 L .759 .44 .445 r
F
.47656 .83154 m .49028 .82572 L .47738 .83311 L F
.47738 .83311 m .50043 .85597 L .47506 .82767 L F
.4716 .81958 m .46514 .80848 L .4685 .80977 L .884 .508 .322 r
F
.49498 .86657 m .49596 .86466 L .49754 .8706 L .847 .538 .465 r
F
.47558 .8289 m .4721 .8212 L .46256 .80319 L 0 0 .408 r
F
.47024 .81643 m .46507 .80566 L .47558 .8289 L F
.47738 .83311 m .46256 .80319 L .47456 .82772 L F
.47593 .82972 m .46256 .80319 L .47738 .83311 L F
.42608 .79964 m .43562 .79949 L .46139 .80205 L 0 .521 .831 r
F
.44763 .80062 m .45289 .80196 L .43376 .78981 L .653 .302 .365 r
F
.46029 .80444 m .45324 .80383 L .44894 .80155 L 0 .521 .831 r
F
.45851 .80465 m .45324 .80383 L .46029 .80444 L F
.47058 .81818 m .46507 .80566 L .46347 .80408 L 0 0 .408 r
F
.4721 .8212 m .46964 .81577 L .47058 .81818 L F
.46964 .81577 m .46507 .80566 L .47058 .81818 L F
.45085 .80059 m .45096 .80062 L .44936 .79875 L .759 .44 .445 r
F
.45259 .80198 m .44923 .80149 L .45024 .80128 L 0 .521 .831 r
F
.4721 .8212 m .46347 .80408 L .46256 .80319 L 0 0 .408 r
F
.47558 .8289 m .46256 .80319 L .47593 .82972 L F
.46507 .80566 m .45136 .80206 L .45259 .80198 L 0 .521 .831 r
F
.45136 .80206 m .44923 .80149 L .45259 .80198 L F
.4426 .79928 m .44285 .79938 L .44277 .79938 L .653 .302 .365 r
F
.4426 .79928 m .44277 .79938 L .44763 .80062 L F
.46507 .80566 m .45024 .80128 L .46426 .80486 L 0 .521 .831 r
F
.44763 .80062 m .4138 .79711 L .43406 .79702 L .217 0 0 r
F
.43376 .78981 m .45289 .80196 L .44641 .80236 L .759 .44 .445 r
F
.45153 .80143 m .45372 .80387 L .45096 .80062 L F
.45372 .80387 m .45395 .80389 L .44936 .79875 L F
.45851 .80465 m .45585 .80404 L .45356 .80388 L 0 .521 .831 r
F
.45585 .80404 m .45349 .80385 L .45356 .80388 L F
.47456 .82772 m .47656 .83154 L .47603 .83176 L .759 .44 .445 r
F
.36488 .85304 m .46011 .81529 L .43608 .80286 L .82 .851 .871 r
F
.3803 .87371 m .46011 .81529 L .36488 .85304 L .809 .74 .788 r
F
.44743 .80337 m .46706 .81341 L .47603 .83176 L .759 .44 .445 r
F
.44905 .80386 m .46706 .81341 L .44743 .80337 L F
.46706 .81341 m .47456 .82772 L .47603 .83176 L F
.47738 .83311 m .47506 .82767 L .45372 .80387 L F
.45351 .80385 m .45372 .80387 L .45153 .80143 L F
.47506 .82767 m .50043 .85597 L .47495 .82742 L F
.49472 .86668 m .47558 .8289 L .49579 .86909 L 0 0 .408 r
F
.47558 .8289 m .47593 .82972 L .49579 .86909 L F
.47738 .83311 m .45372 .80387 L .45351 .80385 L .759 .44 .445 r
F
.47603 .83176 m .47738 .83311 L .45351 .80385 L F
.47603 .83176 m .45351 .80385 L .45349 .80385 L F
.45372 .80387 m .47506 .82767 L .45395 .80389 L F
.47506 .82767 m .47495 .82742 L .45395 .80389 L F
.48725 .85194 m .48056 .83797 L .47558 .8289 L 0 0 .408 r
F
.49617 .86312 m .48377 .84134 L .49507 .86019 L F
.45701 .80413 m .45585 .80404 L .45851 .80465 L 0 .521 .831 r
F
.46426 .80486 m .45289 .80196 L .46139 .80205 L F
.44585 .79439 m .45428 .80392 L .45026 .79607 L .759 .44 .445 r
F
.47238 .82346 m .46479 .80781 L .46504 .80915 L 0 0 .408 r
F
.45428 .80392 m .50043 .85597 L .45701 .80413 L .759 .44 .445 r
F
.45428 .80392 m .45701 .80413 L .45026 .79607 L F
.46507 .80566 m .45851 .80465 L .46029 .80444 L 0 .521 .831 r
F
.46507 .80566 m .45725 .80415 L .45851 .80465 L F
.45725 .80415 m .45683 .80407 L .45701 .80413 L F
.45725 .80415 m .45701 .80413 L .45851 .80465 L F
.44936 .79875 m .45395 .80389 L .44585 .79439 L .759 .44 .445 r
F
.45395 .80389 m .50043 .85597 L .45428 .80392 L F
.45395 .80389 m .45428 .80392 L .44585 .79439 L F
.43376 .78981 m .44641 .80236 L .44524 .79593 L F
.45349 .80385 m .45351 .80385 L .45153 .80143 L F
.45356 .80127 m .45701 .80413 L .45492 .80341 L .847 .538 .465 r
F
.45026 .79607 m .45454 .80118 L .45356 .80127 L F
.45454 .80118 m .45701 .80413 L .45356 .80127 L F
.48056 .83797 m .4733 .82358 L .47558 .8289 L 0 0 .408 r
F
.49336 .86398 m .49076 .85862 L .48725 .85194 L F
.4733 .82358 m .50043 .85597 L .49498 .86657 L .847 .538 .465 r
F
.49076 .85862 m .4736 .82325 L .48725 .85194 L 0 0 .408 r
F
.4736 .82325 m .46507 .80566 L .474 .82428 L F
.4736 .82325 m .474 .82428 L .48725 .85194 L F
.45589 .80495 m .4733 .82358 L .47508 .82711 L .847 .538 .465 r
F
.49903 .87491 m .48768 .85159 L .49958 .87627 L 0 0 .408 r
F
.50043 .85597 m .49932 .86986 L .49856 .86944 L .891 .724 .667 r
F
.50033 .87042 m .50162 .87113 L .503 .87349 L 0 0 .408 r
F
.50043 .85597 m .49856 .86944 L .50817 .88736 L .891 .724 .667 r
F
.49754 .8706 m .50043 .85597 L .50817 .88736 L .847 .538 .465 r
F
.49596 .86466 m .50043 .85597 L .49754 .8706 L F
.49026 .85682 m .50817 .88736 L .487 .85009 L F
.49498 .86657 m .49754 .8706 L .49026 .85682 L F
.49754 .8706 m .50817 .88736 L .49026 .85682 L F
.49835 .87325 m .49026 .85682 L .49903 .87491 L 0 0 .408 r
F
.49026 .85682 m .48768 .85159 L .49903 .87491 L F
.48768 .85159 m .49012 .85691 L .49958 .87627 L F
.49958 .87627 m .49012 .85691 L .49336 .86398 L F
.49012 .85691 m .46507 .80566 L .49336 .86398 L F
.48415 .84601 m .47593 .82972 L .47738 .83311 L F
.47519 .83093 m .47603 .83176 L .45293 .80377 L .759 .44 .445 r
F
.47519 .83093 m .45293 .80377 L .45288 .80376 L F
.45349 .80385 m .45339 .80384 L .45356 .80388 L 0 .521 .831 r
F
.45356 .80388 m .45339 .80384 L .45324 .80383 L F
.47603 .83176 m .45153 .80143 L .4449 .79404 L .759 .44 .445 r
F
.44743 .80337 m .47519 .83093 L .45292 .80381 L F
.46595 .8208 m .47508 .82711 L .49498 .86657 L .847 .538 .465 r
F
.45589 .80495 m .47508 .82711 L .46595 .8208 L F
.45754 .80476 m .4733 .82358 L .45589 .80495 L F
.4889 .85425 m .48781 .85217 L .49012 .85691 L 0 0 .408 r
F
.48768 .85159 m .48781 .85217 L .4889 .85425 L F
.48768 .85159 m .46507 .80566 L .48781 .85217 L F
.47398 .82601 m .47164 .82066 L .49026 .85682 L .325 .323 .703 r
F
.48056 .83797 m .47024 .81643 L .4733 .82358 L 0 0 .408 r
F
.47164 .82066 m .46507 .80566 L .47315 .82207 L .325 .323 .703 r
F
.47164 .82066 m .47315 .82207 L .49026 .85682 L F
.4793 .81516 m .47851 .81267 L .47884 .8149 L F
.48903 .85719 m .49498 .86657 L .49026 .85682 L .847 .538 .465 r
F
.48735 .85131 m .49026 .85682 L .487 .85009 L F
.48903 .85719 m .49026 .85682 L .48735 .85131 L F
.45356 .80127 m .45492 .80341 L .45908 .80409 L F
.46022 .80438 m .45908 .80409 L .45998 .80437 L 0 .521 .831 r
F
.45288 .80376 m .45293 .80377 L .4449 .79404 L .759 .44 .445 r
F
.44641 .80236 m .45288 .80376 L .4449 .79404 L F
.45908 .80409 m .44173 .79952 L .45869 .80402 L 0 .521 .831 r
F
.45908 .80409 m .45869 .80402 L .45998 .80437 L F
.4677 .82357 m .48903 .85719 L .47789 .82754 L .847 .538 .465 r
F
.50064 .88273 m .49653 .86971 L .49812 .87278 L .325 .323 .703 r
F
.50319 .89273 m .49653 .86971 L .50064 .88273 L F
.48903 .85719 m .48735 .85131 L .48554 .84788 L .847 .538 .465 r
F
.47398 .82601 m .49026 .85682 L .49812 .87278 L .325 .323 .703 r
F
.487 .85009 m .50817 .88736 L .48147 .8308 L .847 .538 .465 r
F
.50339 .89264 m .49812 .87278 L .50712 .89106 L .325 .323 .703 r
F
.50319 .89273 m .49812 .87278 L .50339 .89264 L F
.50708 .89095 m .50139 .9096 L .50692 .89053 L .981 .91 .65 r
F
.50687 .8917 m .50307 .90558 L .50684 .89171 L F
.50713 .89109 m .50307 .90558 L .50708 .89095 L F
.49455 .91841 m .49786 .91266 L .49607 .91377 L .127 0 .358 r
F
.49288 .91046 m .49106 .92367 L .49872 .91213 L .891 .724 .667 r
F
.50214 .9026 m .50139 .9096 L .46299 1.00142 L .981 .91 .65 r
F
.50662 .89127 m .49277 .92625 L .51355 .91641 L F
.51354 .91639 m .50319 .89273 L .50665 .89136 L .325 .323 .703 r
F
.50319 .89273 m .50712 .89106 L .50716 .89115 L F
.5058 .89627 m .5048 .89323 L .50541 .89782 L F
.5048 .89323 m .50382 .89062 L .50541 .89782 L F
.48554 .84788 m .48147 .8308 L .48039 .82851 L .847 .538 .465 r
F
.48554 .84788 m .48039 .82851 L .47815 .82764 L F
.48735 .85131 m .48147 .8308 L .48554 .84788 L F
.50319 .89273 m .47398 .82601 L .49653 .86971 L .325 .323 .703 r
F
.50708 .89095 m .50692 .89153 L .50691 .8915 L .981 .91 .65 r
F
.50692 .89153 m .50687 .8917 L .50691 .8915 L F
.50691 .8915 m .50687 .8917 L .50684 .89171 L F
.51349 .9162 m .50665 .89136 L .50716 .89115 L .325 .323 .703 r
F
.51354 .91639 m .50665 .89136 L .51349 .9162 L F
.50692 .89053 m .50671 .89123 L .50662 .89127 L .981 .91 .65 r
F
.50859 .89405 m .50716 .89115 L .50713 .89109 L 0 0 .408 r
F
.50859 .89405 m .50713 .89109 L .50725 .8914 L F
.51354 .91639 m .50716 .89115 L .50859 .89405 L .325 .323 .703 r
F
.50817 .88736 m .50708 .89095 L .50692 .89053 L .981 .91 .65 r
F
.50817 .88736 m .50713 .89109 L .50708 .89095 L F
.50817 .88736 m .50816 .88738 L .51355 .91641 L F
.50816 .88738 m .50662 .89127 L .51355 .91641 L F
.46869 .99684 m .51582 .94797 L .51355 .91641 L .688 .477 .596 r
F
.51355 .91641 m .50477 .93262 L .51455 .93882 L 0 0 0 r
F
.51541 .9422 m .51471 .94233 L .51355 .91641 L .582 .471 .693 r
F
.51582 .94797 m .51508 .94421 L .51541 .9422 L F
.51508 .94421 m .51471 .94233 L .51541 .9422 L F
.4723 .99571 m .51582 .94797 L .46869 .99684 L .688 .477 .596 r
F
.46544 1.0039 m .48241 .98506 L .46463 1.00412 L .785 .573 .614 r
F
.48241 .98506 m .51582 .94797 L .4723 .99571 L F
.48241 .98506 m .4723 .99571 L .46463 1.00412 L F
.50958 .98603 m .51158 .96998 L .51461 .95538 L .722 .573 .687 r
F
.50985 .98389 m .51728 .96968 L .51693 .96947 L F
.51574 .96959 m .51693 .96947 L .51601 .96891 L F
.50985 .98389 m .51693 .96947 L .51574 .96959 L F
.51461 .95538 m .51202 .96645 L .51582 .94797 L F
.51158 .96998 m .51202 .96645 L .51461 .95538 L F
.51304 .96096 m .5102 .96533 L .51237 .96458 L .439 .15 .376 r
F
.51582 .94797 m .51627 .94385 L .51623 .94381 L .582 .471 .693 r
F
.51508 .94421 m .51623 .94381 L .51471 .94233 L F
.51582 .94797 m .51623 .94381 L .51508 .94421 L F
.51628 .94379 m .51486 .9456 L .51589 .94544 L .439 .15 .376 r
F
.5163 .94372 m .51623 .94381 L .51628 .94379 L F
.51623 .94381 m .51486 .9456 L .51628 .94379 L F
.48807 .97918 m .51582 .94797 L .46544 1.0039 L .785 .573 .614 r
F
.50443 .96108 m .51582 .94797 L .4663 1.00367 L F
.51202 .96645 m .51589 .94544 L .51582 .94797 L .722 .573 .687 r
F
.4663 1.00367 m .48807 .97918 L .46544 1.0039 L .785 .573 .614 r
F
.4663 1.00367 m .49477 .97186 L .51826 .94116 L 0 0 0 r
F
.51589 .94544 m .5164 .94269 L .51628 .94379 L .722 .573 .687 r
F
.51589 .94544 m .51628 .94379 L .51582 .94797 L F
.51589 .94544 m .51486 .9456 L .51447 .94803 L .439 .15 .376 r
F
.51826 .94116 m .5163 .94372 L .51589 .94544 L F
.5102 .96533 m .51651 .96921 L .52353 .9607 L F
.49477 .97186 m .45625 1.02223 L .51123 .95389 L F
.4663 1.00367 m .45625 1.02223 L .49477 .97186 L 0 0 0 r
F
.46774 1.00329 m .50443 .96108 L .4663 1.00367 L .785 .573 .614 r
F
.51447 .94803 m .49477 .97186 L .51123 .95389 L .439 .15 .376 r
F
.51486 .9456 m .49477 .97186 L .51447 .94803 L F
.51355 .91641 m .51455 .93882 L .51826 .94116 L 0 0 0 r
F
.51768 .93863 m .51355 .91641 L .51826 .94116 L .85 .565 .028 r
F
.51355 .91641 m .51354 .91639 L .51352 .91631 L .325 .323 .703 r
F
.48039 .82851 m .50817 .88736 L .51355 .91641 L .941 .624 .408 r
F
.50477 .93262 m .51613 .94371 L .51826 .94116 L 0 0 0 r
F
.51471 .94233 m .51106 .92381 L .51355 .91641 L .582 .471 .693 r
F
.47398 .82601 m .47968 .82823 L .46507 .80566 L .325 .323 .703 r
F
.48113 .83047 m .47341 .81001 L .46507 .80566 L F
.47789 .82754 m .47196 .81065 L .47145 .81039 L .847 .538 .465 r
F
.48554 .84788 m .47815 .82764 L .47789 .82754 L F
.47815 .82764 m .47196 .81065 L .47789 .82754 L F
.48376 .84834 m .48113 .83047 L .47968 .82823 L .325 .323 .703 r
F
.48376 .84834 m .47968 .82823 L .47398 .82601 L F
.48113 .83047 m .47851 .81267 L .47341 .81001 L F
.47815 .82764 m .48039 .82851 L .47196 .81065 L .847 .538 .465 r
F
.50541 .89782 m .48396 .8299 L .48376 .84834 L .325 .323 .703 r
F
.48396 .8299 m .48113 .8288 L .48376 .84834 L F
.5035 .88977 m .49962 .87948 L .50334 .89126 L F
.50354 .88936 m .47851 .81267 L .49962 .87948 L F
.50979 .90528 m .47851 .81267 L .50891 .90582 L F
.48147 .80051 m .48362 .80442 L .49028 .82572 L .692 .491 .611 r
F
.48362 .80442 m .5102 .85682 L .49028 .82572 L F
.50375 .8874 m .49034 .81883 L .47851 .81267 L .325 .323 .703 r
F
.49034 .81883 m .47958 .81418 L .47288 .81024 L .308 .581 .938 r
F
.47341 .81001 m .47288 .81024 L .46507 .80566 L F
.49034 .81883 m .47288 .81024 L .47341 .81001 L F
.50354 .88936 m .50334 .89126 L .50541 .89782 L .325 .323 .703 r
F
.48113 .8288 m .48087 .8287 L .48376 .84834 L F
.50891 .90582 m .5058 .89627 L .50541 .89782 L F
.51355 .91641 m .50979 .90528 L .50891 .90582 L F
.47168 .81077 m .48039 .82851 L .51355 .91641 L .941 .624 .408 r
F
.47196 .81065 m .48039 .82851 L .47168 .81077 L F
.48396 .8299 m .4793 .81516 L .48113 .8288 L .325 .323 .703 r
F
.50354 .88936 m .49962 .87948 L .5035 .88977 L F
.5048 .89323 m .50354 .88936 L .50382 .89062 L F
.4793 .81516 m .47884 .8149 L .48087 .8287 L F
.4793 .81516 m .48087 .8287 L .48113 .8288 L F
.50979 .90528 m .5044 .88132 L .50375 .8874 L F
.5044 .88132 m .49034 .81883 L .50375 .8874 L F
.47168 .81077 m .5056 .89636 L .49034 .81883 L .941 .624 .408 r
F
.48409 .81683 m .47467 .81203 L .46507 .80566 L .308 .581 .938 r
F
.4677 .82357 m .47789 .82754 L .47145 .81039 L .847 .538 .465 r
F
.4677 .82357 m .47145 .81039 L .46955 .80942 L F
.46507 .80566 m .45998 .80437 L .45725 .80415 L 0 .521 .831 r
F
.45998 .80437 m .4455 .80068 L .45725 .80415 L F
.46504 .80915 m .46348 .80542 L .46309 .80535 L 0 0 .408 r
F
.45908 .80409 m .4677 .82357 L .46955 .80942 L .847 .538 .465 r
F
.46507 .80566 m .46022 .80438 L .45998 .80437 L 0 .521 .831 r
F
.47987 .81548 m .46022 .80438 L .46507 .80566 L .308 .581 .938 r
F
.47145 .81039 m .47196 .81065 L .46995 .80638 L .847 .538 .465 r
F
.46995 .80638 m .47196 .81065 L .47168 .81077 L .941 .624 .408 r
F
.46995 .80638 m .47168 .81077 L .49034 .81883 L F
.49034 .81883 m .48409 .81683 L .47958 .81418 L .308 .581 .938 r
F
.49277 .92625 m .50295 .93131 L .51355 .91641 L .981 .91 .65 r
F
.5056 .89636 m .50942 .90599 L .50656 .89292 L .941 .624 .408 r
F
.5056 .89636 m .50656 .89292 L .49034 .81883 L F
.51354 .91639 m .51076 .90468 L .50979 .90528 L .325 .323 .703 r
F
.51355 .91641 m .51355 .91639 L .51354 .91639 L F
.51355 .91639 m .49034 .81883 L .51354 .91639 L F
.50942 .90599 m .51355 .91641 L .51076 .90467 L .941 .624 .408 r
F
.51076 .90468 m .49034 .81883 L .50979 .90528 L .325 .323 .703 r
F
.50942 .90599 m .51076 .90467 L .49034 .81883 L .941 .624 .408 r
F
.46454 .99777 m .49779 .94257 L .48688 .94517 L .538 .333 .551 r
F
.47548 .96988 m .485 .96373 L .51355 .91641 L .981 .91 .65 r
F
.46299 1.00142 m .46454 .99777 L .46473 .99753 L .538 .333 .551 r
F
.38444 1.01674 m .37738 1.01985 L .39053 1.01871 L .726 .979 .917 r
F
.37738 1.01985 m .36751 1.0242 L .3808 1.02103 L F
.37738 1.01985 m .3808 1.02103 L .39053 1.01871 L F
.38793 1.01521 m .38444 1.01674 L .39535 1.01756 L F
.38444 1.01674 m .39053 1.01871 L .39535 1.01756 L F
.3027 .98316 m .36751 1.0242 L .31019 .98659 L .626 .065 0 r
F
.38793 1.01521 m .39535 1.01756 L .46299 1.00142 L .726 .979 .917 r
F
.28289 .97061 m .3027 .98316 L .31019 .98659 L .626 .065 0 r
F
.25947 .87191 m .29925 .9776 L .30076 .9724 L .952 .699 .243 r
F
.28336 .96352 m .34245 1.00613 L .28289 .97061 L .553 0 0 r
F
.34245 1.00613 m .36751 1.0242 L .33177 1.00157 L F
.34245 1.00613 m .33177 1.00157 L .28289 .97061 L F
.28336 .96352 m .36157 1.02221 L .36751 1.0242 L F
.36732 1.02413 m .46299 1.00142 L .36751 1.0242 L .677 .294 .313 r
F
.36157 1.02221 m .4253 1.00915 L .36732 1.02413 L F
.4253 1.00915 m .46299 1.00142 L .36732 1.02413 L F
.37446 1.0198 m .38123 1.02095 L .42789 1.0098 L F
.36157 1.02221 m .37768 1.02118 L .37446 1.0198 L F
.37768 1.02118 m .38123 1.02095 L .37446 1.0198 L F
.4253 1.00915 m .42789 1.0098 L .46299 1.00142 L F
.46299 1.00142 m .44784 1.00505 L .45589 1.01235 L 0 0 0 r
F
.45917 1.00689 m .46237 1.00157 L .46272 1.00148 L .688 .477 .596 r
F
.46299 1.00142 m .46522 .99768 L .46454 .99777 L .538 .333 .551 r
F
.46522 .99768 m .51355 .91641 L .46454 .99777 L F
.46441 .99784 m .46299 1.00142 L .46522 .99768 L .981 .91 .65 r
F
.46441 .99784 m .46522 .99768 L .51355 .91641 L F
.46237 1.00157 m .50647 .9282 L .46272 1.00148 L .688 .477 .596 r
F
.46272 1.00148 m .50647 .9282 L .46522 .99768 L F
.50647 .9282 m .51355 .91641 L .50429 .93198 L F
.50647 .9282 m .50429 .93198 L .46522 .99768 L F
.45917 1.00689 m .46522 .99768 L .46299 1.00142 L F
.47336 .98746 m .46522 .99768 L .46507 .99862 L 0 0 0 r
F
.46463 1.00412 m .4723 .99571 L .46869 .99684 L .688 .477 .596 r
F
.47336 .98746 m .46507 .99862 L .46349 1.00887 L 0 0 0 r
F
.47874 .98071 m .47336 .98746 L .46349 1.00887 L F
.50753 .92753 m .47229 .98579 L .47874 .98071 L F
.51355 .91641 m .50429 .93198 L .50753 .92753 L F
.50429 .93198 m .47229 .98579 L .50753 .92753 L F
.47229 .98579 m .46522 .99768 L .47874 .98071 L F
.46522 .99768 m .46299 1.00142 L .46349 1.00887 L F
.46379 .9992 m .46798 .99811 L .50675 .9286 L .688 .477 .596 r
F
.50647 .9282 m .50675 .9286 L .51355 .91641 L F
.46379 .9992 m .50675 .9286 L .50647 .9282 L F
.51157 .9223 m .49034 .81883 L .51355 .91641 L .582 .471 .693 r
F
.51106 .92381 m .49034 .81883 L .51157 .9223 L F
.51346 .91604 m .51355 .91641 L .51382 .91788 L .85 .565 .028 r
F
.51346 .91604 m .51382 .91788 L .51768 .93863 L F
.49034 .81883 m .51346 .91604 L .51768 .93863 L F
.51279 .91721 m .51333 .91957 L .51533 .91279 L F
.51333 .91957 m .51665 .93414 L .51556 .9165 L F
.51333 .91957 m .51556 .9165 L .51533 .91279 L F
.49034 .81883 m .51279 .91721 L .51436 .89719 L F
.51279 .91721 m .51533 .91279 L .51436 .89719 L F
.46236 1.00159 m .4666 1.00057 L .46798 .99811 L .688 .477 .596 r
F
.46236 1.00159 m .46798 .99811 L .46379 .9992 L F
.36157 1.02221 m .42789 1.0098 L .4253 1.00915 L .677 .294 .313 r
F
.51665 .93414 m .51826 .94116 L .51776 .93433 L .85 .565 .028 r
F
.52304 .87643 m .52234 .8758 L .5221 .87542 L .692 .491 .611 r
F
.51319 .8621 m .51257 .85906 L .51338 .85972 L .764 .478 .501 r
F
.51055 .85735 m .51063 .85751 L .5102 .85682 L .692 .491 .611 r
F
.50961 .85566 m .51055 .85735 L .5102 .85682 L F
.51837 .87141 m .51458 .84486 L .52083 .87073 L .764 .478 .501 r
F
.51231 .8731 m .51319 .8621 L .51837 .87141 L F
.51319 .8621 m .51458 .84486 L .51837 .87141 L F
.51231 .8731 m .50499 .85686 L .50979 .85682 L F
.51458 .84486 m .51702 .84956 L .52083 .87073 L F
.51813 .90949 m .52642 .85088 L .50836 .83484 L .582 .471 .693 r
F
.51528 .90018 m .50836 .83484 L .49034 .81883 L F
.51813 .90949 m .50836 .83484 L .51528 .90018 L F
.51528 .90018 m .51826 .94116 L .5205 .94946 L .153 .15 .601 r
F
.51665 .93414 m .51776 .93433 L .51528 .90018 L .85 .565 .028 r
F
.48147 .80051 m .51959 .84164 L .48582 .8067 L .692 .491 .611 r
F
.51665 .93414 m .51528 .90018 L .51436 .89719 L .85 .565 .028 r
F
.514 .93871 m .51813 .90949 L .49034 .81883 L .582 .471 .693 r
F
.514 .93871 m .52642 .85088 L .514 .93871 L F
.5164 .94269 m .52642 .85088 L .514 .93872 L F
.5109 .83839 m .51131 .84427 L .5114 .8441 L .153 .15 .601 r
F
.52642 .85088 m .51805 .84488 L .51077 .83822 L .508 .581 .863 r
F
.51894 .91588 m .52642 .85088 L .51811 .92697 L .722 .573 .687 r
F
.51805 .84488 m .52065 .89991 L .52282 .87977 L .153 .15 .601 r
F
.51854 .84532 m .52282 .87977 L .52582 .85187 L F
.51805 .84488 m .52282 .87977 L .51854 .84532 L F
.52282 .87977 m .52642 .85088 L .51894 .91588 L .722 .573 .687 r
F
.51155 .84381 m .51894 .91588 L .51805 .84488 L .153 .15 .601 r
F
.51894 .91588 m .52353 .9607 L .52065 .89991 L F
.51894 .91588 m .52065 .89991 L .51805 .84488 L F
.5114 .8441 m .51528 .90018 L .5184 .92309 L F
.51805 .84488 m .51315 .84047 L .51077 .83822 L .508 .581 .863 r
F
.52642 .85088 m .51077 .83822 L .50836 .83484 L F
.51101 .83855 m .5184 .92309 L .51894 .91588 L .153 .15 .601 r
F
.51101 .83855 m .51155 .84381 L .51805 .84488 L F
.517 .84413 m .51289 .84117 L .51077 .83822 L .508 .581 .863 r
F
.51028 .83144 m .5109 .83839 L .51101 .83855 L .153 .15 .601 r
F
.5109 .83839 m .5184 .92309 L .51101 .83855 L F
.51436 .89719 m .51077 .83822 L .5107 .83814 L .85 .565 .028 r
F
.48409 .81683 m .47987 .81548 L .47467 .81203 L .308 .581 .938 r
F
.46955 .80942 m .47145 .81039 L .46995 .80638 L .847 .538 .465 r
F
.46638 .80527 m .46955 .80942 L .46995 .80638 L F
.45356 .80127 m .45908 .80409 L .46638 .80527 L F
.46532 .80726 m .45956 .80433 L .46022 .80438 L .308 .581 .938 r
F
.45998 .80437 m .45869 .80402 L .45853 .804 L 0 .521 .831 r
F
.45683 .80407 m .45138 .80302 L .45585 .80404 L F
.45683 .80407 m .45585 .80404 L .45701 .80413 L F
.45585 .80404 m .45138 .80302 L .45349 .80385 L F
.45492 .80341 m .45754 .80476 L .45589 .80495 L .847 .538 .465 r
F
.45701 .80413 m .45754 .80476 L .45492 .80341 L F
.45725 .80415 m .4455 .80068 L .45138 .80302 L 0 .521 .831 r
F
.45492 .80341 m .4677 .82357 L .45908 .80409 L .847 .538 .465 r
F
.45853 .804 m .44173 .79952 L .44326 .80011 L 0 .521 .831 r
F
.45869 .80402 m .44173 .79952 L .45853 .804 L F
.45138 .80302 m .43727 .80029 L .45339 .80384 L F
.45138 .80302 m .45339 .80384 L .45349 .80385 L F
.39317 .7878 m .43376 .78981 L .41251 .79198 L .365 0 0 r
F
.42608 .79964 m .40634 .79658 L .43562 .79949 L 0 .521 .831 r
F
.43406 .79702 m .4138 .79711 L .42936 .79615 L .217 0 0 r
F
.44195 .80119 m .40247 .78973 L .43727 .80029 L 0 .521 .831 r
F
.45138 .80302 m .42397 .79557 L .44195 .80119 L F
.42397 .79557 m .40247 .78973 L .44195 .80119 L F
.43571 .79055 m .44524 .79593 L .4449 .79404 L .759 .44 .445 r
F
.43376 .78981 m .44524 .79593 L .43571 .79055 L F
.4455 .80068 m .40247 .78973 L .45138 .80302 L 0 .521 .831 r
F
.40285 .78982 m .40212 .78911 L .40247 .78973 L F
.41764 .79359 m .40212 .78911 L .40285 .78982 L F
.4104 .79132 m .40212 .78911 L .41764 .79359 L F
.41251 .79198 m .43376 .78981 L .43571 .79055 L .365 0 0 r
F
.44688 .79625 m .45153 .80143 L .44529 .79418 L .759 .44 .445 r
F
.45153 .80143 m .44936 .79875 L .44529 .79418 L F
.44529 .79418 m .44936 .79875 L .44585 .79439 L F
.4449 .79404 m .44688 .79625 L .44529 .79418 L F
.41712 .79248 m .43571 .79055 L .45026 .79607 L .365 0 0 r
F
.41251 .79198 m .43571 .79055 L .41712 .79248 L F
.41121 .79138 m .45026 .79607 L .39538 .78404 L F
.41251 .79198 m .41712 .79248 L .41121 .79138 L F
.41712 .79248 m .45026 .79607 L .41121 .79138 L F
.40967 .79109 m .40212 .78911 L .40925 .79102 L 0 .521 .831 r
F
.41251 .79198 m .39538 .78404 L .39524 .78658 L .365 0 0 r
F
.40967 .79109 m .40925 .79102 L .44326 .80011 L 0 .521 .831 r
F
.44173 .79952 m .40967 .79109 L .44326 .80011 L F
.44326 .80011 m .4104 .79132 L .41764 .79359 L F
.41226 .79196 m .41251 .79198 L .40967 .79109 L .365 0 0 r
F
.43727 .80029 m .40247 .78973 L .4049 .79403 L 0 .521 .831 r
F
.40212 .78911 m .38302 .78409 L .40351 .79158 L F
.38302 .78409 m .37557 .78213 L .40351 .79158 L F
.39727 .79233 m .3917 .78971 L .39574 .79225 L F
.3917 .78971 m .37557 .78213 L .38436 .78679 L F
.4068 .79278 m .39317 .7878 L .35755 .78603 L .041 0 0 r
F
.39506 .79009 m .39317 .7878 L .41251 .79198 L .365 0 0 r
F
.35755 .78603 m .38091 .78719 L .39506 .79009 L F
.38091 .78719 m .39317 .7878 L .39506 .79009 L F
.35755 .78603 m .41226 .79196 L .40967 .79109 L F
.35755 .78603 m .40967 .79109 L .36238 .78228 L F
.39515 .78839 m .40967 .79109 L .41557 .79264 L .308 .581 .938 r
F
.39515 .78839 m .41557 .79264 L .41356 .79285 L F
.39515 .78839 m .37557 .78213 L .3952 .78729 L F
.40864 .7909 m .40858 .79081 L .40967 .79109 L F
.45324 .80383 m .44449 .80248 L .44575 .80222 L 0 .521 .831 r
F
.44449 .80248 m .43844 .80065 L .44575 .80222 L F
.43844 .80065 m .43774 .80043 L .44575 .80222 L F
.45324 .80383 m .43727 .80029 L .44449 .80248 L F
.45339 .80384 m .43727 .80029 L .45324 .80383 L F
.44449 .80248 m .4049 .79403 L .42608 .79964 L F
.43727 .80029 m .4049 .79403 L .44449 .80248 L F
.43964 .80262 m .39515 .78839 L .44978 .80164 L .308 .581 .938 r
F
.39515 .78839 m .39509 .78229 L .37557 .78213 L F
.39509 .78229 m .39499 .772 L .38316 .77798 L F
.39499 .772 m .39453 .77177 L .38316 .77798 L F
.46617 .80524 m .46641 .80531 L .46638 .80527 L .847 .538 .465 r
F
.45908 .80409 m .46641 .80531 L .46617 .80524 L F
.43964 .80262 m .44978 .80164 L .45908 .80409 L .308 .581 .938 r
F
.45956 .80433 m .45908 .80409 L .46022 .80438 L F
.43964 .80262 m .45908 .80409 L .45956 .80433 L F
.45908 .80409 m .46955 .80942 L .46641 .80531 L .847 .538 .465 r
F
.47742 .80268 m .46139 .80205 L .47613 .79931 L .884 .508 .322 r
F
.45026 .79607 m .45356 .80127 L .46995 .80638 L .847 .538 .465 r
F
.41898 .79092 m .45026 .79607 L .46995 .80638 L .522 0 0 r
F
.39538 .78404 m .45026 .79607 L .39546 .78243 L .365 0 0 r
F
.39546 .78243 m .45026 .79607 L .41898 .79092 L .522 0 0 r
F
.39509 .78229 m .38316 .77798 L .37557 .78213 L .308 .581 .938 r
F
.39084 .78729 m .37557 .78213 L .3829 .78557 L 0 .521 .831 r
F
.36238 .78228 m .39515 .78839 L .36788 .77802 L .365 0 0 r
F
.39515 .78839 m .40967 .79109 L .39524 .78658 L F
.396 .77229 m .39498 .77152 L .39515 .78839 L .308 .581 .938 r
F
.39515 .78839 m .39524 .78658 L .36788 .77802 L .365 0 0 r
F
.4102 .7932 m .396 .77229 L .39515 .78839 L .308 .581 .938 r
F
.41356 .79285 m .41557 .79264 L .44978 .80164 L F
.42137 .7955 m .396 .77229 L .4102 .7932 L F
.41898 .79092 m .46549 .80503 L .4141 .7816 L .522 0 0 r
F
.42433 .79371 m .42329 .79376 L .42425 .79369 L .217 0 0 r
F
.42329 .79376 m .42345 .79374 L .42425 .79369 L F
.42861 .79698 m .41791 .78888 L .42137 .7955 L .308 .581 .938 r
F
.41791 .78888 m .396 .77229 L .42137 .7955 L F
.39538 .78404 m .39546 .78243 L .37028 .77616 L .365 0 0 r
F
.37028 .77616 m .39546 .78243 L .41898 .79092 L .522 0 0 r
F
.37028 .77616 m .41898 .79092 L .38712 .7693 L F
.44743 .80337 m .45292 .80381 L .45288 .80376 L .759 .44 .445 r
F
.47987 .81548 m .43964 .80262 L .45956 .80433 L .308 .581 .938 r
F
.45891 .80878 m .41524 .78377 L .43964 .80262 L F
.41524 .78377 m .39856 .77422 L .41686 .78687 L F
.41524 .78377 m .41686 .78687 L .43964 .80262 L F
.46549 .80503 m .46519 .80425 L .41395 .78131 L .522 0 0 r
F
.45326 .80351 m .39856 .77422 L .45891 .80878 L .308 .581 .938 r
F
.46934 .81212 m .39498 .77152 L .39856 .77422 L F
.43964 .80262 m .39856 .77422 L .43342 .80063 L F
.46549 .80503 m .41395 .78131 L .4141 .7816 L .522 0 0 r
F
.46549 .80503 m .46995 .80638 L .46519 .80425 L F
.41395 .78131 m .46995 .80638 L .49034 .81883 L .553 0 0 r
F
.47987 .81548 m .45956 .80433 L .46532 .80726 L .308 .581 .938 r
F
.45153 .80143 m .45096 .80062 L .45085 .80059 L .759 .44 .445 r
F
.46759 .80754 m .39498 .77152 L .46934 .81212 L .308 .581 .938 r
F
.4141 .7816 m .41395 .78131 L .38712 .7693 L .522 0 0 r
F
.41898 .79092 m .4141 .7816 L .38712 .7693 L F
.49034 .81883 m .46759 .80754 L .46934 .81212 L .308 .581 .938 r
F
.38712 .7693 m .41395 .78131 L .49034 .81883 L .553 0 0 r
F
.39499 .772 m .39498 .77152 L .39453 .77177 L .308 .581 .938 r
F
.43342 .80063 m .42861 .79698 L .4102 .7932 L F
.39524 .78658 m .39538 .78404 L .36788 .77802 L .365 0 0 r
F
.36788 .77802 m .39538 .78404 L .37028 .77616 L F
.50836 .83484 m .51077 .83822 L .49034 .81883 L .508 .581 .863 r
F
.49034 .81883 m .51436 .89719 L .51028 .83144 L .85 .565 .028 r
F
.49034 .81883 m .40682 .76505 L .39498 .77152 L .308 .581 .938 r
F
.38712 .7693 m .49034 .81883 L .40682 .76505 L .553 0 0 r
F
.51077 .83822 m .40682 .76505 L .49034 .81883 L .508 .581 .863 r
F
.51077 .83822 m .51528 .90018 L .5109 .83839 L .153 .15 .601 r
F
.51436 .89719 m .51528 .90018 L .51077 .83822 L .85 .565 .028 r
F
.51289 .84117 m .40682 .76505 L .51077 .83822 L .508 .581 .863 r
F
.51528 .90018 m .5205 .94946 L .52353 .9607 L .153 .15 .601 r
F
.50477 .93262 m .4663 1.00367 L .51613 .94371 L 0 0 0 r
F
.51471 .94233 m .5164 .94269 L .514 .93872 L .582 .471 .693 r
F
.51627 .94385 m .5164 .94269 L .51471 .94233 L F
.51693 .94356 m .50625 .96291 L .5205 .94946 L .439 .15 .376 r
F
.50625 .96291 m .5102 .96533 L .5205 .94946 L F
.51202 .96645 m .51984 .90367 L .51798 .92481 L .722 .573 .687 r
F
.51202 .96645 m .51798 .92481 L .51557 .94718 L F
.52268 .88091 m .52282 .87977 L .51894 .91588 L F
.51984 .90367 m .52268 .88091 L .51894 .91588 L F
.52065 .89991 m .52353 .9607 L .52488 .89638 L .153 .15 .601 r
F
.52282 .87977 m .55091 .90382 L .52642 .85088 L .722 .573 .687 r
F
.52299 .88117 m .55091 .90382 L .52282 .87977 L F
.52065 .89991 m .52488 .89638 L .52282 .87977 L .153 .15 .601 r
F
.53146 .88979 m .54461 .90978 L .53314 .93956 L .797 .714 .772 r
F
.53013 .93595 m .55091 .90382 L .52299 .88117 L .722 .573 .687 r
F
.53124 .94295 m .52997 .97441 L .53313 .95478 L .58 .472 .695 r
F
.52991 .93461 m .52993 .94524 L .53124 .94295 L F
.52993 .94524 m .52997 .97441 L .53124 .94295 L F
.5412 .92454 m .53567 .93414 L .53124 .94295 L .851 .705 .7 r
F
.5412 .92454 m .53124 .94295 L .53145 .9426 L F
.53124 .94295 m .55091 .90382 L .53013 .93595 L .722 .573 .687 r
F
.53108 .94328 m .52299 .88117 L .52632 .90795 L F
.54296 .87991 m .54407 .87956 L .54975 .85145 L .58 .472 .695 r
F
.5412 .92454 m .53145 .9426 L .53471 .93693 L .851 .705 .7 r
F
.53124 .94295 m .53313 .95478 L .5365 .9338 L .58 .472 .695 r
F
.5238 .95568 m .52353 .9607 L .52993 .94524 L F
.53955 .92807 m .5412 .92454 L .52421 .95693 L .851 .705 .7 r
F
.54975 .85145 m .54529 .87917 L .54727 .88106 L .731 .611 .724 r
F
.54975 .85145 m .55507 .91802 L .56325 .85544 L F
.56022 .87867 m .56199 .87386 L .54099 .88222 L .635 .606 .803 r
F
.56199 .87386 m .54247 .88007 L .54099 .88222 L F
.53124 .94295 m .5365 .9338 L .54529 .87917 L .58 .472 .695 r
F
.54407 .87956 m .54529 .87917 L .54975 .85145 L F
.53124 .94295 m .54529 .87917 L .54407 .87956 L F
.54099 .88222 m .54247 .88007 L .54031 .88075 L .635 .606 .803 r
F
.54579 .8669 m .54089 .84685 L .54764 .83915 L .599 .432 .627 r
F
.52977 .84262 m .5298 .85809 L .54975 .85145 L .58 .472 .695 r
F
.54099 .88222 m .54031 .88075 L .53719 .87402 L .635 .606 .803 r
F
.54031 .88075 m .53752 .87474 L .53719 .87402 L F
.54099 .88222 m .53719 .87402 L .52642 .85088 L F
.53957 .87913 m .52904 .85646 L .52642 .85088 L F
.52904 .85646 m .52413 .84588 L .52642 .85088 L F
.52488 .89638 m .52632 .90795 L .52904 .85646 L .153 .15 .601 r
F
.52898 .85632 m .52904 .85646 L .52913 .85484 L F
.52488 .89638 m .52904 .85646 L .52898 .85632 L F
.52769 .85355 m .52898 .85632 L .52913 .85484 L F
.51028 .83144 m .51101 .83855 L .52977 .84262 L F
.52642 .85088 m .52413 .84588 L .51805 .84488 L .508 .581 .863 r
F
.51101 .83855 m .52913 .85484 L .52977 .84262 L .153 .15 .601 r
F
.51917 .82046 m .52727 .82848 L .50859 .81427 L .568 .349 .543 r
F
.50763 .81225 m .50859 .81427 L .48159 .79373 L F
.51917 .82046 m .50859 .81427 L .50763 .81225 L F
.48575 .78739 m .50013 .79053 L .49486 .79641 L F
.48804 .78656 m .5247 .79589 L .48575 .78739 L F
.49896 .78892 m .49851 .77535 L .49963 .78906 L .142 0 0 r
F
.50819 .79091 m .5247 .79589 L .48804 .78656 L .568 .349 .543 r
F
.51917 .82046 m .48159 .79373 L .48129 .7935 L F
.48129 .79352 m .50379 .81062 L .49337 .8059 L F
.48159 .79373 m .52044 .82328 L .48129 .79352 L F
.48537 .79719 m .49384 .78311 L .49913 .79403 L .142 0 0 r
F
.49384 .78311 m .49851 .77535 L .49913 .79403 L F
.48185 .79319 m .48804 .78656 L .48537 .79719 L F
.48804 .78656 m .49851 .77535 L .49134 .78727 L F
.48804 .78656 m .49134 .78727 L .48537 .79719 L F
.4816 .79308 m .48852 .7836 L .49168 .78267 L F
.48102 .78272 m .49064 .78562 L .48804 .78656 L .568 .349 .543 r
F
.48403 .7857 m .48804 .78656 L .48575 .78739 L F
.48102 .78272 m .48804 .78656 L .48403 .7857 L F
.49851 .77535 m .50081 .77477 L .50002 .79383 L .142 0 0 r
F
.50089 .7728 m .5038 .77634 L .50002 .79383 L F
.50567 .76768 m .50679 .76734 L .50433 .77698 L F
.5038 .77634 m .50433 .77698 L .50002 .79383 L F
.50567 .76768 m .50433 .77698 L .5038 .77634 L F
.52387 .75801 m .52774 .75219 L .52284 .78278 L 0 0 0 r
F
.50691 .78297 m .50685 .77453 L .50823 .7815 L F
.50685 .77453 m .50679 .76734 L .50746 .77394 L F
.50685 .77453 m .50746 .77394 L .50823 .7815 L F
.51002 .77145 m .52981 .75224 L .52608 .77109 L .255 0 .315 r
F
.52387 .75801 m .50679 .76734 L .52961 .74939 L 0 0 0 r
F
.50921 .77224 m .52608 .77109 L .50777 .77364 L .255 0 .315 r
F
.50746 .77394 m .50679 .76734 L .52387 .75801 L 0 0 0 r
F
.50517 .77367 m .50679 .76734 L .50685 .77453 L F
.50089 .7728 m .49869 .77137 L .50476 .76866 L .142 0 0 r
F
.49851 .77535 m .49862 .77296 L .50089 .7728 L F
.49862 .77296 m .49869 .77137 L .50089 .7728 L F
.49168 .78267 m .49869 .77137 L .49851 .77535 L F
.49481 .77288 m .49781 .77132 L .49571 .77178 L .797 .966 .914 r
F
.49571 .77178 m .51002 .77145 L .49862 .77296 L .255 0 .315 r
F
.51002 .77145 m .52608 .77109 L .50921 .77224 L F
.51002 .77145 m .50921 .77224 L .49862 .77296 L F
.50557 .77578 m .50685 .77453 L .50691 .78297 L 0 0 0 r
F
.50517 .77367 m .50685 .77453 L .50557 .77578 L F
.50823 .7815 m .50746 .77394 L .52387 .75801 L F
.50089 .7728 m .50921 .77224 L .50221 .77442 L .255 0 .315 r
F
.50921 .77224 m .50777 .77364 L .50221 .77442 L F
.50683 .76714 m .53082 .74713 L .49781 .77132 L .796 .96 .637 r
F
.49996 .77168 m .53082 .74713 L .52981 .75224 L .255 0 .315 r
F
.49996 .77168 m .52981 .75224 L .51002 .77145 L F
.49781 .77132 m .53082 .74713 L .49571 .77178 L .796 .96 .637 r
F
.49571 .77178 m .49845 .76985 L .49996 .77168 L .255 0 .315 r
F
.49845 .76985 m .53082 .74713 L .49996 .77168 L F
.49064 .78562 m .50819 .79091 L .48804 .78656 L .568 .349 .543 r
F
.49913 .79403 m .49896 .78892 L .50002 .79383 L .142 0 0 r
F
.49896 .78892 m .49963 .78906 L .50002 .79383 L F
.52904 .85646 m .52357 .84453 L .52403 .84566 L .635 .606 .803 r
F
.49816 .78288 m .51556 .78305 L .49064 .78562 L .568 .349 .543 r
F
.51556 .78305 m .51798 .78356 L .49064 .78562 L F
.50379 .81062 m .52044 .82328 L .49707 .80962 L F
.52569 .8251 m .50002 .79383 L .52182 .78709 L .667 .445 .573 r
F
.49064 .78562 m .50555 .78449 L .50158 .78892 L .568 .349 .543 r
F
.52382 .78479 m .53174 .7942 L .52931 .79639 L .592 .48 .695 r
F
.52569 .8251 m .52587 .7995 L .53649 .82885 L .667 .445 .573 r
F
.52587 .7995 m .5287 .79695 L .53649 .82885 L F
.52382 .78479 m .53666 .8325 L .5247 .79589 L .592 .48 .695 r
F
.50555 .78449 m .51798 .78356 L .50158 .78892 L .568 .349 .543 r
F
.50002 .79383 m .50699 .78336 L .52597 .7858 L 0 0 0 r
F
.50002 .79383 m .50115 .78939 L .50691 .78297 L F
.50002 .79383 m .50691 .78297 L .50699 .78336 L F
.48102 .78272 m .49816 .78288 L .49064 .78562 L .568 .349 .543 r
F
.50745 .81213 m .50002 .79383 L .52569 .8251 L .667 .445 .573 r
F
.52044 .82328 m .51655 .82193 L .48147 .80051 L .568 .349 .543 r
F
.4908 .77729 m .49816 .78288 L .48102 .78272 L .255 0 .315 r
F
.49862 .77296 m .49851 .77535 L .4908 .77729 L F
.49851 .77535 m .49816 .78288 L .4908 .77729 L F
.49571 .77178 m .49862 .77296 L .48102 .78272 L F
.47096 .79839 m .47411 .79902 L .45992 .79874 L .653 .302 .365 r
F
.47742 .80268 m .47613 .79931 L .47742 .80194 L .884 .508 .322 r
F
.46708 .79421 m .51028 .83144 L .52002 .83702 L .093 .444 .88 r
F
.48803 .8098 m .52002 .83702 L .51859 .83383 L F
.46708 .79421 m .52002 .83702 L .48803 .8098 L F
.45537 .78549 m .51028 .83144 L .46708 .79421 L F
.51028 .83144 m .51044 .83361 L .51049 .83375 L .153 .15 .601 r
F
.51044 .83361 m .51077 .83822 L .51049 .83375 L F
.51049 .83375 m .51077 .83822 L .5109 .83839 L F
.5107 .83814 m .51077 .83822 L .51028 .83144 L .85 .565 .028 r
F
.47411 .79902 m .47468 .79904 L .47573 .79922 L .217 0 0 r
F
.47935 .80001 m .48011 .80014 L .47973 .8004 L .764 .478 .501 r
F
.4806 .80066 m .48011 .80014 L .48146 .80003 L F
.4809 .80044 m .48147 .80051 L .48 .80021 L .445 .029 .155 r
F
.48 .80021 m .48147 .80051 L .47964 .80045 L .653 .302 .365 r
F
.47964 .80045 m .48147 .80051 L .47963 .80046 L F
.4796 .80048 m .47935 .80001 L .47973 .8004 L .764 .478 .501 r
F
.48011 .80014 m .47877 .79871 L .48077 .79969 L F
.48011 .80014 m .48077 .79969 L .48146 .80003 L F
.47383 .78408 m .48127 .79253 L .48146 .80003 L .445 .029 .155 r
F
.4813 .80015 m .48146 .80003 L .48147 .80051 L F
.47383 .78408 m .48146 .80003 L .4813 .80015 L F
.4809 .80044 m .4813 .80015 L .48147 .80051 L F
.48129 .79352 m .49337 .8059 L .48146 .80003 L .568 .349 .543 r
F
.50379 .81062 m .49707 .80962 L .48147 .80051 L F
.5026 .81045 m .47877 .79871 L .50002 .79383 L .764 .478 .501 r
F
.48146 .80003 m .49337 .8059 L .48147 .80051 L .568 .349 .543 r
F
.5026 .81045 m .50002 .79383 L .50575 .81092 L .764 .478 .501 r
F
.48185 .79319 m .4816 .79308 L .48784 .78664 L .142 0 0 r
F
.48185 .79319 m .48784 .78664 L .48804 .78656 L F
.48129 .7935 m .48159 .79373 L .48129 .79352 L .568 .349 .543 r
F
.48102 .78272 m .48575 .78739 L .48129 .7935 L F
.47613 .79931 m .4751 .79699 L .48185 .79319 L .142 0 0 r
F
.47383 .78408 m .48102 .78272 L .48127 .79253 L .445 .029 .155 r
F
.47613 .79931 m .48185 .79319 L .48537 .79719 L .142 0 0 r
F
.40682 .76505 m .49034 .81883 L .51028 .83144 L 0 .193 .618 r
F
.40682 .76505 m .51028 .83144 L .45537 .78549 L F
.5011 .80475 m .49092 .77327 L .43167 .76748 L .508 .581 .863 r
F
.46129 .78799 m .43167 .76748 L .40682 .76505 L F
.5011 .80475 m .43167 .76748 L .46129 .78799 L F
.53924 .84196 m .52977 .84262 L .54975 .85145 L .391 .56 .901 r
F
.41786 .77298 m .5011 .80475 L .40682 .76505 L .508 .581 .863 r
F
.48803 .8098 m .51859 .83383 L .50773 .82014 L .093 .444 .88 r
F
.51859 .83383 m .52977 .84262 L .51637 .82895 L F
.51859 .83383 m .51637 .82895 L .50773 .82014 L F
.50575 .8191 m .5011 .80475 L .41786 .77298 L .508 .581 .863 r
F
.5145 .82483 m .52977 .84262 L .53924 .84196 L .391 .56 .901 r
F
.50773 .82014 m .51637 .82895 L .5145 .82483 L F
.51637 .82895 m .52977 .84262 L .5145 .82483 L F
.50728 .80897 m .51382 .82334 L .5145 .82483 L .635 .606 .803 r
F
.52044 .82328 m .52727 .82848 L .51655 .82193 L .568 .349 .543 r
F
.51049 .816 m .5145 .82483 L .53924 .84196 L .391 .56 .901 r
F
.51176 .81879 m .5145 .82483 L .51774 .83191 L .635 .606 .803 r
F
.50728 .80897 m .5145 .82483 L .51176 .81879 L F
.51805 .84488 m .517 .84413 L .51315 .84047 L .508 .581 .863 r
F
.50575 .81092 m .50002 .79383 L .50745 .81213 L .667 .445 .573 r
F
.51767 .83176 m .51664 .82952 L .51289 .84117 L .508 .581 .863 r
F
.51152 .81831 m .49092 .77327 L .50425 .81447 L F
.50728 .80897 m .506 .80618 L .51382 .82334 L .635 .606 .803 r
F
.506 .80618 m .49092 .77327 L .51152 .81831 L F
.506 .80618 m .51152 .81831 L .51382 .82334 L F
.50699 .78336 m .50823 .7815 L .51556 .78305 L 0 0 0 r
F
.54764 .83915 m .52597 .7858 L .53215 .78336 L .599 .432 .627 r
F
.57347 .84749 m .5597 .80161 L .57816 .76541 L .569 .453 .682 r
F
.57347 .84749 m .57839 .76132 L .58104 .85013 L F
.52518 .78986 m .54888 .83773 L .53666 .8325 L .592 .48 .695 r
F
.52587 .7995 m .52597 .7858 L .5287 .79695 L .667 .445 .573 r
F
.5287 .79695 m .52597 .7858 L .53876 .81728 L .599 .432 .627 r
F
.52587 .7995 m .52182 .78709 L .52597 .7858 L .667 .445 .573 r
F
.52569 .8251 m .52182 .78709 L .52587 .7995 L F
.5247 .79589 m .53666 .8325 L .52727 .82848 L .592 .48 .695 r
F
.50699 .78336 m .51556 .78305 L .52597 .7858 L 0 0 0 r
F
.49851 .77535 m .50592 .77764 L .49816 .78288 L .255 0 .315 r
F
.50592 .77764 m .50691 .78297 L .49816 .78288 L F
.50699 .78336 m .50691 .78297 L .50823 .7815 L 0 0 0 r
F
.51917 .82046 m .5247 .79589 L .52727 .82848 L .568 .349 .543 r
F
.49807 .78885 m .57972 .82591 L .49092 .77327 L .635 .606 .803 r
F
.51854 .80321 m .57972 .82591 L .49807 .78885 L F
.53266 .81982 m .57972 .82591 L .50182 .797 L F
.57347 .84749 m .58104 .85013 L .57409 .84853 L .569 .453 .682 r
F
.5783 .8495 m .57829 .84454 L .57936 .85079 L .592 .48 .695 r
F
.57518 .84878 m .57936 .85079 L .57409 .84853 L F
.57659 .85275 m .57936 .85079 L .57807 .85525 L .711 .597 .727 r
F
.58115 .84714 m .57173 .85795 L .59727 .86316 L .555 .633 .883 r
F
.55423 .83578 m .56452 .84013 L .53266 .81982 L .635 .606 .803 r
F
.5415 .83457 m .57329 .84819 L .57109 .85662 L .711 .597 .727 r
F
.57342 .84838 m .57332 .84805 L .57347 .84749 L .569 .453 .682 r
F
.57313 .84376 m .57173 .85795 L .58115 .84714 L .555 .633 .883 r
F
.55423 .83578 m .56687 .85179 L .57313 .84376 L F
.56687 .85179 m .57173 .85795 L .57313 .84376 L F
.57645 .83949 m .57972 .82591 L .57378 .84197 L .743 .672 .782 r
F
.57514 .84117 m .57378 .84197 L .57313 .84376 L F
.57645 .83949 m .57378 .84197 L .57514 .84117 L F
.56794 .84231 m .57006 .83936 L .53266 .81982 L .635 .606 .803 r
F
.57006 .83936 m .57972 .82591 L .54438 .82134 L F
.57006 .83936 m .54438 .82134 L .53266 .81982 L F
.53266 .81982 m .54975 .85145 L .56325 .85544 L .514 .607 .884 r
F
.56604 .8524 m .56325 .85544 L .57173 .85795 L F
.53266 .81982 m .56325 .85544 L .56604 .8524 L F
.57514 .84117 m .58115 .84714 L .57633 .84069 L .555 .633 .883 r
F
.5762 .84055 m .5809 .84532 L .57972 .82591 L .743 .672 .782 r
F
.5762 .84055 m .57633 .84069 L .57622 .84054 L .555 .633 .883 r
F
.57514 .84117 m .57633 .84069 L .5762 .84055 L F
.581 .847 m .58101 .84708 L .58115 .84714 L F
.5542 .84085 m .56604 .8524 L .5611 .84449 L .514 .607 .884 r
F
.56604 .8524 m .57173 .85795 L .56687 .85179 L F
.56604 .8524 m .56687 .85179 L .5611 .84449 L F
.53803 .93093 m .52997 .97441 L .53955 .92807 L .731 .611 .724 r
F
.54529 .87917 m .52997 .97441 L .54727 .88106 L F
.52997 .97441 m .5203 .99008 L .52174 .99046 L .862 .644 .606 r
F
.52997 .97441 m .52174 .99046 L .52781 .98746 L F
.52997 .97441 m .52781 .98746 L .53363 .97928 L F
.50905 .99316 m .51969 .98992 L .52997 .97441 L .685 .415 .508 r
F
.50905 .99316 m .54052 .97164 L .53955 .92807 L .851 .705 .7 r
F
.54052 .97164 m .54112 .97123 L .5407 .95963 L F
.54052 .97164 m .5407 .95963 L .53955 .92807 L F
.54054 .97043 m .54111 .9734 L .55437 .9234 L .731 .611 .724 r
F
.55507 .91802 m .55437 .9234 L .57173 .85795 L F
.54054 .97043 m .55437 .9234 L .55507 .91802 L F
.55437 .9234 m .57491 .84589 L .56353 .86971 L .743 .672 .782 r
F
.5542 .92436 m .55169 .93913 L .56383 .91094 L .783 .681 .752 r
F
.54813 .94738 m .5498 .94973 L .56383 .91094 L F
.54541 .9683 m .55646 .95909 L .54986 .94982 L .743 .672 .782 r
F
.54131 .97323 m .54238 .97234 L .56383 .91094 L .783 .681 .752 r
F
.57173 .85795 m .54111 .9734 L .54131 .97323 L F
.54986 .94982 m .55217 .94026 L .55437 .9234 L .743 .672 .782 r
F
.57101 .87322 m .57259 .86293 L .58135 .86078 L .765 .681 .77 r
F
.57173 .85795 m .55668 .95883 L .59727 .86316 L .783 .681 .752 r
F
.55668 .95883 m .55685 .95876 L .59727 .86316 L F
.55661 .95931 m .58521 .89617 L .59727 .86316 L F
.55661 .95931 m .53898 .98206 L .55282 .98478 L F
.56383 .91094 m .55012 .95018 L .55646 .95909 L F
.56383 .91094 m .55646 .95909 L .55668 .95883 L F
.55646 .95909 m .5791 .94022 L .54986 .94982 L .743 .672 .782 r
F
.5791 .94022 m .57953 .93712 L .54986 .94982 L F
.57199 .94728 m .5791 .94022 L .55687 .95875 L .865 .833 .813 r
F
.58445 .93492 m .57855 .94421 L .57524 .98642 L .782 .709 .783 r
F
.56341 .95579 m .55282 .98478 L .58445 .93492 L F
.59202 .93209 m .55687 .95875 L .55886 .95785 L .865 .833 .813 r
F
.56357 .94395 m .57953 .93712 L .58413 .89854 L .743 .672 .782 r
F
.59727 .86316 m .58521 .89617 L .58445 .93492 L .782 .709 .783 r
F
.58521 .89617 m .5791 .94022 L .58445 .93492 L F
.57953 .93712 m .5863 .93423 L .58436 .90228 L .743 .672 .782 r
F
.57953 .93712 m .58436 .90228 L .58413 .89854 L F
.55661 .95931 m .55282 .98478 L .56341 .95579 L .783 .681 .752 r
F
.57855 .94421 m .55282 .98478 L .57273 .98623 L .782 .709 .783 r
F
.57855 .94421 m .57273 .98623 L .57524 .98642 L F
.57076 .95247 m .59202 .93209 L .55886 .95785 L .865 .833 .813 r
F
.58115 .84714 m .59727 .86316 L .59242 .85701 L .555 .633 .883 r
F
.58115 .84714 m .59242 .85701 L .58616 .85066 L F
.59727 .86316 m .59333 .89794 L .59996 .86368 L .782 .709 .783 r
F
.5863 .93423 m .59807 .87343 L .59129 .85586 L .743 .672 .782 r
F
.5809 .84532 m .59129 .85586 L .57972 .82591 L F
.57313 .84376 m .57972 .82591 L .56872 .8419 L .635 .606 .803 r
F
.58115 .84714 m .58895 .85262 L .57839 .83925 L .555 .633 .883 r
F
.5762 .84055 m .57645 .83949 L .57593 .84071 L .743 .672 .782 r
F
.5298 .85809 m .54193 .88424 L .54975 .85145 L .58 .472 .695 r
F
.54247 .88007 m .56679 .84471 L .54031 .88075 L .635 .606 .803 r
F
.56679 .84471 m .57972 .82591 L .56634 .84454 L F
.56679 .84471 m .56634 .84454 L .54031 .88075 L F
.62291 .86474 m .59727 .86316 L .62736 .86902 L .547 .644 .898 r
F
.51556 .78305 m .52387 .75801 L .52284 .78278 L 0 0 0 r
F
.52331 .77147 m .52608 .77109 L .5233 .77172 L .255 0 .315 r
F
.54554 .78105 m .53215 .78336 L .5399 .7803 L .599 .432 .627 r
F
.52284 .78278 m .52608 .77109 L .52369 .78313 L .255 0 .315 r
F
.5233 .77172 m .52608 .77109 L .52284 .78278 L F
.6042 .85516 m .60567 .74006 L .63799 .84193 L .591 .513 .736 r
F
.6042 .85516 m .57839 .76132 L .60567 .74006 L F
.52176 .76754 m .58895 .85262 L .62291 .86474 L .547 .644 .898 r
F
.58895 .85262 m .59727 .86316 L .62291 .86474 L F
.51556 .78305 m .52369 .78313 L .51798 .78356 L .568 .349 .543 r
F
.50823 .7815 m .52387 .75801 L .51556 .78305 L 0 0 0 r
F
.50221 .77442 m .50777 .77364 L .50557 .77578 L .255 0 .315 r
F
.51556 .78305 m .526 .78525 L .52597 .7858 L 0 0 0 r
F
.52261 .78279 m .52369 .78313 L .51556 .78305 L .255 0 .315 r
F
.49797 .76455 m .58101 .84708 L .581 .847 L .555 .633 .883 r
F
.49797 .76455 m .55423 .83578 L .58101 .84708 L F
.57645 .83949 m .57313 .84376 L .56353 .86971 L .743 .672 .782 r
F
.57622 .84054 m .57839 .83925 L .52176 .76754 L .555 .633 .883 r
F
.58115 .84714 m .57839 .83925 L .57622 .84054 L F
.57595 .84156 m .5762 .84055 L .57523 .84236 L .743 .672 .782 r
F
.5762 .84055 m .57593 .84071 L .57523 .84236 L F
.5863 .93423 m .59129 .85586 L .5809 .84532 L F
.58616 .85066 m .59242 .85701 L .58895 .85262 L .555 .633 .883 r
F
.55687 .95875 m .56341 .95579 L .58521 .89617 L .783 .681 .752 r
F
.55661 .95931 m .56341 .95579 L .55687 .95875 L F
.55474 .96105 m .55646 .95909 L .54541 .9683 L .865 .833 .813 r
F
.54131 .97323 m .53898 .98206 L .54238 .97234 L .783 .681 .752 r
F
.53913 .97832 m .53882 .98203 L .5399 .97797 L .731 .611 .724 r
F
.5399 .97797 m .53882 .98203 L .54013 .9777 L .783 .681 .752 r
F
.53703 .98049 m .53654 .98315 L .53882 .98203 L .862 .644 .606 r
F
.5024 1.02816 m .53607 .98574 L .54075 .97699 L .963 .919 .714 r
F
.54226 .97268 m .54075 .97699 L .54541 .9683 L F
.5024 1.02816 m .54075 .97699 L .54226 .97268 L F
.55012 .95018 m .53898 .98206 L .55661 .95931 L .783 .681 .752 r
F
.53882 .98203 m .53757 .98405 L .53898 .98206 L .923 .957 .632 r
F
.53607 .98574 m .57076 .95247 L .55474 .96105 L .865 .833 .813 r
F
.57076 .95247 m .55886 .95785 L .55474 .96105 L F
.58521 .89617 m .56341 .95579 L .5791 .94022 L .782 .709 .783 r
F
.55886 .95785 m .55687 .95875 L .55646 .95909 L .865 .833 .813 r
F
.55668 .95883 m .55646 .95909 L .55661 .95931 L .783 .681 .752 r
F
.55668 .95883 m .55661 .95931 L .55685 .95876 L F
.55886 .95785 m .55646 .95909 L .55474 .96105 L .865 .833 .813 r
F
.5791 .94022 m .5863 .93423 L .57953 .93712 L .743 .672 .782 r
F
.59202 .93209 m .5863 .93423 L .5791 .94022 L .865 .833 .813 r
F
.59202 .93209 m .5791 .94022 L .57199 .94728 L F
.54986 .94982 m .56357 .94395 L .5809 .84532 L .743 .672 .782 r
F
.56357 .94395 m .58413 .89854 L .5809 .84532 L F
.55217 .94026 m .57491 .84589 L .55437 .9234 L F
.57491 .84589 m .57595 .84156 L .57363 .84683 L F
.57491 .84589 m .57363 .84683 L .56353 .86971 L F
.56199 .87386 m .57313 .84376 L .54247 .88007 L .635 .606 .803 r
F
.57313 .84376 m .56872 .8419 L .54247 .88007 L F
.54986 .94982 m .5809 .84532 L .5762 .84055 L .743 .672 .782 r
F
.57595 .84156 m .57523 .84236 L .56353 .86971 L F
.52369 .78313 m .52446 .78406 L .52382 .78479 L .592 .48 .695 r
F
.51798 .78356 m .52369 .78313 L .52382 .78479 L .568 .349 .543 r
F
.49797 .76455 m .57514 .84117 L .52176 .76754 L .555 .633 .883 r
F
.57514 .84117 m .57622 .84054 L .52176 .76754 L F
.56624 .84467 m .56794 .84231 L .56452 .84013 L .635 .606 .803 r
F
.56624 .84467 m .56452 .84013 L .55423 .83578 L F
.50182 .797 m .51854 .80321 L .49807 .78885 L F
.51111 .80609 m .54975 .85145 L .53266 .81982 L .514 .607 .884 r
F
.54157 .82642 m .5542 .84085 L .54597 .82967 L F
.49587 .78393 m .5542 .84085 L .48669 .76374 L F
.5542 .84085 m .5611 .84449 L .49797 .76455 L F
.50321 .80003 m .56624 .84467 L .50182 .797 L .635 .606 .803 r
F
.50333 .80029 m .53924 .84196 L .50752 .80334 L .391 .56 .901 r
F
.51049 .816 m .50728 .80897 L .51176 .81879 L .635 .606 .803 r
F
.50866 .81199 m .50728 .80897 L .51049 .816 L F
.51049 .816 m .53924 .84196 L .50333 .80029 L .391 .56 .901 r
F
.50321 .80003 m .49092 .77327 L .50866 .81199 L .635 .606 .803 r
F
.45098 .76227 m .50752 .80334 L .45413 .76235 L .391 .56 .901 r
F
.51859 .83383 m .52002 .83702 L .52977 .84262 L .093 .444 .88 r
F
.52977 .84262 m .52904 .85646 L .5298 .85809 L .58 .472 .695 r
F
.53926 .87847 m .50321 .80003 L .52904 .85646 L .635 .606 .803 r
F
.50321 .80003 m .50866 .81199 L .52904 .85646 L F
.45413 .76235 m .50321 .80003 L .47428 .76285 L .391 .56 .901 r
F
.56451 .84708 m .56624 .84467 L .50321 .80003 L .635 .606 .803 r
F
.50321 .80003 m .50752 .80334 L .50123 .79567 L .391 .56 .901 r
F
.50321 .80003 m .50123 .79567 L .47428 .76285 L F
.45098 .76227 m .51049 .816 L .50333 .80029 L F
.50915 .81307 m .50866 .81199 L .51049 .816 L .635 .606 .803 r
F
.53924 .84196 m .54975 .85145 L .54381 .84447 L .391 .56 .901 r
F
.53924 .84196 m .54381 .84447 L .47428 .76285 L F
.54031 .88075 m .56451 .84708 L .50321 .80003 L .635 .606 .803 r
F
.47428 .76285 m .51111 .80609 L .53266 .81982 L .514 .607 .884 r
F
.50221 .77442 m .50557 .77578 L .49851 .77535 L .255 0 .315 r
F
.50557 .77578 m .50592 .77764 L .49851 .77535 L F
.49851 .77535 m .50089 .7728 L .50081 .77477 L .142 0 0 r
F
.48669 .76374 m .54157 .82642 L .49797 .76455 L .514 .607 .884 r
F
.54157 .82642 m .54597 .82967 L .49797 .76455 L F
.47428 .76285 m .49587 .78393 L .48669 .76374 L F
.51664 .82952 m .51152 .81831 L .50749 .82448 L .508 .581 .863 r
F
.51152 .81831 m .50425 .81447 L .50749 .82448 L F
.51664 .82952 m .50749 .82448 L .51289 .84117 L F
.45098 .76227 m .50773 .82014 L .5145 .82483 L .391 .56 .901 r
F
.45098 .76227 m .5145 .82483 L .51049 .816 L F
.51595 .8279 m .50915 .81307 L .51774 .83191 L .635 .606 .803 r
F
.50915 .81307 m .51176 .81879 L .51774 .83191 L F
.51289 .84117 m .50575 .8191 L .41786 .77298 L .508 .581 .863 r
F
.42834 .76288 m .48803 .8098 L .45098 .76227 L .093 .444 .88 r
F
.48803 .8098 m .50773 .82014 L .45098 .76227 L F
.40682 .76505 m .45537 .78549 L .42834 .76288 L 0 .193 .618 r
F
.42834 .76288 m .46708 .79421 L .48803 .8098 L .093 .444 .88 r
F
.52413 .84588 m .51774 .83191 L .51805 .84488 L .508 .581 .863 r
F
.51774 .83191 m .51767 .83176 L .51767 .83186 L F
.51774 .83191 m .51767 .83186 L .51805 .84488 L F
.51805 .84488 m .51767 .83186 L .51289 .84117 L F
.51767 .83186 m .51767 .83176 L .51763 .83183 L F
.51767 .83186 m .51763 .83183 L .51289 .84117 L F
.42834 .76288 m .45537 .78549 L .46708 .79421 L .093 .444 .88 r
F
.52357 .84453 m .51595 .8279 L .52243 .84216 L .635 .606 .803 r
F
.51595 .8279 m .51774 .83191 L .52243 .84216 L F
.52357 .84453 m .52243 .84216 L .52403 .84566 L F
.53957 .87913 m .53926 .87847 L .52904 .85646 L F
.52904 .85646 m .52403 .84566 L .52413 .84588 L F
.52582 .85187 m .52488 .89638 L .52898 .85632 L .153 .15 .601 r
F
.52582 .85187 m .52898 .85632 L .52769 .85355 L F
.5298 .85809 m .52991 .93461 L .54193 .88424 L .58 .472 .695 r
F
.54031 .88075 m .53957 .87913 L .53752 .87474 L .635 .606 .803 r
F
.52991 .93461 m .53124 .94295 L .54407 .87956 L .58 .472 .695 r
F
.52991 .93461 m .54407 .87956 L .54296 .87991 L F
.53471 .93693 m .53108 .94328 L .53387 .93852 L .851 .705 .7 r
F
.53145 .9426 m .53108 .94328 L .53471 .93693 L F
.53145 .9426 m .53124 .94295 L .53108 .94328 L F
.53108 .94328 m .53124 .94295 L .53013 .93595 L .722 .573 .687 r
F
.52488 .89638 m .52353 .9607 L .52632 .90795 L .153 .15 .601 r
F
.52632 .90795 m .52299 .88117 L .52268 .88091 L .722 .573 .687 r
F
.52282 .87977 m .52488 .89638 L .52582 .85187 L .153 .15 .601 r
F
.52268 .88091 m .52299 .88117 L .52282 .87977 L .722 .573 .687 r
F
.51894 .91588 m .5184 .92309 L .52353 .9607 L .153 .15 .601 r
F
.5205 .94946 m .51304 .96096 L .52353 .9607 L .439 .15 .376 r
F
.51304 .96096 m .51237 .96458 L .52353 .9607 L F
.51826 .94116 m .51693 .94356 L .5205 .94946 L F
.52991 .93461 m .5238 .95568 L .52993 .94524 L .58 .472 .695 r
F
.5266 .91004 m .5238 .95568 L .52991 .93461 L F
.52904 .85646 m .5238 .95568 L .5298 .85809 L F
.51202 .96645 m .52996 .935 L .51382 .95199 L .722 .573 .687 r
F
.50985 .98389 m .51601 .96891 L .51202 .96645 L F
.51601 .96891 m .52996 .935 L .51202 .96645 L F
.48085 1.00842 m .46892 1.03304 L .48514 1.00508 L .864 .65 .611 r
F
.47543 1.01871 m .46892 1.03304 L .48085 1.00842 L F
.50641 .95988 m .49413 .97515 L .47494 1.01964 L .439 .15 .376 r
F
.46874 1.0331 m .46892 1.03304 L .4797 1.00931 L .864 .65 .611 r
F
.50625 .96291 m .47494 1.01964 L .5102 .96533 L .439 .15 .376 r
F
.51557 .94718 m .51798 .92481 L .5164 .94269 L .722 .573 .687 r
F
.51984 .90367 m .51811 .92697 L .5164 .94269 L F
.51382 .95199 m .52971 .93526 L .52268 .88091 L F
.52971 .93526 m .52996 .935 L .52632 .90795 L F
.52971 .93526 m .52632 .90795 L .52268 .88091 L F
.51131 .84427 m .51528 .90018 L .5114 .8441 L .153 .15 .601 r
F
.51886 .96692 m .51693 .96947 L .51796 .96938 L .685 .415 .508 r
F
.51081 .98359 m .51768 .96993 L .50985 .98389 L .722 .573 .687 r
F
.51651 .96921 m .51681 .9694 L .52353 .9607 L .439 .15 .376 r
F
.46733 1.03343 m .46918 1.033 L .52353 .9607 L F
.52353 .9607 m .51886 .96692 L .51796 .96938 L .685 .415 .508 r
F
.51921 .96926 m .51796 .96938 L .51482 .97797 L F
.52353 .9607 m .51796 .96938 L .51921 .96926 L F
.51768 .96993 m .51796 .96938 L .51728 .96968 L .722 .573 .687 r
F
.51796 .96938 m .53108 .94328 L .51741 .96943 L F
.51796 .96938 m .51741 .96943 L .51728 .96968 L F
.51768 .96993 m .51728 .96968 L .50985 .98389 L F
.47494 1.01964 m .47044 1.02941 L .51681 .9694 L .439 .15 .376 r
F
.47494 1.01964 m .51681 .9694 L .51651 .96921 L F
.51003 .99107 m .51796 .96938 L .50958 .98603 L .851 .705 .7 r
F
.51796 .96938 m .50969 .9791 L .51482 .97797 L .685 .415 .508 r
F
.51693 .96947 m .50969 .9791 L .51796 .96938 L F
.50969 .9791 m .49508 .99854 L .50858 .98447 L F
.50969 .9791 m .50858 .98447 L .51482 .97797 L F
.5102 .96533 m .47494 1.01964 L .51651 .96921 L .439 .15 .376 r
F
.51601 .96891 m .53108 .94328 L .52996 .935 L .722 .573 .687 r
F
.51728 .96968 m .53108 .94328 L .51601 .96891 L F
.46934 .81212 m .45326 .80351 L .45891 .80878 L .308 .581 .938 r
F
.48688 .94517 m .49984 .9312 L .4933 .93006 L .538 .333 .551 r
F
.49277 .92625 m .47548 .96988 L .50295 .93131 L .981 .91 .65 r
F
.514 .93872 m .514 .93871 L .514 .93871 L .582 .471 .693 r
F
.47548 .96988 m .46441 .99784 L .485 .96373 L .981 .91 .65 r
F
.35873 1.01818 m .39599 1.01745 L .36157 1.02221 L .746 .346 .294 r
F
.39599 1.01745 m .38123 1.02095 L .36157 1.02221 L F
.38212 1.02074 m .36751 1.0242 L .37027 1.02357 L 0 0 0 r
F
.38212 1.02074 m .37027 1.02357 L .3713 1.02333 L F
.3789 1.02153 m .3713 1.02333 L .37538 1.0224 L F
.38212 1.02074 m .3713 1.02333 L .3789 1.02153 L F
.38466 1.02017 m .44352 1.03116 L .37959 1.02137 L .783 .326 .159 r
F
.38803 1.01937 m .39881 1.02166 L .38466 1.02017 L F
.39881 1.02166 m .44352 1.03116 L .38466 1.02017 L F
.40117 1.01623 m .38212 1.02074 L .3789 1.02153 L 0 0 0 r
F
.40117 1.01623 m .3789 1.02153 L .38901 1.01914 L F
.3804 1.01775 m .38798 1.01936 L .39599 1.01745 L .746 .346 .294 r
F
.41167 1.02361 m .41537 1.02449 L .38803 1.01937 L .783 .326 .159 r
F
.41537 1.02449 m .44352 1.03116 L .41828 1.0258 L F
.41537 1.02449 m .41828 1.0258 L .38803 1.01937 L F
.44784 1.00505 m .4048 1.01536 L .45589 1.01235 L 0 0 0 r
F
.41167 1.02361 m .38803 1.01937 L .38901 1.01914 L .783 .326 .159 r
F
.4048 1.01536 m .37538 1.0224 L .40813 1.01831 L 0 0 0 r
F
.4048 1.01536 m .40813 1.01831 L .45589 1.01235 L F
.36833 1.00165 m .39449 1.01787 L .36044 1.01146 L .69 .152 0 r
F
.41167 1.02361 m .43746 1.04089 L .44352 1.03116 L .783 .326 .159 r
F
.44352 1.03116 m .45446 1.02369 L .45056 1.02307 L .785 .573 .614 r
F
.45446 1.02369 m .45418 1.02334 L .45056 1.02307 L F
.44352 1.03116 m .44805 1.02594 L .45036 1.02099 L F
.44805 1.02594 m .45056 1.02307 L .45048 1.02225 L F
.44805 1.02594 m .45048 1.02225 L .45036 1.02099 L F
.46188 1.00485 m .45048 1.02225 L .45625 1.02223 L 0 0 0 r
F
.45036 1.02099 m .46774 1.00329 L .4535 1.01632 L .785 .573 .614 r
F
.45625 1.02223 m .44017 1.02227 L .45418 1.02334 L .352 0 0 r
F
.45056 1.02307 m .46774 1.00329 L .45036 1.02099 L .785 .573 .614 r
F
.4535 1.01632 m .45589 1.01235 L .46299 1.00142 L .688 .477 .596 r
F
.4535 1.01632 m .45656 1.01296 L .45589 1.01235 L F
.46774 1.00329 m .46463 1.00412 L .4535 1.01632 L .785 .573 .614 r
F
.46299 1.00142 m .44945 1.02225 L .45048 1.02225 L 0 0 0 r
F
.46299 1.00142 m .45048 1.02225 L .46188 1.00485 L F
.45076 1.02517 m .40524 1.02234 L .44768 1.02682 L .352 0 0 r
F
.45418 1.02334 m .45057 1.02327 L .45076 1.02517 L F
.45057 1.02327 m .40524 1.02234 L .45076 1.02517 L F
.44017 1.02227 m .40524 1.02234 L .45418 1.02334 L F
.40445 1.01877 m .39386 1.0201 L .40976 1.02233 L 0 0 0 r
F
.39386 1.0201 m .40524 1.02234 L .40976 1.02233 L F
.36044 1.01146 m .41167 1.02361 L .35994 1.01341 L .783 .326 .159 r
F
.40718 1.02255 m .43746 1.04089 L .41167 1.02361 L F
.40022 1.02313 m .43746 1.04089 L .40718 1.02255 L F
.40022 1.02313 m .43583 1.0435 L .43746 1.04089 L F
.40524 1.02234 m .37538 1.0224 L .39472 1.02358 L .352 0 0 r
F
.40524 1.02234 m .39472 1.02358 L .40718 1.02255 L F
.39386 1.0201 m .37538 1.0224 L .40524 1.02234 L 0 0 0 r
F
.39091 1.01869 m .39911 1.02322 L .40022 1.02313 L .783 .326 .159 r
F
.39911 1.02322 m .43583 1.0435 L .40022 1.02313 L F
.39472 1.02358 m .38366 1.02291 L .3899 1.02399 L .352 0 0 r
F
.3823 1.02075 m .3899 1.02399 L .39091 1.01869 L .783 .326 .159 r
F
.3899 1.02399 m .43583 1.0435 L .39911 1.02322 L F
.3899 1.02399 m .39911 1.02322 L .39091 1.01869 L F
.40991 1.02743 m .43583 1.0435 L .3899 1.02399 L .69 .152 0 r
F
.40991 1.02743 m .43553 1.05135 L .43583 1.0435 L F
.40822 1.03059 m .43553 1.05135 L .40991 1.02743 L F
.40801 1.03099 m .40561 1.03066 L .40779 1.03141 L .352 0 0 r
F
.40812 1.03078 m .40658 1.03071 L .40801 1.03099 L F
.40658 1.03071 m .40561 1.03066 L .40801 1.03099 L F
.40801 1.03099 m .43553 1.05135 L .40822 1.03059 L .69 .152 0 r
F
.42084 1.03357 m .43553 1.05135 L .40801 1.03099 L 0 .254 .757 r
F
.42084 1.03357 m .43514 1.04403 L .43553 1.05135 L F
.43553 1.05135 m .44015 1.04928 L .43578 1.0447 L .938 .694 .543 r
F
.47709 1.05939 m .54238 .97234 L .52676 .98893 L .963 .919 .714 r
F
.50178 1.04169 m .4954 1.04435 L .47696 1.06032 L .619 .823 .419 r
F
.47696 1.06032 m .4954 1.04435 L .47709 1.05939 L F
.4954 1.04435 m .49446 1.04474 L .47709 1.05939 L F
.47709 1.05939 m .47867 1.05806 L .48972 1.04414 L .963 .919 .714 r
F
.47709 1.05939 m .52676 .98893 L .47815 1.05726 L F
.52174 .99046 m .47564 1.06249 L .51156 1.0103 L .862 .644 .606 r
F
.52676 .98893 m .52821 .98733 L .50841 .99452 L .851 .705 .7 r
F
.5203 .99008 m .47564 1.06249 L .52174 .99046 L .862 .644 .606 r
F
.48085 1.07017 m .47564 1.06249 L .48006 1.07171 L F
.5024 1.02816 m .4759 1.06215 L .48085 1.07017 L F
.4759 1.06215 m .47564 1.06249 L .48085 1.07017 L F
.46808 1.0493 m .46872 1.05049 L .47103 1.05412 L .613 .046 0 r
F
.4766 1.05929 m .47485 1.05895 L .47686 1.06001 L .862 .644 .606 r
F
.47404 1.05879 m .47382 1.05875 L .47395 1.05897 L .685 .415 .508 r
F
.47367 1.05873 m .47696 1.06032 L .4766 1.05929 L .951 .614 .21 r
F
.44868 1.05393 m .47429 1.05971 L .47367 1.05873 L F
.4899 1.05252 m .48085 1.07017 L .49379 1.0506 L .862 .644 .606 r
F
.48085 1.07017 m .48006 1.07171 L .48095 1.07034 L F
.48085 1.07017 m .48095 1.07034 L .49379 1.0506 L F
.52675 1.01738 m .51423 1.03302 L .55987 .99816 L 0 0 0 r
F
.52675 1.01738 m .48897 1.06517 L .51423 1.03302 L F
.51922 1.02175 m .56691 .99408 L .52911 1.01017 L .865 .833 .813 r
F
.56691 .99408 m .56788 .99306 L .52911 1.01017 L F
.53456 1.00776 m .48897 1.06517 L .52675 1.01738 L 0 0 0 r
F
.49116 1.06115 m .48805 1.06579 L .49331 1.05802 L .619 .823 .419 r
F
.48162 1.07493 m .48164 1.07498 L .48159 1.07446 L 0 0 .384 r
F
.48006 1.07171 m .48162 1.07493 L .48129 1.07393 L F
.48006 1.07171 m .48168 1.07481 L .48122 1.07553 L F
.4817 1.07517 m .48181 1.07506 L .48179 1.07503 L 0 0 0 r
F
.48181 1.07506 m .50093 1.05708 L .48179 1.07503 L F
.48757 1.06611 m .48159 1.07446 L .48572 1.06925 L .923 .957 .632 r
F
.4862 1.06704 m .48159 1.07446 L .48757 1.06611 L F
.48236 1.07329 m .48271 1.07333 L .49914 1.04926 L .619 .823 .419 r
F
.5038 1.04231 m .49914 1.04926 L .50948 1.03411 L F
.48236 1.07329 m .49914 1.04926 L .5038 1.04231 L F
.53479 .98881 m .502 1.0416 L .50861 1.03515 L .923 .957 .632 r
F
.4812 1.07555 m .48279 1.07334 L .48272 1.07333 L .619 .823 .419 r
F
.4812 1.07555 m .49682 1.05272 L .49914 1.04926 L F
.48805 1.06579 m .48572 1.06925 L .48897 1.06517 L .923 .957 .632 r
F
.48179 1.07503 m .50093 1.05708 L .48805 1.06579 L 0 0 0 r
F
.48138 1.07541 m .48293 1.07335 L .48284 1.07334 L .619 .823 .419 r
F
.48138 1.07541 m .48537 1.06975 L .4831 1.0729 L F
.4812 1.07555 m .48138 1.07541 L .48284 1.07326 L F
.54032 1.02201 m .49006 1.06735 L .52719 1.0354 L .827 .998 .78 r
F
.4817 1.07517 m .56689 1.00244 L .55021 1.01073 L 0 0 0 r
F
.48138 1.07541 m .49331 1.05802 L .49506 1.0553 L .619 .823 .419 r
F
.48203 1.07617 m .49731 1.06276 L .56689 1.00244 L 0 0 0 r
F
.48203 1.07617 m .49731 1.06276 L .48203 1.07617 L F
.48203 1.07617 m .56689 1.00244 L .48181 1.07552 L F
.48181 1.07552 m .56689 1.00244 L .4817 1.07517 L F
.48182 1.07458 m .50634 1.11463 L .48168 1.07481 L 0 0 .384 r
F
.55427 1.12932 m .51229 1.12402 L .50856 1.11216 L .395 .305 .635 r
F
.48227 1.07386 m .48137 1.0753 L .48271 1.07333 L .619 .823 .419 r
F
.48262 1.07279 m .48006 1.07171 L .48159 1.07446 L .923 .957 .632 r
F
.4823 1.07328 m .48182 1.07458 L .48006 1.07171 L .629 .212 0 r
F
.48034 1.0762 m .48271 1.07333 L .48236 1.07329 L .619 .823 .419 r
F
.49393 1.05053 m .48095 1.07035 L .49415 1.05029 L .923 .957 .632 r
F
.48095 1.07035 m .48006 1.07171 L .48095 1.07035 L F
.48095 1.07035 m .48095 1.07035 L .49415 1.05029 L F
.43553 1.05135 m .4738 1.05875 L .46602 1.04621 L .938 .694 .543 r
F
.43553 1.05135 m .46602 1.04621 L .45569 1.04231 L F
.476 1.05918 m .47435 1.05885 L .4738 1.05875 L .951 .614 .21 r
F
.47376 1.05874 m .4738 1.05875 L .43553 1.05135 L F
.476 1.05918 m .4738 1.05875 L .47376 1.05874 L F
.48129 1.07393 m .48162 1.07493 L .48159 1.07446 L 0 0 .384 r
F
.48006 1.07171 m .48182 1.07458 L .48168 1.07481 L F
.48535 1.04838 m .47564 1.06249 L .5024 1.02816 L .862 .644 .606 r
F
.47513 1.06143 m .47638 1.06355 L .48006 1.07171 L .629 .212 0 r
F
.48095 1.07034 m .49393 1.05053 L .49393 1.05054 L .862 .644 .606 r
F
.48095 1.07035 m .48006 1.07171 L .48262 1.07279 L .923 .957 .632 r
F
.48095 1.07034 m .48006 1.07171 L .48095 1.07035 L .862 .644 .606 r
F
.48223 1.07347 m .50156 1.0455 L .47649 1.06374 L .619 .823 .419 r
F
.47649 1.06374 m .49261 1.05201 L .47696 1.06032 L F
.47466 1.0598 m .47556 1.06173 L .47696 1.06032 L .951 .614 .21 r
F
.47556 1.06173 m .47649 1.06374 L .47655 1.06331 L F
.47556 1.06173 m .47655 1.06331 L .47696 1.06032 L F
.47556 1.06173 m .4823 1.07328 L .48199 1.07306 L .629 .212 0 r
F
.47649 1.06374 m .48199 1.07306 L .48025 1.07184 L F
.47556 1.06173 m .48199 1.07306 L .47649 1.06374 L F
.47556 1.06173 m .48025 1.07184 L .48006 1.07171 L F
.47336 1.08631 m .48223 1.07347 L .47649 1.06374 L .619 .823 .419 r
F
.45751 1.043 m .45689 1.05552 L .46881 1.05782 L .613 .046 0 r
F
.45569 1.04231 m .45689 1.05552 L .45751 1.043 L F
.44868 1.05393 m .47336 1.08631 L .47649 1.06374 L .951 .614 .21 r
F
.47462 1.06024 m .47556 1.06173 L .47638 1.06355 L .629 .212 0 r
F
.47395 1.05897 m .47445 1.05997 L .47556 1.06173 L F
.47395 1.05897 m .47638 1.06355 L .47513 1.06143 L F
.44868 1.05393 m .47649 1.06374 L .47556 1.06173 L .951 .614 .21 r
F
.47429 1.05971 m .47556 1.06173 L .47466 1.0598 L F
.44868 1.05393 m .47556 1.06173 L .47429 1.05971 L F
.47283 1.05846 m .47383 1.05993 L .47014 1.05311 L .613 .046 0 r
F
.46964 1.05232 m .47014 1.05311 L .46808 1.0493 L F
.47283 1.05846 m .47014 1.05311 L .46964 1.05232 L F
.47001 1.06456 m .47336 1.08631 L .45112 1.05377 L 0 .075 .633 r
F
.46881 1.05782 m .46612 1.05798 L .47697 1.06853 L .613 .046 0 r
F
.46612 1.05798 m .45918 1.05838 L .4767 1.06837 L F
.46612 1.05798 m .4767 1.06837 L .47697 1.06853 L F
.48034 1.0762 m .4812 1.07555 L .48137 1.0753 L .619 .823 .419 r
F
.48034 1.0762 m .48137 1.0753 L .48227 1.07386 L F
.49129 1.06036 m .50948 1.03411 L .51092 1.03194 L F
.48034 1.0762 m .49142 1.06019 L .49129 1.06036 L F
.49142 1.06019 m .50948 1.03411 L .49129 1.06036 L F
.48057 1.07207 m .4811 1.07316 L .48128 1.07317 L .629 .212 0 r
F
.48057 1.07207 m .48128 1.07317 L .4821 1.07326 L F
.47445 1.05997 m .4811 1.07316 L .47556 1.06173 L F
.48178 1.07738 m .48183 1.07714 L .48166 1.0752 L 0 0 .384 r
F
.48178 1.07738 m .48166 1.0752 L .48165 1.07521 L F
.48183 1.07714 m .48178 1.07511 L .48166 1.0752 L F
.51037 1.12378 m .49933 1.12239 L .50634 1.11463 L .395 .305 .635 r
F
.48109 1.07698 m .48203 1.07617 L .48097 1.07625 L 0 0 0 r
F
.48178 1.07738 m .48189 1.07772 L .48183 1.07714 L 0 0 .384 r
F
.48833 1.09745 m .49373 1.11588 L .48318 1.10137 L .516 .147 .278 r
F
.48833 1.09745 m .48318 1.10137 L .48283 1.09814 L F
.48034 1.11999 m .47874 1.11825 L .48186 1.09991 L .553 .121 .174 r
F
.49373 1.11588 m .48685 1.1107 L .48099 1.09836 L .516 .147 .278 r
F
.49373 1.11588 m .50086 1.14019 L .48685 1.1107 L F
.49513 1.12106 m .49373 1.11588 L .48833 1.09745 L 0 0 .384 r
F
.49644 1.12564 m .4953 1.1215 L .49513 1.12106 L F
.49645 1.12565 m .4953 1.1215 L .49644 1.12564 L F
.48857 1.09847 m .48833 1.09745 L .48346 1.08084 L F
.48346 1.08088 m .48346 1.08084 L .48294 1.07907 L F
.48857 1.09847 m .48346 1.08084 L .48346 1.08088 L F
.48134 1.0844 m .48283 1.09814 L .48099 1.09836 L .516 .147 .278 r
F
.48099 1.09836 m .48685 1.1107 L .4808 1.10614 L F
.48034 1.11999 m .48172 1.08792 L .47993 1.09776 L .553 .121 .174 r
F
.48172 1.08792 m .48134 1.0844 L .47993 1.09776 L F
.48034 1.11999 m .48136 1.10656 L .48373 1.10835 L F
.48034 1.11999 m .48395 1.10852 L .48172 1.08792 L F
.49644 1.12563 m .48833 1.09745 L .48857 1.09847 L 0 0 .384 r
F
.49651 1.12586 m .49644 1.12564 L .49644 1.12563 L F
.49644 1.12564 m .48833 1.09745 L .49644 1.12563 L F
.48227 1.07821 m .48978 1.1037 L .48294 1.07907 L F
.48189 1.07772 m .48352 1.08311 L .48227 1.07821 L F
.48352 1.08311 m .48978 1.1037 L .48227 1.07821 L F
.48554 1.09096 m .48646 1.1157 L .48019 1.08332 L 0 0 .183 r
F
.48978 1.1037 m .49651 1.12586 L .48857 1.09847 L 0 0 .384 r
F
.48978 1.1037 m .48857 1.09847 L .48294 1.07907 L F
.48352 1.08311 m .50383 1.11741 L .48978 1.1037 L F
.50383 1.11741 m .50294 1.1184 L .48978 1.1037 L F
.49651 1.12586 m .49645 1.12565 L .49644 1.12564 L F
.4953 1.1215 m .49373 1.11588 L .49513 1.12106 L F
.49651 1.12586 m .49803 1.13088 L .49373 1.11588 L F
.49803 1.13088 m .49866 1.13267 L .49373 1.11588 L F
.48978 1.1037 m .50038 1.11554 L .49803 1.13088 L F
.49746 1.10799 m .49105 1.11248 L .48554 1.09096 L 0 0 .183 r
F
.49105 1.11248 m .48646 1.1157 L .48554 1.09096 L F
.49848 1.10838 m .49631 1.11007 L .49746 1.10799 L .395 .305 .635 r
F
.48525 1.083 m .50383 1.11741 L .48352 1.08311 L 0 0 .384 r
F
.4823 1.07328 m .50547 1.113 L .48182 1.07458 L .629 .212 0 r
F
.50547 1.113 m .50608 1.11405 L .50556 1.11321 L F
.50547 1.113 m .50556 1.11321 L .48182 1.07458 L F
.48272 1.07333 m .48284 1.07326 L .49682 1.05272 L .619 .823 .419 r
F
.49914 1.04926 m .49682 1.05272 L .50948 1.03411 L F
.49506 1.0553 m .49331 1.05802 L .5127 1.02938 L F
.50516 1.04028 m .48805 1.06579 L .5105 1.03805 L .923 .957 .632 r
F
.48805 1.06579 m .48897 1.06517 L .5105 1.03805 L F
.5024 1.02816 m .4899 1.05252 L .53569 .98621 L .862 .644 .606 r
F
.4899 1.05252 m .49379 1.0506 L .53569 .98621 L F
.4766 1.05929 m .47709 1.05939 L .47477 1.05894 L .951 .614 .21 r
F
.5203 .99008 m .47485 1.05895 L .4775 1.05947 L .862 .644 .606 r
F
.4831 1.0729 m .48537 1.06975 L .48805 1.06579 L .619 .823 .419 r
F
.4831 1.0729 m .48805 1.06579 L .49116 1.06115 L F
.52911 1.01017 m .53226 1.00648 L .53515 .98746 L .865 .833 .813 r
F
.53594 .98642 m .49393 1.05053 L .53491 .98834 L .923 .957 .632 r
F
.49393 1.05053 m .49415 1.05029 L .53491 .98834 L F
.49393 1.05054 m .49393 1.05053 L .53617 .98606 L .862 .644 .606 r
F
.49393 1.05053 m .50156 1.0455 L .4948 1.04957 L .619 .823 .419 r
F
.49261 1.05201 m .49611 1.04946 L .49393 1.05053 L F
.49611 1.04946 m .50156 1.0455 L .49393 1.05053 L F
.49261 1.05201 m .49393 1.05053 L .47696 1.06032 L F
.49393 1.05053 m .4899 1.05252 L .47696 1.06032 L F
.53569 .98621 m .49379 1.0506 L .53617 .98606 L .862 .644 .606 r
F
.49379 1.0506 m .49393 1.05054 L .53617 .98606 L F
.52015 1.07616 m .5099 1.07891 L .51371 1.07881 L .534 .924 .853 r
F
.60316 .99195 m .49848 1.06465 L .6078 .99287 L .827 .998 .78 r
F
.6078 .99287 m .49848 1.06465 L .52015 1.07616 L .849 .91 .876 r
F
.52901 1.04683 m .50051 1.10209 L .47976 1.05192 L .417 .456 .793 r
F
.50608 1.11405 m .50634 1.11463 L .48182 1.07458 L .629 .212 0 r
F
.4823 1.07328 m .48228 1.0752 L .48974 1.08752 L F
.49237 1.09188 m .49238 1.09189 L .48138 1.07372 L 0 .075 .633 r
F
.4823 1.07328 m .48974 1.08752 L .49693 1.09924 L .629 .212 0 r
F
.50634 1.11463 m .50633 1.11464 L .48168 1.07481 L 0 0 .384 r
F
.51229 1.12402 m .51037 1.12378 L .5064 1.11456 L .395 .305 .635 r
F
.51037 1.12378 m .50634 1.11463 L .5064 1.11456 L F
.50515 1.11977 m .50809 1.11748 L .50652 1.1224 L 0 0 .384 r
F
.48168 1.07481 m .50698 1.11569 L .50515 1.11977 L F
.50698 1.11569 m .50809 1.11748 L .50515 1.11977 L F
.48168 1.07481 m .50652 1.1224 L .48122 1.07553 L F
.49969 1.10367 m .50008 1.10431 L .49746 1.10799 L .417 .456 .793 r
F
.4823 1.07328 m .49658 1.09861 L .50608 1.11405 L .629 .212 0 r
F
.49658 1.09861 m .50379 1.11037 L .50608 1.11405 L F
.64911 1.00997 m .52015 1.07616 L .54706 1.11325 L .776 .778 .854 r
F
.6078 .99287 m .52015 1.07616 L .64911 1.00997 L .849 .91 .876 r
F
.53262 1.05862 m .50856 1.11216 L .50379 1.11037 L .417 .456 .793 r
F
.50008 1.10431 m .50379 1.11037 L .49746 1.10799 L F
.53262 1.05862 m .50379 1.11037 L .50008 1.10431 L F
.49969 1.10367 m .49746 1.10799 L .49237 1.09188 L F
.49658 1.09861 m .49763 1.10046 L .50379 1.11037 L .629 .212 0 r
F
.50856 1.11216 m .49631 1.11007 L .49848 1.10838 L .395 .305 .635 r
F
.50856 1.11216 m .49272 1.11655 L .49631 1.11007 L F
.48438 1.11253 m .50086 1.14019 L .49972 1.13983 L .516 .147 .278 r
F
.48435 1.11216 m .50086 1.14019 L .48438 1.11253 L F
.55427 1.12932 m .54054 1.15216 L .48034 1.11999 L .395 .305 .635 r
F
.54054 1.15216 m .48865 1.12801 L .48034 1.11999 L F
.50038 1.11554 m .50652 1.1224 L .49803 1.13088 L 0 0 .384 r
F
.49933 1.12239 m .49488 1.12183 L .50856 1.11216 L .395 .305 .635 r
F
.49488 1.12183 m .49272 1.11655 L .50856 1.11216 L F
.50608 1.11405 m .50809 1.11748 L .50634 1.11463 L .629 .212 0 r
F
.50675 1.1152 m .49763 1.10046 L .50809 1.11748 L F
.50608 1.11405 m .50379 1.11037 L .50675 1.1152 L F
.50379 1.11037 m .49763 1.10046 L .50675 1.1152 L F
.52901 1.04683 m .53262 1.05862 L .50008 1.10431 L .417 .456 .793 r
F
.52901 1.04683 m .50008 1.10431 L .49969 1.10367 L F
.69509 1.04046 m .54706 1.11325 L .57781 1.17549 L .699 .653 .801 r
F
.64911 1.00997 m .54706 1.11325 L .69509 1.04046 L .776 .778 .854 r
F
.53262 1.05862 m .55427 1.12932 L .50856 1.11216 L .417 .456 .793 r
F
.49238 1.09189 m .49746 1.10799 L .48029 1.07191 L 0 .075 .633 r
F
.48974 1.08752 m .49009 1.0882 L .49237 1.09188 L .629 .212 0 r
F
.48974 1.08752 m .49237 1.09188 L .49693 1.09924 L F
.48138 1.07372 m .48029 1.07191 L .48029 1.07191 L 0 .075 .633 r
F
.49238 1.09189 m .48029 1.07191 L .48138 1.07372 L F
.4811 1.07316 m .48138 1.07372 L .4823 1.07328 L .629 .212 0 r
F
.48138 1.07372 m .48228 1.07549 L .48228 1.0752 L F
.48138 1.07372 m .48228 1.0752 L .4823 1.07328 L F
.48031 1.07194 m .48046 1.07218 L .4794 1.07023 L .613 .046 0 r
F
.47932 1.0701 m .4794 1.07023 L .47383 1.05993 L F
.48031 1.07194 m .4794 1.07023 L .47932 1.0701 L F
.48122 1.07553 m .48525 1.083 L .48352 1.08311 L 0 0 .384 r
F
.48081 1.07618 m .48028 1.07703 L .48138 1.07541 L .619 .823 .419 r
F
.47336 1.08631 m .48028 1.07703 L .48081 1.07618 L F
.47957 1.07831 m .48115 1.07692 L .48109 1.07698 L 0 0 0 r
F
.47957 1.07831 m .48109 1.07698 L .48097 1.07625 L F
.47825 1.08001 m .47957 1.07831 L .48097 1.07625 L .619 .823 .419 r
F
.48029 1.07191 m .49746 1.10799 L .4767 1.06837 L 0 .075 .633 r
F
.46602 1.04621 m .45751 1.043 L .47697 1.06853 L .613 .046 0 r
F
.46602 1.04621 m .47697 1.06853 L .47856 1.06944 L F
.46602 1.04621 m .48073 1.07345 L .48097 1.07314 L F
.47704 1.06653 m .4767 1.06837 L .46818 1.05267 L 0 .075 .633 r
F
.4767 1.06837 m .47336 1.08631 L .47001 1.06456 L F
.4767 1.06837 m .47001 1.06456 L .46818 1.05267 L F
.47856 1.06944 m .47697 1.06853 L .48073 1.07345 L .613 .046 0 r
F
.46818 1.05267 m .47704 1.06653 L .46818 1.05267 L 0 .075 .633 r
F
.47293 1.05861 m .48031 1.07194 L .47383 1.05993 L .613 .046 0 r
F
.47673 1.06415 m .48057 1.07207 L .4821 1.07326 L .629 .212 0 r
F
.47673 1.06415 m .4821 1.07326 L .4823 1.07328 L F
.47556 1.06173 m .47673 1.06415 L .4823 1.07328 L F
.47283 1.05846 m .47291 1.05861 L .47293 1.05861 L .613 .046 0 r
F
.47291 1.05861 m .48029 1.07191 L .47293 1.05861 L F
.48029 1.07191 m .48097 1.07314 L .48031 1.07194 L F
.48029 1.07191 m .48031 1.07194 L .47293 1.05861 L F
.47704 1.06653 m .48029 1.07191 L .47704 1.06653 L 0 .075 .633 r
F
.48097 1.07314 m .48101 1.07315 L .48074 1.07265 L .613 .046 0 r
F
.48046 1.07218 m .48074 1.07265 L .46808 1.0493 L F
.48097 1.07314 m .48074 1.07265 L .48046 1.07218 L F
.48279 1.07334 m .48284 1.07326 L .48272 1.07333 L .619 .823 .419 r
F
.48086 1.07285 m .4811 1.07316 L .47395 1.05897 L .613 .046 0 r
F
.48101 1.07315 m .48104 1.07315 L .48086 1.07285 L F
.48104 1.07315 m .4811 1.07316 L .48086 1.07285 L F
.47018 1.05317 m .48101 1.07315 L .4723 1.05655 L F
.47489 1.06148 m .48101 1.07315 L .47602 1.06314 L F
.48284 1.07334 m .48293 1.07335 L .48537 1.06975 L .619 .823 .419 r
F
.47976 1.05192 m .48867 1.08015 L .48029 1.07191 L 0 .075 .633 r
F
.47976 1.05192 m .48029 1.07191 L .47704 1.06653 L F
.48029 1.07191 m .48029 1.07191 L .47704 1.06653 L F
.4649 1.0442 m .47283 1.05846 L .46808 1.0493 L .613 .046 0 r
F
.47429 1.05971 m .47696 1.06032 L .47367 1.05873 L .951 .614 .21 r
F
.46872 1.05049 m .47018 1.05317 L .47141 1.05486 L .613 .046 0 r
F
.47018 1.05317 m .4723 1.05655 L .47141 1.05486 L F
.46872 1.05049 m .47141 1.05486 L .47103 1.05412 L F
.51983 .98996 m .47485 1.05895 L .5203 .99008 L .862 .644 .606 r
F
.51983 .98996 m .47463 1.05794 L .47485 1.05895 L F
.51969 .98992 m .47463 1.05794 L .51983 .98996 L F
.4766 1.05929 m .47696 1.06032 L .47709 1.05939 L .951 .614 .21 r
F
.4775 1.05947 m .4766 1.05929 L .47686 1.06001 L .862 .644 .606 r
F
.46626 1.04633 m .46808 1.0493 L .46766 1.04852 L .613 .046 0 r
F
.4649 1.0442 m .46808 1.0493 L .46626 1.04633 L F
.47156 1.05514 m .47396 1.059 L .47395 1.05897 L F
.46766 1.04852 m .46808 1.0493 L .47103 1.05412 L F
.4738 1.05875 m .4674 1.04673 L .46602 1.04621 L .938 .694 .543 r
F
.476 1.05918 m .4766 1.05929 L .47435 1.05885 L .951 .614 .21 r
F
.4766 1.05929 m .47477 1.05894 L .47435 1.05885 L F
.50909 .98932 m .4846 1.01688 L .47467 1.05755 L .685 .415 .508 r
F
.51482 .97797 m .47467 1.05755 L .49764 1.02321 L F
.47467 1.05755 m .47463 1.05794 L .49764 1.02321 L F
.46188 1.03953 m .47431 1.05576 L .47135 1.03529 L .938 .694 .543 r
F
.47156 1.05514 m .47489 1.06148 L .47396 1.059 L .613 .046 0 r
F
.47489 1.06148 m .47602 1.06314 L .47395 1.05897 L F
.47976 1.05192 m .47704 1.06653 L .46818 1.05267 L 0 .075 .633 r
F
.47704 1.06653 m .47704 1.06653 L .46818 1.05267 L F
.47704 1.06653 m .48029 1.07191 L .4767 1.06837 L F
.48867 1.08015 m .49237 1.09188 L .48029 1.07191 L F
.49237 1.09188 m .48138 1.07372 L .48029 1.07191 L F
.48974 1.08752 m .48228 1.07549 L .49009 1.0882 L .629 .212 0 r
F
.48228 1.0752 m .48228 1.07549 L .48974 1.08752 L F
.49693 1.09924 m .49009 1.0882 L .49763 1.10046 L F
.50051 1.10209 m .49969 1.10367 L .48447 1.06684 L .417 .456 .793 r
F
.49969 1.10367 m .49237 1.09188 L .48447 1.06684 L F
.50051 1.10209 m .48447 1.06684 L .47976 1.05192 L F
.49272 1.11655 m .48034 1.11999 L .49105 1.11248 L .395 .305 .635 r
F
.49272 1.11655 m .49105 1.11248 L .49746 1.10799 L F
.4815 1.08324 m .48019 1.08332 L .47961 1.08031 L 0 0 .183 r
F
.49746 1.10799 m .48019 1.08332 L .4815 1.08324 L F
.48646 1.1157 m .48 1.10147 L .47961 1.08031 L F
.4804 1.07968 m .47961 1.08031 L .47957 1.07831 L F
.49746 1.10799 m .47961 1.08031 L .4804 1.07968 L F
.48616 1.09783 m .47957 1.07831 L .47336 1.08631 L F
.49746 1.10799 m .48431 1.08616 L .48616 1.09783 L F
.48431 1.08616 m .47957 1.07831 L .48616 1.09783 L F
.50383 1.11741 m .50652 1.1224 L .50294 1.1184 L 0 0 .384 r
F
.49488 1.12183 m .48034 1.11999 L .49272 1.11655 L .395 .305 .635 r
F
.47336 1.08631 m .47825 1.08001 L .48028 1.07703 L .619 .823 .419 r
F
.4767 1.06837 m .49746 1.10799 L .48616 1.09783 L 0 .075 .633 r
F
.47608 1.07169 m .48616 1.09783 L .47336 1.08631 L F
.4767 1.06837 m .48616 1.09783 L .47608 1.07169 L F
.48031 1.07194 m .48097 1.07314 L .48046 1.07218 L .613 .046 0 r
F
.48097 1.07314 m .48073 1.07345 L .48228 1.07549 L F
.47697 1.06853 m .45716 1.05849 L .48228 1.07549 L F
.45918 1.05838 m .45716 1.05849 L .47697 1.06853 L F
.45112 1.05377 m .47336 1.08631 L .44868 1.05393 L 0 .075 .633 r
F
.45689 1.05552 m .45716 1.05849 L .46881 1.05782 L .613 .046 0 r
F
.45551 1.04038 m .45569 1.04231 L .45751 1.043 L F
.44015 1.04928 m .47521 1.03355 L .43578 1.0447 L .938 .694 .543 r
F
.43578 1.0447 m .47521 1.03355 L .43583 1.0435 L F
.47521 1.03355 m .47176 1.0335 L .43583 1.0435 L F
.43583 1.0435 m .44812 1.03392 L .44352 1.03116 L .864 .65 .611 r
F
.45611 1.02569 m .45354 1.02676 L .45551 1.04038 L .352 0 0 r
F
.44812 1.03392 m .4524 1.03059 L .44691 1.02909 L .864 .65 .611 r
F
.4524 1.03059 m .45416 1.02468 L .44691 1.02909 L F
.44812 1.03392 m .44691 1.02909 L .44352 1.03116 L F
.45625 1.02223 m .45464 1.0231 L .45611 1.02569 L .352 0 0 r
F
.45464 1.0231 m .45446 1.02369 L .45611 1.02569 L F
.45864 1.02875 m .45551 1.04038 L .46031 1.03332 L F
.45625 1.02223 m .45611 1.02569 L .45864 1.02875 L F
.45611 1.02569 m .45551 1.04038 L .45864 1.02875 L F
.45488 1.0234 m .46821 1.01429 L .45296 1.02187 L .785 .573 .614 r
F
.45418 1.02334 m .45296 1.02187 L .45056 1.02307 L F
.45488 1.0234 m .45296 1.02187 L .45418 1.02334 L F
.47494 1.01964 m .49413 .97515 L .46672 1.03342 L .439 .15 .376 r
F
.48085 1.00842 m .46821 1.01429 L .45446 1.02369 L .864 .65 .611 r
F
.45416 1.02468 m .45446 1.02369 L .44352 1.03116 L F
.45418 1.02334 m .42851 1.03708 L .45611 1.02569 L .352 0 0 r
F
.42851 1.03708 m .42864 1.03722 L .45611 1.02569 L F
.45354 1.02676 m .42864 1.03722 L .44968 1.03969 L F
.44962 1.03989 m .42959 1.03821 L .44566 1.05003 L .613 .046 0 r
F
.44962 1.03989 m .44566 1.05003 L .44654 1.05064 L F
.44724 1.05112 m .45112 1.05377 L .44868 1.05393 L .318 .468 .852 r
F
.45339 1.05495 m .44653 1.05067 L .45363 1.0559 L .613 .046 0 r
F
.44962 1.03989 m .44653 1.05067 L .45339 1.05495 L F
.48085 1.00842 m .45446 1.02369 L .45416 1.02468 L .864 .65 .611 r
F
.45354 1.02676 m .44968 1.03969 L .45551 1.04038 L .352 0 0 r
F
.4524 1.03059 m .48085 1.00842 L .45416 1.02468 L .864 .65 .611 r
F
.45551 1.04038 m .44962 1.03989 L .45716 1.05849 L .613 .046 0 r
F
.44962 1.03989 m .45363 1.0559 L .45716 1.05849 L F
.45569 1.04231 m .46602 1.04621 L .46188 1.03953 L .938 .694 .543 r
F
.42864 1.03722 m .42959 1.03821 L .45551 1.04038 L .352 0 0 r
F
.40718 1.02255 m .39472 1.02358 L .44768 1.02682 L F
.45056 1.02307 m .46821 1.01429 L .5003 .96583 L .785 .573 .614 r
F
.44768 1.02682 m .41143 1.02461 L .43761 1.0322 L .352 0 0 r
F
.40445 1.01877 m .40976 1.02233 L .44945 1.02225 L 0 0 0 r
F
.43853 1.00727 m .43306 1.00857 L .42681 1.01007 L F
.47494 1.01964 m .46672 1.03342 L .46733 1.03343 L .439 .15 .376 r
F
.47494 1.01964 m .46733 1.03343 L .47044 1.02941 L F
.4524 1.03059 m .46874 1.0331 L .4797 1.00931 L .864 .65 .611 r
F
.4582 1.03643 m .46874 1.0331 L .4524 1.03059 L F
.46602 1.04621 m .4674 1.04673 L .46188 1.03953 L .938 .694 .543 r
F
.47176 1.0335 m .46768 1.03343 L .4582 1.03643 L F
.47176 1.0335 m .4582 1.03643 L .45749 1.03747 L F
.47135 1.03529 m .47521 1.05149 L .47689 1.0328 L F
.40712 .97278 m .47976 1.05192 L .45112 1.05377 L .318 .468 .852 r
F
.43761 1.0322 m .41554 1.03114 L .42851 1.03708 L .352 0 0 r
F
.43761 1.0322 m .38697 1.02423 L .40561 1.03066 L F
.41143 1.02461 m .40991 1.02743 L .43761 1.0322 L F
.38366 1.02291 m .37538 1.0224 L .43761 1.0322 L F
.40712 .97278 m .45112 1.05377 L .44724 1.05112 L .318 .468 .852 r
F
.44654 1.05064 m .44566 1.05003 L .44653 1.05067 L .613 .046 0 r
F
.40712 .97278 m .44724 1.05112 L .38373 .98865 L .318 .468 .852 r
F
.44724 1.05112 m .44868 1.05393 L .44367 1.04889 L F
.42959 1.03821 m .44949 1.05331 L .45716 1.05849 L .613 .046 0 r
F
.44724 1.05112 m .44367 1.04889 L .38373 .98865 L .318 .468 .852 r
F
.43476 1.03994 m .44868 1.05393 L .42084 1.03357 L 0 .254 .757 r
F
.42851 1.03708 m .42682 1.03798 L .42864 1.03722 L .352 0 0 r
F
.38373 .98865 m .43476 1.03994 L .42851 1.03708 L 0 .254 .757 r
F
.41496 1.02289 m .42851 1.03708 L .42747 1.0366 L F
.38373 .98865 m .42851 1.03708 L .41496 1.02289 L F
.45464 1.0231 m .45418 1.02334 L .45446 1.02369 L .352 0 0 r
F
.42959 1.03821 m .42682 1.03798 L .44949 1.05331 L .613 .046 0 r
F
.41643 1.02823 m .42747 1.0366 L .42084 1.03357 L 0 .254 .757 r
F
.40596 1.01508 m .39537 1.01759 L .40117 1.01623 L 0 0 0 r
F
.38373 .98865 m .42747 1.0366 L .41643 1.02823 L 0 .254 .757 r
F
.46818 1.05267 m .47001 1.06456 L .45112 1.05377 L 0 .075 .633 r
F
.51229 1.12402 m .5064 1.11456 L .50856 1.11216 L .395 .305 .635 r
F
.50634 1.11463 m .50809 1.11748 L .50633 1.11464 L 0 0 .384 r
F
.50834 1.03581 m .51534 1.03162 L .5127 1.02938 L 0 0 0 r
F
.51534 1.03162 m .51993 1.02578 L .5127 1.02938 L F
.50861 1.03515 m .5105 1.03805 L .52733 1.01687 L .923 .957 .632 r
F
.502 1.0416 m .50516 1.04028 L .50861 1.03515 L F
.50516 1.04028 m .5105 1.03805 L .50861 1.03515 L F
.51092 1.03194 m .50948 1.03411 L .5127 1.02938 L .619 .823 .419 r
F
.53156 1.00093 m .50861 1.03515 L .52733 1.01687 L .923 .957 .632 r
F
.53479 .98881 m .50861 1.03515 L .53156 1.00093 L F
.48097 1.07314 m .48228 1.07549 L .48101 1.07315 L .613 .046 0 r
F
.43514 1.04403 m .44868 1.05393 L .44365 1.05294 L 0 .254 .757 r
F
.43514 1.04403 m .44365 1.05294 L .43553 1.05135 L F
.42864 1.03722 m .42682 1.03798 L .42959 1.03821 L .352 0 0 r
F
.42851 1.03708 m .40812 1.03078 L .42688 1.03795 L F
.41554 1.03114 m .40812 1.03078 L .42851 1.03708 L F
.39091 1.01869 m .40022 1.02313 L .40718 1.02255 L .783 .326 .159 r
F
.41143 1.02461 m .39472 1.02358 L .40991 1.02743 L .352 0 0 r
F
.38373 .98865 m .42084 1.03357 L .36833 1.00165 L 0 .254 .757 r
F
.39472 1.02358 m .3899 1.02399 L .40991 1.02743 L .352 0 0 r
F
.39449 1.01787 m .40991 1.02743 L .3823 1.02075 L .69 .152 0 r
F
.40991 1.02743 m .3899 1.02399 L .3823 1.02075 L F
.38901 1.01914 m .3789 1.02153 L .37622 1.0222 L 0 0 0 r
F
.38901 1.01914 m .37622 1.0222 L .37867 1.02161 L F
.38901 1.01914 m .38803 1.01937 L .35994 1.01341 L .783 .326 .159 r
F
.35873 1.01818 m .37959 1.02137 L .38795 1.01937 L .746 .346 .294 r
F
.35994 1.01341 m .38803 1.01937 L .35873 1.01818 L .783 .326 .159 r
F
.38803 1.01937 m .37959 1.02137 L .35873 1.01818 L F
.36044 1.01146 m .3823 1.02075 L .39091 1.01869 L F
.39449 1.01787 m .3823 1.02075 L .36044 1.01146 L .69 .152 0 r
F
.37407 1.00589 m .40801 1.03099 L .37811 1.00771 L F
.40801 1.03099 m .40822 1.03059 L .37811 1.00771 L F
.40812 1.03078 m .40779 1.03141 L .42688 1.03795 L .352 0 0 r
F
.37811 1.00771 m .40822 1.03059 L .40991 1.02743 L .69 .152 0 r
F
.36833 1.00165 m .37407 1.00589 L .37811 1.00771 L F
.42084 1.03357 m .40801 1.03099 L .36833 1.00165 L 0 .254 .757 r
F
.42688 1.03795 m .40779 1.03141 L .42682 1.03798 L .352 0 0 r
F
.40779 1.03141 m .40561 1.03066 L .40779 1.03141 L F
.40779 1.03141 m .40779 1.03141 L .42682 1.03798 L F
.38697 1.02423 m .37538 1.0224 L .38261 1.02459 L F
.38697 1.02423 m .38261 1.02459 L .42682 1.03798 L F
.45446 1.02369 m .45488 1.0234 L .45418 1.02334 L .785 .573 .614 r
F
.37867 1.02161 m .37622 1.0222 L .37538 1.0224 L 0 0 0 r
F
.45589 1.01235 m .46463 1.00412 L .4666 1.00057 L .688 .477 .596 r
F
.45589 1.01235 m .45917 1.00689 L .46299 1.00142 L F
.45589 1.01235 m .4666 1.00057 L .46236 1.00159 L F
.45656 1.01296 m .46463 1.00412 L .45589 1.01235 L F
.50958 .98603 m .51081 .98359 L .50985 .98389 L .722 .573 .687 r
F
.5298 .85809 m .5266 .91004 L .52991 .93461 L .58 .472 .695 r
F
.54623 .89354 m .54405 .91961 L .55195 .90589 L .731 .611 .724 r
F
.54623 .89354 m .55195 .90589 L .55384 .90262 L F
.53387 .93852 m .53108 .94328 L .52421 .95693 L .851 .705 .7 r
F
.55384 .90262 m .5407 .95963 L .55507 .91802 L .731 .611 .724 r
F
.54405 .91961 m .5407 .95963 L .55384 .90262 L F
.53939 .9236 m .53803 .93093 L .53955 .92807 L F
.51003 .99107 m .53955 .92807 L .51796 .96938 L .851 .705 .7 r
F
.53955 .92807 m .52421 .95693 L .51796 .96938 L F
.54049 .97374 m .54111 .9734 L .54054 .97043 L .731 .611 .724 r
F
.5407 .95963 m .54054 .97043 L .55507 .91802 L F
.53955 .92807 m .54101 .93808 L .5412 .92454 L .851 .705 .7 r
F
.54727 .88106 m .53939 .9236 L .5407 .95963 L .731 .611 .724 r
F
.55437 .9234 m .56353 .86971 L .56022 .87867 L .743 .672 .782 r
F
.5542 .92436 m .54813 .94738 L .55169 .93913 L .783 .681 .752 r
F
.54813 .94738 m .54131 .97323 L .5498 .94973 L F
.52821 .98733 m .54049 .97374 L .5159 .98893 L .851 .705 .7 r
F
.51969 .98992 m .5159 .98893 L .50905 .99316 L F
.52821 .98733 m .5159 .98893 L .51969 .98992 L F
.54049 .97374 m .54052 .97164 L .50905 .99316 L F
.54034 .97776 m .55474 .96105 L .54075 .97699 L .865 .833 .813 r
F
.53607 .98574 m .54305 .97651 L .54034 .97776 L F
.54305 .97651 m .55474 .96105 L .54034 .97776 L F
.54111 .9734 m .54049 .97374 L .53982 .97448 L .963 .919 .714 r
F
.54238 .97234 m .53982 .97448 L .52676 .98893 L F
.48535 1.04838 m .5024 1.02816 L .54226 .97268 L F
.48535 1.04838 m .54226 .97268 L .54238 .97234 L F
.52049 .99013 m .52821 .98733 L .51969 .98992 L .851 .705 .7 r
F
.53226 1.00648 m .59759 .93001 L .53607 .98574 L .865 .833 .813 r
F
.59759 .93001 m .61297 .912 L .59202 .93209 L F
.59759 .93001 m .59202 .93209 L .53607 .98574 L F
.59996 .86368 m .58934 .93309 L .62005 .86759 L .782 .709 .783 r
F
.59333 .89794 m .58934 .93309 L .59996 .86368 L F
.58934 .93309 m .59759 .93001 L .62005 .86759 L F
.59428 .93388 m .58605 .96208 L .59759 .93001 L .865 .833 .813 r
F
.58605 .96208 m .58527 .96473 L .59759 .93001 L F
.62005 .86759 m .58605 .96208 L .62736 .86902 L .782 .709 .783 r
F
.58605 .96208 m .57524 .98642 L .57874 .98711 L .751 .708 .811 r
F
.57115 .99162 m .57661 .98845 L .61297 .912 L .865 .833 .813 r
F
.60707 .93584 m .69644 .80118 L .6197 .92152 L .888 .96 .839 r
F
.60707 .93584 m .6702 .82323 L .69644 .80118 L F
.62736 .86902 m .58605 .96208 L .6078 .99287 L .751 .708 .811 r
F
.58605 .96208 m .57874 .98711 L .6078 .99287 L F
.52911 1.01017 m .57115 .99162 L .58527 .96473 L .865 .833 .813 r
F
.52911 1.01017 m .58527 .96473 L .59428 .93388 L F
.57115 .99162 m .57615 .98941 L .57661 .98845 L F
.56691 .99408 m .57115 .99162 L .56788 .99306 L F
.56622 .9948 m .57615 .98941 L .57115 .99162 L F
.56416 .99696 m .57615 .98941 L .56622 .9948 L F
.56416 .99696 m .55952 1.00457 L .57615 .98941 L F
.55428 1.00734 m .55952 1.00457 L .56416 .99696 L F
.53491 .98834 m .49415 1.05029 L .50191 1.04164 L .923 .957 .632 r
F
.48118 1.03088 m .46768 1.03343 L .47176 1.0335 L .938 .694 .543 r
F
.47521 1.03355 m .48118 1.03088 L .47176 1.0335 L F
.51123 .95389 m .50641 .95988 L .47494 1.01964 L .439 .15 .376 r
F
.4797 1.00931 m .47543 1.01871 L .48085 1.00842 L .864 .65 .611 r
F
.4846 1.01688 m .47048 1.03277 L .48118 1.03088 L .685 .415 .508 r
F
.47689 1.0328 m .47701 1.04797 L .48118 1.03088 L .938 .694 .543 r
F
.48101 1.07315 m .48228 1.07549 L .4811 1.07316 L .613 .046 0 r
F
.46551 1.10461 m .46242 1.1101 L .46636 1.10515 L .695 .275 .246 r
F
.46551 1.10461 m .46656 1.10562 L .46242 1.1101 L F
.49803 1.13088 m .50086 1.14019 L .49866 1.13267 L 0 0 .384 r
F
.49803 1.13088 m .50652 1.1224 L .50086 1.14019 L F
.48035 1.12415 m .48485 1.12625 L .48011 1.13368 L .516 .147 .278 r
F
.47134 1.1102 m .48011 1.13368 L .46763 1.11705 L .695 .275 .246 r
F
.48646 1.1157 m .48034 1.11999 L .48 1.10147 L 0 0 .183 r
F
.57874 .98711 m .56116 1.00409 L .60316 .99195 L .827 .998 .78 r
F
.55952 1.00457 m .57611 .9895 L .57615 .98941 L .865 .833 .813 r
F
.52911 1.01017 m .52733 1.01687 L .53456 1.00776 L .923 .957 .632 r
F
.50905 .99316 m .49764 1.02321 L .51969 .98992 L .685 .415 .508 r
F
.50905 .99316 m .51003 .99107 L .50999 .99068 L .851 .705 .7 r
F
.51482 .97797 m .49508 .99854 L .50909 .98932 L .685 .415 .508 r
F
.40557 .79522 m .39963 .79286 L .34995 .80103 L .438 .876 .871 r
F
.34995 .80103 m .39963 .79286 L .35012 .79903 L F
.39963 .79286 m .39842 .79238 L .35012 .79903 L F
.35012 .79903 m .39842 .79238 L .4068 .79278 L .041 0 0 r
F
.35012 .79903 m .4068 .79278 L .35755 .78603 L F
.39721 .79813 m .40557 .79522 L .34995 .80103 L .438 .876 .871 r
F
.42608 .79964 m .4049 .79403 L .40557 .79522 L 0 .521 .831 r
F
.41068 .79726 m .40557 .79522 L .40634 .79658 L F
.42608 .79964 m .40557 .79522 L .41068 .79726 L F
.30139 .98781 m .30138 .98781 L .28822 .98277 L .655 .102 0 r
F
.34883 .81493 m .39721 .79813 L .34995 .80103 L .438 .876 .871 r
F
.34883 .81493 m .40729 .79827 L .39721 .79813 L F
.40729 .79827 m .40639 .79667 L .39721 .79813 L F
.55159 .78001 m .55189 .77556 L .55269 .77896 L .599 .432 .627 r
F
.54554 .78105 m .56708 .779 L .56794 .78404 L .592 .48 .695 r
F
.55159 .78001 m .54554 .78105 L .55189 .77556 L .599 .432 .627 r
F
.54554 .78105 m .5399 .7803 L .55189 .77556 L F
.56504 .77872 m .55189 .77556 L .56716 .76966 L .569 .453 .682 r
F
.55291 .77896 m .55189 .77556 L .56504 .77872 L F
.56673 .77837 m .56676 .77778 L .56708 .779 L .322 .245 .612 r
F
.56672 .77868 m .56673 .77837 L .56708 .779 L F
.57816 .76541 m .56716 .76966 L .57839 .76132 L .569 .453 .682 r
F
.56716 .76966 m .55189 .77556 L .56727 .76729 L F
.56716 .76966 m .56727 .76729 L .57839 .76132 L F
.54461 .73984 m .5513 .75037 L .55189 .77556 L 0 0 0 r
F
.039 .916 .04 r
.41997 .87268 m
.44249 .86544 L
s
.44249 .86544 m
.47936 .85359 L
s
.47936 .85359 m
.48523 .85171 L
s
.47972 .85821 m
.48096 .85758 L
s
.48096 .85758 m
.48287 .85661 L
s
.48287 .85661 m
.48533 .85536 L
s
.48533 .85536 m
.4859 .85507 L
s
.4859 .85507 m
.48656 .85474 L
s
.28633 .89729 m .39826 .89444 L .3803 .87371 L .888 .695 .635 r
F
.039 .916 .04 r
.41276 .88223 m
.41364 .87761 L
s
.28995 .91117 m .39826 .89444 L .28633 .89729 L .869 .632 .577 r
F
.30085 .95734 m .45399 .96779 L .2993 .94761 L .806 .462 .406 r
F
.039 .916 .04 r
.39392 .98173 m
.41276 .88223 L
s
.28319 .88296 m .3803 .87371 L .36488 .85304 L .903 .765 .699 r
F
.28633 .89729 m .3803 .87371 L .28319 .88296 L .888 .695 .635 r
F
.60083 .68422 m .55899 .67345 L .55799 .71594 L .893 .762 .71 r
F
.60083 .68422 m .58358 .62142 L .55899 .67345 L F
.64557 .65191 m .58358 .62142 L .60083 .68422 L .744 .663 .771 r
F
.69881 .75293 m .69355 .61225 L .67865 .62514 L .181 .24 .689 r
F
.71386 .7626 m .69355 .61225 L .69881 .75293 L .839 .622 .076 r
F
.039 .916 .04 r
.65719 .86863 m
.66286 .87093 L
s
.65883 .86684 m
.66286 .87093 L
s
.65675 .86472 m
.65883 .86684 L
s
.64557 .65191 m .60487 .56705 L .58358 .62142 L .744 .663 .771 r
F
.67865 .62514 m .60487 .56705 L .64557 .65191 L .557 .59 .842 r
F
.6197 .92152 m .69644 .80118 L .71227 .77959 L .69 .882 .501 r
F
.039 .916 .04 r
.65576 .86806 m
.65719 .86863 L
s
.65482 .86767 m
.65576 .86806 L
s
.64479 .84943 m
.64621 .85041 L
s
.62666 .80624 m
.64662 .79983 L
s
.644 .84824 m
.64621 .85041 L
s
.36488 .85304 m .43608 .80286 L .35394 .83318 L .82 .851 .871 r
F
0 g
.51653 .75716 m
.53814 .73657 L
s
.28097 .86848 m .36488 .85304 L .35394 .83318 L .909 .841 .766 r
F
.28319 .88296 m .36488 .85304 L .28097 .86848 L .903 .765 .699 r
F
0 g
.53814 .73657 m
.55038 .71078 L
s
.55899 .67345 m
.58358 .62142 L
s
.71386 .7626 m .69156 .61819 L .69355 .61225 L .839 .622 .076 r
F
.71227 .77959 m .69156 .61819 L .71386 .7626 L .975 .811 .615 r
F
.67865 .62514 m .60674 .52317 L .60487 .56705 L .557 .59 .842 r
F
0 g
.58358 .62142 m
.60487 .56705 L
s
.69355 .61225 m .60674 .52317 L .67865 .62514 L 0 .045 .559 r
F
.28007 .85416 m .35394 .83318 L .34883 .81493 L .894 .916 .83 r
F
.28097 .86848 m .35394 .83318 L .28007 .85416 L .909 .841 .766 r
F
0 g
.55228 .72212 m
.55899 .67345 L
s
.71227 .77959 m .67781 .64153 L .69156 .61819 L .975 .811 .615 r
F
.69644 .80118 m .67781 .64153 L .71227 .77959 L .869 .758 .738 r
F
.28082 .8403 m .34883 .81493 L .35012 .79903 L .839 .975 .879 r
F
.28007 .85416 m .34883 .81493 L .28082 .8403 L .894 .916 .83 r
F
.69355 .61225 m .58985 .50402 L .60674 .52317 L 0 .045 .559 r
F
0 g
.60487 .56705 m
.60674 .52317 L
s
.69156 .61819 m .58985 .50402 L .69355 .61225 L .859 .552 .466 r
F
0 g
.56676 .77778 m
.56708 .779 L
s
.69644 .80118 m .65716 .67529 L .67781 .64153 L .869 .758 .738 r
F
.039 .916 .04 r
.66041 .64868 m
.66377 .66449 L
s
.6702 .82323 m .65716 .67529 L .69644 .80118 L .762 .685 .778 r
F
.039 .916 .04 r
.68869 .78174 m
.68959 .78601 L
s
.68787 .77792 m
.6879 .77802 L
s
.6879 .77802 m
.68869 .78174 L
s
.68717 .78679 m
.68959 .78601 L
s
.68208 .78843 m
.68281 .78819 L
s
.64662 .79983 m
.66755 .7931 L
s
.68281 .78819 m
.68717 .78679 L
s
.57839 .76132 m .55252 .68936 L .55077 .66583 L 0 0 .485 r
F
.55189 .77556 m .55252 .68936 L .57839 .76132 L 0 0 .118 r
F
0 g
.55038 .71078 m
.55252 .68936 L
s
.25947 .87191 m .29358 .92434 L .28995 .91117 L .888 .595 .084 r
F
.25947 .87191 m .29681 .93655 L .29358 .92434 L .879 .578 .063 r
F
.25947 .87191 m .2993 .94761 L .29681 .93655 L .883 .585 .071 r
F
.25947 .87191 m .28995 .91117 L .28633 .89729 L .907 .634 .134 r
F
.25947 .87191 m .30085 .95734 L .2993 .94761 L .898 .609 .105 r
F
.6702 .82323 m .6325 .71047 L .65716 .67529 L .762 .685 .778 r
F
.63799 .84193 m .6325 .71047 L .6702 .82323 L .662 .599 .774 r
F
.25947 .87191 m .30133 .96563 L .30085 .95734 L .918 .643 .153 r
F
.25947 .87191 m .28633 .89729 L .28319 .88296 L .927 .689 .203 r
F
0 0 0 r
5 Mabswid
.68959 .78601 Mdot
0 g
.5 Mabswid
.63769 .04219 m
.64577 .46291 L
s
.63799 .84193 m .60567 .74006 L .6325 .71047 L .662 .599 .774 r
F
.25947 .87191 m .30076 .9724 L .30133 .96563 L .938 .675 .203 r
F
.28339 .8272 m .35012 .79903 L .35755 .78603 L .718 .986 .886 r
F
.28082 .8403 m .35012 .79903 L .28339 .8272 L .839 .975 .879 r
F
.25947 .87191 m .28319 .88296 L .28097 .86848 L .939 .75 .279 r
F
.039 .916 .04 r
.29112 .89254 m
.37236 .85775 L
s
.37236 .85775 m
.40764 .84264 L
s
.40764 .84264 m
.4143 .83978 L
s
.4143 .83978 m
.45227 .82352 L
s
.45227 .82352 m
.45311 .82316 L
s
.45311 .82316 m
.46307 .8189 L
s
.29095 .89262 m
.29112 .89254 L
s
.29006 .893 m
.29095 .89262 L
s
.28917 .89338 m
.29006 .893 L
s
.28829 .89375 m
.28917 .89338 L
s
.28639 .89457 m
.28829 .89375 L
s
.28557 .89492 m
.28639 .89457 L
s
.28483 .89524 m
.28557 .89492 L
s
.28461 .89533 m
.28483 .89524 L
s
.2911 .90478 m
.39156 .98333 L
s
.29096 .90467 m
.2911 .90478 L
s
.29023 .9041 m
.29096 .90467 L
s
.2894 .90345 m
.29023 .9041 L
s
.28873 .90293 m
.2894 .90345 L
s
.28702 .90158 m
.28873 .90293 L
s
.28595 .90075 m
.28702 .90158 L
s
.28551 .9004 m
.28595 .90075 L
s
.28503 .90003 m
.28551 .9004 L
s
0 g
.56708 .779 m
.56812 .78509 L
s
.60567 .74006 m .55077 .66583 L .54748 .63375 L .245 .367 .789 r
F
.039 .916 .04 r
.35137 .59567 m
.53892 .62539 L
s
.57839 .76132 m .55077 .66583 L .60567 .74006 L 0 0 .485 r
F
0 g
.55077 .66583 m
.55252 .68936 L
s
.69156 .61819 m .56705 .51468 L .58985 .50402 L .859 .552 .466 r
F
.67781 .64153 m .56705 .51468 L .69156 .61819 L .785 .593 .64 r
F
.25947 .87191 m .28097 .86848 L .28007 .85416 L .935 .807 .347 r
F
.57781 1.17549 m .3872 1.28099 L .61462 1.25066 L .769 .676 .76 r
F
0 g
.37931 1.79705 m
.38218 1.61516 L
s
.38745 1.28086 m
.38772 1.26388 L
s
.57781 1.17549 m .39595 1.18084 L .3872 1.28099 L .769 .676 .76 r
F
0 g
.38218 1.61516 m
.38422 1.48573 L
s
.38422 1.48573 m
.38745 1.28096 L
s
.74025 1.08192 m .57781 1.17549 L .61462 1.25066 L .624 .537 .735 r
F
.69509 1.04046 m .57781 1.17549 L .74025 1.08192 L .699 .653 .801 r
F
.61462 1.25066 m .42031 1.3872 L .65748 1.31796 L .727 .554 .657 r
F
.61462 1.25066 m .3872 1.28099 L .42031 1.3872 L F
.77844 1.1269 m .61462 1.25066 L .65748 1.31796 L .534 .409 .656 r
F
.74025 1.08192 m .61462 1.25066 L .77844 1.1269 L .624 .537 .735 r
F
.60567 .74006 m .54748 .63375 L .6325 .71047 L .245 .367 .789 r
F
.039 .916 .04 r
.53892 .62539 m
.65694 .6441 L
s
.25947 .87191 m .28007 .85416 L .28082 .8403 L .905 .847 .394 r
F
.28784 .81511 m .35755 .78603 L .37028 .77616 L .52 .915 .822 r
F
.28339 .8272 m .35755 .78603 L .28784 .81511 L .718 .986 .886 r
F
.6325 .71047 m .54748 .63375 L .5457 .59238 L .576 .563 .802 r
F
0 g
.54748 .63375 m
.55077 .66583 L
s
.67781 .64153 m .55097 .54852 L .56705 .51468 L .785 .593 .64 r
F
0 g
.56705 .51468 m
.58985 .50402 L
s
.65716 .67529 m .55097 .54852 L .67781 .64153 L .711 .6 .73 r
F
.6325 .71047 m .5457 .59238 L .65716 .67529 L .576 .563 .802 r
F
.25947 .87191 m .28082 .8403 L .28339 .8272 L .841 .859 .406 r
F
.65716 .67529 m .5457 .59238 L .55097 .54852 L .711 .6 .73 r
F
0 g
.5457 .59238 m
.54748 .63375 L
s
.55097 .54852 m
.56705 .51468 L
s
.3872 1.28099 m
.39595 1.18084 L
s
.5457 .59238 m
.55097 .54852 L
s
.36751 1.0242 m
.37825 1.02342 L
s
.37825 1.02342 m
.37863 1.02339 L
s
.25947 .87191 m .28339 .8272 L .28784 .81511 L .732 .828 .372 r
F
.2941 .80423 m .37028 .77616 L .38712 .7693 L .287 .774 .698 r
F
.28784 .81511 m .37028 .77616 L .2941 .80423 L .52 .915 .822 r
F
.77844 1.1269 m .65748 1.31796 L .80233 1.16525 L .534 .409 .656 r
F
.65748 1.31796 m .49584 1.45734 L .69651 1.35511 L .65 .404 .533 r
F
.65748 1.31796 m .42031 1.3872 L .49584 1.45734 L F
0 g
.3872 1.28099 m
.42031 1.3872 L
s
.80233 1.16525 m .65748 1.31796 L .69651 1.35511 L .355 .189 .513 r
F
.039 .916 .04 r
.457 .82546 m
.46747 .81824 L
s
.46747 .81824 m
.47078 .81595 L
s
.47078 .81595 m
.47183 .81522 L
s
.47183 .81522 m
.47433 .8135 L
s
.28761 .94246 m
.28782 .94231 L
s
.28716 .94276 m
.28761 .94246 L
s
.28698 .94289 m
.28716 .94276 L
s
.28628 .94338 m
.28698 .94289 L
s
.28573 .94375 m
.28628 .94338 L
s
.28546 .94394 m
.28573 .94375 L
s
.28542 .94397 m
.28546 .94394 L
s
.27127 .95374 m
.27752 .94942 L
s
0 0 0 r
5 Mabswid
.27127 .95374 Mdot
.039 .916 .04 r
.5 Mabswid
.49058 .88339 m
.49805 .88099 L
s
.28962 .94785 m
.48165 .88625 L
s
.28883 .94811 m
.28962 .94785 L
s
.28859 .94818 m
.28883 .94811 L
s
.28771 .94847 m
.28859 .94818 L
s
.28702 .94869 m
.28771 .94847 L
s
.28666 .9488 m
.28702 .94869 L
s
.28658 .94883 m
.28666 .9488 L
s
.48165 .88625 m
.48796 .88423 L
s
.48796 .88423 m
.49058 .88339 L
s
.27127 .95374 m
.27802 .95157 L
s
.49004 .87894 m
.49705 .87872 L
s
.27634 .88564 m
.48068 .87924 L
s
.48068 .87924 m
.4871 .87903 L
s
.4871 .87903 m
.49004 .87894 L
s
.27625 .88565 m
.27634 .88564 L
s
.27578 .88566 m
.27625 .88565 L
s
.2753 .88567 m
.27578 .88566 L
s
.25794 .88622 m
.26277 .88607 L
s
.27486 .88569 m
.2753 .88567 L
s
.27387 .88572 m
.27486 .88569 L
s
.27335 .88574 m
.27387 .88572 L
s
.27304 .88575 m
.27335 .88574 L
s
.27284 .88575 m
.27304 .88575 L
s
.37805 .99127 m
.37848 .99308 L
s
0 g
.39595 1.18084 m
.423 1.11606 L
s
0 0 0 r
5 Mabswid
.25794 .88622 Mdot
.039 .916 .04 r
.5 Mabswid
.51548 .94525 m
.51973 .94622 L
s
.54587 .95221 m
.56833 .95736 L
s
.53478 .94967 m
.54587 .95221 L
s
.53219 .94907 m
.53478 .94967 L
s
.51973 .94622 m
.52955 .94847 L
s
.49819 .94128 m
.50168 .94208 L
s
.5145 .94502 m
.51548 .94525 L
s
.50798 .94353 m
.5145 .94502 L
s
.50168 .94208 m
.50798 .94353 L
s
.47664 .93634 m
.49819 .94128 L
s
.32775 .90222 m
.47664 .93634 L
s
.27628 .89042 m
.32775 .90222 L
s
.2762 .8904 m
.27628 .89042 L
s
.27581 .89031 m
.2762 .8904 L
s
.27537 .89021 m
.27581 .89031 L
s
.25794 .88622 m
.26308 .8874 L
s
.27505 .89014 m
.27537 .89021 L
s
.27423 .88995 m
.27505 .89014 L
s
.27359 .88981 m
.27423 .88995 L
s
.27356 .8898 m
.27359 .88981 L
s
.27321 .88972 m
.27356 .8898 L
s
.25947 .87191 m .28784 .81511 L .2941 .80423 L 0 0 0 r
F
.73274 .91076 m .69509 1.04046 L .74025 1.08192 L .489 .521 .817 r
F
.698 .89157 m .69509 1.04046 L .73274 .91076 L .612 .621 .836 r
F
.698 .89157 m .64911 1.00997 L .69509 1.04046 L F
0 g
.64577 .46291 m
.64769 .56274 L
s
.66162 .87786 m .64911 1.00997 L .698 .89157 L .696 .68 .831 r
F
.66162 .87786 m .6078 .99287 L .64911 1.00997 L F
.2941 .80423 m .38712 .7693 L .30196 .79472 L .287 .774 .698 r
F
.30196 .79472 m .38712 .7693 L .40682 .76505 L 0 0 0 r
F
.76091 .93435 m .74025 1.08192 L .77844 1.1269 L .296 .36 .759 r
F
.73274 .91076 m .74025 1.08192 L .76091 .93435 L .489 .521 .817 r
F
.039 .916 .04 r
.71478 .99092 m
.75791 1.00081 L
s
.75791 1.00081 m
.75795 1.00082 L
s
0 0 0 r
5 Mabswid
.30424 1.39812 Mdot
.62736 .86902 m .6078 .99287 L .66162 .87786 L .751 .708 .811 r
F
.039 .916 .04 r
.5 Mabswid
.56833 .95736 m
.71478 .99092 L
s
.25947 .87191 m .2941 .80423 L .30196 .79472 L 0 0 0 r
F
.039 .916 .04 r
.28782 .94231 m
.457 .82546 L
s
0 g
.57611 .9895 m
.5764 .9889 L
s
.5764 .9889 m
.58111 .97899 L
s
.039 .916 .04 r
.47757 .82666 m
.48244 .8149 L
s
.48244 .8149 m
.4834 .81258 L
s
.45718 .87589 m
.47757 .82666 L
s
.30196 .79472 m .40682 .76505 L .31113 .78671 L 0 0 0 r
F
.31113 .78671 m .40682 .76505 L .42834 .76288 L .061 0 0 r
F
.25947 .87191 m .30196 .79472 L .31113 .78671 L 0 0 0 r
F
.7771 .95982 m .77844 1.1269 L .80233 1.16525 L 0 .053 .589 r
F
.76091 .93435 m .77844 1.1269 L .77725 .97867 L .296 .36 .759 r
F
.80233 1.16525 m .69651 1.35511 L .80334 1.18788 L .355 .189 .513 r
F
.77637 .98406 m .80155 1.15978 L .80334 1.18788 L .757 .548 0 r
F
.80155 1.15978 m .80233 1.16525 L .80236 1.16581 L F
.80155 1.15978 m .80236 1.16581 L .80334 1.18788 L F
.77409 .95508 m .77725 .97867 L .7771 .95982 L .296 .36 .759 r
F
.76091 .93435 m .77725 .97867 L .77409 .95508 L F
0 g
.59138 .85609 m
.59689 .87037 L
s
.59129 .85586 m
.59138 .85609 L
s
.59689 .87037 m
.59807 .87343 L
s
.423 1.11606 m
.44641 1.09596 L
s
.69651 1.35511 m .49584 1.45734 L .57864 1.45583 L .343 0 .156 r
F
0 g
.42031 1.3872 m
.49584 1.45734 L
s
.25947 .87191 m .28289 .97061 L .28375 .97619 L 0 0 .207 r
F
.039 .916 .04 r
.55514 1.23452 m
.61421 1.11986 L
s
.36033 1.61267 m
.55514 1.23452 L
s
.31434 1.70193 m
.36033 1.61267 L
s
.61421 1.11986 m
.6829 .98654 L
s
.6829 .98654 m
.69396 .96507 L
s
.69396 .96507 m
.69615 .96082 L
s
.69615 .96082 m
.6972 .95878 L
s
.69484 .95121 m
.69754 .95051 L
s
.69754 .95051 m
.69828 .95032 L
s
.69828 .95032 m
.69897 .95014 L
s
.72241 .98617 m
.72255 .98496 L
s
.72255 .98496 m
.7227 .98377 L
s
.68939 .9662 m
.71005 .96714 L
s
.71005 .96714 m
.71188 .96722 L
s
.71188 .96722 m
.71223 .96724 L
s
.31113 .78671 m .42834 .76288 L .32126 .78026 L .061 0 0 r
F
.32126 .78026 m .42834 .76288 L .45098 .76227 L .152 0 0 r
F
.25947 .87191 m .31113 .78671 L .32126 .78026 L 0 0 .117 r
F
.69651 1.35511 m .57864 1.45583 L .71118 1.34813 L .343 0 .156 r
F
.80334 1.18788 m .69651 1.35511 L .71118 1.34813 L 0 0 0 r
F
0 g
.4644 1.10266 m
.47175 1.0935 L
s
.3713 1.02333 m
.37538 1.0224 L
s
.36751 1.0242 m
.3713 1.02333 L
s
.039 .916 .04 r
.6809 .92696 m
.6873 .92721 L
s
.6873 .92721 m
.68857 .92726 L
s
.70159 .93917 m
.70218 .94218 L
s
.45132 1.02093 m
.45383 1.02018 L
s
.46099 1.01804 m
.46469 1.01693 L
s
.45383 1.02018 m
.46099 1.01804 L
s
.46744 1.01611 m
.48609 1.01054 L
s
.46469 1.01693 m
.46744 1.01611 L
s
.25947 .87191 m .38269 .80929 L .377 .82127 L .195 0 .293 r
F
.25947 .87191 m .3857 .7987 L .38269 .80929 L .203 0 .308 r
F
.25947 .87191 m .38592 .78968 L .3857 .7987 L .218 0 .333 r
F
.25947 .87191 m .38348 .78234 L .38592 .78968 L .236 .015 .361 r
F
.25947 .87191 m .37862 .77677 L .38348 .78234 L .253 .04 .385 r
F
.32126 .78026 m .45098 .76227 L .33196 .77542 L .152 0 0 r
F
.25947 .87191 m .37169 .77298 L .37862 .77677 L .264 .056 .399 r
F
.33196 .77542 m .45098 .76227 L .47428 .76285 L .211 0 0 r
F
.33196 .77542 m .47428 .76285 L .34279 .77224 L F
.34279 .77224 m .47428 .76285 L .49797 .76455 L .263 0 0 r
F
.34279 .77224 m .49797 .76455 L .35333 .77075 L F
.25947 .87191 m .36311 .77098 L .37169 .77298 L .265 .058 .4 r
F
.25947 .87191 m .35333 .77075 L .36311 .77098 L .252 .041 .386 r
F
.25947 .87191 m .34279 .77224 L .35333 .77075 L .222 .002 .354 r
F
.25947 .87191 m .33196 .77542 L .34279 .77224 L .168 0 .301 r
F
.25947 .87191 m .32126 .78026 L .33196 .77542 L .084 0 .223 r
F
.25947 .87191 m .28336 .96352 L .28289 .97061 L 0 0 .353 r
F
.25947 .87191 m .28545 .95492 L .28336 .96352 L 0 0 .465 r
F
.25947 .87191 m .28938 .94485 L .28545 .95492 L 0 0 .531 r
F
.25947 .87191 m .29528 .93342 L .28938 .94485 L .018 .054 .556 r
F
.25947 .87191 m .30312 .92077 L .29528 .93342 L .11 .09 .552 r
F
.25947 .87191 m .31272 .90712 L .30312 .92077 L .17 .099 .527 r
F
.25947 .87191 m .3237 .89274 L .31272 .90712 L .205 .087 .489 r
F
.25947 .87191 m .33551 .87794 L .3237 .89274 L .22 .061 .442 r
F
.25947 .87191 m .34747 .86306 L .33551 .87794 L .221 .027 .392 r
F
.25947 .87191 m .35884 .84844 L .34747 .86306 L .213 0 .347 r
F
.25947 .87191 m .36889 .83441 L .35884 .84844 L .203 0 .312 r
F
.25947 .87191 m .377 .82127 L .36889 .83441 L .195 0 .294 r
F
.039 .916 .04 r
.34666 .85782 m
.34671 .85803 L
s
.34656 .85741 m
.34657 .85742 L
s
.34657 .85742 m
.34666 .85782 L
s
.3478 .86267 m
.34808 .86385 L
s
.34808 .86385 m
.3481 .86397 L
s
.34779 .86264 m
.3478 .86267 L
s
.34671 .85803 m
.34674 .85815 L
s
.34616 .8557 m
.34656 .85741 L
s
.54506 .77225 m .62736 .86902 L .66162 .87786 L .487 .637 .921 r
F
0 g
.64769 .56274 m
.6497 .66747 L
s
.52176 .76754 m .62736 .86902 L .54506 .77225 L .547 .644 .898 r
F
.5669 .77919 m .66162 .87786 L .698 .89157 L .34 .586 .935 r
F
0 g
.6497 .66747 m
.6506 .71425 L
s
.54506 .77225 m .66162 .87786 L .5669 .77919 L .487 .637 .921 r
F
0 g
.6506 .71425 m
.65114 .74219 L
s
.7771 .95982 m .80233 1.16525 L .77637 .98406 L 0 .053 .589 r
F
.039 .916 .04 r
.78284 1.00652 m
.78579 1.0072 L
s
.28545 .95492 m .36157 1.02221 L .28336 .96352 L 0 .119 .606 r
F
.28545 .95492 m .35873 1.01818 L .36157 1.02221 L F
.58581 .78875 m .698 .89157 L .73274 .91076 L .026 .425 .865 r
F
0 g
.65114 .74219 m
.65172 .77233 L
s
.5669 .77919 m .698 .89157 L .58581 .78875 L .34 .586 .935 r
F
0 g
.65172 .77233 m
.65198 .78606 L
s
0 0 0 r
5 Mabswid
.78579 1.0072 Mdot
.039 .916 .04 r
.5 Mabswid
.77833 1.03318 m
.77834 1.03316 L
s
.78378 1.0142 m
.78461 1.01131 L
s
.78461 1.01131 m
.78579 1.0072 L
s
0 g
.37931 1.79705 m
.97512 1.64732 L
s
.0271 1.50888 m
.37931 1.79705 L
s
.44641 1.09596 m
.46242 1.1101 L
s
.35333 .77075 m .49797 .76455 L .52176 .76754 L .329 0 0 r
F
.28938 .94485 m .35873 1.01818 L .28545 .95492 L 0 .259 .764 r
F
.59992 .80111 m .73274 .91076 L .76091 .93435 L .463 0 0 r
F
.039 .916 .04 r
.59269 .92352 m
.6809 .92696 L
s
.58581 .78875 m .73274 .91076 L .59992 .80111 L .026 .425 .865 r
F
.28938 .94485 m .36044 1.01146 L .35873 1.01818 L 0 .259 .764 r
F
0 0 0 r
5 Mabswid
.35137 .59567 Mdot
.35333 .77075 m .52176 .76754 L .36311 .77098 L .329 0 0 r
F
.36311 .77098 m .52176 .76754 L .54506 .77225 L .411 0 0 r
F
.29528 .93342 m .36044 1.01146 L .28938 .94485 L .126 .362 .823 r
F
.71118 1.34813 m .57864 1.45583 L .61461 1.37859 L .825 .951 .901 r
F
0 g
.5 Mabswid
.49584 1.45734 m
.57864 1.45583 L
s
.039 .916 .04 r
.34616 .8557 m
.34883 .85542 L
s
.34883 .85542 m
.34885 .85542 L
s
.34885 .85542 m
.34942 .85536 L
s
.34942 .85536 m
.34976 .85532 L
s
.34976 .85532 m
.34977 .85532 L
s
.35382 .8549 m
.35412 .85486 L
s
.35412 .85486 m
.35661 .8546 L
s
.35661 .8546 m
.35834 .85442 L
s
.35834 .85442 m
.35851 .8544 L
s
.64068 .82463 m
.64469 .8242 L
s
0 0 0 r
5 Mabswid
.64469 .8242 Mdot
.039 .916 .04 r
.5 Mabswid
.65095 .8476 m
.65106 .84802 L
s
.65088 .84734 m
.65095 .8476 L
s
.6493 .84143 m
.64931 .84148 L
s
.64563 .82772 m
.64918 .84097 L
s
.64918 .84097 m
.6493 .84143 L
s
.64469 .8242 m
.64563 .82772 L
s
0 g
.4644 1.10266 m
.46467 1.10309 L
s
.36311 .77098 m .54506 .77225 L .37169 .77298 L .411 0 0 r
F
.60725 .81614 m .76091 .93435 L .7771 .95982 L .789 .29 0 r
F
.039 .916 .04 r
.65106 .84802 m
.65168 .85032 L
s
.59992 .80111 m .76091 .93435 L .60725 .81614 L .463 0 0 r
F
.039 .916 .04 r
.6309 .82566 m
.64068 .82463 L
s
.63033 .82572 m
.6309 .82566 L
s
0 g
.40742 1.0321 m
.42682 1.03798 L
s
.40323 1.03084 m
.40742 1.0321 L
s
.39538 1.02846 m
.40323 1.03084 L
s
.38261 1.02459 m
.39538 1.02846 L
s
.37538 1.0224 m
.38261 1.02459 L
s
.71118 1.34813 m .61461 1.37859 L .68229 1.30027 L .825 .951 .901 r
F
.039 .916 .04 r
.67545 1.32636 m
.68158 1.32517 L
s
.30424 1.39812 m
.65659 1.33001 L
s
.77407 1.19061 m .71118 1.34813 L .68229 1.30027 L .89 .887 .823 r
F
.039 .916 .04 r
.68158 1.32517 m
.6823 1.31919 L
s
.6823 1.31919 m
.68242 1.31824 L
s
.37731 1.3845 m
.68513 1.29687 L
s
.80334 1.18788 m .71118 1.34813 L .77407 1.19061 L 0 0 0 r
F
.039 .916 .04 r
.75163 1.27794 m
.75712 1.27637 L
s
.75712 1.27637 m
.76155 1.27511 L
s
.76155 1.27511 m
.76501 1.27413 L
s
.76163 1.26149 m
.76294 1.26641 L
s
.76294 1.26641 m
.76403 1.27047 L
s
.76403 1.27047 m
.76501 1.27413 L
s
.75802 1.228 m
.75955 1.23581 L
s
.75786 1.2272 m
.75802 1.228 L
s
.76074 1.25819 m
.76163 1.26149 L
s
.65285 .85472 m
.75028 1.21904 L
s
.7584 1.23614 m
.75955 1.23581 L
s
.34545 1.355 m
.72884 1.24465 L
s
.75198 1.23799 m
.7584 1.23614 L
s
.74929 1.23876 m
.75198 1.23799 L
s
.75126 1.27804 m
.75163 1.27794 L
s
.68497 1.29707 m
.72241 .98617 L
s
.7554 1.00451 m .80334 1.18788 L .77407 1.19061 L .992 .811 .561 r
F
.039 .916 .04 r
.77025 1.06133 m
.77833 1.03318 L
s
.77637 .98406 m .80334 1.18788 L .7554 1.00451 L .757 .548 0 r
F
.37169 .77298 m .54506 .77225 L .5669 .77919 L .493 0 0 r
F
0 0 0 r
5 Mabswid
.76501 1.27413 Mdot
.29528 .93342 m .36833 1.00165 L .36044 1.01146 L .126 .362 .823 r
F
.30312 .92077 m .36833 1.00165 L .29528 .93342 L .309 .415 .808 r
F
.37169 .77298 m .5669 .77919 L .37862 .77677 L .493 0 0 r
F
0 g
.5 Mabswid
.46242 1.1101 m
.46763 1.11705 L
s
.46763 1.11705 m
.47847 1.13149 L
s
.47847 1.13149 m
.48011 1.13368 L
s
.37862 .77677 m .5669 .77919 L .58581 .78875 L .558 .092 .104 r
F
.30312 .92077 m .38373 .98865 L .36833 1.00165 L .309 .415 .808 r
F
.31272 .90712 m .38373 .98865 L .30312 .92077 L .427 .436 .766 r
F
.37862 .77677 m .58581 .78875 L .38348 .78234 L .558 .092 .104 r
F
.60601 .83345 m .7771 .95982 L .77637 .98406 L .873 .468 .257 r
F
.60725 .81614 m .7771 .95982 L .60601 .83345 L .789 .29 0 r
F
.039 .916 .04 r
.53048 .95897 m
.68939 .9662 L
s
.70218 .94218 m
.75514 1.21323 L
s
.38348 .78234 m .59992 .80111 L .38592 .78968 L .601 .177 .209 r
F
.38348 .78234 m .58581 .78875 L .59992 .80111 L F
.31272 .90712 m .40712 .97278 L .38373 .98865 L .427 .436 .766 r
F
.3237 .89274 m .40712 .97278 L .31272 .90712 L .505 .439 .716 r
F
0 g
.49972 1.13983 m
.50086 1.14019 L
s
.48011 1.13368 m
.49972 1.13983 L
s
.38592 .78968 m .60725 .81614 L .3857 .7987 L .626 .239 .29 r
F
.38592 .78968 m .59992 .80111 L .60725 .81614 L F
0 0 0 r
5 Mabswid
.75955 1.23581 Mdot
.3237 .89274 m .43772 .95461 L .40712 .97278 L .505 .439 .716 r
F
.33551 .87794 m .43772 .95461 L .3237 .89274 L .558 .433 .665 r
F
.039 .916 .04 r
.5 Mabswid
.3481 .86397 m
.3548 .89241 L
s
0 g
.44639 1.05121 m
.45112 1.05441 L
s
.43467 1.04328 m
.44639 1.05121 L
s
.42682 1.03798 m
.43467 1.04328 L
s
.45112 1.05441 m
.48228 1.07549 L
s
.3857 .7987 m .60601 .83345 L .38269 .80929 L .639 .284 .353 r
F
.039 .916 .04 r
.58638 .83036 m
.60638 .82824 L
s
.3857 .7987 m .60725 .81614 L .60601 .83345 L .639 .284 .353 r
F
.039 .916 .04 r
.35851 .8544 m
.58183 .83084 L
s
0 0 0 r
5 Mabswid
.68158 1.32517 Mdot
.77407 1.19061 m .68229 1.30027 L .71381 1.1763 L .89 .887 .823 r
F
.039 .916 .04 r
.5 Mabswid
.72935 1.20384 m
.73126 1.1972 L
s
.72222 1.20592 m
.72935 1.20384 L
s
.71402 1.02012 m .77407 1.19061 L .71381 1.1763 L .868 .741 .72 r
F
.039 .916 .04 r
.75152 1.12659 m
.76347 1.08496 L
s
.7554 1.00451 m .77407 1.19061 L .71402 1.02012 L .992 .811 .561 r
F
.33551 .87794 m .47328 .93489 L .43772 .95461 L .558 .433 .665 r
F
.039 .916 .04 r
.39359 .90195 m
.47972 .85821 L
s
.4305 .9172 m
.59269 .92352 L
s
.42649 .95424 m
.42654 .95424 L
s
.42476 .95416 m
.42498 .95417 L
s
.42498 .95417 m
.42649 .95424 L
s
.42527 .95292 m
.42528 .95289 L
s
.42476 .95416 m
.42483 .95399 L
s
.42483 .95399 m
.42527 .95292 L
s
.34747 .86306 m .47328 .93489 L .33551 .87794 L .595 .419 .613 r
F
.039 .916 .04 r
.44049 .91617 m
.45718 .87589 L
s
0 g
.50086 1.14019 m
.50809 1.11748 L
s
.60601 .83345 m .77637 .98406 L .59509 .85247 L .873 .468 .257 r
F
0 g
.65198 .78606 m
.65316 .84731 L
s
.65316 .84731 m
.65325 .85185 L
s
.59509 .85247 m .77637 .98406 L .7554 1.00451 L .865 .543 .44 r
F
0 0 0 r
5 Mabswid
.34616 .8557 Mdot
.38269 .80929 m .59509 .85247 L .377 .82127 L .644 .319 .406 r
F
.38269 .80929 m .60601 .83345 L .59509 .85247 L F
.34747 .86306 m .51046 .91428 L .47328 .93489 L .595 .419 .613 r
F
.039 .916 .04 r
.5 Mabswid
.36847 .91471 m
.36851 .91469 L
s
.36833 .91478 m
.36847 .91471 L
s
.36865 .91479 m
.36872 .9148 L
s
.37295 .91496 m
.3741 .91501 L
s
.3741 .91501 m
.3756 .91506 L
s
.3756 .91506 m
.37566 .91507 L
s
.36872 .9148 m
.37295 .91496 L
s
.36833 .91478 m
.36865 .91479 L
s
.35884 .84844 m .51046 .91428 L .34747 .86306 L .619 .399 .561 r
F
.377 .82127 m .57445 .87262 L .36889 .83441 L .642 .348 .457 r
F
.377 .82127 m .59509 .85247 L .57445 .87262 L F
.68229 1.30027 m .61461 1.37859 L .57665 1.26317 L .77 .68 .764 r
F
0 g
.57864 1.45583 m
.61461 1.37859 L
s
.68229 1.30027 m .57665 1.26317 L .61171 1.23219 L .77 .68 .764 r
F
.039 .916 .04 r
.31306 1.32499 m
.60177 1.24097 L
s
.71381 1.1763 m .68229 1.30027 L .61171 1.23219 L .745 .679 .787 r
F
.35884 .84844 m .54537 .89337 L .51046 .91428 L .619 .399 .561 r
F
.039 .916 .04 r
.37065 .91361 m
.37073 .91357 L
s
.37038 .91374 m
.37065 .91361 L
s
.37073 .91357 m
.37147 .91319 L
s
.37147 .91319 m
.37149 .91318 L
s
.36851 .91469 m
.37038 .91374 L
s
.36889 .83441 m .54537 .89337 L .35884 .84844 L .635 .375 .508 r
F
.36889 .83441 m .57445 .87262 L .54537 .89337 L F
0 g
.49009 1.0882 m
.49368 1.09404 L
s
.49368 1.09404 m
.50809 1.11748 L
s
.48228 1.07549 m
.49009 1.0882 L
s
.61171 1.23219 m .50193 1.16342 L .53067 1.16857 L .671 .501 .647 r
F
.61171 1.23219 m .57665 1.26317 L .50193 1.16342 L F
0 g
.48439 1.13502 m
.50193 1.16342 L
s
.57665 1.26317 m
.61461 1.37859 L
s
.50193 1.16342 m
.52869 1.19915 L
s
.63352 1.15312 m .53067 1.16857 L .55427 1.12932 L .611 .531 .74 r
F
.63352 1.15312 m .61171 1.23219 L .53067 1.16857 L F
0 g
.52869 1.19915 m
.57665 1.26317 L
s
0 0 0 r
5 Mabswid
.36833 .91478 Mdot
.72935 1.20384 Mdot
.31434 1.70193 Mdot
.43772 .95461 m .47976 1.05192 L .40712 .97278 L .523 .531 .805 r
F
.57445 .87262 m .7554 1.00451 L .71402 1.02012 L .825 .572 .557 r
F
.039 .916 .04 r
.5 Mabswid
.68558 .95362 m
.69484 .95121 L
s
.59509 .85247 m .7554 1.00451 L .57445 .87262 L .865 .543 .44 r
F
.43772 .95461 m .52901 1.04683 L .47976 1.05192 L .523 .531 .805 r
F
.039 .916 .04 r
.43785 .95475 m
.53048 .95897 L
s
.71381 1.1763 m .61171 1.23219 L .63352 1.15312 L .745 .679 .787 r
F
0 g
.65963 1.18438 m
.66242 1.32932 L
s
.65642 1.03145 m .71381 1.1763 L .63352 1.15312 L .745 .658 .764 r
F
.71402 1.02012 m .71381 1.1763 L .65642 1.03145 L .868 .741 .72 r
F
.59113 1.03997 m .55427 1.12932 L .52901 1.04683 L .619 .577 .785 r
F
.59113 1.03997 m .63352 1.15312 L .55427 1.12932 L F
0 0 0 r
5 Mabswid
.42476 .95416 Mdot
.47328 .93489 m .52901 1.04683 L .43772 .95461 L .633 .558 .752 r
F
.65642 1.03145 m .63352 1.15312 L .59113 1.03997 L .745 .658 .764 r
F
.54537 .89337 m .71402 1.02012 L .65642 1.03145 L .773 .579 .637 r
F
.039 .916 .04 r
.5 Mabswid
.64099 .96523 m
.65792 .96083 L
s
.57445 .87262 m .71402 1.02012 L .54537 .89337 L .825 .572 .557 r
F
.47328 .93489 m .59113 1.03997 L .52901 1.04683 L .633 .558 .752 r
F
.51046 .91428 m .59113 1.03997 L .47328 .93489 L .71 .573 .699 r
F
.039 .916 .04 r
.55837 .98893 m
.60736 .97429 L
s
.54537 .89337 m .65642 1.03145 L .51046 .91428 L .773 .579 .637 r
F
.51046 .91428 m .65642 1.03145 L .59113 1.03997 L .71 .573 .699 r
F
.039 .916 .04 r
.61194 .97292 m
.6151 .97198 L
s
.6151 .97198 m
.61762 .97132 L
s
.61785 .97126 m
.61789 .97125 L
s
.61789 .97125 m
.61892 .97098 L
s
.61762 .97132 m
.61785 .97126 L
s
0 g
.65325 .85185 m
.6553 .95893 L
s
.6553 .95893 m
.6556 .97432 L
s
.039 .916 .04 r
.60936 .97369 m
.60945 .97366 L
s
.60945 .97366 m
.61194 .97292 L
s
0 g
.6556 .97432 m
.65963 1.18438 L
s
0 0 0 r
5 Mabswid
.6151 .97198 Mdot
0 g
.5 Mabswid
.97512 1.64732 m
.66242 1.32932 L
s
.66242 1.32932 m
.0271 1.50888 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{156.25, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002L000180P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000009ad002LM000W7@009ad002LM000W7@009ad
002LM000HW@24CQd001OM0<A00=d4A40=g@005ed0Q44M08A=g@005Yd0a46M0034G@A03Id001GM0<A
2G@0115dM14eM000EG@24@ad00DAM7Ad4@0dM000DW@34@id00DAM7Ad4@0dM000Cg@34A5d00<AM7@0
0W@00a5dM00aM000C7@34AAd00<AM7@00g@00a5dM00`M000BW@24AMd00<AM7@00g@00a5dM00`M000
Ag@34AUd00<AM7@017@00a5dM00_M000A7@34Aad00<AM7@01G@00a5dM00^M000@W@24Amd00<AM7@0
1W@00a5dM00]M000?g@34B5d00<AM7@01W@00a5dM00]M000?7@34BAd00<AM7@01g@00a5dM00/M000
>G@34BMd00<AM7@027@00a5dM00[M000=g@24BYd00<AM7@02G@00a5dM00ZM000=7@34Bad00<AM7@0
2G@00a5dM00ZM000<G@34Bmd00<AM7@02W@00a5dM00YM000;g@24C9d00<AM7@02g@00a5dM00XM000
;7@34CAd00<AM7@02g@00a5dM00XM000:G@34CMd00<AM7@037@00a5dM00WM0009g@24CYd00<AM7@0
3G@00a5dM00VM00097@34Cad00<AM7@03W@00a5dM00UM0008G@34Cmd00<AM7@03W@00a5dM00UM000
7W@34D9d00<AM7@03g@00a5dM00TM00077@24DEd00<AM7@047@00a5dM00SM0006G@34DMd00<AM7@0
47@00a5dM00SM0005W@34DYd00<AM7@04G@00a5dM00RM00057@24Ded00<AM7@04W@00a5dM00QM000
4G@34Dmd00<AM7@04g@00a5dM00PM0003g@24E9d00<AM7@04g@00a5dM00PM0003g@24E9d00<AM7@0
57@00a5dM00OM0003g@00a5d4@1BM0034GAd01Ad00<AM7@07W@000md00@AM7@ADG@00a5dM00DM003
4GAd01id000?M0044GAd4E5d00<AM7@05G@00a5dM00MM0003g@01A5dM7@A051d00<AM7@05W@00a5d
M00LM0003g@00a5dM002M0034GAd04ed00<AM7@05g@00a5dM00KM0003g@00a5dM003M0034GAd04ad
00<AM7@05g@00a5dM00KM0003g@00a5dM004M0034GAd04]d00<AM7@067@00a5dM00JM0003W@00a5d
M006M0034GAd04Yd00<AM7@06G@00a5dM00IM0003W@00a5dM007M0034GAd04Ud00<AM7@06G@00a5d
M00IM0003W@00a5dM008M0034GAd04Qd00<AM7@06W@00a5dM00HM0003W@00a5dM008M0034GAd04Qd
00<AM7@06g@00a5dM00GM0003W@00a5dM009M0034GAd04Md00<AM7@077@00a5dM00FM0003W@00a5d
M00:M0034GAd04Id00<AM7@077@00a5dM00FM0003W@00a5dM00;M0034GAd04Ed00<AM7@07G@00a5d
M00EM0003W@00a5dM00<M0034GAd04Ad00<AM7@07W@00a5dM00DM0003W@00a5dM00=M0034GAd04=d
00<AM7@07g@00a5dM00CM0003W@00a5dM00>M0034GAd049d00<AM7@07g@00a5dM00CM0003W@00a5d
M00>M0034GAd049d00<AM7@087@00a5dM00BM0003W@00a5dM00?M0034GAd045d00<AM7@08G@00a5d
M00AM0003W@00a5dM00@M0034GAd041d00<AM7@08G@00a5dM00AM0003W@00a5dM00AM0034GAd03md
00<AM7@08W@00a5dM00@M0003W@00a5dM00BM0034GAd03id00<AM7@08g@00a5dM00?M0003W@00a5d
M00CM0034GAd03ed00<AM7@097@00a5dM00>M0003W@00a5dM00DM0034GAd03ad00<AM7@097@00a5d
M00>M0003W@00a5dM00EM0034GAd03]d00<AM7@097@24@md000=M0034GAd01Id00<AM7@0>g@00a5d
M00QM0<A00=d4G@03W@000ed00<AM7@05g@00a5dM00jM0034GAd01id0a44M0034GAd00ed000=M003
4GAd01Qd00<AM7@0>G@00a5dM00KM0<A1g@00a5dM00=M0003G@00a5dM00IM0034GAd03Qd00<AM7@0
67@34@Yd00<AM7@03G@000ed00<AM7@06W@00a5dM00gM0034GAd01Ed0a4=M0034GAd00ed000=M003
4GAd01]d00<AM7@0=W@00a5dM00BM0<A47@00a5dM00=M0003G@00a5dM00LM0034GAd03Ed00<AM7@0
47@24A=d00<AM7@03G@000ed00<AM7@07G@00a5dM00dM0034GAd00ed0a4EM0034GAd00ed000=M003
4GAd01ed00<AM7@0=7@00a5dM00:M0<A6G@00a5dM00<M0003G@00a5dM00NM0034GAd03=d00<AM7@0
1g@34Aad00<AM7@037@000ed00<AM7@07g@00a5dM00bM0034GAd00Ad0a4OM0034GAd00ad000=M003
4GAd021d00<AM7@0<G@0115dM7@34B9d00<AM7@037@000ed00<AM7@08G@00a5dM00`M0@A9G@00a5d
M00<M0003G@00a5dM00RM0034GAd02Id00<AM7@017@34BQd00<AM7@037@000ed00<AM7@08g@00a5d
M00SM08A00A[M7Ad0a42M0034GAd02Id00<AM7@037@000ed00<AM7@08g@00a5dM00RM0054EI_EVl0
0Q45M0034GAd02Id00<AM7@037@000ed00<AM7@097@00a5dM00PM0084EMKEV]FJa45M0034GAd02Id
00<AM7@037@000ed00<AM7@09G@00a5dM00NM08A00M_EfmFKeI_00Ed00<AM7@09W@00a5dM00<M000
37@00a5dM00WM0034GAd01Yd11402E]GFeMKEV]FJ`04M0034GAd02Id00<AM7@037@000ad00<AM7@0
:7@00a5dM00GM08A0g@02a5GKeM_EfmFKeI_00=d00<AM7@09W@00a5dM00<M00037@00a5dM00YM003
4GAd01=d0a44M00=4EMKEe]GFeMKEV]FJ`02M0034GAd02Id00<AM7@037@000ad00<AM7@0:W@00a5d
M00?M0<A1g@0415LEfmGKeM_EfmGKeI_M14XM0034GAd00ad000<M0034GAd02]d00<AM7@02g@34@Yd
010AEe]GFeMKEe]GFeM[EV/A:7@00a5dM00<M00037@00a5dM00[M0034GAd00Qd0a4=M00@4EaGG5M_
EfmGKeM_EfmF4BQd00<AM7@037@000ad00<AM7@0;7@00a5dM004M0<A3g@04Q5KEe]GFeMKEe]GFeMK
Ef/AJbMd00<AM7@037@000ad00<AM7@09W@44@=d00<AM7@00a4BM00C4EMLEeaGG5M_EfmGKeM_Ea5F
K`0VM0034GAd00ad000<M0034GAd02Id1144M08A5G@0515KEe]GFeMKEe]GFeMKEe/AFeI[9W@00a5d
M00;M00037@00a5dM00VM0@A17@00a5dM00DM00E4EMLEeaGG5MLEeaGKeM_Ea5GKeI_02Ed00<AM7@0
2g@000ad00<AM7@09W@44@068AdQ7B4M5G@05Q54Ee]GFeMKEe]GFeMKEe/AFeMKEV/TM0034GAd00]d
000<M0034GAd02id00<AM2401B4?M00G4D=LEeaGG5MLEeaGG5M_Ea5GKeM_EVl08g@00a5dM00;M000
37@00a5dM00^M0034GAd00Ed00HQ7B4M8Ad9M00G4DA3A4=KEe]GFeMKEe]GFa5KEe]GFeH08g@00a5d
M00;M00037@00a5dM00^M0034GAd00]d1R43M00H4D=L@ea3G5MLEeaGG5MLEa5GKeM_EfmE8W@00a5d
M00;M00037@00a5dM00^M0034GAd015d01/Q7B4AA4=4@dA3FeMKEe]GFeMK4E]GFeMKEfl08W@00a5d
M00;M00037@00a5dM00^M0034GAd01Ad01PA@ea3G4=L@eaGG5MLEeaG4EMLEfmGLflRM0034GAd00]d
000<M0034GAd02id00<AM7@057@0614`@dA3A4=4@dAGFeMKEe/AFeMKEe]^Kb9d00<AM7@02g@000ad
00<AM7@0;W@00a5dM00DM00H4B/`@ea3G4=L@ea3G5MLEa5GG5MLKg=_8W@00a5dM00;M0002g@00a5d
M00_M0034GAd01Ed01LA:c13A4=4@dA3A4=KEe/AFeMKEfm^K`0RM0034GAd00]d000;M0034GAd02md
00<AM7@05G@05a4`:c13G4=L@ea3G4=LEa5GG5M`Fg=_029d00<AM7@02g@000]d00<AM7@0;g@00a5d
M00EM00B4B/`:c13A4=4@dA3A4=44E]G0U/016m^KeDQM0034GAd00]d000;M0034GAd02md00<AM7@0
5G@0614`:c0[<4=L@ea3G4=L@a5GG5]`Fg=_Lb5d00<AM7@02g@000]d00<AM7@0;g@00a5dM00EM00H
4A8`:c0[<2]4@dA3A4=44DAKKe]_Ffm^8G@00a5dM00;M0002g@00a5dM00_M0034GAd01Ed01PA4a8`
:c0[<2]L@ea3G4<A@eaKL5]`Kg<QM0034GAd00]d000;M0034GAd02md00<AM7@05G@0614B4b/`:c0[
<2]4@dA3A15LEfmKKe]_KR5d00<AM7@02g@000]d00<AM7@0;g@00a5dM00EM00H4A<B4b/`:c0[<2]L
@ea3G15LFg1KL6mc8W@00a5dM00:M0002g@00a5dM00_M0034GAd01Ed01PA4Q<B4b/`:c0[<2]4@eaG
4EMLFfmKKfhRM0034GAd00Yd000;M0034GAd02md00<AM7@05G@0614B4Q<B4b/`:c0[<2]LFe`AG5]`
Fg1KLb9d00<AM7@02W@000]d00<AM7@0;g@00a5dM00EM08A01LC4Q<B<2/`:c0[<4=LEa5GG5]_Ffm^
K`0QM0034GAd00Yd000;M0034GAd02md00<AM7@057@24@8B01HC4Q<B<2/`:c1GG5]L4EaKG5]`Fg=_
8G@00a5dM00:M0002g@00a5dM00_M0034GAd01Ad11405Q8C4Q<B<2/`@ea3G5LAEeaGKe]_FflQM003
4GAd00Yd000;M0034GAd02md00<AM7@04g@06a4o4A8A4a8C4Q<B<5MLEeaGG15LFeaKL5]`K`0QM003
4GAd00Yd000;M0034GAd02md00<AM7@04W@00a4[4@034@0F4Q<B4a8C@ea3G4=LEa5GG5MLFfmKKb5d
00<AM7@02W@000]d00<AM7@0;g@00a5dM00AM08A00D[4A4B4@024P0D4a8C@eQGG5MLEe`AG5]LFg1K
L6lQM0034GAd00Yd000;M0034GAd02md00<AM7@047@24@03:Q4A00@A01DC4UM3Ed=L@ea3G4<AEeaG
G5]_Ffl08G@00a5dM00:M0002g@00a5dM00_M0034GAd00md00@V4BHo0a40618A4T=H@eQ3F5MLEeaG
G15LFeaKG5]`Fb5d00<AM7@02W@000Yd00<AM7@0<7@00bDA9@0=9@<V00<A9RX011405e`o@d=G@eM3
Ed=L@ea34EMLEeaGKe]_025d00<AM7@02W@000Yd00<AM7@09W@39@0d>BDi9CTU>BDi9CTU>BDi9CTU
>BDi9CTU>BDi9CTU4D=G@eM3F4=H@eQ3G5MLEe`AG5]LF`@A8G@00a5dM00:M0002W@00a5dM00TM004
4Q4V4@DV7ST04Q53@eM3Ed=G@ea3G4<AEeaGG0@A8G@00a5dM00:M0002W@00a5dM00SM0044Q4V4P8V
00<W9RL00RH0;ceB?E8mDSeB?E8mDSeB?E8mDSeB?E8mDSeB?E8mDSeG@eQ3F4=HEeaGG15LFe`Q00@A
8G@00a5dM00:M0002W@00a5dM00QM0<A00<V4BH01bH0;e8iDSUB>E8iDSUB>E8iDSUB>E8iDSUB>E8i
DSUB>E8iDT=G@eM3G4=L@a53G5ML00@A8G@00a5dM00:M0002W@00a5dM00QM08A00LV4RHV9bHW00@V
038nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB@eQ3F5MLEe`AG5]LFeaKGb9d00<AM7@0
2W@000Yd00<AM7@087@24@034Q4V00HV03<B9Q9B?U8nDSiB?U8nDSiB?E8mDSeB?E8mDSeB?E8mDSeB
?E8mDREG@b53G4<A@eaGG5L097@00a5dM00:M0002W@00a5dM00PM0034BHB008V00<W9RL01RH08ciB
?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8n008i00=H@e`011400eMLF`0VM0034GAd00Ud
000:M0034GAd01md0a479P0]4RHB9SiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDRDi
9EM300@A00ALEgAO9G@00a5dM009M0002W@00a5dM00NM003FQ4A008V00<W9RH01bH09eLnEciG?ULn
EciG?ULnEciG?ULnEciG?ULnDSiB?U8nDSiB?VEA>@048@8A00=GM7<09W@00a5dM009M0002W@00a5d
M00NM08A1BH0;A8V4RHA9Q4V?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB7@02D@04
>BDA7@8A00=`Gg@09W@00a5dM009M0002W@00a5dM00NM0044BHV9`XV02TnEciG?ULnEciG?ULnEciG
?ULnEciG?ULnEciG?ULnEciG?ULnJUIUD@03>@034GAc02Qd00<AM7@02G@000Yd00<AM7@07G@00a4V
9P039P044RHA9P@A02PnEciG?ULnEciB?U8nDSiB?U8nDSiB?U8nDSiB?U8nDSiB?U8nJU5Z15400bDA
F`0YM0034GAd00Ud000:M0034GAd01ed0RH00bLV9P059P<A030nEciG?ULnEciG?ULnEciG?ULnEciG
?ULnEciG?ULnEciG?ULnJUIZEVYFIE5U4CTYM0034GAd00Ud000:M0034GAd01ad00/A9RHB9Q4V4RHB
9P024@0b?ULnEciG?ULnEciG?ULnEciG?ULnEciB?U8nDSiB?U8nDSiB?VYFJU5ZDFYAJU4A9CTXM003
4GAd00Ud000:M0034GAd01ad2bH0=A4oEcmG?eLoEcmG?eLnEciG?ULnEciG?ULnEciG?ULnEciG?ULn
KeI_EVmFJUIZEVXAIE4i02Md00<AM7@02G@000Yd00<AM7@06g@0?Q8V4RHB9Q8V4RHB9Q9G?ULnEciG
?ULnEciG?ULnEciG?ULnEciG?ULnEciG?ULnEciZEVYFJUIZDFYAJU4A0e400cTUM00TM0034GAd00Ud
000:M0034GAd01Yd0Q40@A8[9R/V:bH[9R/VEd=G@eM3Ed=G?eLoEcmG?eLoEcmG?ULnEciG?ULnEciG
?ULnKeM_EVmFKeI_EVYFJQ5ZEVEA008i97@00a5dM009M0002G@00a5dM00KM08A03lC4RLB9Q8V4RHB
9Sm3?eLnEciG?ULnEciG?ULnEciG?ULnEciG?ULnEciG?ULnJeI[EV]FJUIZEVYFJU4ADFX015400bEd
M00QM0034GAd00Ud0009M0034GAd01]d04LA8A<[4R/V:bH[9R]3Ed=G@eM3Ed=G@eM3Ed=G?eLoEcmG
?eLoEcmG?eLnEciG?VmGKeM_EfmFKeI_EVmFJQ5ZEVYFIE5U>@0RM0034GAd00Ud0009M0034GAd01]d
0Q40@A<B4a8W4RLB9cm3?d<o8Cm3?eLnEciG?ULnEciG?ULnEciG?ULnEciG?UMFJeI[EV]FJeI[EVYF
JUIZEQ5AJU5Z00AA00<UM7@07g@00a5dM009M0002G@00a5dM00MM00?4Q<C:a8[9R]3A4=G@eM300@A
01IG8EM3Ed=G@eM3Ed=G?eLoEcmG?eLo0UL07FmGKeM_EfmGKeM_EfmFKeI_4FmFJUIZEVYAIE4i01md
00<AM7@02G@000Ud00<AM7@07W@03Q8C4Q<B9cm3?d<o@cm311405Cm3?d<nEciG?ULnEciG?ULnEciG
?P06E`0GJeI[EV]FJeI[EVYFJUHAEVYAJU5ZDFX00e400cUdM00LM0034GAd00Ud0009M0034GAd01id
0Q<032/C:a94@dA3A4=4@`@A019G@eM3Ed=G@eM3Ed=G@eM3Ed<2E`0SKeM_EfmGKeM_EfmGKeM_EfmG
KeI_4FmFKeIZEVYFJU5UDCT07G@00a5dM009M0002G@00a5dM00NM00>4Q<B4a93:d<[@cm3?d<44@0A
?d<o@cm3?d<oEciG?ULnEch03EL05UI[EV]FJeI[EV]F4EIZEVYFJU5ZDFX4DAed00<AM7@027@000Ud
00<AM7@07W@44`0LA2m4@dA3A4=4@dA3A4=G@eM3Ed=G@eM3Ed=G@`9G02ULEeaGG5M_EfmGKeM_EfmG
KeM_EfmGKeM_4FmFKeI_EVYFJUIZEVEAI@0LM0034GAd00Qd0009M0034GAd01id01lB4a8`:c0[<2]3
:d<o@cm3?d<o@cm3?d<o@cm3?d<o01AG01E[EV]FJeI[EQ5FJUIZEVYFJU5ZDFX0154KM0034GAd00Qd
0009M0034GAd01ed0Q405A8C5c0_A2m4@dA3A4=4@dA3A4=4@`044@0cEd=G@ea3G5MLEeaGG5MLEfmG
KeM_EfmGKeM_EfmGKeM_4FmGKeI_EVmFKeIZEVYFJU5U01Yd00<AM7@027@000Ud00<AM7@07G@24@0E
4aL`5c0[<2/`:d<[@b]3?d<o@cm300@A00LoEd=G@eM301AG01U[EV]FJeHAEV]FJUIZEVYFJU5ZDFYA
JU4_01Ud00<AM7@027@000Ud00<AM7@07G@05a4Q4QPG<1L`;d@_A4=4@dA3A4=4@dA300<A03E3G4=L
@ea3G4=LEeaGG5MLEeaGG5M_EfmGKeM_EfmGKeM_4FmGKeLQEVmFKeI_EVYFJUIZD@0IM0034GAd00Qd
0009M0034GAd01ed0Q405A<B5aL`5c0[<2/`:d<[@b]3?d<o@`044@09@eM3Ed=G@eM3015G11405UI[
EQ4MJeI[EV]FJUIZEVYFJU5ZDFXIM0034GAd00Qd0009M0034GAd01md00<C5a<00QL0;S0G<2m4;d@_
A4=4@dA3A4=4@dQ3B4=L@ea3G4=L@eaGG5MLEeaGG5MLEfmGKeL44@0GKb5_4FmGKeM_EfmFKeI_EVmF
JUIZEQ<067@00a5dM008M0002G@00a5dM00OM0044STG4P8G01h`5c0G<2/`:d<[@b]3:dA3A4=4@dA3
Ed=G@eM3Ed<?E`@A0eL0515FJeI[EV]FJeIZEVYFJUIZDFXB67@00a5dM008M0002G@00a5dM00PM004
DCTG4`8G02``5c0GA2m4;dA3A254<4Q3B4=8@dQ3G4=L@ea3G4=LEeaGG5MLEeaGG5M_E`@A01M_EflA
KeM_EfmGKeM_EfmFKeI_EVmF4`0HM0034GAd00Qd0009M0034GAd021d00DiCCTi4P025`0N<1L`5c0[
<2/`7C0[<2]4@dA3A4=4@eM3Ed=G@eM355L0515GEeI[EV]FJeI[EVYFJUIZEVXB67@00a5dM008M000
27@00a5dM00TM003CE4C008G04D`5c0GA2lQ5d@`A314<4Q3B4=8@dQ3G4=L@ea3G4=L@eaGG5MLEeaG
G5M_EfmGKeM_4FmGKeM_EfmGKeM_EfmFKeI_EET00a4EM0034GAd00Qd0008M0034GAd02Id00M=>ALG
<1L`00DG01P`:c0[<2]4@dA3A4=4@eM3Ed=G@eM3Ed<@E`034EMG009G00aFJeI[EV]FJeI[EVX3E@<A
5G@00a5dM008M00027@00a5dM00YM08G04@`5e5=DALH5d@`A314<4Q3B4=8@dQ3G4=L@ea3G4=L@eaG
G5MLEeaGG5MLEfmGKa5_EfmGKeM_EfmGKeM_EfmEFEEI8@8A5G@00a5dM008M00027@00a5dM00ZM007
CAMA>E4iD@035`0H<2/`:c0[A4=4@dA3A4=G@eM3Ed=G@eM33UL00a5GE`05E`09JeI[EV]^Kfi_00=E
00<Q4A405G@00a5dM008M00027@00a5dM00/M013DFYAJTeA5aPGA314<4@`B4=8@dQ3B4=L@ea3G4=L
@ea3G5MLEeaGG5MLEeaGKa5_EfmGKeM_Eg=_LfmcKg=_FEEI4`0GM0034GAd00Qd0008M0034GAd02ed
00Hn4A4A>E435`0H<2/`:c0[A4=4@dA3A4=G@eM3Ed=G@eM335L00a5GE`02E`0<FfmKKe]_KVm^Kfi_
0eD00a=dM00EM0034GAd00Qd0008M0034GAd035d1A40>AM4<4@`A318@dQ3B4=8@ea3G4=L@ea3G4=L
EeaGG5MLEeaGG15`Fg1KL5]`Fg1_LfmcKg=_FEEI4@0GM0034GAd00Qd0008M0034GAd035d00<AM7@0
0W@24@0d<2/`:c0[A4=4@dA3A4=G@eM3Ed=G@eM3FeMKEe]GFeMKEa5KKe]_FfmKKe]_KVm^Kfi_KP=E
67@00a5dM007M00027@00a5dM00aM0034GAd00=d03PH4D@`A314<4Q3B4=8@dQ3G4=L@ea3G4=L@eaK
G5]LFeaKG15`Fg1KL5]`Fg1KLfmcKg=_LeEIEAQd00<AM7@01g@000Qd00<AM7@0<G@00a5dM004M00d
5a4A:c0[<2]4:d@[A2]4FeQ3F4=H@eQ3F5MKEe]GFeMKEa5GKe]_FfmKKe]_KVm^Kfi_KP=E67@00a5d
M007M00027@00a5dM00aM0034GAd00Id03D`4A<G4aM3A4=4@dA3M4=L@ea3G4=L@eaKG5]LFeaKG15L
Fg1KL5]`Fg1KL6mcKg=_LeEIE@0HM0034GAd00Md0008M0034GAd035d00<AM7@01g@0<Q<A>DdCA2]4
:d@[A2]H@eQ3F4=H@eQ3FeMKEe]GFeLAEfmKKe]_FfmKKe]_KVm^KfhQ0UDHM0034GAd00Md0008M003
4GAd035d00<AM7@027@031<A4AM3A4=4@dA3A09L02I3G4=L@ea3G5]LFeaKG5]L4EaKL5]`Fg1KL5]`
Kg=_LfmcKeUE4aMd00<AM7@01g@000Qd00<AM7@0<G@00a5dM009M08C01dA?R]4:d@[A2]4@eQ3F4=H
@eQ3F5MKEe]GFeLAE`02F`0?Ke]_FfmKKe]_KVm^Kfi_009E00<BM7@05G@00a5dM007M00027@00a5d
M00aM0034GAd00Yd038C5a54@dA3A4=4@ea3G4=L@ea3G4=LFeaKG5]LFa5KG5]`Fg1KL5]`Fg=_Lfmc
KeUEFAMd00<AM7@01g@000Qd00<AM7@0<G@00a5dM008M003>BDC008C02dAA2]4:d@[A5]H@eQ3F4=H
@eQ3FeMKEe]GFa5KEfmKKe]_FfmKKe]_KVm^Kfh00UDGM0034GAd00Md0008M0034GAd035d00<AM7@0
1W@0=Q4i9CTA4Q<A@dA3A4=4@dA3G4=L@ea3G4=LFeaKG5]LFa5KG5]`Fg1KL5]`Fg1_LfmcKg=EFAMd
00<AM7@01g@000Qd00<AM7@0<G@00a5dM004M08A02A<4CTADQ4B4a4[A2]4:d@[F4=H@eQ3F4=H@e]G
FeMKEe/AFeL2F`0>Ke]_FfmKKe]_KVm^Kfh2EAMd00<AM7@01g@000Md00<AM7@0<W@00a5dM003M00C
4DaPC3TADSTB4A8AA4=4@dA3A002G00T@ea3G4=L@ea3G5]LFeaK4E]LFg1KL5]`Fg1KL5]cKg=_LeEI
5g@00a5dM007M0001g@00a5dM00bM0034GAd009d03XAAda7C4M<4E8A4R/o4D@[A2]4:dA3F4=H@eQ3
F4=HEe]GFeMK4E]GFeM_FfmKKe]_Ffm^Kfi_KVmE5g@00a5dM007M0001g@00a5dM00bM0034GAd009d
03/AM5adG7ALM153:d<B4B]3:dA3A4=L@ea3G4=L@ea3G5]LFeaK4E]LFeaKL5]`Fg1KL5]cKg=_LfmI
4`0FM0034GAd00Md0007M0034GAd039d03hAM7Ad4F1KH5]PFf1K4CTo:a8A?b/o:cl[?d=H@eQ3F4=H
@eQ3FeMKEe/AFeMKEfmKKe]_FfmKKae_KVm^K`9E5W@00a5dM007M0001g@00a5dM00bM00>4GAdM15L
M5adG7ALM5`24@0`?Q53:d<[@b]3:ea3G4=L@ea3G4=LFeaKG5/AFeaKG5]`Fg1KL5]`Fg1_LfmcKeUE
5W@00a5dM007M0001g@00a5dM00bM00?4GAd4E]PFf1KH5]PFf1K00<A01eK?b/o:cl[Ed=G@eM3Ed=H
@eQ3F5MKEe/AFeMKE`02F`0?Ke]_FfmKKe]_KVm^KfiE01Id00<AM7@01g@000Md00<AM7@0<W@0@15d
M15dG7ALM5adG7ALM5`A?U8[M2]3:ea3G4=L@ea3G4=L@ea3G5]LFa5KG5]LFeaKL5]`Fg1KL5]cKg=_
LeDGM0034GAd00Id0007M0034GAd039d02DAM7@AFf1KH5]PFf1KH5]P4E8nDR/o:f13Ed=G@eM3Ed=G
@eM3009G01UKEe/AFeMKEe]GKe]_FfmKKe]_KVm^KfiE01Md00<AM7@01W@000Md00<AM7@0<W@05Q5d
4EadG7ALM5adG7ALM5ad4E8nDR/2@`0XG4=L@ea3G4=L@ea3G4=LFeaK4E]LFeaKG5]`Fg1KL5]`Fg1_
LfmcEAMd00<AM7@01W@000Md00<AM7@0<W@09A5d4F1KH5]PFf1KH5]PFf1K4CiB?U93Ed=G@eM3Ed=G
@eM3Ed<00UL02UaGG15LEe]GFeL2F`0=Ke]_FfmKKe]_KVm^K`0GM0034GAd00Id0007M0034GAd039d
0Q404GALM5adG7ALM5adG7ALM5`A00EG02QL@ea3G4=L@ea3G4=LFeaKG5/AFeaKG5]LFg1KL5]`Fg1K
L6mcKg=_5g@00a5dM006M0001g@00a5dM00bM08A03iGFeMKEe]GFeMKEe]GFeMKEa53Ed=G@eM3Ed=G
@eM3Ed=G@eaGG5ML4EaGG5MLEeaKKe]_FfmKKe]_KVm^KaMd00<AM7@01W@000Md00<AM7@0<W@24@0C
L5]`Fg1KL5]`Fg1KL5]`Fg1K4@05E`0VG4=L@ea3G4=L@eaKG5]LFa5KG5]LFeaKM7=dLgAKL5]`Fg=_
LflGM0034GAd00Id0007M0034GAd039d0Q408EMKEe]GFeMKEe]GFeMKEe]GFeLA@eM3Ed=G@eM3Ed=G
@`02E`0?G5MLEe`AG5MLEeaGG5]d00@A00AKM5]d114GM0034GAd00Id0007M0034GAd039d0Q405G1K
L5]`Fg1KL5]`Fg1KL5]`Fg1G4@05E`0HG4=L@ea3G4=LFeaKG5/AFeaKG5]LFgAc114017AcM7<34AQd
00<AM7@01W@000Md00<AM7@0<W@24@0QEe]GFeMKEe]GFeMKEe]GFeMKEe]34D=G@eM3Ed=G@eM3009G
00mLEeaGG15LEeaGG5MdFg@0114015]dFg@34AQd00<AM7@01W@000Md00<AM7@0<W@24@0FL5]`Fg1K
L5]`Fg1KL5]`Fg1KL5]`4@MG01E3G4=LFeaKG5]LFa5KG5]LFeacM7<011400gAcM0034AUd00<AM7@0
1W@000Md00<AM7@0<W@24@0iEe]GFeMKEe]GFeMKEe]GFeMKEe]GFa5G@eM3Ed=G@eM3G5MLEeaGG15L
EeaGG5MdFgAKM5]dFgAK00<A6G@00a5dM006M0001W@00a5dM00cM08A01Q`Fg1KL5]`Fg1KL5]`Fg1K
L5]`Fg1KL147E`0G@eaKG5]LFeaK4E]LFeaKG7=dLgAcM7<01A4JM0034GAd00Id0006M0034GAd03=d
0Q407eMKEe]GFeMKEe]GFeMKEe]GFeMKEe]G4D=G@eM3Ed<00UL05EaGG5MLEe`AG5MLEeaKM5]dFgAK
M0054AYd00<AM7@01W@000Id00<AM7@0<g@06a5KL5]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1K4@06E`0G
Fg1KG5]LFeaK4E]LFeaKM7=dLgAcM7<0114KM0034GAd00Id0006M0034GAd03=d03PAFeMKEe]GFeMK
Ee]GFeMKEe]GFeMKEe]G8ELA@eM3EadQEe]GG5MLEe`AG5MLEeaKM5]dFb5KM0@A6g@00a5dM006M000
1W@00a5dM00cM00M4E]`Fg1KL5]`Fg1KL5]`Fg1KL5]`Fg1KL25`Fa400UL06R5`Fg1KL5]LFeaK4E]L
FeaKM7=dLgAcM7=d0Q4LM0034GAd00Id0006M0034GAd03=d01dAFeMKEe]GFeMKEe]GFeMKEe]GFeMK
Ee/M8AdQ4@02E`0IFeMKEe]GFeMLEe`AG5MLEgAKM5]dFgAKM0024@037GAd01]d00<AM7@01G@000Id
00<AM7@0<g@05A5KL5]`Fg1KL5]`Fg1KL5]`Fg1KL0048@0OEe]GFa5`Fg1KL5]`Fg1KG5/AFeaKG7=d
LgAcM7=dL`054A]d00<AM7@01G@000Id00<AM7@0<g@03Q5KEe]GFeMKEe]GFeMK15L00adQ7@02E`03
8EMG00=G01XAEe]GFeMKEe]GFeML4EaGG5MdFgAKM5]dF`HA6g@00a5dM005M0001W@00a5dM00cM00>
4E]`Fg1KL5MKEe]GFeL48@0WFeMKEe/QFeMKEe]G4E]`Fg1KL5]`Fg1K4E]LFeacM7=dLgAcM14Q00@A
6g@00a5dM005M0001W@00a5dM00cM0034EMG00QG00<Q7B4025L00aeGE`05E`0K4E]GFeMKEe]GFeMK
4EaGG5]dFgAKM5]dFa5d00@A6g@00a5dM005M0001W@00a5dM00cM0084EMKEe]GFeL38@0@Ee]GFeMK
Ee]GFeLQEe]GF`<Q01PAFg1KL5]`Fg1KL5/AFeaKM7=dLgAcM7<24B1d00<AM7@01G@000Id00<AM7@0
<g@24@9G00@M8AdQ3EL01R5G8AdQ7@AG01PAEe]GFeMKEe]GFa5KEe`MM5]dFgAKM14QM0034GAd00Ed
0006M0034GAd03=d01@A8B4QFeMKEe]GFeMKEe]GFeMKE`<Q01mGFeMKEe]GFa5`Fg1KL5]`Fg1K4E]`
LgAcM7=dLg@A029d00<AM7@01G@000Id00<AM7@0<7@01B4M8AdA00iG00DM8AdQ7@0:E`0G4EMKEe]G
FeMKEe/AFeMdFgAKM5]dFa408W@00a5dM005M0001W@00a5dM00]M0<Q0g@03A5d4EMKEe]GFeMKEe/0
0b4075]GFeLQEe]GFeMKEe]GFeLAFg1KL5]`Fg1K4E/44@04M7=dLbAd00<AM7@01G@000Id00<AM7@0
:G@011dQ7B46M0034G@A00IG00@Q7B4M1UL00b5GE`09E`0=8A5KEe]GFeMKEe/AM0044@05FgAKM140
8g@00a5dM005M0001W@00a5dM00WM08Q2W@01Q5d4EMKE`<Q01=GFeMKEe]GFeMK8E]GFeMKEe]G00<Q
00YG4E]`Fg1KL5]`0Q400f0A4@024@04M7=dLbAd00<AM7@01G@000Id00<AM7@0<g@01Q5d7B4M8@aG
00<MEeL00eL011dQ7B45E`044EMKE`@A00=dGa40114015mdFa4TM0034GAd00Ed0005M0034GAd03=d
0b404g@AFeMKEe]GFeMKEe]GFb5KEe/00b401E]GFeMK00@Q11403E]`FgAPM60AH7APM6009W@00a5d
M005M0001G@00a5dM00_M0068AdQ7G@A0W@00a5GE`0;E`048AdQ7@=G00HM8AdQ7EL44@0?Ee]GFeMK
GgAOM5lAGgAO02Md00<AM7@01G@000Ed00<AM7@0;G@28@Ed00hAM7@AFeMKEe]GFeMKE`<Q00=GFb40
12400eMBE`034@0BEe9GDQ5KL5]`H7APM61dH15P:7@00a5dM005M0001G@00a5dM00dM0054GAdM140
1EL03AdQ7B4M8AdQ7ELnEch011405ELnEciG?ULAFeMKGgAOM5mdGgAO4@0XM0034GAd00Ed0005M003
4GAd03Ad00LAM7Ad4EMK00LQ00IK8E]BEe834@0GDUMBEe9GDUMBEe8AFg1PM61dH7APM6000W@00a5d
M00UM0034GAd00Ed0005M0034GAd03Ad00XAM7Ad7B4M8AdQ15L00chQ4@034@0I?ULnEciG?ULnEciG
?ULn4EmdGgAOM5mdG`04M0034GAd02Ed00<AM7@017@000Ed00<AM7@0=7@58@084E]GFe9GDUL34@0L
Ee9GDUMBEe9GDUMBEe9GDUMBEa5dH7APM61dH0Id00<AM7@097@00a5dM004M0001G@00a5dM00VM0@A
1G@01R4M8AdQ4@Ad00@A?ULn11407ULMEciG?ULnEciG?ULnEciG?ULnEchAGgAOM5mdG`Qd00<AM7@0
8g@00a5dM004M0001G@00a5dM00VM0@A1B44M0034GAd00Ad0a408E9GDULQEe9GDUMBEe9GDUMBEe9G
DUMBEe8AH7APM61dH00:M0034GAd029d00<AM7@017@000Ed00<AM7@09W@0114Q7B49M0034GAd00@A
02=d4CiG?ULn8CiG?ULnEciG?ULnEciG?ULnEciG4GAOM5mdG`0<M0034GAd025d00<AM7@017@000Ed
00<AM7@09W@44@Ud0a46M00N4E9GDR5BEe9GDUMBEe9GDUMBEe9GDUMB>Q5dH7AP47@00a5dM00PM003
4GAd00Ad0005M0034GAd02md1A49M00L4CiG7ELnEciG?ULnEciG?ULnEciG9BHU4EmdGa9d00<AM7@0
7g@00a5dM004M0001G@00a5dM00/M0<A17@00a5dM008M00J4B5GDUMBEe9GDUMBEe9GDUMB>RDj9A5P
M60DM0034GAd01id00<AM7@017@000Ed00<AM7@0:7@44@Md00<AM7@02G@0624nEciG?ULnEciG?ULn
EbDV9BHU9Q5dGaId00<AM7@07G@00a5dM004M0001G@00a5dM00UM0<A2g@00a5dM008M00H8G@ADUMB
Ee9GDUMBEe8j9CXU>RDj4GAP67@00a5dM00LM0034GAd00Ad0005M0034GAd025d114>M0034GAd00Md
01PQM7Ad4CiG?ULnEciG9BHU9RDV9BHU4ElJM0034GAd01]d00<AM7@017@000Ed00<AM7@07W@34A9d
00<AM7@01g@00b5dM002M00B4E9GDUMB>RDj9CXU>RDj9A5P77@00a5dM00JM0034GAd00Ad0005M003
4GAd01Yd114EM0034GAd00Id00<MM7@017@0414nEbDV9BHU9RDV9BHU9Q4NM0034GAd01Ud00<AM7@0
17@000Ad00<AM7@067@34AUd00<AM7@01W@00b5dM005M0hA87@00a5dM00HM0034GAd00Ad0004M003
4GAd01Ad114LM0034GAd00Ed00<QM7@0=G@00a5dM00GM0034GAd00Ad0004M0034GAd015d0a4PM003
4GAd00Ed00<QM7@0=W@00a5dM00FM0034GAd00Ad0004M0034GAd00ed114SM0034GAd00Ad00<MM7@0
>7@00a5dM00EM0034GAd00Ad0004M0034GAd00Yd0a4WM0034GAd00Ad00<QM7@0>G@00a5dM00EM003
4GAd00=d0004M0034GAd00Id114ZM0034GAd00=d00<QM7@0>W@00a5dM00EM0034GAd00=d0004M003
4GAd00=d0a4^M0034GAd00=d00<QM7@0>g@00a5dM00DM0034GAd00=d0004M0034G@A00<A<G@00a5d
M002M0037GAd03ed00<AM7@04g@00a5dM003M00017@24CEd00<AM7@00W@00b5dM00nM0034GAd019d
00<AM7@00g@000Ed00<AM7@0<g@01A5dM7@Q049d00<AM7@04G@00a5dM003M0001W@00a5dM00bM004
4GAd8DAd00<AM7@047@00a5dM003M0001g@24C9d00@AM7@MAG@00a5dM00?M0034GAd00=d0009M003
4GAd02md00<AM240Ag@00a5dM00>M0034GAd00=d000:M0034GAd02id00<AM240B7@00a5dM00=M003
4GAd00=d000;M0034GAd02ed00<A8G@0BG@00a5dM00<M0034GAd00=d000<M0034GAd02ad00<A7G@0
BW@00a5dM00;M0034GAd00=d000=M08A;7@00b5dM01;M0034GAd00Yd00<AM7@00g@000md00<AM7@0
:G@00b5dM01<M0034GAd00Ud00<AM7@00g@0011d00<AM7@09g@00b4AM01>M0034GAd00Qd00<AM7@0
0g@0015d00<AM7@09W@00adAM01?M0034GAd00Md00<AM7@00g@0019d00<AM7@097@00b5d4@1AM003
4GAd00Id00<AM7@00g@001=d0Q4TM0038G@A059d00<AM7@01G@00a5dM003M0005G@00a5dM00PM004
8GAd4E=d00<AM7@01G@00a5dM002M0005W@00a5dM00OM0047GAd4EAd00<AM7@017@00a5dM002M000
5g@00a5dM00MM0058GAdM140EG@00a5dM003M0034GAd009d000HM0034GAd01ad00DQM7Ad4@1FM003
4GAd009d00<AM7@00W@001Ud0Q4KM0038GAd009d00<AM7@0EG@01A5dM7@A00Ad000KM0034GAd01Qd
00<MM7@00W@00a5dM01FM0044GAd4@Ad000LM0034GAd01Id00<QM7@00g@00a5dM01GM0034G@A00Ad
000MM0034GAd01Ed00<QM7@00g@00a5dM01HM08A17@001id00<AM7@04g@00b5dM004M0034GAd05Md
0a44M0007g@24A=d00<MM7@017@00a5dM01CM0@A1g@0025d00<AM7@03g@00b5dM005M0034GAd04md
114;M0008W@00a5dM00>M0038GAd00Ed00<AM7@0Bg@44@md000SM0034GAd00ad00<QM7@01W@00a5d
M017M0@A4g@002Ad00<AM7@02g@00aedM006M0034GAd04=d114GM0009G@24@Qd1148M0034GAd03md
114KM0009g@00a5dM005M0@A27@00a5dM00kM0@A7g@002Qd00<AM7@017@44@Qd00<AM7@0=g@44B=d
000YM0034GAd00=d1148M0034GAd03=d114WM000:W@00a5dM00=M0034GAd031d114[M000:g@24@ed
00<AM7@0;7@44Bmd000]M0034GAd00Yd00<AM7@0:7@44C=d000^M0034GAd00Ud00<AM7@097@44CMd
000_M0034GAd00Qd00<AM7@087@44C]d000`M0034GAd00Md00<AM7@077@44Cmd000aM08A1g@00a5d
M00HM0@A@g@003=d00<AM7@017@00a5dM00DM0@AAg@003Ad00<AM7@00g@00a5dM00@M0@ABg@003Ed
00<AM7@00W@00a5dM00<M0@ACg@003Id00DAM7Ad4@0:M0@ADg@003Md0Q400g@AM005M0@AEg@003Ud
0Q42M0@AFg@003Yd0a5OM000W7@009ad002LM000W7@009ad002LM000W7@00001\
\>"],
  ImageRangeCache->{{{0, 155.25}, {287, 0}} -> {0.228143, 0.0180311, \
0.00342704, 0.00342704}}]
}, Open  ]],

Cell["The rays are reflected many times.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[propagatedseashellmirror, 
\tShowLabels -> False, PlotType -> SideView, PlotPoints -> 30, RayPointSize \
-> 5];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.190476 0.0571429 0.190476 [
[ 0 0 0 0 ]
[ 1 2.4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.2278 1.22402 m
.5 1.31378 L
.4863 1.33138 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.4863 1.33138 L
.46773 1.34689 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.46773 1.34689 L
.44506 1.35983 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.44506 1.35983 L
.41925 1.36982 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.41925 1.36982 L
.39141 1.37664 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.39141 1.37664 L
.36268 1.3802 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.36268 1.3802 L
.33412 1.38054 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.33412 1.38054 L
.30664 1.37782 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.30664 1.37782 L
.28095 1.37229 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.28095 1.37229 L
.25749 1.36426 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.25749 1.36426 L
.2365 1.35404 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.2365 1.35404 L
.21804 1.34194 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.21804 1.34194 L
.20202 1.32825 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.20202 1.32825 L
.18825 1.31323 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.18825 1.31323 L
.17651 1.29708 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.17651 1.29708 L
.16655 1.27999 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.16655 1.27999 L
.15813 1.26214 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.15813 1.26214 L
.15102 1.24369 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.15102 1.24369 L
.14504 1.22486 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.14504 1.22486 L
.14004 1.20585 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.14004 1.20585 L
.13597 1.18696 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.13597 1.18696 L
.13283 1.16848 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.13283 1.16848 L
.13076 1.15079 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.13076 1.15079 L
.13 1.13426 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.13 1.13426 L
.13089 1.11926 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.13089 1.11926 L
.13383 1.10615 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.13383 1.10615 L
.13926 1.09523 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.13926 1.09523 L
.14755 1.08672 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.14755 1.08672 L
.15901 1.08076 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.15901 1.08076 L
.17377 1.07741 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.17377 1.07741 L
.19179 1.07662 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.19179 1.07662 L
.21286 1.07829 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.21286 1.07829 L
.23658 1.08226 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.23658 1.08226 L
.26243 1.08835 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.26243 1.08835 L
.28982 1.09635 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.28982 1.09635 L
.3181 1.1061 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.3181 1.1061 L
.34663 1.11743 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.34663 1.11743 L
.37477 1.13024 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.37477 1.13024 L
.4019 1.14445 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.4019 1.14445 L
.4274 1.15998 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.4274 1.15998 L
.45064 1.17679 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.45064 1.17679 L
.471 1.19478 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.471 1.19478 L
.48782 1.21382 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.48782 1.21382 L
.50048 1.23368 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.50048 1.23368 L
.5084 1.25407 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.5084 1.25407 L
.51112 1.27455 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.51112 1.27455 L
.50834 1.29464 L
.2278 1.22402 L
.2278 1.22402 L
F
.2278 1.22402 m
.50834 1.29464 L
.5 1.31378 L
.2278 1.22402 L
.2278 1.22402 L
F
.5 1.31378 m
.79336 1.40354 L
.76912 1.44114 L
.4863 1.33138 L
.5 1.31378 L
F
.4863 1.33138 m
.76912 1.44114 L
.73059 1.47317 L
.46773 1.34689 L
.4863 1.33138 L
F
.46773 1.34689 m
.73059 1.47317 L
.67999 1.4976 L
.44506 1.35983 L
.46773 1.34689 L
F
.44506 1.35983 m
.67999 1.4976 L
.62104 1.51312 L
.41925 1.36982 L
.44506 1.35983 L
F
.41925 1.36982 m
.62104 1.51312 L
.55848 1.51932 L
.39141 1.37664 L
.41925 1.36982 L
F
.39141 1.37664 m
.55848 1.51932 L
.49729 1.51664 L
.36268 1.3802 L
.39141 1.37664 L
F
.36268 1.3802 m
.49729 1.51664 L
.44171 1.50616 L
.33412 1.38054 L
.36268 1.3802 L
F
.33412 1.38054 m
.44171 1.50616 L
.39462 1.48941 L
.30664 1.37782 L
.33412 1.38054 L
F
.30664 1.37782 m
.39462 1.48941 L
.35718 1.46804 L
.28095 1.37229 L
.30664 1.37782 L
F
.28095 1.37229 m
.35718 1.46804 L
.32902 1.44364 L
.25749 1.36426 L
.28095 1.37229 L
F
.25749 1.36426 m
.32902 1.44364 L
.30875 1.41755 L
.2365 1.35404 L
.25749 1.36426 L
F
.2365 1.35404 m
.30875 1.41755 L
.29456 1.39078 L
.21804 1.34194 L
.2365 1.35404 L
F
.21804 1.34194 m
.29456 1.39078 L
.28481 1.36399 L
.20202 1.32825 L
.21804 1.34194 L
F
.20202 1.32825 m
.28481 1.36399 L
.27827 1.33745 L
.18825 1.31323 L
.20202 1.32825 L
F
.18825 1.31323 m
.27827 1.33745 L
.27415 1.31115 L
.17651 1.29708 L
.18825 1.31323 L
F
.17651 1.29708 m
.27415 1.31115 L
.27202 1.2848 L
.16655 1.27999 L
.17651 1.29708 L
F
.16655 1.27999 m
.27202 1.2848 L
.27151 1.25799 L
.15813 1.26214 L
.16655 1.27999 L
F
.15813 1.26214 m
.27151 1.25799 L
.27213 1.23025 L
.15102 1.24369 L
.15813 1.26214 L
F
.15102 1.24369 m
.27213 1.23025 L
.27312 1.20122 L
.14504 1.22486 L
.15102 1.24369 L
F
.14504 1.22486 m
.27312 1.20122 L
.27347 1.17076 L
.14004 1.20585 L
.14504 1.22486 L
F
.14004 1.20585 m
.27347 1.17076 L
.27199 1.13908 L
.13597 1.18696 L
.14004 1.20585 L
F
.13597 1.18696 m
.27199 1.13908 L
.26767 1.10676 L
.13283 1.16848 L
.13597 1.18696 L
F
.13283 1.16848 m
.26767 1.10676 L
.25993 1.07481 L
.13076 1.15079 L
.13283 1.16848 L
F
.13076 1.15079 m
.25993 1.07481 L
.24895 1.0445 L
.13 1.13426 L
.13076 1.15079 L
F
.13 1.13426 m
.24895 1.0445 L
.23585 1.01726 L
.13089 1.11926 L
.13 1.13426 L
F
.13089 1.11926 m
.23585 1.01726 L
.22265 .99447 L
.13383 1.10615 L
.13089 1.11926 L
F
.13383 1.10615 m
.22265 .99447 L
.21202 .97726 L
.13926 1.09523 L
.13383 1.10615 L
F
.13926 1.09523 m
.21202 .97726 L
.20677 .96634 L
.14755 1.08672 L
.13926 1.09523 L
F
.14755 1.08672 m
.20677 .96634 L
.2093 .96198 L
.15901 1.08076 L
.14755 1.08672 L
F
.15901 1.08076 m
.2093 .96198 L
.22106 .96391 L
.17377 1.07741 L
.15901 1.08076 L
F
.17377 1.07741 m
.22106 .96391 L
.24229 .97148 L
.19179 1.07662 L
.17377 1.07741 L
F
.19179 1.07662 m
.24229 .97148 L
.27202 .98372 L
.21286 1.07829 L
.19179 1.07662 L
F
.21286 1.07829 m
.27202 .98372 L
.30842 .99949 L
.23658 1.08226 L
.21286 1.07829 L
F
.23658 1.08226 m
.30842 .99949 L
.34923 1.01766 L
.26243 1.08835 L
.23658 1.08226 L
F
.26243 1.08835 m
.34923 1.01766 L
.39233 1.03719 L
.28982 1.09635 L
.26243 1.08835 L
F
.28982 1.09635 m
.39233 1.03719 L
.43607 1.05726 L
.3181 1.1061 L
.28982 1.09635 L
F
.3181 1.1061 m
.43607 1.05726 L
.47944 1.07735 L
.34663 1.11743 L
.3181 1.1061 L
F
.34663 1.11743 m
.47944 1.07735 L
.52208 1.09733 L
.37477 1.13024 L
.34663 1.11743 L
F
.37477 1.13024 m
.52208 1.09733 L
.56401 1.1174 L
.4019 1.14445 L
.37477 1.13024 L
F
.4019 1.14445 m
.56401 1.1174 L
.60538 1.13815 L
.4274 1.15998 L
.4019 1.14445 L
F
.4274 1.15998 m
.60538 1.13815 L
.64612 1.16045 L
.45064 1.17679 L
.4274 1.15998 L
F
.45064 1.17679 m
.64612 1.16045 L
.68567 1.18528 L
.471 1.19478 L
.45064 1.17679 L
F
.471 1.19478 m
.68567 1.18528 L
.72281 1.21356 L
.48782 1.21382 L
.471 1.19478 L
F
.48782 1.21382 m
.72281 1.21356 L
.75561 1.24586 L
.50048 1.23368 L
.48782 1.21382 L
F
.50048 1.23368 m
.75561 1.24586 L
.78164 1.28215 L
.5084 1.25407 L
.50048 1.23368 L
F
.5084 1.25407 m
.78164 1.28215 L
.79821 1.32168 L
.51112 1.27455 L
.5084 1.25407 L
F
.51112 1.27455 m
.79821 1.32168 L
.80276 1.36287 L
.50834 1.29464 L
.51112 1.27455 L
F
.50834 1.29464 m
.80276 1.36287 L
.79336 1.40354 L
.5 1.31378 L
.50834 1.29464 L
F
.79336 1.40354 m
.92984 1.4933 L
.9174 1.55303 L
.76912 1.44114 L
.79336 1.40354 L
F
.76912 1.44114 m
.9174 1.55303 L
.87857 1.60092 L
.73059 1.47317 L
.76912 1.44114 L
F
.73059 1.47317 m
.87857 1.60092 L
.81444 1.63149 L
.67999 1.4976 L
.73059 1.47317 L
F
.67999 1.4976 m
.81444 1.63149 L
.73152 1.64208 L
.62104 1.51312 L
.67999 1.4976 L
F
.62104 1.51312 m
.73152 1.64208 L
.64113 1.63312 L
.55848 1.51932 L
.62104 1.51312 L
F
.55848 1.51932 m
.64113 1.63312 L
.55653 1.60753 L
.49729 1.51664 L
.55848 1.51932 L
F
.49729 1.51664 m
.55653 1.60753 L
.4888 1.56973 L
.44171 1.50616 L
.49729 1.51664 L
F
.44171 1.50616 m
.4888 1.56973 L
.44338 1.52452 L
.39462 1.48941 L
.44171 1.50616 L
F
.39462 1.48941 m
.44338 1.52452 L
.41921 1.47624 L
.35718 1.46804 L
.39462 1.48941 L
F
.35718 1.46804 m
.41921 1.47624 L
.41055 1.4283 L
.32902 1.44364 L
.35718 1.46804 L
F
.32902 1.44364 m
.41055 1.4283 L
.41021 1.38306 L
.30875 1.41755 L
.32902 1.44364 L
F
.30875 1.41755 m
.41021 1.38306 L
.41252 1.34194 L
.29456 1.39078 L
.30875 1.41755 L
F
.29456 1.39078 m
.41252 1.34194 L
.4147 1.30552 L
.28481 1.36399 L
.29456 1.39078 L
F
.28481 1.36399 m
.4147 1.30552 L
.41663 1.27374 L
.27827 1.33745 L
.28481 1.36399 L
F
.27827 1.33745 m
.41663 1.27374 L
.41982 1.24593 L
.27415 1.31115 L
.27827 1.33745 L
F
.27415 1.31115 m
.41982 1.24593 L
.42617 1.22093 L
.27202 1.2848 L
.27415 1.31115 L
F
.27202 1.2848 m
.42617 1.22093 L
.43709 1.19709 L
.27151 1.25799 L
.27202 1.2848 L
F
.27151 1.25799 m
.43709 1.19709 L
.45287 1.17253 L
.27213 1.23025 L
.27151 1.25799 L
F
.27213 1.23025 m
.45287 1.17253 L
.47234 1.14535 L
.27312 1.20122 L
.27213 1.23025 L
F
.27312 1.20122 m
.47234 1.14535 L
.49269 1.1141 L
.27347 1.17076 L
.27312 1.20122 L
F
.27347 1.17076 m
.49269 1.1141 L
.50985 1.07816 L
.27199 1.13908 L
.27347 1.17076 L
F
.27199 1.13908 m
.50985 1.07816 L
.51918 1.03814 L
.26767 1.10676 L
.27199 1.13908 L
F
.26767 1.10676 m
.51918 1.03814 L
.51663 .99598 L
.25993 1.07481 L
.26767 1.10676 L
F
.25993 1.07481 m
.51663 .99598 L
.5 .95474 L
.24895 1.0445 L
.25993 1.07481 L
F
.24895 1.0445 m
.5 .95474 L
.46992 .91811 L
.23585 1.01726 L
.24895 1.0445 L
F
.23585 1.01726 m
.46992 .91811 L
.4304 .8897 L
.22265 .99447 L
.23585 1.01726 L
F
.22265 .99447 m
.4304 .8897 L
.38833 .87232 L
.21202 .97726 L
.22265 .99447 L
F
.21202 .97726 m
.38833 .87232 L
.35207 .86754 L
.20677 .96634 L
.21202 .97726 L
F
.20677 .96634 m
.35207 .86754 L
.3292 .87542 L
.2093 .96198 L
.20677 .96634 L
F
.2093 .96198 m
.3292 .87542 L
.32432 .89469 L
.22106 .96391 L
.2093 .96198 L
F
.22106 .96391 m
.32432 .89469 L
.33773 .92309 L
.24229 .97148 L
.22106 .96391 L
F
.24229 .97148 m
.33773 .92309 L
.36576 .95784 L
.27202 .98372 L
.24229 .97148 L
F
.27202 .98372 m
.36576 .95784 L
.40243 .99601 L
.30842 .99949 L
.27202 .98372 L
F
.30842 .99949 m
.40243 .99601 L
.44166 1.03491 L
.34923 1.01766 L
.30842 .99949 L
F
.34923 1.01766 m
.44166 1.03491 L
.47907 1.07222 L
.39233 1.03719 L
.34923 1.01766 L
F
.39233 1.03719 m
.47907 1.07222 L
.51258 1.1061 L
.43607 1.05726 L
.39233 1.03719 L
F
.43607 1.05726 m
.51258 1.1061 L
.54224 1.13527 L
.47944 1.07735 L
.43607 1.05726 L
F
.47944 1.07735 m
.54224 1.13527 L
.56957 1.15913 L
.52208 1.09733 L
.47944 1.07735 L
F
.52208 1.09733 m
.56957 1.15913 L
.59701 1.1779 L
.56401 1.1174 L
.52208 1.09733 L
F
.56401 1.1174 m
.59701 1.1779 L
.62726 1.1928 L
.60538 1.13815 L
.56401 1.1174 L
F
.60538 1.13815 m
.62726 1.1928 L
.66259 1.20616 L
.64612 1.16045 L
.60538 1.13815 L
F
.64612 1.16045 m
.66259 1.20616 L
.70405 1.22133 L
.68567 1.18528 L
.64612 1.16045 L
F
.68567 1.18528 m
.70405 1.22133 L
.75087 1.24219 L
.72281 1.21356 L
.68567 1.18528 L
F
.72281 1.21356 m
.75087 1.24219 L
.80038 1.27236 L
.75561 1.24586 L
.72281 1.21356 L
F
.75561 1.24586 m
.80038 1.27236 L
.84841 1.31411 L
.78164 1.28215 L
.75561 1.24586 L
F
.78164 1.28215 m
.84841 1.31411 L
.88982 1.36732 L
.79821 1.32168 L
.78164 1.28215 L
F
.79821 1.32168 m
.88982 1.36732 L
.9189 1.42896 L
.80276 1.36287 L
.79821 1.32168 L
F
.80276 1.36287 m
.9189 1.42896 L
.92984 1.4933 L
.79336 1.40354 L
.80276 1.36287 L
F
.92984 1.4933 m
.81452 1.58306 L
.84302 1.66675 L
.9174 1.55303 L
.92984 1.4933 L
F
.9174 1.55303 m
.84302 1.66675 L
.84247 1.72797 L
.87857 1.60092 L
.9174 1.55303 L
F
.87857 1.60092 m
.84247 1.72797 L
.80192 1.75552 L
.81444 1.63149 L
.87857 1.60092 L
F
.81444 1.63149 m
.80192 1.75552 L
.72314 1.74616 L
.73152 1.64208 L
.81444 1.63149 L
F
.73152 1.64208 m
.72314 1.74616 L
.62432 1.70434 L
.64113 1.63312 L
.73152 1.64208 L
F
.64113 1.63312 m
.62432 1.70434 L
.5336 1.63946 L
.55653 1.60753 L
.64113 1.63312 L
F
.55653 1.60753 m
.5336 1.63946 L
.47508 1.56229 L
.4888 1.56973 L
.55653 1.60753 L
F
.4888 1.56973 m
.47508 1.56229 L
.45651 1.48216 L
.44338 1.52452 L
.4888 1.56973 L
F
.44338 1.52452 m
.45651 1.48216 L
.46739 1.40557 L
.41921 1.47624 L
.44338 1.52452 L
F
.41921 1.47624 m
.46739 1.40557 L
.48796 1.33618 L
.41055 1.4283 L
.41921 1.47624 L
F
.41055 1.4283 m
.48796 1.33618 L
.5017 1.27555 L
.41021 1.38306 L
.41055 1.4283 L
F
.41021 1.38306 m
.5017 1.27555 L
.50283 1.22402 L
.41252 1.34194 L
.41021 1.38306 L
F
.41252 1.34194 m
.50283 1.22402 L
.49545 1.18146 L
.4147 1.30552 L
.41252 1.34194 L
F
.4147 1.30552 m
.49545 1.18146 L
.48777 1.14749 L
.41663 1.27374 L
.4147 1.30552 L
F
.41663 1.27374 m
.48777 1.14749 L
.48672 1.12147 L
.41982 1.24593 L
.41663 1.27374 L
F
.41982 1.24593 m
.48672 1.12147 L
.49598 1.10215 L
.42617 1.22093 L
.41982 1.24593 L
F
.42617 1.22093 m
.49598 1.10215 L
.51668 1.08738 L
.43709 1.19709 L
.42617 1.22093 L
F
.43709 1.19709 m
.51668 1.08738 L
.54852 1.07396 L
.45287 1.17253 L
.43709 1.19709 L
F
.45287 1.17253 m
.54852 1.07396 L
.58978 1.05794 L
.47234 1.14535 L
.45287 1.17253 L
F
.47234 1.14535 m
.58978 1.05794 L
.63648 1.03541 L
.49269 1.1141 L
.47234 1.14535 L
F
.49269 1.1141 m
.63648 1.03541 L
.68209 1.00365 L
.50985 1.07816 L
.49269 1.1141 L
F
.50985 1.07816 m
.68209 1.00365 L
.71824 .96235 L
.51918 1.03814 L
.50985 1.07816 L
F
.51918 1.03814 m
.71824 .96235 L
.7364 .91425 L
.51663 .99598 L
.51918 1.03814 L
F
.51663 .99598 m
.7364 .91425 L
.72989 .86498 L
.5 .95474 L
.51663 .99598 L
F
.5 .95474 m
.72989 .86498 L
.69615 .82185 L
.46992 .91811 L
.5 .95474 L
F
.46992 .91811 m
.69615 .82185 L
.6387 .79208 L
.4304 .8897 L
.46992 .91811 L
F
.4304 .8897 m
.6387 .79208 L
.56792 .78097 L
.38833 .87232 L
.4304 .8897 L
F
.38833 .87232 m
.56792 .78097 L
.49933 .79076 L
.35207 .86754 L
.38833 .87232 L
F
.35207 .86754 m
.49933 .79076 L
.44857 .82041 L
.3292 .87542 L
.35207 .86754 L
F
.3292 .87542 m
.44857 .82041 L
.42506 .86632 L
.32432 .89469 L
.3292 .87542 L
F
.32432 .89469 m
.42506 .86632 L
.42788 .92352 L
.33773 .92309 L
.32432 .89469 L
F
.33773 .92309 m
.42788 .92352 L
.44706 .98685 L
.36576 .95784 L
.33773 .92309 L
F
.36576 .95784 m
.44706 .98685 L
.46979 1.05177 L
.40243 .99601 L
.36576 .95784 L
F
.40243 .99601 m
.46979 1.05177 L
.48722 1.1147 L
.44166 1.03491 L
.40243 .99601 L
F
.44166 1.03491 m
.48722 1.1147 L
.49734 1.17285 L
.47907 1.07222 L
.44166 1.03491 L
F
.47907 1.07222 m
.49734 1.17285 L
.50283 1.22402 L
.51258 1.1061 L
.47907 1.07222 L
F
.51258 1.1061 m
.50283 1.22402 L
.50691 1.26622 L
.54224 1.13527 L
.51258 1.1061 L
F
.54224 1.13527 m
.50691 1.26622 L
.51103 1.29771 L
.56957 1.15913 L
.54224 1.13527 L
F
.56957 1.15913 m
.51103 1.29771 L
.51584 1.31727 L
.59701 1.1779 L
.56957 1.15913 L
F
.59701 1.1779 m
.51584 1.31727 L
.52322 1.32492 L
.62726 1.1928 L
.59701 1.1779 L
F
.62726 1.1928 m
.52322 1.32492 L
.53674 1.32289 L
.66259 1.20616 L
.62726 1.1928 L
F
.66259 1.20616 m
.53674 1.32289 L
.55965 1.31634 L
.70405 1.22133 L
.66259 1.20616 L
F
.70405 1.22133 m
.55965 1.31634 L
.59247 1.31339 L
.75087 1.24219 L
.70405 1.22133 L
F
.75087 1.24219 m
.59247 1.31339 L
.63279 1.32375 L
.80038 1.27236 L
.75087 1.24219 L
F
.80038 1.27236 m
.63279 1.32375 L
.67737 1.35594 L
.84841 1.31411 L
.80038 1.27236 L
F
.84841 1.31411 m
.67737 1.35594 L
.72413 1.41368 L
.88982 1.36732 L
.84841 1.31411 L
F
.88982 1.36732 m
.72413 1.41368 L
.7714 1.49322 L
.9189 1.42896 L
.88982 1.36732 L
F
.9189 1.42896 m
.7714 1.49322 L
.81452 1.58306 L
.92984 1.4933 L
.9189 1.42896 L
F
.81452 1.58306 m
.5 1.67282 L
.58201 1.78195 L
.84302 1.66675 L
.81452 1.58306 L
F
.84302 1.66675 m
.58201 1.78195 L
.65978 1.85199 L
.84247 1.72797 L
.84302 1.66675 L
F
.84247 1.72797 m
.65978 1.85199 L
.69067 1.86416 L
.80192 1.75552 L
.84247 1.72797 L
F
.80192 1.75552 m
.69067 1.86416 L
.6524 1.81808 L
.72314 1.74616 L
.80192 1.75552 L
F
.72314 1.74616 m
.6524 1.81808 L
.56492 1.72859 L
.62432 1.70434 L
.72314 1.74616 L
F
.62432 1.70434 m
.56492 1.72859 L
.48146 1.61704 L
.5336 1.63946 L
.62432 1.70434 L
F
.5336 1.63946 m
.48146 1.61704 L
.45068 1.5026 L
.47508 1.56229 L
.5336 1.63946 L
F
.47508 1.56229 m
.45068 1.5026 L
.48061 1.39744 L
.45651 1.48216 L
.47508 1.56229 L
F
.45651 1.48216 m
.48061 1.39744 L
.536 1.30633 L
.46739 1.40557 L
.45651 1.48216 L
F
.46739 1.40557 m
.536 1.30633 L
.56963 1.22898 L
.48796 1.33618 L
.46739 1.40557 L
F
.48796 1.33618 m
.56963 1.22898 L
.55799 1.16299 L
.5017 1.27555 L
.48796 1.33618 L
F
.5017 1.27555 m
.55799 1.16299 L
.51258 1.1061 L
.50283 1.22402 L
.5017 1.27555 L
F
.50283 1.22402 m
.51258 1.1061 L
.46399 1.05726 L
.49545 1.18146 L
.50283 1.22402 L
F
.49545 1.18146 m
.46399 1.05726 L
.43762 1.0168 L
.48777 1.14749 L
.49545 1.18146 L
F
.48777 1.14749 m
.43762 1.0168 L
.44072 .98578 L
.48672 1.12147 L
.48777 1.14749 L
F
.48672 1.12147 m
.44072 .98578 L
.46607 .96509 L
.49598 1.10215 L
.48672 1.12147 L
F
.49598 1.10215 m
.46607 .96509 L
.50343 .95414 L
.51668 1.08738 L
.49598 1.10215 L
F
.51668 1.08738 m
.50343 .95414 L
.54749 .94999 L
.54852 1.07396 L
.51668 1.08738 L
F
.54852 1.07396 m
.54749 .94999 L
.59753 .94704 L
.58978 1.05794 L
.54852 1.07396 L
F
.58978 1.05794 m
.59753 .94704 L
.65275 .9381 L
.63648 1.03541 L
.58978 1.05794 L
F
.63648 1.03541 m
.65275 .9381 L
.70912 .91664 L
.68209 1.00365 L
.63648 1.03541 L
F
.68209 1.00365 m
.70912 .91664 L
.75968 .87962 L
.71824 .96235 L
.68209 1.00365 L
F
.71824 .96235 m
.75968 .87962 L
.79619 .82966 L
.7364 .91425 L
.71824 .96235 L
F
.7364 .91425 m
.79619 .82966 L
.81016 .77522 L
.72989 .86498 L
.7364 .91425 L
F
.72989 .86498 m
.81016 .77522 L
.79415 .72846 L
.69615 .82185 L
.72989 .86498 L
F
.69615 .82185 m
.79415 .72846 L
.74541 .7014 L
.6387 .79208 L
.69615 .82185 L
F
.6387 .79208 m
.74541 .7014 L
.67122 .70213 L
.56792 .78097 L
.6387 .79208 L
F
.56792 .78097 m
.67122 .70213 L
.59083 .7326 L
.49933 .79076 L
.56792 .78097 L
F
.49933 .79076 m
.59083 .7326 L
.52871 .78889 L
.44857 .82041 L
.49933 .79076 L
F
.44857 .82041 m
.52871 .78889 L
.50004 .86336 L
.42506 .86632 L
.44857 .82041 L
F
.42506 .86632 m
.50004 .86336 L
.49943 .94748 L
.42788 .92352 L
.42506 .86632 L
F
.42788 .92352 m
.49943 .94748 L
.50435 1.03415 L
.44706 .98685 L
.42788 .92352 L
F
.44706 .98685 m
.50435 1.03415 L
.49318 1.11876 L
.46979 1.05177 L
.44706 .98685 L
F
.46979 1.05177 m
.49318 1.11876 L
.46264 1.19893 L
.48722 1.1147 L
.46979 1.05177 L
F
.48722 1.1147 m
.46264 1.19893 L
.42902 1.27362 L
.49734 1.17285 L
.48722 1.1147 L
F
.49734 1.17285 m
.42902 1.27362 L
.41252 1.34194 L
.50283 1.22402 L
.49734 1.17285 L
F
.50283 1.22402 m
.41252 1.34194 L
.41976 1.40221 L
.50691 1.26622 L
.50283 1.22402 L
F
.50691 1.26622 m
.41976 1.40221 L
.43973 1.45138 L
.51103 1.29771 L
.50691 1.26622 L
F
.51103 1.29771 m
.43973 1.45138 L
.45513 1.48521 L
.51584 1.31727 L
.51103 1.29771 L
F
.51584 1.31727 m
.45513 1.48521 L
.4572 1.4994 L
.52322 1.32492 L
.51584 1.31727 L
F
.52322 1.32492 m
.4572 1.4994 L
.45046 1.49186 L
.53674 1.32289 L
.52322 1.32492 L
F
.53674 1.32289 m
.45046 1.49186 L
.44438 1.46569 L
.55965 1.31634 L
.53674 1.32289 L
F
.55965 1.31634 m
.44438 1.46569 L
.44223 1.43156 L
.59247 1.31339 L
.55965 1.31634 L
F
.59247 1.31339 m
.44223 1.43156 L
.43926 1.4073 L
.63279 1.32375 L
.59247 1.31339 L
F
.63279 1.32375 m
.43926 1.4073 L
.43207 1.41316 L
.67737 1.35594 L
.63279 1.32375 L
F
.67737 1.35594 m
.43207 1.41316 L
.42851 1.46307 L
.72413 1.41368 L
.67737 1.35594 L
F
.72413 1.41368 m
.42851 1.46307 L
.44652 1.55601 L
.7714 1.49322 L
.72413 1.41368 L
F
.7714 1.49322 m
.44652 1.55601 L
.5 1.67282 L
.81452 1.58306 L
.7714 1.49322 L
F
.5 1.67282 m
.16433 1.76258 L
.27573 1.89823 L
.58201 1.78195 L
.5 1.67282 L
F
.58201 1.78195 m
.27573 1.89823 L
.44218 1.97063 L
.65978 1.85199 L
.58201 1.78195 L
F
.65978 1.85199 m
.44218 1.97063 L
.57406 1.95305 L
.69067 1.86416 L
.65978 1.85199 L
F
.69067 1.86416 m
.57406 1.95305 L
.59817 1.85548 L
.6524 1.81808 L
.69067 1.86416 L
F
.6524 1.81808 m
.59817 1.85548 L
.52394 1.71269 L
.56492 1.72859 L
.6524 1.81808 L
F
.56492 1.72859 m
.52394 1.71269 L
.44399 1.56294 L
.48146 1.61704 L
.56492 1.72859 L
F
.48146 1.61704 m
.44399 1.56294 L
.45111 1.43178 L
.45068 1.5026 L
.48146 1.61704 L
F
.45068 1.5026 m
.45111 1.43178 L
.5492 1.32761 L
.48061 1.39744 L
.45068 1.5026 L
F
.48061 1.39744 m
.5492 1.32761 L
.65162 1.24639 L
.536 1.30633 L
.48061 1.39744 L
F
.536 1.30633 m
.65162 1.24639 L
.6658 1.17913 L
.56963 1.22898 L
.536 1.30633 L
F
.56963 1.22898 m
.6658 1.17913 L
.57359 1.11765 L
.55799 1.16299 L
.56963 1.22898 L
F
.55799 1.16299 m
.57359 1.11765 L
.43607 1.05726 L
.51258 1.1061 L
.55799 1.16299 L
F
.51258 1.1061 m
.43607 1.05726 L
.33546 .99713 L
.46399 1.05726 L
.51258 1.1061 L
F
.46399 1.05726 m
.33546 .99713 L
.31545 .93968 L
.43762 1.0168 L
.46399 1.05726 L
F
.43762 1.0168 m
.31545 .93968 L
.36385 .88935 L
.44072 .98578 L
.43762 1.0168 L
F
.44072 .98578 m
.36385 .88935 L
.43787 .85119 L
.46607 .96509 L
.44072 .98578 L
F
.46607 .96509 m
.43787 .85119 L
.50145 .82876 L
.50343 .95414 L
.46607 .96509 L
F
.50343 .95414 m
.50145 .82876 L
.54406 .82192 L
.54749 .94999 L
.50343 .95414 L
F
.54749 .94999 m
.54406 .82192 L
.5737 .82524 L
.59753 .94704 L
.54749 .94999 L
F
.59753 .94704 m
.5737 .82524 L
.60013 .8284 L
.65275 .9381 L
.59753 .94704 L
F
.65275 .9381 m
.60013 .8284 L
.62688 .81954 L
.70912 .91664 L
.65275 .9381 L
F
.70912 .91664 m
.62688 .81954 L
.6541 .79059 L
.75968 .87962 L
.70912 .91664 L
F
.75968 .87962 m
.6541 .79059 L
.6821 .74226 L
.79619 .82966 L
.75968 .87962 L
F
.79619 .82966 m
.6821 .74226 L
.70874 .68546 L
.81016 .77522 L
.79619 .82966 L
F
.81016 .77522 m
.70874 .68546 L
.72457 .63787 L
.79415 .72846 L
.81016 .77522 L
F
.79415 .72846 m
.72457 .63787 L
.71501 .61703 L
.74541 .7014 L
.79415 .72846 L
F
.74541 .7014 m
.71501 .61703 L
.67311 .63338 L
.67122 .70213 L
.74541 .7014 L
F
.67122 .70213 m
.67311 .63338 L
.61316 .68683 L
.59083 .7326 L
.67122 .70213 L
F
.59083 .7326 m
.61316 .68683 L
.5673 .76827 L
.52871 .78889 L
.59083 .7326 L
F
.52871 .78889 m
.5673 .76827 L
.55837 .86448 L
.50004 .86336 L
.52871 .78889 L
F
.50004 .86336 m
.55837 .86448 L
.57194 .96357 L
.49943 .94748 L
.50004 .86336 L
F
.49943 .94748 m
.57194 .96357 L
.56213 1.05829 L
.50435 1.03415 L
.49943 .94748 L
F
.50435 1.03415 m
.56213 1.05829 L
.49515 1.14649 L
.49318 1.11876 L
.50435 1.03415 L
F
.49318 1.11876 m
.49515 1.14649 L
.38863 1.22959 L
.46264 1.19893 L
.49318 1.11876 L
F
.46264 1.19893 m
.38863 1.22959 L
.30362 1.31032 L
.42902 1.27362 L
.46264 1.19893 L
F
.42902 1.27362 m
.30362 1.31032 L
.29456 1.39078 L
.41252 1.34194 L
.42902 1.27362 L
F
.41252 1.34194 m
.29456 1.39078 L
.36466 1.47098 L
.41976 1.40221 L
.41252 1.34194 L
F
.41976 1.40221 m
.36466 1.47098 L
.46519 1.54769 L
.43973 1.45138 L
.41976 1.40221 L
F
.43973 1.45138 m
.46519 1.54769 L
.53585 1.61385 L
.45513 1.48521 L
.43973 1.45138 L
F
.45513 1.48521 m
.53585 1.61385 L
.5492 1.65898 L
.4572 1.4994 L
.45513 1.48521 L
F
.4572 1.4994 m
.5492 1.65898 L
.52178 1.67196 L
.45046 1.49186 L
.4572 1.4994 L
F
.45046 1.49186 m
.52178 1.67196 L
.48563 1.64674 L
.44438 1.46569 L
.45046 1.49186 L
F
.44438 1.46569 m
.48563 1.64674 L
.45157 1.58989 L
.44223 1.43156 L
.44438 1.46569 L
F
.44223 1.43156 m
.45157 1.58989 L
.40245 1.52537 L
.43926 1.4073 L
.44223 1.43156 L
F
.43926 1.4073 m
.40245 1.52537 L
.3212 1.49011 L
.43207 1.41316 L
.43926 1.4073 L
F
.43207 1.41316 m
.3212 1.49011 L
.22183 1.51783 L
.42851 1.46307 L
.43207 1.41316 L
F
.42851 1.46307 m
.22183 1.51783 L
.15202 1.61771 L
.44652 1.55601 L
.42851 1.46307 L
F
.44652 1.55601 m
.15202 1.61771 L
.16433 1.76258 L
.5 1.67282 L
.44652 1.55601 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.16433 1.76258 m
.27573 1.89823 L
.44218 1.97063 L
.57406 1.95305 L
.59817 1.85548 L
.52394 1.71269 L
.44399 1.56294 L
.45111 1.43178 L
.5492 1.32761 L
.65162 1.24639 L
.6658 1.17913 L
.57359 1.11765 L
.43607 1.05726 L
.33546 .99713 L
.31545 .93968 L
.36385 .88935 L
.43787 .85119 L
.50145 .82876 L
.54406 .82192 L
.5737 .82524 L
.60013 .8284 L
.62688 .81954 L
.6541 .79059 L
.6821 .74226 L
.70874 .68546 L
.72457 .63787 L
.71501 .61703 L
.67311 .63338 L
.61316 .68683 L
.5673 .76827 L
.55837 .86448 L
.57194 .96357 L
.56213 1.05829 L
.49515 1.14649 L
.38863 1.22959 L
.30362 1.31032 L
.29456 1.39078 L
.36466 1.47098 L
.46519 1.54769 L
.53585 1.61385 L
.5492 1.65898 L
.52178 1.67196 L
.48563 1.64674 L
.45157 1.58989 L
.40245 1.52537 L
.3212 1.49011 L
.22183 1.51783 L
.15202 1.61771 L
.16433 1.76258 L
s
.97619 .05714 m
.97619 .05714 L
.97619 2.34286 L
.97619 2.34286 L
.97619 .05714 L
s
.97619 .05714 m
.02381 .05714 L
.02381 2.34286 L
.97619 2.34286 L
.97619 .05714 L
s
.02381 .05714 m
.02381 .05714 L
.02381 2.34286 L
.02381 2.34286 L
.02381 .05714 L
s
.02381 .05714 m
.97619 .05714 L
.97619 2.34286 L
.02381 2.34286 L
.02381 .05714 L
s
.97619 .05714 m
.97619 .05714 L
.02381 .05714 L
.02381 .05714 L
.97619 .05714 L
s
.97619 2.34286 m
.97619 2.34286 L
.02381 2.34286 L
.02381 2.34286 L
.97619 2.34286 L
s
.039 .916 .04 r
.11905 1.77143 m
.79997 1.77143 L
s
0 0 0 r
5 Mabswid
.79997 1.77143 Mdot
.039 .916 .04 r
.5 Mabswid
.11905 1.77143 m
.80048 1.77143 L
s
0 0 0 r
5 Mabswid
.80048 1.77143 Mdot
.039 .916 .04 r
.5 Mabswid
.11905 1.77143 m
.76211 1.77143 L
s
0 0 0 r
5 Mabswid
.76211 1.77143 Mdot
.039 .916 .04 r
.5 Mabswid
.79997 1.77143 m
.8663 1.40977 L
s
0 0 0 r
5 Mabswid
.8663 1.40977 Mdot
.039 .916 .04 r
.5 Mabswid
.80048 1.77143 m
.76866 1.28409 L
s
0 0 0 r
5 Mabswid
.76866 1.28409 Mdot
.039 .916 .04 r
.5 Mabswid
.76211 1.77143 m
.78537 1.23628 L
s
0 0 0 r
5 Mabswid
.78537 1.23628 Mdot
.039 .916 .04 r
.5 Mabswid
.8663 1.40977 m
.16563 1.16498 L
s
0 0 0 r
5 Mabswid
.16563 1.16498 Mdot
.039 .916 .04 r
.5 Mabswid
.76866 1.28409 m
.46454 1.43953 L
s
0 0 0 r
5 Mabswid
.46454 1.43953 Mdot
.039 .916 .04 r
.5 Mabswid
.78537 1.23628 m
.444 1.34791 L
s
0 0 0 r
5 Mabswid
.444 1.34791 Mdot
.039 .916 .04 r
.5 Mabswid
.16563 1.16498 m
.49186 1.1523 L
s
0 0 0 r
5 Mabswid
.49186 1.1523 Mdot
.039 .916 .04 r
.5 Mabswid
.46454 1.43953 m
.47864 .82901 L
s
0 0 0 r
5 Mabswid
.47864 .82901 Mdot
.039 .916 .04 r
.5 Mabswid
.444 1.34791 m
.27416 1.32953 L
s
0 0 0 r
5 Mabswid
.27416 1.32953 Mdot
.039 .916 .04 r
.5 Mabswid
.49186 1.1523 m
.15014 1.23981 L
s
0 0 0 r
5 Mabswid
.15014 1.23981 Mdot
.039 .916 .04 r
.5 Mabswid
.47864 .82901 m
.63884 1.03749 L
s
0 0 0 r
5 Mabswid
.63884 1.03749 Mdot
.039 .916 .04 r
.5 Mabswid
.27416 1.32953 m
.23782 .94536 L
s
0 0 0 r
5 Mabswid
.23782 .94536 Mdot
.039 .916 .04 r
.5 Mabswid
.15014 1.23981 m
.5207 1.10132 L
s
0 0 0 r
5 Mabswid
.5207 1.10132 Mdot
.039 .916 .04 r
.5 Mabswid
.63884 1.03749 m
.48646 .81913 L
s
0 0 0 r
5 Mabswid
.48646 .81913 Mdot
.039 .916 .04 r
.5 Mabswid
.23782 .94536 m
.72647 .9627 L
s
0 0 0 r
5 Mabswid
.72647 .9627 Mdot
.039 .916 .04 r
.5 Mabswid
.5207 1.10132 m
.53823 1.51236 L
s
0 0 0 r
5 Mabswid
.53823 1.51236 Mdot
.039 .916 .04 r
.5 Mabswid
.48646 .81913 m
.59674 .97018 L
s
0 0 0 r
5 Mabswid
.59674 .97018 Mdot
.039 .916 .04 r
.5 Mabswid
.72647 .9627 m
.69767 .70071 L
s
0 0 0 r
5 Mabswid
.69767 .70071 Mdot
.039 .916 .04 r
.5 Mabswid
.53823 1.51236 m
.77772 1.32013 L
s
0 0 0 r
5 Mabswid
.77772 1.32013 Mdot
.039 .916 .04 r
.5 Mabswid
.59674 .97018 m
.46707 .99093 L
s
0 0 0 r
5 Mabswid
.46707 .99093 Mdot
.039 .916 .04 r
.5 Mabswid
.69767 .70071 m
.4945 .95209 L
s
0 0 0 r
5 Mabswid
.4945 .95209 Mdot
.039 .916 .04 r
.5 Mabswid
.77772 1.32013 m
.67096 1.88033 L
s
0 0 0 r
5 Mabswid
.67096 1.88033 Mdot
.039 .916 .04 r
.5 Mabswid
.46707 .99093 m
.13959 1.10496 L
s
0 0 0 r
5 Mabswid
.13959 1.10496 Mdot
.039 .916 .04 r
.5 Mabswid
.67096 1.88033 m
.02381 1.79488 L
s
0 0 0 r
5 Mabswid
.02381 1.79488 Mdot
.039 .916 .04 r
.5 Mabswid
.13959 1.10496 m
.40074 1.40185 L
s
0 0 0 r
5 Mabswid
.40074 1.40185 Mdot
.039 .916 .04 r
.5 Mabswid
.40074 1.40185 m
.79101 1.57066 L
s
0 0 0 r
5 Mabswid
.79101 1.57066 Mdot
.039 .916 .04 r
.5 Mabswid
.79101 1.57066 m
.75512 1.29646 L
s
0 0 0 r
5 Mabswid
.75512 1.29646 Mdot
.039 .916 .04 r
.5 Mabswid
.75512 1.29646 m
.0876 2.34286 L
s
0 0 0 r
5 Mabswid
.0876 2.34286 Mdot
0 0 m
1 0 L
1 2.4 L
0 2.4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{120, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001h000180P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000007Qd001hM000N7@007Qd001hM000N7@007Qd
001hM0000WAc4@=d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd06md00<AM7@00G@0009d00<AM7@0Kg@00a5dM001M0000W@00a5d
M01_M0034GAd005d0002M0034GAd04md0Q4NM0034GAd005d0002M0034GAd04ed0Q400d8AM00MM003
4GAd005d0002M0034GAd04]d0Q401D=2@d8A01ed00<AM7@00G@0009d00<AM7@0BG@24@07@T=2@d93
4@0MM0034GAd005d0002M0034GAd04Qd00/A@d93@T=2@a53@P0LM0034GAd005d0002M0034GAd04Md
00dA@d93@T=2@d8A@T=201]d00<AM7@00G@0009d00<AM7@0AG@24@0=@d93@T=2@d934D=2@`0KM003
4GAd005d0002M0034GAd04Ad014A@T=2@d93@T=2@a53@T=2@`0JM0034GAd005d0002M0034GAd04=d
00XA@T=2@d93@T=211401D=2@d9301Ud00<AM7@00G@0009d00<AM7@0@g@02Q53@T=2@d93@T<44@06
@T=2@d9367@00a5dM001M0000W@00a5dM012M00=4D=2@d93@T=2@d8A8@024@06@d93@T=267@00a5d
M001M0000W@00a5dM012M00<4D93@T=2@d93@T<M0a401d93@T=2@d805g@00a5dM001M0000W@00a5d
M011M00H4D93@T=2@d93@T<Q4B53@T=2@d93@T=25W@00a5dM001M0000W@00a5dM011M00H4D=2@d93
@T=2@ae34B52@d93@T=2@d935W@00a5dM001M0000W@00a5dM010M00J4D=2@d93@T=2@d8Q4D<Q@d93
@T=2@d93@T<EM0034GAd005d0002M0034GAd03id01a3@Q52@d93@T=2@d8Q@Q528D93@T=2@d93@T=2
5G@00a5dM001M0000W@00a5dM00mM00N@d8A@T=2@d93@T=28D8A@T=28D93@T=2@d93@T=257@00a5d
M001M0000W@00a5dM00kM00P@T=2@a53@T=2@d93@R524D93@T<M@d93@T=2@d93@T<DM0034GAd005d
0002M0034GAd03Yd0252@d934D=2@d93@T=28D934D=2@d8Q@T=2@d93@T=2@d8057@00a5dM001M000
0W@00a5dM00hM00S@d93@T=24D93@T=2@d8Q@T<A@d93@T<M@d93@T=2@d93@T<057@00a5dM001M000
0W@00a5dM00fM00U@T=2@d93@T<A@d93@T=28D934D=2@d93@R52@d93@T=2@d93@P0DM0034GAd005d
0002M0034GAd03Ad02M3@T=2@d93@T=24D93@T=2@ae34D=2@d93@T<M@d93@T=2@d93@T<057@00a5d
M001M0000W@00a5dM00bM003@Q4A008A02=3@T=2@d934D=2@d938D=24D93@T=2@d8Q@T=2@d93@T=2
@`0EM0034GAd005d0002M0034GAd031d00=3@Q4011408d93@T=2@d8A@T=2@ae3@Q52@d93@T=2@ae3
@T=2@d93@T=201Ed00<AM7@00G@0009d00<AM7@0;W@01493@T<24@058A4A@d8021400d<Q@`024@0D
@T=2@d93@T=28D93@T=2@d93@T<EM0034GAd005d0002M0034GAd02ad00I3@T=2@d834@0=7A4A4D93
@T<A@d937@024@0E@d93@T=2@d93@T<M@d93@T=2@d9301Id00<AM7@00G@0009d00<AM7@0:W@01d93
@T=2@d800a438@0R@d93@T=24D938D=2@d93@T=2@d93@T=2@b53@T=2@d93@QId00<AM7@00G@0009d
00<AM7@0:7@01d=2@d93@T<00Q409d937D<M8D93@T=2@a537D=2@d93@T=2@d93@T=2@d8Q@T=2@d93
@P0GM0034GAd005d0002M0034GAd02Id00M2@d93@T=2008A02Q3@T=28D8Q@R52@d93@Q4Q@d93@T=2
@d93@T=2@d93@T<Q@d93@T=267@00a5dM001M0000W@00a5dM00TM007@d93@T=2@`024@0Z@T=2@d93
7D=28D8Q@T=2@a4Q@T=2@d93@T=2@d93@T=2@d8Q@T=2@d9367@00a5dM001M0000W@00a5dM00RM007
@T=2@d93@P024@0<@d93@T=2@d8Q@T=20b407493@R52@d93@T=2@d93@T=2@d93@T<Q@d93@T<IM003
4GAd005d0002M0034GAd025d00I2@d93@T<24@0/@T=2@d93@T=2@ae3@T=28Ae3@R4A@d93@T=2@d93
@T=2@d93@T=28D93@T<JM0034GAd005d0002M0034GAd021d01U2@d93@T<A@d93@T=2@d93@T=28D93
@T=200<Q01U24D93@T=2@d93@T=2@d93@T=2@b53@T=201Yd00<AM7@00G@0009d00<AM7@07W@0=T=2
@d93@T<A@d93@T=2@d93@T=2@ae3@T=2@adQ7D=24D93@T=2@d93@T=2@d93@T=28D93@Q]d00<AM7@0
0G@0009d00<AM7@07G@074=2@d93@T<A@d93@T=2@d93@T=2@d8Q@T=2@d848@0G@a53@T=2@d93@T=2
@d93@T=2@b53@T<06g@00a5dM001M0000W@00a5dM00LM00g@d93@T=2@a53@T=2@d93@T=2@d93@T<M
@d93@R52@adQ7A52@d93@T=2@d93@T=2@d93@R52@`0LM0034GAd005d0002M0034GAd01Yd0292@d93
@T=2@a53@T=2@d93@T=2@d93@T=28D93@T<Q@d930R405A53@T=2@d93@T=2@d93@T=2@d8Q@P0LM003
4GAd005d0002M0034GAd01Id11406T=2@d93@T<A@d93@T=2@d93@T=2@d93@T<M11406T=2@d937B52
@d93@T=2@d93@T=2@d93@T<M7G@00a5dM001M0000W@00a5dM00FM0@A01Y2@d93@T<A@d93@T=2@d93
@T=2@d93@T=28@@A00E2@d93@P038@0B@T=2@d93@T=2@d93@T=2@d8Q7G@00a5dM001M0000W@00a5d
M00FM00N4AdQ7B4M8AdQ7B4M8AdQ7D=2@d93@T=2@d93@T<M11406T=2@d93@R4M8D93@T=2@d93@T=2
@d93@Q4M0Q4KM0034GAd005d0002M0034GAd01Ed00=34A400Q403493@T=2@d8A@T=2@`hQ11498@@A
00e3@T=2@d93@T=2@a4Q008A6g@00a5dM001M0000W@00a5dM00CM00^@T=2@ae3@T=2@d93@T<A@d93
@T=2@d93@T=2@d93@T<M@d93@T=2@d93@T<A8@@A00dM8AdQ7B4M8AdQ7A4M008A6g@00a5dM001M000
0W@00a5dM00CM00N@d93@R52@d93@T=2@d8A@T=2@d93@T=2@d93@T=211402D=2@d93@T=2@`058@8A
00]3@T=2@d93@T=2@`044A]d00<AM7@00G@0009d00<AM7@04g@07T93@T<M@d93@T=2@d934D=2@d93
@T=2@d93@T=2@`@A00a28AdQ7B4M8Ae34D<44@0:@T=2@d93@T=2@b1d00<AM7@00G@0009d00<AM7@0
4W@07d93@T=28D93@T=2@d93@T<A@d93@T=2@d93@T=2@d800R424@0=8D93@T=2@d934D=2@`028@0:
@T=2@d93@T=2@b5d00<AM7@00G@0009d00<AM7@04W@07d=2@d93@R52@d93@T=2@d8A@T=2@d93@T=2
@d8Q7B4011406493@T=2@d93@Q52@d937D=2@d93@T=2@b9d00<AM7@00G@0009d00<AM7@04G@04T=2
@d93@T<Q@d93@T=2@d93@P8A00M3@T=2@d93008Q01i2@d93@R52@d93@T=2@d934D=2@d938D=2@d93
@T<SM0034GAd005d0002M0034GAd015d01A2@d93@T=28D93@T=2@d93@T=2@`8A02=2@adQ7D=2@d93
@T<M@d93@T=2@d93@Q52@d93@T<M@d93@P0UM0034GAd005d0002M0034GAd011d01I2@d93@T=2@b53
@T=2@d93@T=2@d930b4074=2@d93@T=2@d8Q@T=2@d93@T=2@a53@T=2@d828@<A9G@00a5dM001M000
0W@00a5dM00@M00H@d93@T=2@d8Q@T=2@d93@T=2@adQ7D=20Q407D=2@d93@T=2@ae3@T=2@d93@T=2
4D93@T=2@d8Q00<A9G@00a5dM001M0000W@00a5dM00?M00A@d93@T=2@d938D=2@d93@T<00b401d=2
@d93@T<00Q407493@T=2@d8Q@T=2@d93@T=24D93@T=2@d9d4B424BEd00<AM7@00G@0009d00<AM7@0
3g@07D93@T=2@d93@R52@d93@R4M@d93@T=2@d93@T=2008A01E3@T=2@ae3@T=2@d93@T<A@d93@T<0
0g@44BEd00<AM7@00G@0009d00<AM7@03W@03D93@T=2@d93@T<Q@d800b404493@T=2@d93@T=2@d93
@T<24@0A@T=28D93@T=2@d93@Q52@d80;W@00a5dM001M0000W@00a5dM00>M00R@d93@T=2@d93@R4M
8D93@T=2@d93@T=2@d93@T=2@d93@P8A00i37D=2@d93@T=24D93@Rmd00<AM7@00G@0009d00<AM7@0
3G@024=2@d93@T=212409T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A8A53@T=2@d934D=2<7@00a5d
M001M0000W@00a5dM00=M00X@T=2@d8Q7B52@d8Q@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<M@`LA
00=3M7@0<7@00a5dM001M0000W@00a5dM00:M0@A02U2@b4Q@T=2@d93@R52@d93@T=2@d93@T=2@d93
@T=2@d93@T=28D93@P044@03@gAd035d00<AM7@00G@0009d00<AM7@02W@44@0[8Ae3@T=2@d93@T<M
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@ae3@T<A8@034C=d00<AM7@00G@0009d00<AM7@02W@0:a4Q
4A52@d93@T=2@d93@R52@d93@T=2@d93@T=2@d93@T=2@d93@T=28D800R401A4Q4A53008A<G@00a5d
M001M0000W@00a5dM00:M08A038Q4D=2@d93@T=2@d937D=2@d93@T=2@d93@T=2@d93@T=2@d93@R4M
8D93@R52@d93@P8A;g@00a5dM001M0000W@00a5dM00:M00U@T=28D93@T=2@d93@T=28D93@T=2@d93
@T=2@d93@T=2@d93@P038@0>@R52@d8A8D=2@d93@T<24Bed00<AM7@00G@0009d00<AM7@02W@0:T=2
@d8Q@T=2@d93@T=2@ae3@T=2@d93@T=2@d93@T=2@d937B52@d937@@A00/Q@T=2@d93@T=24@0/M003
4GAd005d0002M0034GAd00Yd0212@d93@R52@d93@T=2@d8Q@T=2@d93@T=2@d93@T=2@`<Q00M3@T=2
@b5300@A00`Q@d93@T=2@d93@Q4[M0034GAd005d0002M0034GAd00Yd00=3@T<00Q409adA@T=2@d93
@T<M@d93@T=2@d93@T=2@d8Q7D=28AdQ7B4M8AdQ7@024@0<8D93@T=2@d93@T=20Q4YM0034GAd005d
0002M0034GAd00Yd00=2@d800a402253@T=2@d9352401493@T<48@@A00lQ@d93@T=2@d93@T=2@a40
:7@00a5dM001M0000W@00a5dM00:M00o@d934B4M8AdQ7B4M8Ae37D=2@d93@T=28AdQ@T=2@d93@R4M
8Ae3@R4A@d93@R52@d93@T=2@d93@T=2@a5302Id00<AM7@00G@0009d00<AM7@02g@00d=24@034@8Q
00e3@T=2@d8Q@T=2@d93008Q00I2@d93@T<48@0L@T=2@d8A8D=2@d93@R52@d93@T=2@d93@T=2@`8A
00=2M7@08W@00a5dM001M0000W@00a5dM00;M011@T=2@d93@T<M8Ae3@T<M@d937B4M@d93@T<M8Ae3
@T=2@d93@Q528D93@T=2@ae3@T=2@d93@T=2@d93@T=24D808g@00a5dM001M0000W@00a5dM00;M00;
@d93@T=2@d938D<00b4024<Q8B53@T=21240:D=2@d93@T=2@d8A@T<Q@d93@T=28D93@T=2@d93@T=2
@d93@T<A@d93025d00<AM7@00G@0009d00<AM7@02g@0A493@T=2@d93@T<M@d8Q7B4M@adQ7B52@d93
@T=2@d93@T=24D93@R52@d93@T<M@d93@T=2@d93@T=2@d93@Q52@d9387@00a5dM001M0000W@00a5d
M00;M00;@d93@T=2@d93@T<00R400d938@038@0>@T=2@d93@T=2@d93@T<24@0R@T=2@b53@T=2@d8Q
@T=2@d93@T=2@d93@T=24D93@T=2@amd00<AM7@00G@0009d00<AM7@037@0AD=2@d93@T<M8AdQ7B4M
8D93@R4M8D93@T=2@d93@T<A@d93@T=28D93@T=2@ae3@T=2@d93@T=2@d93@T<A@d93@T=2@`06M0@A
57@00a5dM001M0000W@00a5dM00;M0@A00=38B4012402d8Q@T<Q@d93@T=200<Q02i2@d93@T<A@d93
@T=2@b53@T=2@d8Q@T=2@d93@T=2@d93@T=24D93@T=2@d931G@44AAd00<AM7@00G@0009d00<AM7@0
2g@34@158AdQ7D=2@d93@R528D93@T=2@d93@R4M8D934D=2@d93@T=28D93@T=2@ae3@T=2@d93@T=2
@d93@T<A@d93@T=2@d9300Ad00@M8A4A57@00a5dM001M0000W@00a5dM00;M00>4B4Q4D=2@d93@T=2
@d828@0<@d93@T=2@d93@T=20b40:T93@T=2@d938D=2@d93@R52@d93@T=2@d93@T=2@a53@T=2@d93
@T=2@`<Q114DM0034GAd005d0002M0034GAd00]d1140Ad93@T=2@d93@T=28D93@T=2@d93@T=2@a53
@R4M8D93@T=28D93@T=2@ae3@T=2@d93@T=2@d93@Q52@d93@T=2@adQ7D=2009d00<QM7@057@00a5d
M001M0000W@00a5dM00=M00=@d93@T=2@d93@T=2@`028@0A@T=2@d93@T=2@a53@T=2@d800b405T93
8D=2@d93@R52@d93@T=2@d93@T<24@06@T=2@d930b4024=2@d93@W@Q5W@00a5dM001M0000W@00a5d
M00>M00F@d93@T=2@d93@T=28D8Q@T=2@d93@P8A02m3@T=2@d93@T=28AdQ@T=2@d937D=2@d93@T=2
@d934D=2@d937B4M@d93@T=2@`034@038GAd01Ad00<AM7@00G@0009d00<AM7@03W@09493@T=2@d93
@T=2@b53@R52@d93@Q52@d93@T=2@d93@T=2@`@Q0192@d8Q@T=2@d93@T=2@a53@T<38@08@d93@T=2
@d854@038D=d01Ad00<AM7@00G@0009d00<AM7@03W@0=4=2@d93@T=2@d93@T<M@d8Q@T=24D93@T=2
@d93@T=2@d93@R52@d8Q7D<M@d93@T=2@d824@0?@adQ7D=2@d93@T=2@d9300DA00<Q@T<057@00a5d
M001M0000W@00a5dM00?M00Y@d93@T=2@d93@T=28D938D=24D93@T=2@d93@T=2@d93@T<Q@d93@T<0
0b4024=2@d93@Q520R4044=2@d93@T=2@d93@T=24B434@048D=2@a=d00<AM7@00G@0009d00<AM7@0
47@0A4=2@d93@T=2@d937D=2@adA@T=2@d93@T=2@d93@T=2@d8Q@T=2@d937D<M8Ae3@R4M8D93@T=2
@d93@T=2@d93@R4M1Q400d=2@`0BM0034GAd005d0002M0034GAd015d00]3@T=2@d93@T<A8@024@0O
@Q4Q@d93@T=2@d93@T=2@d93@T<Q@d93@T=2@b53@P048@0?@d93@T=2@d93@T=2@d93008Q00A28B53
11401493@T<AM0034GAd005d0002M0034GAd019d00Y3@T=2@d93@Q4M0Q40>T<A@ae3@T=2@d93@T=2
@d93@T=28D93@T=2@d8Q7B4A@d937B4M@d93@T=2@d93@R4M@d8Q@R524Ad24@05@d93@T<047@00a5d
M001M0000W@00a5dM00CM009@d93@T=2@a4Q008A01TQ4D938D=2@d93@T=2@d93@T=2@b53@T=200@Q
00U34D=2@d93@T<00b401D=2@d93008Q00Y2@d8Q@T=28A4Q0Q401T93@T=2@`md00<AM7@00G@0009d
00<AM7@057@01T=2@d93@P@A01137B4M8AdQ@T=2@d93@T=21140;b528AdQ@T=28A53@T=2@d93@T=2
@adQ7B4M@d93@T<M@d8Q7B4M@d93@T=2@d9300id00<AM7@00G@0009d00<AM7@057@04493@T=2@d93
@T=24D93@T<88@03@T<A00<A0R405493@T=2@b53@T=2@d93@T=2@d931B4024=2@b53@R520b402T93
@T=2@d93@T<=M0034GAd005d0002M0034GAd01Id01Y3@T=2@d93@T<A@d93@T<M@d93@T=28AdQ7@8A
034Q@T=2@d934B52@d93@T=2@d93@R4M@d93@T<M8AdQ@R52@adQ7D=2@d93@T=2@d9300ad00<AM7@0
0G@0009d00<AM7@067@05T93@T=2@a53@T=2@d938D=2@d93@T<44@0B8D=2@d934D<Q@d93@T=2@d93
0R402D93@T=2@d93@P048@03@d8Q008Q00a2@d93@T=2@d93@T<;M0034GAd005d0002M0034GAd01Ud
04]2@d93@Q52@d93@T=28D93@T=2@d93@T=28D93@T<A@d8Q@T=2@d93@T<M@d93@T=2@d93@R528D93
7B4M8Ae3@T=2@d93@T=2@d802g@00a5dM001M0000W@00a5dM00JM00W@T=2@a53@T=2@d93@R52@d93
@T=2@d938D=2@a53@T<Q@d93@T=2008Q00]3@T=2@d93@T=2@`028@05@T=2@d800b403D93@T=2@d93
@T=2@d802W@00a5dM001M0000W@00a5dM00KM00>@T=24D93@T=2@d93@R444@0i@T=2@d8Q@T=24D93
@R52@d937B52@d93@T=2@d93@T<M@d93@T=2@adQ7B4M8D93@T=2@d93@T=200Ud00<AM7@00G@0009d
00<AM7@077@03D934D=2@d93@T=2@d80114044=2@d938D=24D93@T<Q@d828@0F@d93@T=2@d93@T=2
@b53@T=2@d93@P<Q00=2@d800b400d93@P044@03@gAd00Md00<AM7@00G@0009d00<AM7@07G@0A493
4D=2@d93@T=2@a4Q7A52@d93@R524D93@T=28AdQ@T=2@d93@T=2@d93@T<M8D93@T=2@d937B4M@d93
@T=28AdQ11400d93M007M0034GAd005d0002M0034GAd01id00]2@a53@T=2@d93@P034@8Q00]2@d93
8A52@d93@P028@0>@d93@T=2@d93@T=2@d838@09@T=2@d93@T=200<Q00U2@d93@T=2@d800R424@03
@d9d00Md00<AM7@00G@0009d00<AM7@07g@0@T934D=2@d93@T=2@d93@R4M@d8Q@T=2@adQ@R52@d93
@T=2@d93@T=28D937D=2@d93@T=2@adQ7D=2@d93@T=2@`@A00=2@d801g@00a5dM001M0000W@00a5d
M00PM00@@T<A@d93@T=2@d93@T=2@`<Q0Q428@0O@d938D=2@d93@T=2@d93@R52@b53@T=2@d93@T<Q
@`028@0@@T=2@d93@T=2@b53@T=2@`Md00<AM7@00G@0009d00<AM7@08G@03d8A@T=2@d93@T=2@d93
@P024@0g8AdQ@T=2@d8Q@T=2@d93@T=2@d8Q@T<M@d93@T=2@d93@R52@ae3@T=2@d93@T<M@d93@T=2
@`06M0034GAd005d0002M0034GAd029d00i24D93@T=2@d93@T=2@`8A00<Q4A400R40<T=2@d8Q@T=2
@d93@T=28D93@R52@d93@T=2@d938D=28D93@T=2@d93@R52@d93@T=21W@00a5dM001M0000W@00a5d
M00SM00=@Q52@d93@T=2@d93@P054@0d@T<M8Ae37D=2@d93@T<M8D93@R52@d93@T=2@d93@R52@ae3
@T=2@d93@T<M@d93@T=2@`Id00<AM7@00G@0009d00<AM7@097@05T8A@T=2@d93@T=2@a53@T=2@d93
@T<28@0]@T=2@d938D=2@d8Q@T=2@d93@T=2@d938D=28D93@T=2@d93@R52@d93@T=200Id00<AM7@0
0G@0009d00<AM7@09G@0A48A@T=2@d93@T=24D93@T=2@d93@T<M8Ae3@T<M@d93@T<M@d93@T=2@d93
@T=28D937B52@d93@T=2@ae3@T=2@d931W@00a5dM001M0000W@00a5dM00TM00J@T=24D93@T=2@d93
4D=2@d93@T=2@d8Q@T<38@0F@d93@T<Q@d93@T=2@d93@T=28D93@P8Q0113@T=2@d93@R52@d93@T=2
1W@00a5dM001M0000W@00a5dM00SM005@T=2@d800Q40?d=2@d93@Q52@d93@T=2@d937D=2@ae37B52
@ae3@T=2@d93@T=2@d937D=2@adQ@T=2@d93@R52@d93@T=2@`06M0034GAd005d0002M0034GAd01md
11405d=2@d93@T<A@d93@T<A@d93@T=2@d9300<A0R4014=2@d838@0A@T=2@d93@T=2@d93@R52@d80
0R4044=2@d93@T<Q@d93@T=2@d86M0034GAd005d0002M0034GAd01]d11401493@T<24@0E@T=2@d93
4D=2@a53@T=2@d93@T=2008A02dQ4D=2@d93@R528Ae3@T=2@d93@T=2@ae3@T<M8D93@T=2@d8Q@T=2
@d93@T<01W@00a5dM001M0000W@00a5dM00GM0@A00Y3@T=2@d93@T=20Q401D=2@d93008A00i24D93
@T=2@d93@T<A8@8A00Y2@d93@T<Q@d930R407d93@T=2@d93@R52@b538D=2@d93@T<Q@d93@T=2@d80
1W@00a5dM001M0000W@00a5dM00EM08A0112@d93@T=2@d93@T=2@d930Q401D93@T=2008A00Y3@T=2
@d93@T=21140:d=2@d937D=2@d93@R4M8D93@T=28D93@R528D93@T=2@d8Q@T=2@d93@T<01W@00a5d
M001M0000W@00a5dM00DM00E4D=2@d93@T=2@d93@T=2@d93@T=2008A0293@T=24D93@T=2@d93@T=2
@d93@T=2@b53@T=2@d93@T=20R406T=2@b53@T<Q@b53@T=2@d8Q@T=2@d93@T=21W@00a5dM001M000
0W@00a5dM00DM00K4D93@T=2@d93@T=2@d93@T=2@d93@T<A@d9300<A03M3@T=2@d93@T=2@d93@T=2
8D93@T=2@d93@T=2@adQ@R52@d8Q@R52@d93@T<M@d93@T=2@d9300Id00<AM7@00G@0009d00<AM7@0
4g@0?Q52@d93@T=2@d93@T=2@d93@T=2@d93@T<A@d8A@T<A@d93@T=2@d93@T=2@d8Q@T=2@d93@T=2
@d93@T=20b4014938D<28@0?@T=2@d8Q@T=2@d93@T=200Id00<AM7@00G@0009d00<AM7@04W@0B152
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@a534D=2@a53@T=2@d93@T=2@d8Q@T=2@d93@T=2@d93@T=2
@d8Q@R4M8D8A7@8A00a3@T<M@d93@T=2@d87M0034GAd005d0002M0034GAd019d04@A@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d8A@Q52@d934D=2@d93@T=2@d938D=2@d93@T=2@d93@T=2@d8Q@T=2@`8Q
010A8A4A@T=28D93@T=2@d931g@00a5dM001M0000W@00a5dM00AM0194D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d8A@Q52@d934D=2@d93@T=2@ae3@T=2@d93@T=2@d93@T=2@ae3@T=28D8A7@024@0;
@d8Q@T=2@d93@T<027@00a5dM001M0000W@00a5dM00@M00O4D=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@P024@0W@d93@T<A@d93@T=2@d8Q@T=2@d93@T=2@d93@T=2@d8Q@T=2@b5300@A00]2@b53
@T=2@d93@P08M0034GAd005d0002M0034GAd011d020A@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@P8A03A3@T=2@a53@T=2@d8Q@T=2@d93@T=2@d93@T=2@d937D=2@d8Q@R52@d93@R52@d93@T=2
2G@00a5dM001M0000W@00a5dM00?M01F4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q52
@d93@T<A@d93@R52@d93@T=2@d93@T=2@d93@T=28D93@T<Q@d8Q@T=2@b53@T=2@d8:M0034GAd005d
0002M0034GAd00id02<A@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@`024@0b@T=2@d93
4D=2@ae3@T=2@d93@T=2@d93@T=2@d8Q@T=2@d8Q@T<M@d93@R52@d93@T<:M0034GAd005d0002M003
4GAd00id05HA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A@d93@T=2@a538D=2@d93
@T=2@d93@T=2@d93@T<Q@d93@T<Q@d8Q@T=2@b53@T=2@`]d00<AM7@00G@0009d00<AM7@03G@09A53
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d800Q40;d=2@d93@Q4M@d93@T=2@d93@T=2
@d93@T=2@d8Q@T=2@d8Q@T<M@d937D=2@d9300ad00<AM7@00G@0009d00<AM7@03G@0EQ52@d93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=24D93@T=2@d8Q@T=2@d93@T=2@d93@T=2@d93@T<Q
@d93@T<Q@d8Q@T=28D93@T=237@00a5dM001M0000W@00a5dM00=M00V4D=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T<24@0]@T=2@d8Q4D=2@d93@T=2@d93@T=2@d93@T=28D93@T=28D93
7D=2@ae3@T=200ed00<AM7@00G@0009d00<AM7@03G@09a52@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@`024@0/@T=28D8A@T=2@d93@T=2@d93@T=2@d93@R52@d93@T<Q@d8Q@T=28D93
@T<=M0034GAd005d0002M0034GAd00ed02PA@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=2@d930Q40:d937D=24D93@T=2@d93@T=2@d93@T=2@ae3@T=2@d8Q@T<M@d937D=2@d803G@00a5d
M001M0000W@00a5dM00=M00Y4D93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<0
0Q400b53@P024@0U@d93@T=2@d93@T=2@d93@T=28D93@T=2@b53@R52@b53@T=2@`0=M0034GAd005d
0002M0034GAd00ed02`A@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@Q528@8A
02I2@d93@T=2@d93@T=2@d93@T=2@ae3@T=2@d8Q@T<M@d8Q@T=2@`id00<AM7@00G@0009d00<AM7@0
3G@0E152@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@R52@d93@T=2@d93@T=2
@d93@T=2@d93@R52@d93@T<Q@d8Q@T<Q@d93@Pid00<AM7@00G@0009d00<AM7@03G@0E153@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=28A53@T=2@d93@T=2@d93@T=2@d93@T=28D93
@T=2@ae3@T<M@d8Q@T=2@`id00<AM7@00G@0009d00<AM7@03W@0Da53@T=2@d93@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T<Q@a53@T=2@d93@T=2@d93@T=2@d93@T<Q@d93@T=28D93@R52@b53
@T=200id00<AM7@00G@0009d00<AM7@03W@0DQ52@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@ae3@Q52@d93@T=2@d93@T=2@d93@T=2@d8Q@T=2@d937D=2@ae37D=2@d8?M0034GAd005d
0002M0034GAd00id04`A@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@b53@T=24D93
@T=2@d93@T=2@d93@T=2@d938D=2@d93@R52@d930R401493@T<?M0034GAd005d0002M0034GAd00id
058A@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@R52@d93@Q52@d93@T=2@d93@T=2
@d93@T=28D93@T=2@ae3@T=28Ae3@T=23g@00a5dM001M0000W@00a5dM00>M01<4D=2@d93@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@R52@d93@T<A@d93@T=2@d93@T=2@d93@T=28D93@T=2@d8Q
@T=2@`8Q00=2@d8047@00a5dM001M0000W@00a5dM00>M01@4D93@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=2@d93@T=2@ae3@T=2@d934D=2@d93@T=2@d93@T=2@d937D=2@d93@T<M@d93@R4M@d8AM003
4GAd005d0002M0034GAd00id04`A@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T<Q@d93
@T=2@d8A@T=2@d93@T=2@d93@T=2@d8Q@T=2@d93@R52@d930R400d9dM00@M0034GAd005d0002M003
4GAd00id04PA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@ae3@T=2@d93@T=24D93@T=2
@d93@T=2@d93@T<M@d93@T=24Ad24@03@a4Q008A4W@00a5dM001M0000W@00a5dM00>M0184D=2@d93
@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d8Q@T=2@d93@T=2@a53@T=2@d93@T=2@d93@T=28D93
@T=2@a4Q0Q400d8A8@024A9d00<AM7@00G@0009d00<AM7@02G@0CAdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ
7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7A4M008A
00<Q4B400Q4BM0034GAd005d00000g@A4@024A1d04@A@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d93
@T=28D93@T=2@d93@T=2@d8A@T=2@d93@T=2@d93@T<Q@d93@T=2@`@A00=d4A400Q4BM0034GAd005d
00000g@A4@024A1d04HA@T=2@d93@T=2@d93@T=2@d93@T=2@d93@T=2@d937D=2@d93@T=2@d93@T=2
4D93@T=2@d93@T=2@d8Q@T=2@d93@T=26G@00a5dM001M00000=d4A400Q400b5dM00>M0144D93@T=2
@d93@T=2@d93@T=2@d93@T=2@d93@T<Q@d93@T=2@d93@T=2@d934D=2@d93@T=2@d93@T<Q@d93@T=2
@d8JM0034GAd005d00000g@A4@024@09M1dQ7B4M8AdQ00Ud048A@T=2@d93@T=2@d93@T=2@d93@T=2
@d93@T<M@d93@T=2@d93@T=2@d93@T<A@d93@T=2@d93@T=28D93@T=2@d8KM0034GAd005d0002M003
4GAd00Ud2242M0104D93@T=2@d93@T=2@d93@T=2@d93@T=2@d8Q@T=2@d93@T=2@d93@T=2@d8A@T=2
@d93@T=2@d938D=2@d93@Qad00<AM7@00G@0009d00<AM7@04G@0@AdQ7B4M8Ae3@T=2@d93@T=2@d93
@T=2@d93@R52@d93@T=2@d93@T=2@d93@T=24D93@T=2@d93@T<M@d93@T=201ed00<AM7@00G@0009d
00<AM7@057@01153@T<88@0a@T=2@d93@T=2@d938D=2@d93@T=2@d93@T=2@d93@T<A@d93@T=2@d93
@R52@d93@P0NM0034GAd005d0002M0034GAd01Ed03/A@d93@T=2@d93@R4M8AdQ7B4M@d937D=2@d93
@T=2@d93@T=2@d93@T=2@a53@T=2@d93@T<M@d93@P0OM0034GAd005d0002M0034GAd01Id018A@d93
@T=2@d93@T=2@d93@T<88@0O@T=2@d93@T=2@d93@T=2@d8A@T=2@d93@T=28D93@P0PM0034GAd005d
0002M0034GAd01Md03LA@d93@T=2@d93@T=2@d93@T=28D93@T=28AdQ7B4M8D93@T=2@d93@T=24D93
@T=2@d937D=2025d00<AM7@00G@0009d00<AM7@067@07a53@T=2@d93@T=2@d93@T=28D93@T=2@d93
@T=2@d8022402T=2@a53@T=2@d844B9d00<AM7@00G@0009d00<AM7@06G@0<153@T=2@d93@T=2@d93
@R52@d93@T=2@d93@T=2@d93@T=2@d937B4M8AdQ7B52@`@A8W@00a5dM001M0000W@00a5dM00IM00^
4D93@T=2@d93@T=2@d938D=2@d93@T=2@d93@T=2@d93@T=2@d93@Q52@d93@P@Q0Q4RM0034GAd005d
0002M0034GAd01Yd02lA@T=2@d93@T=2@d937D=2@d93@T=2@d93@T=2@d93@T=2@d93@T<A@d93@T=2
@`044B9d00<AM7@00G@0009d00<AM7@06g@24@0[@d93@T=2@d938D=2@d93@T=2@d93@T=2@d93@T=2
@d93@T=24D93@T=2@`0WM0034GAd005d0002M0034GAd01ed0Q40:493@T=2@d8Q@T=2@d93@T=2@d93
@T=2@d93@T=2@d93@T<A@d93@T<XM0034GAd005d0002M0034GAd01md0Q409D=2@d8Q@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T<A@d93@T<0:G@00a5dM001M0000W@00a5dM00QM08A0292@ae3@T=2@d93
@T=2@d93@T=2@d93@T=2@d93@Q52@d93:W@00a5dM001M0000W@00a5dM00SM00P4B53@T=2@d93@T=2
@d93@T=2@d93@T=2@d93@T<A@d8/M0034GAd005d0002M0034GAd02=d00<MM1400Q406T=2@d93@T=2
@d93@T=2@d93@T=2@d93@Q52;G@00a5dM001M0000W@00a5dM00SM0038GAd009d0Q405d93@T=2@d93
@T=2@d93@T=2@d93@Q5202id00<AM7@00G@0009d00<AM7@08W@00b5dM005M08A00m3@T=2@d93@T=2
@d93@T<01A4_M0034GAd005d0002M0034GAd025d00<QM7@027@24@05@T=2@d80214dM0034GAd005d
0002M0034GAd025d00<MM7@02W@54Cad00<AM7@00G@0009d00<AM7@087@00b5dM01<M0034GAd005d
0002M0034GAd021d00<QM7@0C7@00a5dM001M0000W@00a5dM00OM0038GAd04ed00<AM7@00G@0009d
00<AM7@07W@00b5dM01>M0034GAd005d0002M0034GAd01id00<QM7@0CW@00a5dM001M0000W@00a5d
M00MM0037GAd04md00<AM7@00G@0009d00<AM7@077@00b5dM01@M0034GAd005d0002M0034GAd01ad
00<QM7@0D7@00a5dM001M0000W@00a5dM00KM0038GAd055d00<AM7@00G@0009d00<AM7@06W@00b5d
M01BM0034GAd005d0002M0034GAd01Yd00<QM7@0DW@00a5dM001M0000W@00a5dM00IM0037GAd05=d
00<AM7@00G@0009d00<AM7@06G@00b5dM01CM0034GAd005d0002M0034GAd01Qd00<QM7@0E7@00a5d
M001M0000W@00a5dM00GM0038GAd05Ed00<AM7@00G@0009d00<AM7@05g@00aedM01EM0034GAd005d
0002M0034GAd01Id00<QM7@0EW@00a5dM001M0000W@00a5dM00EM0037GAd05Md00<AM7@00G@0009d
00<AM7@05G@00b5dM01GM0034GAd005d0002M0034GAd01Ad00<QM7@0F7@00a5dM001M0000W@00a5d
M00DM0038GAd05Qd00<AM7@00G@0009d00<AM7@04g@00aedM01IM0034GAd005d0002M0034GAd019d
00<QM7@0FW@00a5dM001M0000W@00a5dM00BM0038GAd05Yd00<AM7@00G@0009d00<AM7@04G@00b5d
M01KM0034GAd005d0002M0034GAd011d00<QM7@0G7@00a5dM001M0000W@00a5dM00@M0038GAd05ad
00<AM7@00G@0009d00<AM7@03g@00aedM01MM0034GAd005d0002M0034GAd00id00<QM7@0GW@00a5d
M001M0000W@00a5dM00>M0038GAd05id00<AM7@00G@0009d00<AM7@03G@00b5dM01OM0034GAd005d
0002M0034GAd00ed00<MM7@0Gg@00a5dM001M0000W@00a5dM00<M0038GAd061d00<AM7@00G@0009d
00<AM7@02g@00aedM01QM0034GAd005d0002M0034GAd00]d00<QM7@0HG@00a5dM001M0000W@00a5d
M00:M0038GAd069d00<AM7@00G@0009d00<AM7@02G@00b5dM01SM0034GAd005d0002M0034GAd00Ud
00<MM7@0Hg@00a5dM001M0000W@00a5dM008M0038GAd06Ad00<AM7@00G@0009d00<AM7@027@00b5d
M01TM0034GAd005d0002M0034GAd00Md00<QM7@0IG@00a5dM001M0000W@00a5dM004M0@AIg@00a5d
M001M0000W@00a5dM004M0@AIg@00a5dM001M0000WAc4@=d0009M0@AJg@007Qd001hM000N7@007Qd
001hM000N7@00001\
\>"],
  ImageRangeCache->{{{0, 119}, {287, 0}} -> {-2.62503, -0.330946, 0.0441181, \
0.0441181}}]
}, Open  ]],

Cell["Here are the rays without the surface.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[propagatedseashellmirror, GraphicDesign -> Off, 
\tRayPointSize -> 5, ShowText -> Hold[RaySourceNumber[[1,1]]]];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.6106 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.299887 1.62312 -0.0125237 1.62312 [
[ 0 0 0 0 ]
[ 1 1.6106 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.6106 L
0 1.6106 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.65045 .53019 m
.72442 .57137 L
s
0 0 0 r
5 Mabswid
.65045 .53019 Mdot
.039 .916 .04 r
.5 Mabswid
.41975 .62641 m
.65045 .53019 L
s
.46695 .60366 m
.77247 .50001 L
s
0 0 0 r
5 Mabswid
.46695 .60366 Mdot
.039 .916 .04 r
.5 Mabswid
.43743 .76049 m
.46695 .60366 L
s
.74026 .59838 m
.56056 .51961 L
s
0 0 0 r
5 Mabswid
.74026 .59838 Mdot
.039 .916 .04 r
.5 Mabswid
.60209 .45733 m
.74026 .59838 L
s
0 0 0 r
5 Mabswid
.60209 .45733 Mdot
.039 .916 .04 r
.5 Mabswid
.72442 .57137 m
.60209 .45733 L
s
.73692 .34899 m
.39986 .27456 L
s
0 0 0 r
5 Mabswid
.73692 .34899 Mdot
.039 .916 .04 r
.5 Mabswid
.77247 .50001 m
.73692 .34899 L
s
0 0 0 r
5 Mabswid
.72442 .57137 Mdot
.77247 .50001 Mdot
.039 .916 .04 r
.5 Mabswid
.56056 .51961 m
.32094 .62221 L
s
0 0 0 r
5 Mabswid
.56056 .51961 Mdot
.039 .916 .04 r
.5 Mabswid
.32094 .62221 m
.50177 .75645 L
s
0 0 0 r
5 Mabswid
.32094 .62221 Mdot
.039 .916 .04 r
.5 Mabswid
.31014 .68221 m
.54982 .51488 L
s
0 0 0 r
5 Mabswid
.31014 .68221 Mdot
.039 .916 .04 r
.5 Mabswid
.57088 .59842 m
.31014 .68221 L
s
0 0 0 r
5 Mabswid
.57088 .59842 Mdot
.039 .916 .04 r
.5 Mabswid
.29532 .6069 m
.57088 .59842 L
s
0 0 0 r
5 Mabswid
.43743 .76049 Mdot
.039 .916 .04 r
.5 Mabswid
.39453 .56099 m
.43743 .76049 L
s
0 0 0 r
5 Mabswid
.29532 .6069 Mdot
.039 .916 .04 r
.5 Mabswid
.88598 .73711 m
.29532 .6069 L
s
.42802 1.16048 m
.86485 1.03482 L
s
0 0 0 r
5 Mabswid
.34679 1.17554 Mdot
.039 .916 .04 r
.5 Mabswid
.77302 1.09124 m
.34679 1.17554 L
s
.54982 .51488 m
.48396 .66951 L
s
0 0 0 r
5 Mabswid
.54982 .51488 Mdot
.039 .916 .04 r
.5 Mabswid
.3928 1.12715 m
.86073 .99056 L
s
.79069 .67447 m
.35869 1.51702 L
s
0 0 0 r
5 Mabswid
.79069 .67447 Mdot
.039 .916 .04 r
.5 Mabswid
.70098 .68775 m
.79069 .67447 L
s
.81591 .695 m
.77302 1.09124 L
s
0 0 0 r
5 Mabswid
.81591 .695 Mdot
.039 .916 .04 r
.5 Mabswid
.48396 .66951 m
.81591 .695 L
s
.78811 .64968 m
.41975 .62641 L
s
0 0 0 r
5 Mabswid
.78811 .64968 Mdot
.039 .916 .04 r
.5 Mabswid
.86073 .99056 m
.78811 .64968 L
s
.50177 .75645 m
.70098 .68775 L
s
0 0 0 r
5 Mabswid
.50177 .75645 Mdot
.039 .916 .04 r
.5 Mabswid
.35679 1.09306 m
.82826 .95338 L
s
0 0 0 r
5 Mabswid
.88598 .73711 Mdot
.039 .916 .04 r
.5 Mabswid
.82826 .95338 m
.88598 .73711 L
s
0 0 0 r
5 Mabswid
.39986 .27456 Mdot
.039 .916 .04 r
.5 Mabswid
.7293 .52988 m
.39453 .56099 L
s
0 0 0 r
5 Mabswid
.7293 .52988 Mdot
.039 .916 .04 r
.5 Mabswid
.86485 1.03482 m
.7293 .52988 L
s
0 0 0 r
5 Mabswid
.86485 1.03482 Mdot
.86073 .99056 Mdot
.77302 1.09124 Mdot
.39453 .56099 Mdot
.41975 .62641 Mdot
.82826 .95338 Mdot
.35869 1.51702 Mdot
.48396 .66951 Mdot
.70098 .68775 Mdot
gsave
.58721 1.02479 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.62155 1.06038 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.6419 1.09895 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.85771 .84303 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.82372 .81684 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.79696 .78194 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5864 .67107 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.60852 .63833 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.56373 .54527 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.43316 .60266 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.54273 .57512 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.41665 .66386 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.44045 .64033 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.68669 .55037 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.45259 .67993 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.42932 .59901 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.66257 .51371 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.61716 .5527 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.51802 .58955 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.67125 .52793 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.75449 .42365 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.65504 .68265 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.65163 .55953 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.57514 .31327 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.79494 .88879 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.44076 .57091 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.554 1.13456 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.40951 .68796 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.59795 .72328 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.74748 .68087 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.58064 1.08414 -65.5 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
68.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{185.562, 298.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002i0001:PP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiN@000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000;Ud002iM000^G@00;Ud002iM000^G@00;Ud
002iM000^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud
002iM000^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud
002iM000^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud0018M0@AKG@004Qd
115]M000B7@44Fed0018M0@A00DM8AdQ7@1XM000DG@58F=d001FM0047B4M8Emd001JM0DQFW@005md
00DQ7B4M8@1EM000I7@58E1d001WM0<A00@M8AdQBg@006Yd00@AM7Ad1B56M000JW@00a5dM006M005
8AdQ7B40@G@006Qd0Q4>M0@Q?G@006Yd00<AM7@03g@01AdQ7B4M00Id114^M000Ig@0115dM14FM0DQ
00=d4A400Q4^M000J7@24Aad00<M4Ad00Q4^M000Qg@0114Q4A4^M000R7@00aedM00^M000RG@00b5d
M00]M000RG@00b5dM00]M000RG@00b5dM00]M000RG@00b5dM00]M000RG@00b5dM00]M000RW@00aed
M00/M000RW@00b5dM00/M000RW@00aedM00/M000RW@00b5dM00/M000Rg@00b5dM00[M000Rg@00b5d
M00[M000R7@34@038GAd02]d002;M0034GAd02]d002;M0034GAd02]d0029M08A00=d8G@0:g@006id
114IM0034Aed02]d001^M0@A5W@01A5dM14Q02ad001^M0044B4A4AMd0Q400g@MM00[M000KW@24@03
8A5d01Ud00<QM7@0:W@0075d00<QM7@06G@00b5dM00YM000LW@00b5dM00HM0038GAd02Ud001cM003
8GAd01Md00<QM7@0:G@007Ad00<QM7@05W@00b5dM00YM000MG@00b5dM00EM0@A:7@007Id00<QM7@0
57@44BQd001gM0038GAd01=d114XM000I7@44A1d00<QM7@03g@38@@A:7@006Ad1Q4=M0@A37@00b4M
8@0_M000I7@64@id00@AM24Q27@38C9d001SM0038A4A00@A3G@44@038Aed00=d00@Q7B5d114`M000
HW@0125d8B444@038GAd00Yd1Q448@Ad114`M000HG@0124M8Ad6M0038Aed00Ud00PQ7A4A8AdQ7@9d
00HQ7B4M4Ad24C1d001OM0<Q00=d8G@027@38@Ed0R400a4Q8@024@DQ17@0114Q4A4`M000GG@00b4M
M003M0038G@A008A1G@02b4M8AdQ7B4M8AdQ008A00Md4Aed7G@M00Id00<QM7@0;g@005]d0b44M0HQ
00<A8B400R43M0DQ1g@44@03M25d00Ad00<QM7@0;g@004Md114=M00;7B4M8AdQ7B4M8Ad01G@00a5d
M003M0047A4A4@9d00<M8Ad00W@00a5dM0024@05M24MM1d017@00b5dM00_M000Ag@44@=d2R400g@Q
8@07M0048GAdM08A0g@58@9d00<AM7@011400g@A4@02M0034GAd00<Q0a400b5dM00_M000Ag@44@03
8AdQ00Id00DM8GAd7@08M0038GAd00Ad00DA8AdQ7@05M0054GAdM1400W@00b4M8@02M0064GAdM1dQ
11400aedM00^M000Ag@44@=d11428@=d00<QM7@01g@02B5dM7@AM24A8@06M08A1G@00a5dM002M08Q
00=d4G@00W@00b4A4@024@038GAd02id0018M0037GAd00Ad00<A7G@00g@00b4MM008M0037A4A008A
00<Q4A402W@00a5dM002M0034GAd009d00@AM1dA17@44@037GAd02id0019M0048GAdM08Q00=d4G@0
0W@00b5dM009M08Q00<A8G@02W@0115dM145M0034GAd009d0Q4017@Q8B42M0048GAd8C1d0019M004
8G@Q7@=d00@AM1dQ2W@34@038G@A00Ad1144M08A0g@0115dM14:M0048Aed7@8A00<Q4G@0;G@004Qd
0b46M0044GAdM0@A0W@48@054GAdM14017@44@Yd0Q4=M0<Q00<A8A40;W@003Ed114=M0047B5d8@=d
0a400adAM002M0@A014Q7B4M8AdA7B4M8A4Q7B4M8@024A]d00@A7B4A;W@003Ed114:M0/Q0a4<8@05
M24AM1400W@0114Q8B444A]d0Q400b4AM00]M000=G@03a4M8AdQ7B4M8AdQ7B4M8@06M0047GAd8@8A
1G@0114M4A45M0047A5dM08A00<MM7@08g@00aedM00/M000=G@44@@Q00@AM24Q2G@38@03M14A00=d
1247M08A0R4XM0038GAd02ad000jM0<A00DQ7B4M8@08M0037G@A00<A00=d8Ad00W@00b5dM004M004
7B4M4BYd00<MM7@0;7@003Yd1144M0@Q0W@38@03M14A008A00<QM7@00W@0125dM7@38@03M25d02ad
00<QM7@0:g@003Yd1148M0067B4M8AdQ11402AdQ7B4M8AdQ7@03M0037GAd02ad00<QM7@0:g@003ed
0R47M0038GAd009d00<Q4A400Q43M1@Q1W@44AYd00<QM7@0:g@003md00<QM7@00W@00adQM004M004
8GAdM0<A00@M8G@Q1G@00b5dM009M00A8AdQ7B4M8A4Q7B4M8AdQ7B404g@00b5dM002M0@A9G@0041d
00@QM7@Q1g@00b5d8@028@044GAdM0DQ0W@00b5dM00AM0034GAd00Id4B43M0048GAdM0@A9G@0045d
00<Q7G@01W@00adQ7@03M0054GAdM1d017@0124M8AdBM0034GAd01Md00TQ7B4M8AdQ4B400Q4UM000
@7@0125dM243M0<Q0W@01B5dM7@A00=d00<QM7@00g@00b5dM0058@id00<AM7@06G@01R5dM7@A8@8A
9G@003id00<M8G@00g@00adQ7@03M0<A0g@01A5dM7@M00=d1146M0047B4M8@Md00@AM7@A6g@01Qed
M7@A8@8A9G@003ed00@QM7Ad0b400g@Q8@05M0038A5d008A0g@0125dM7@44@Yd1B43M08A7G@00b5d
M0024@038A5d02Ad000hM0@A00DMM1dQ7@06M0038GAd009d00DM4GAd4@02M0038GAd009d11401AdQ
7B4M00Ud0a400b4MM00MM0078G@Q7B4M4@0UM000>7@34@<Q2W@00b5dM0024@048GAdM0<A17@44@Ed
2R400a4Q8@068@ad1143M0@A12401G@A4B4A02Ed000hM0044B4M4@ed00DQ7GAd4@05M0038A5d01Ed
00<AM7@00W@01adQ7B4M8Ad00a401QdQ7B4M8@@A00DM8AdQ4@05M0057G@MM1d00W@44B1d000hM0@A
3G@54@Ed00<Q4G@05G@00a5dM00:M0034B4Q008Q0g@44@DQ00<A8B401242M0038GAd00@A87@004Yd
0a400b5dM002M08A5g@00a5dM00:M0034GAd009d00<Q7B401145M0034GAd009d00TM8AdQ7B4M8Ad0
0Q4PM000Bg@0115d8B43M0038G@A01Ed0Q4<M0034G@Q008Q17@58@Ad00DAM7Ad8@04M0038G@A00<A
87@004]d00XAM7@M8G@A7G@A5W@00a5dM00:M0034B5d00]d00DM4AdQ4@03M0037B5d009d00@QM7@M
8W@004ad00HAM25d8G@24B5d0R424@md0Q400g@Q8@038@=d00@QM7@Q8W@004Ud00HAM7@AM1d2M003
8Aed01id00<M8Ad00g@00a5dM00BM0078G@Q7B4M8@02M0037GAd021d001:M08A0W@01R5dM25d8AMd
11438AYd00@QM7@Q17@48B5d001?M0038G@Q009d00<MM7@05G@00a4Q7@0MM0057GAdM1d00g@02AdQ
M7@M8AdQ7@05M0@A4g@004md00<QM2400g@28A9d0b400g@AM00LM0038GAd009d00@QM7Ad0R47M0@Q
00=d4A400Q4CM000Cg@00b5d8@05M0038GAd00ad00<M8Ad017@00a5dM00KM0038GAd009d00HMM7Ad
7B4;M0038A4Q008A4g@004md00<QM2401W@00b5dM009M08Q27@00a5dM00IM0038GAd00=d00<QM7@0
0W@00b5dM00:M0044B4A4A=d001?M0044AdA4@Id00<Q7A400a42M0038AdQ00Md00@AM7@A6g@00aed
M004M0058GAdM24037@00aedM00DM000Cg@0114Q4A48M0@A0R4;M08A6g@00b5dM005M0058GAdM240
37@00b5dM00DM000Cg@0114M4A48M0@A:W@00b5dM005M0058GAdM24037@00aedM00DM000Cg@44@Qd
114YM0038GAd00Md00@QM7@Q37@00b5dM00DM000R7@00aedM007M0057G@MM1d02W@00b5dM00EM000
Qg@00b5dM008M0058G@QM2402W@00b5dM00EM000Qg@00b5dM006M0<A00Ad7G@M2W@00b5dM00EM000
QW@00b5dM00:M0044B5d8@Yd00<QM7@05G@008Id00<MM7@02W@0114MM1d9M0037GAd01Id0025M003
8GAd00Ud0Q428@9d00<QM7@01W@00b5dM00FM000QG@00b5dM00;M0054AedM24027@00aedM00FM000
Q7@00b5dM009M0054GAd4B400W@00b5dM005M0038GAd01Md0024M0037GAd00Yd0Q400g@M4@034@Id
00<QM7@05g@008=d00<QM7@03G@28@03M14Q00Md00<QM7@05g@008=d00<QM7@03G@01R5d8G@A7@Id
00<QM7@05g@0089d00<QM7@03W@01R5d8G@A8@Ed00<QM7@067@0089d00<MM7@03W@00b5d8@02M003
4GAd00=d00<MM7@067@0085d00<QM7@03g@00b5d4@02M0044GAdM0<A6W@0085d00<QM7@03g@00b5d
M0024@037GAd009d00<A7G@06G@0081d00<QM7@047@0125dM242M0058GAdM1406g@0081d00<MM7@0
47@0125dM1d2M0058GAdM1406g@007md00<QM7@04G@0125dM242M0058GAdM1406g@007md00<QM7@0
47@00aedM002M0038G@Q009d0Q4KM000OW@00b5dM00AM0038GAd009d00<QM2400W@00b4AM00JM000
OW@00aedM00AM0037GAd009d00HQM7@MM1dLM000OG@00b5dM00BM0038GAd009d00HQM7@QM24LM000
OG@00b5dM00AM0<A17@011ed7B4MM000O7@00b5dM00CM0034GAd00=d00@QM24Q7G@007ad00<MM7@0
4g@00a5dM003M0047G@M8Aed001kM0038GAd01Ad00<AM7@017@38Aed001kM0038GAd01Ad00<AM7@0
17@00b4M8@0MM000NW@00b5dM00DM08A1W@38Aed001jM0037GAd01Ad00<Q4G@01G@00b4M8@0MM000
NG@00b5dM00EM0038GAd00Ed0R400g@QM00KM000NG@00b5dM00EM0038GAd00Ed00@Q7G@M77@007Qd
00<QM7@05W@00b5dM005M08Q00=d8G@06g@007Qd00<MM7@05W@00b5dM003M0@A00=d7G@06g@007Md
00<QM7@05g@00b5dM003M0@A0R4LM000Mg@00b5dM00GM0038GAd00=d11400b5d8@0KM000MW@00b5d
M00HM0038G@Q00<Q11400b5d8@0KM000MW@00aedM00GM0037B4M00Ud00<M8G@06W@007Ed00<QM7@0
5G@48@]d0R4KM000MG@00b5dM00AM0048AdQ7@=d00<MM7@02G@00adQM00JM000M7@00b5dM00?M0<Q
1g@00b5dM009M0038A4A008A67@007Ad00<MM7@037@00b4M8@0:M0037GAd00Yd114HM000Lg@00b5d
M009M0@Q3G@00b5dM00:M0@A67@007=d00<QM7@01W@00adQ7@0AM0037GAd00Id00@Q7B4M114HM000
LW@00b5dM004M0<Q57@00b5dM003M0<Q17@00b5dM00IM000LW@01aedM24M8Ad05g@01Qed7B4M8@Qd
00<MM7@067@0075d124JM0<Q37@00b5dM00HM000Kg@00b4M8@0JM0047B4M8@id00<MM7@067@006Yd
0a428@03M25d01Id1243M0038GAd00ad114GM000J7@011dQ7A44M0037GAd019d00<Q7B401g@00b5d
M00<M0@A5g@006Ed0b43M0054GAdM2404G@48@Yd00<QM7@037@44AMd001QM0048AdQ7@Id00DAM7Ad
8@0>M0037B4M00id00<QM7@027@011dQ7B444AMd001NM0<Q2W@0115dM24;M0@Q4G@00b5dM005M0<Q
7g@005]d00<Q7B4037@24@9d00<MM7@01W@00b4M8@0EM0088GAdM24M8AdRM000Eg@48A1d00<AM240
0W@44@<Q67@48BId001DM0037B4M01Id00HQM7@M4AdIM0047B4M8BUd001AM0<Q67@48@9d00<AM7@0
57@38@9d00<QM7@0:7@004ed00@Q7B4M67@0124M8Ad5M0034GAd011d00@Q7B4M1G@00aedM00XM000
BW@38AUd0b42M0038GAd00Ed00<AM7@037@38@Qd114XM000Ag@00b4M8@0HM0047B4M8@9d1144M004
4GAd4@Yd00@M8AdQ2g@44BQd0013M0@Q67@38@Md00<A8G@01G@24@Qd0b4>M0038A4A008A:7@0045d
00<Q7G@05g@0124M8Ad;M0034GAd00Yd00@Q7B4M37@01R4M8AdQM0@A:7@005Qd0b4>M0038A5d00Md
0a400b5dM009M0DQ<W@005Ed00<Q7B4047@011edM144M0037B4M00=d00<AM7@017@01B4M8AdQ03Md
001AM0@Q4g@0115dM1448@Id00<AM7@0124lM000CW@00adQ7@0FM0058G@A4B4027@24@037B4M041d
001:M0@Q5g@48@Id1B42M0034GAd041d0018M0037B5d01Md00DM8Aed7@03M0057B4M8Ad017@0115d
M152M000GW@48@9d0a438@Yd0Q53M000Fg@00b4M8@02M0067B4M8AdADg@005Md2B45M0034GAd055d
001DM0077B4M8AdQ7@09M0037A5d059d001@M0HQ3W@00b4AM01BM000CG@01B4M8AdQ015d00<Q4A40
Dg@003md1145M0DQ5W@00b5d4@1CM000?g@44@058AdQ7B406W@00aedM01DM000?g@0114Q8B4OM003
8GAd05Ad000oM0@A7W@00b5dM01EM000HG@00b5dM01EM000H7@00aedM01FM000H7@00b5dM01FM000
Gg@00b5dM01GM000Gg@00b5dM01GM000GW@00aedM01HM000GW@00b5dM01HM000GG@00b5dM01IM000
GG@00b5dM01IM000G7@00aedM01JM000G7@00b5dM01JM000Fg@00b5dM01KM000Fg@00b5dM01KM000
FW@00aedM01LM000FW@00b5dM01LM000FG@00b5dM01MM000FG@00b5dM01MM000F7@00aedM01NM000
F7@00b5dM01NM000Eg@00b5dM01OM000Eg@00b5dM01OM000EW@00aedM01PM000EW@00b5dM01PM000
EG@00b5dM01QM000EG@00b5dM01QM000E7@00aedM01RM000E7@00b5dM01RM000Dg@00b5dM01SM000
Dg@00b5dM01SM000DW@00aedM01TM000DW@00b5dM01TM000DG@00b5dM01UM000DG@00b5dM01UM000
D7@00aedM01VM000D7@00b5dM01VM000Cg@00b5dM01WM000Cg@00b5dM01WM000CW@00aedM01XM000
CW@00b5dM01XM000CG@00b5dM01YM000CG@00b5dM01YM000C7@00aedM01ZM000C7@00b5dM01ZM000
Bg@00b5dM01[M000Bg@00b5dM01[M000BW@00aedM01/M000BW@00b5dM01/M000BG@00b5dM01]M000
BG@00b5dM01]M000B7@00aedM01^M000B7@00b5dM01^M000Ag@00b5dM01_M000Ag@00b5dM01_M000
AW@00aedM01`M000AW@00b5dM01`M000AG@00b5dM01aM000AG@00b5dM01aM000A7@00aedM01bM000
A7@00b5dM01bM000@G@44GAd0011M0@AM7@0045d115dM000@G@44GAd002iM000^G@00;Ud002iM000
^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud002iM000^G@00;Ud002iM000\
\>"],
  ImageRangeCache->{{{0, 184.562}, {297.812, 0}} -> {0.184757, 0.00678261, \
0.00333818, 0.00333818}}]
}, Open  ]],

Cell["Altogether, 31 intersections are found.", "Text"],

Cell[CellGroupData[{

Cell["Length[First[propagatedseashellmirror]]", "Input"],

Cell[BoxData[
    \(31\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Creating a Fiber", "Section"],

Cell["\<\
This notebook shows the construction of a straight fiber from \
scratch. First the cylindrical surfaces are defined.\
\>", "Text"],

Cell["\<\
Clear[fibercylinder];
fibercylinder[radius_, fiberlength_, opts___] := {
\tMove3D[
\t\tCylindricalLensSurface[
\t\t\tradius, {2*radius*Cos[30*Degree], fiberlength}, opts],
\t\t{0, 0, radius}, {0, 0, -1}, 0],
\tMove3D[
\t\tMove3D[
\t\t\tCylindricalLensSurface[
\t\t\t\tradius, {2*radius*Cos[30*Degree], fiberlength}, opts],
\t\t\t{0, 0, radius}, {0, 0, -1}, 0],
\t\t{0, 0, 0}, {1, 0, 0}, 120],
\tMove3D[
\t\tMove3D[
\t\t\tCylindricalLensSurface[
\t\t\t\tradius, {2*radius*Cos[30*Degree], fiberlength}, opts],
\t\t\t{0, 0, radius}, {0, 0, -1}, 0],
\t\t{0, 0, 0}, {1, 0, 0}, 240]
};\
\>", "Input"],

Cell["\<\
Next, the fiber is plugged together. On the left side is a planar \
surface, on the right a spherical. In between are the two cylindrical \
surfaces.\
\>", "Text"],

Cell["\<\
Clear[OpticalFiber];
OpticalFiber[coreradius_, claddingradius_, fiberlength_, lensradius_, \
opts___] :=
Resonate[
\tMove[Flatten[{
\t\tMove[LensSurface[2*claddingradius, opts], {-0.5*fiberlength, 0, 0}],
\t\tfibercylinder[coreradius, fiberlength, opts],
 \t\tfibercylinder[claddingradius, fiberlength, opts],
\t\tMove[SphericalLensSurface[lensradius, 50, opts], 
\t\t\t{0.5*fiberlength-lensradius-Sqrt[lensradius^2-25^2], 0, 0}]
\t}], {0.5*fiberlength, 0, 0}],\"Fiber\"
];\
\>", "Input"],

Cell["The fiber is ready to be used.", "Text"],

Cell["\<\
DrawSystem[{
  Move[ConeOfRays[20], {10, 0, 0}],
  Move[OpticalFiber[10, 30, 300, -25.1], {60, 0, 0}],Boundary[450]
}, 
\tPlotType -> TopView, 
\tShowLabels -> False, 
\tQuickTrace -> False,
\tPlotPoints -> 50
];\
\>", "Input"],

Cell[CellGroupData[{

Cell["?CustomLensSurface", "Input"],

Cell[BoxData[
    \("CustomLensSurface[surfacefunction, aperture, label, options] indicates \
a component that has a user-defined surfacefunction that models the \
refractive index boundary at a lens surface, and a user-named objectlabel. \n\
\nCustomLensSurface is always used in combination with one or more additional \
LensSurface component types to create a complete lens object. The component \
shape, given by surfacefunction, is specified either by a function of two \
variables or by Function[0.] for planar surfaces. CustomLensSurface is \
created with its surface centered about the origin. The aperture parameter \
may indicate a circle, rectangle, or polygon depending on the number and type \
of elements listed by it. LensSurface, SphericalLensSurface, \
CylindricalLensSurface, ParabolicLensSurface, and CustomLensSurface are all \
related components."\)], "Print"]
}, Open  ]],

Cell["Plot3D[Sqrt[x^2+y^2],{x,-5,5},{y,-5,5}];", "Input"],

Cell["DrawSystem[CustomLensSurface[Sqrt[#1^2+#2^2]&,60,\"Cone\"]];", "Input"],

Cell["\<\
DrawSystem[{
\tLineOfRays[55,NumberOfRays->6],
\tMove[CustomLensSurface[Sqrt[#1^2+#2^2]&,60,\"Cone\",SurfaceRayIntersections-\
>Solve],10],
\tBoundary[70]},
\tPlotType->TopView];\
\>", "Input"],

Cell["\<\
Clear[PointedFiber];
PointedFiber[coreradius_, claddingradius_, fiberlength_, slope_, opts___] :=
Resonate[
\tMove[Flatten[{
\t\tMove[LensSurface[2*claddingradius, opts], {-0.5*fiberlength, 0, 0}],
\t\tfibercylinder[coreradius, fiberlength, opts],
 \t\tfibercylinder[claddingradius, fiberlength, opts],
 \t\tMove[CustomLensSurface[(slope*Sqrt[#1^2+#2^2])&,2*claddingradius,\"Cone\"\
,
 \t\t\tSurfaceRayIntersections->Solve], 
\t\t\t{0.5*fiberlength-slope*claddingradius, 0, 0}]
\t}], {0.5*fiberlength, 0, 0}],\"Fiber\"
];\
\>", "Input"],

Cell["\<\
DrawSystem[{
  Move[ConeOfRays[20], {10, 0, 0}],
  Move[PointedFiber[10, 30, 300, -1], {60, 0, 0}],
  Boundary[450]
}, 
\tPlotType -> TopView, 
\tShowLabels -> False, 
\tQuickTrace -> False,
\tPlotPoints -> 50
];\
\>", "Input"]
}, Closed]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{9, Automatic}, {Automatic, 21}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 42, 0, 56, "Section"],
Cell[1821, 55, 695, 12, 110, "Text"],
Cell[2519, 69, 109, 3, 42, "Input"],
Cell[2631, 74, 86, 3, 42, "Input"],

Cell[CellGroupData[{
Cell[2742, 81, 70, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[2837, 85, 52, 0, 42, "Subsubsection"],
Cell[2892, 87, 118, 3, 30, "Text"],
Cell[3013, 92, 283, 7, 117, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3333, 104, 70, 0, 28, "Subsubsection"],
Cell[3406, 106, 198, 4, 46, "Text"],
Cell[3607, 112, 155, 7, 117, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3799, 124, 60, 0, 28, "Subsubsection"],
Cell[3862, 126, 95, 3, 30, "Text"],
Cell[3960, 131, 115, 6, 87, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4112, 142, 86, 1, 28, "Subsubsection"],
Cell[4201, 145, 118, 3, 30, "Text"],
Cell[4322, 150, 296, 8, 132, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4667, 164, 51, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[4743, 168, 31, 0, 42, "Subsubsection"],
Cell[4777, 170, 156, 3, 46, "Text"],
Cell[4936, 175, 81, 3, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5054, 183, 39, 0, 28, "Subsubsection"],
Cell[5096, 185, 119, 3, 30, "Text"],
Cell[5218, 190, 275, 6, 117, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5530, 201, 40, 0, 28, "Subsubsection"],
Cell[5573, 203, 75, 0, 30, "Text"],
Cell[5651, 205, 186, 5, 87, "Input"],
Cell[5840, 212, 115, 3, 30, "Text"],
Cell[5958, 217, 184, 5, 102, "Input"],
Cell[6145, 224, 61, 0, 30, "Text"],
Cell[6209, 226, 260, 6, 117, "Input"],
Cell[6472, 234, 310, 5, 62, "Text"],
Cell[6785, 241, 93, 4, 57, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6915, 250, 38, 0, 28, "Subsubsection"],
Cell[6956, 252, 194, 4, 46, "Text"],
Cell[7153, 258, 996, 31, 477, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8186, 294, 31, 0, 28, "Subsubsection"],
Cell[8220, 296, 253, 5, 62, "Text"],
Cell[8476, 303, 617, 20, 342, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9142, 329, 51, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[9218, 333, 30, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[9273, 337, 73, 0, 42, "Input"],
Cell[9349, 339, 56722, 2474, 271, 37794, 2236, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[66120, 2819, 55, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[66200, 2823, 441, 13, 282, "Input"],
Cell[66644, 2838, 57783, 3487, 152, 44971, 3324, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[124476, 6331, 40, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[124541, 6335, 54, 0, 27, "Input"],
Cell[124598, 6337, 77170, 3339, 296, 46108, 2951, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[201805, 9681, 54, 0, 27, "Input"],
Cell[201862, 9683, 80039, 3518, 296, 45877, 3092, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[281962, 13208, 29, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[282016, 13212, 40, 0, 42, "Subsubsection"],
Cell[282059, 13214, 73, 0, 30, "Text"],
Cell[282135, 13216, 412, 12, 222, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[282584, 13233, 39, 0, 28, "Subsubsection"],
Cell[282626, 13235, 48, 0, 30, "Text"],
Cell[282677, 13237, 326, 11, 177, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[283040, 13253, 34, 0, 28, "Subsubsection"],
Cell[283077, 13255, 788, 22, 492, "Input"],
Cell[283868, 13279, 212, 5, 102, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[284129, 13290, 30, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[284184, 13294, 60, 0, 27, "Input"],
Cell[284247, 13296, 57661, 3372, 147, 49492, 3267, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[341945, 16673, 68, 0, 27, "Input"],
Cell[342016, 16675, 56866, 3480, 147, 48838, 3376, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[398919, 20160, 175, 4, 87, "Input"],
Cell[399097, 20166, 40489, 2468, 248, 28437, 2315, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[439623, 22639, 167, 4, 87, "Input"],
Cell[439793, 22645, 56494, 3097, 248, 37500, 2858, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[496348, 25749, 48, 0, 36, "Section"],
Cell[496399, 25751, 325, 6, 62, "Text"],

Cell[CellGroupData[{
Cell[496749, 25761, 32, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[496806, 25765, 44, 0, 42, "Subsubsection"],
Cell[496853, 25767, 58, 0, 32, "Text"],
Cell[496914, 25769, 102, 3, 27, "Input"],
Cell[497019, 25774, 129, 4, 42, "Input"],
Cell[497151, 25780, 157, 5, 57, "Input"],
Cell[497311, 25787, 274, 7, 102, "Input"],
Cell[497588, 25796, 108, 3, 27, "Input"],
Cell[497699, 25801, 56, 0, 32, "Text"],
Cell[497758, 25803, 64, 0, 27, "Input"],
Cell[497825, 25805, 151, 5, 57, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[498013, 25815, 30, 0, 28, "Subsubsection"],
Cell[498046, 25817, 48, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[498119, 25821, 221, 13, 192, "Input"],
Cell[498343, 25836, 174529, 8130, 296, 149181, 7813, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[672921, 33972, 42, 0, 28, "Subsubsection"],
Cell[672966, 33974, 74, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[673065, 33978, 316, 16, 237, "Input"],
Cell[673384, 33996, 1204, 31, 56, "Output"]
}, Open  ]],
Cell[674603, 34030, 480, 8, 78, "Text"],

Cell[CellGroupData[{
Cell[675108, 34042, 259, 9, 132, "Input"],
Cell[675370, 34053, 2041, 42, 107, "Output"]
}, Open  ]],
Cell[677426, 34098, 137, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[677588, 34105, 42, 0, 27, "Input"],
Cell[677633, 34107, 40, 1, 27, "Output"]
}, Open  ]],
Cell[677688, 34111, 105, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[677818, 34118, 120, 3, 27, "Input"],
Cell[677941, 34123, 153687, 4193, 296, 129752, 3893, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[831643, 38319, 113, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[831781, 38326, 124, 3, 42, "Input"],
Cell[831908, 38331, 490137, 17789, 295, 465577, 17481, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1322048, 56122, 70, 1, 26, "Output"]
}, Open  ]],
Cell[1322133, 56126, 185, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[1322343, 56134, 186, 5, 72, "Input"],
Cell[1322532, 56141, 66030, 2534, 296, 28583, 2067, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1388623, 58682, 27, 0, 46, "Subsection"],
Cell[1388653, 58684, 49, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[1388727, 58688, 218, 6, 87, "Input"],
Cell[1388948, 58696, 70, 1, 26, "Output"]
}, Open  ]],
Cell[1389033, 58700, 76, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[1389134, 58704, 101, 3, 27, "Input"],
Cell[1389238, 58709, 230796, 6530, 296, 208701, 6253, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1620049, 65242, 50, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[1620124, 65246, 147, 4, 57, "Input"],
Cell[1620274, 65252, 52889, 2397, 296, 29311, 2101, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1673178, 67652, 54, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[1673257, 67656, 148, 3, 42, "Input"],
Cell[1673408, 67661, 52103, 1838, 307, 41742, 1706, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1725526, 69502, 55, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[1725606, 69506, 56, 0, 27, "Input"],
Cell[1725665, 69508, 36, 1, 26, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1725762, 69516, 35, 0, 36, "Section"],
Cell[1725800, 69518, 140, 3, 30, "Text"],
Cell[1725943, 69523, 604, 20, 297, "Input"],
Cell[1726550, 69545, 173, 4, 30, "Text"],
Cell[1726726, 69551, 498, 13, 177, "Input"],
Cell[1727227, 69566, 46, 0, 30, "Text"],
Cell[1727276, 69568, 237, 10, 147, "Input"],

Cell[CellGroupData[{
Cell[1727538, 69582, 35, 0, 27, "Input"],
Cell[1727576, 69584, 881, 12, 187, "Print"]
}, Open  ]],
Cell[1728472, 69599, 57, 0, 27, "Input"],
Cell[1728532, 69601, 77, 0, 27, "Input"],
Cell[1728612, 69603, 203, 7, 102, "Input"],
Cell[1728818, 69612, 546, 14, 192, "Input"],
Cell[1729367, 69628, 237, 11, 162, "Input"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

